@@ -8,7 +8,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.uiaccounts.inc.php 24457 2007-09-22 15:03:03Z ralfbecker $ */
+	/* $Id: class.uiaccounts.inc.php 25853 2008-08-07 10:31:54Z leithoff $ */
 
 	class uiaccounts
 	{
@@ -33,12 +33,16 @@
 		var $bo;
 		var $nextmatchs;
 		var $apps_with_acl = array(
-			'addressbook' => True,
 			'todo'        => True,
 			'calendar'    => True,
 			'projects'    => True,
 			'infolog'     => True,
-			'filemanager' => True,
+			'filemanager' => array(
+				'menuaction' => 'filemanager.filemanager_ui.file',
+				'path' => '/home/$account_lid',
+				'tabs' => 'eacl',
+				'popup' => '495x400',
+			),
 			'tts'         => True,
 			'bookmarks'   => True,
 			'img'         => True,
@@ -57,10 +61,9 @@
 			{
 				$_POST = $this->array_stripslashes($_POST);
 			}
-			// remove ACL from addressbook, if contacts-backend is LDAP, as the ACL can not be modified there
-			if ($GLOBALS['egw_info']['server']['contact_repository'] == 'ldap')
+			foreach($GLOBALS['egw']->hooks->process('group_acl','',true) as $app => $data)
 			{
-				unset($this->apps_with_acl['addressbook']);
+				if ($data) $this->apps_with_acl[$app] = $data;
 			}
 		}
 
@@ -126,10 +129,6 @@
 
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 			$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps']['admin']['title'].' - '.
 				lang('User groups');
@@ -237,8 +236,8 @@
 				'sort'       => $sort
 			);
 			$p->set_var(array(
-				'query' => $GLOBALS['egw']->html->htmlspecialchars($GLOBALS['query']),
-				'query_type' => is_array($query_types) ? $GLOBALS['egw']->html->select('query_type',$_REQUEST['query_type'],$query_types) : '',
+				'query' => html::htmlspecialchars($GLOBALS['query']),
+				'query_type' => is_array($query_types) ? html::select('query_type',$_REQUEST['query_type'],$query_types) : '',
 				//'lang_group' => lang('group'),
 				//'group' => $uiaccountsel->selection('group_id','admin_uiaccount_listusers_group_id',$_REQUEST['group_id'],'groups',0,False,'','this.form.submit();',lang('all')),
 				'accounts_url' => $GLOBALS['egw']->link('/index.php',$link_data),
@@ -288,13 +287,8 @@
 		{
 			if ($GLOBALS['egw']->acl->check('account_access',1,'admin'))
 			{
-				$GLOBALS['egw']->redirect($GLOBALS['egw']->link('/admin/index.php'));
+				$GLOBALS['egw']->redirect_link('/admin/index.php');
 			}
-			if (!is_object($GLOBALS['egw']->html))
-			{
-				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
-			}
-
 			if($param_cd)
 			{
 				$cd = $param_cd;
@@ -338,10 +332,6 @@
 
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 			$GLOBALS['egw_info']['flags']['app_header'] = $GLOBALS['egw_info']['apps']['admin']['title'].' - '.
 				lang('User accounts');
@@ -383,13 +373,14 @@
 				'left_next_matchs'   => $this->nextmatchs->left('/index.php',$start,$total,$link_data),
 				'lang_showing' => ($_REQUEST['group_id'] ? $GLOBALS['egw']->common->grab_owner_name($_REQUEST['group_id']).': ' : '').
 					($GLOBALS['query'] ? lang("Search %1 '%2'",lang($uiaccountsel->query_types[$_REQUEST['query_type']]),
-					$GLOBALS['egw']->html->htmlspecialchars($GLOBALS['query'])).': ' : '')
+					html::htmlspecialchars($GLOBALS['query'])).': ' : '')
 					.$this->nextmatchs->show_hits($total,$start),
 				'right_next_matchs'  => $this->nextmatchs->right('/index.php',$start,$total,$link_data),
 				'lang_loginid'       => $this->nextmatchs->show_sort_order($sort,'account_lid',$order,'/index.php',lang('LoginID'),$link_data),
 				'lang_lastname'      => $this->nextmatchs->show_sort_order($sort,'account_lastname',$order,'/index.php',lang('last name'),$link_data),
 				'lang_firstname'     => $this->nextmatchs->show_sort_order($sort,'account_firstname',$order,'/index.php',lang('first name'),$link_data),
 				'lang_email'         => $this->nextmatchs->show_sort_order($sort,'account_email',$order,'/index.php',lang('email'),$link_data),
+				'lang_account_active'   => lang('Account active')."<br>".lang('Created')."<br>".lang('Modified'),
 				'lang_edit'    => lang('edit'),
 				'lang_delete'  => lang('delete'),
 				'lang_view'    => lang('view'),
@@ -400,8 +391,8 @@
 				'sort'       => $sort,
 			);
 			$p->set_var(array(
-				'query' => $GLOBALS['egw']->html->htmlspecialchars($GLOBALS['query']),
-				'query_type' => is_array($uiaccountsel->query_types) ? $GLOBALS['egw']->html->select('query_type',$_REQUEST['query_type'],$uiaccountsel->query_types) : '',
+				'query' => html::htmlspecialchars($GLOBALS['query']),
+				'query_type' => is_array($uiaccountsel->query_types) ? html::select('query_type',$_REQUEST['query_type'],$uiaccountsel->query_types) : '',
 				'lang_group' => lang('group'),
 				'group' => $uiaccountsel->selection('group_id','admin_uiaccount_listusers_group_id',$_REQUEST['group_id'],'groups',0,False,'','this.form.submit();',lang('all')),
 				'accounts_url' => $GLOBALS['egw']->link('/index.php',$link_data),
@@ -459,6 +450,19 @@
 				foreach($account_info as $account)
 				{
 					$p->set_var('class',$this->nextmatchs->alternate_row_color('',True));
+					if ($account['account_status']=='A')
+					{
+						$account['account_status'] = lang('Enabled');
+					}
+					else
+					{
+						$account['account_status'] = '<font color="red">' . lang('Disabled') . '</font>';
+					}
+					if (isset($account['account_created']))
+						$account['account_status'].= '<br>'.$GLOBALS['egw']->common->show_date($account['account_created'],$GLOBALS['egw_info']['user']['preferences']['common']['dateformat']);
+					if (isset($account['account_modified']))
+						$account['account_status'].= '<br>'.$GLOBALS['egw']->common->show_date($account['account_modified'],$GLOBALS['egw_info']['user']['preferences']['common']['dateformat']);
+
 
 					$p->set_var($account);
 
@@ -547,6 +551,7 @@
 			if ($GLOBALS['egw']->acl->check('account_access',4,'admin'))
 			{
 				$this->list_users();
+				return;
 			}
 
 			if($_POST['submit'])
@@ -612,10 +617,7 @@
 
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
+
 			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 			$GLOBALS['egw']->common->egw_header();
 
@@ -694,10 +696,6 @@
 
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 			$GLOBALS['egw']->common->egw_header();
 
@@ -715,16 +713,9 @@
 			// the account can have special chars/white spaces, if it is a ldap dn
 			$account_id = rawurlencode($_GET['account_id']);
 
-			// Find out who the new owner is of the deleted users records...
-			$users = $GLOBALS['egw']->accounts->get_list('accounts');
-			$c_users = count($users);
-			$str = '';
-			for($i=0;$i<$c_users;$i++)
-			{
-				$str .= '<option value='.$users[$i]['account_id'].'>'.$GLOBALS['egw']->common->display_fullname($users[$i]['account_lid'],$users[$i]['account_firstname'],$users[$i]['account_lastname']).'</option>'."\n";
-			}
 			$var['lang_new_owner'] = lang('Who would you like to transfer ALL records owned by the deleted user to?');
-			$var['new_owner_select'] = '<select name="new_owner" size="5">'."\n".'<option value=0 selected>'.lang('Delete All Records').'</option>'."\n".$str.'</select>'."\n";
+			$accountsel = new uiaccountsel();
+			$var['new_owner_select'] = $accountsel->selection('new_owner','new_owner',array(''),'accounts',0,$account_id,'size="15"','',lang('Delete all records'));
 			$var['cancel'] = lang('cancel');
 			$var['delete'] = lang('delete');
 			$t->set_var($var);
@@ -766,7 +757,7 @@
 					}
 				}
 				@reset($account_apps);
-	
+
 				$group_info = Array(
 					'account_id'   => ($_POST['account_id']?(int)$_POST['account_id']:0),
 					'account_name' => ($_POST['account_name']?$_POST['account_name']:''),
@@ -955,10 +946,6 @@
 			}
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 			$GLOBALS['egw']->common->egw_header();
 
@@ -1011,6 +998,9 @@
 			{
 				$var['account_status'] = '<b>' . lang('Disabled') . '</b>';
 			}
+			if (isset($userData['account_created'])) $var['account_status'].= '<br>'.lang('Created').': '.$GLOBALS['egw']->common->show_date($userData['account_created']);
+			if (isset($userData['account_modified'])) $var['account_status'].= '<br>'.lang('Modified').': '.$GLOBALS['egw']->common->show_date($userData['account_modified']);
+
 
 			// Last login time
 			if ($userData['lastlogin'])
@@ -1153,10 +1143,6 @@
 		{
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 			$GLOBALS['egw']->common->egw_header();
 
@@ -1167,10 +1153,6 @@
 //fix from Maanus 280105
 			$accounts =& CreateObject('phpgwapi.accounts',$group_info['account_id'],'g');
 
-			if (!is_object($GLOBALS['egw']->uiaccountsel))
-			{
-				$GLOBALS['egw']->uiaccountsel =& CreateObject('phpgwapi.uiaccountsel');
-			}
 			$p->set_var('accounts',$GLOBALS['egw']->uiaccountsel->selection('account_user[]','admin_uiaccounts_user',$group_info['account_user'],'accounts',min(3+count($group_info['account_user']),10),false,'style="width: 300px;"'));
 
 			$var = Array(
@@ -1205,7 +1187,7 @@
 			{
 				$p->set_var(array(
 					'lang_email' => lang('Email'),
-					'email' => $GLOBALS['egw']->html->input('account_email',$group_repository['account_email'],'',' style="width: 100%;"'),
+					'email' => html::input('account_email',$group_repository['account_email'],'',' style="width: 100%;"'),
 				));
 			}
 			reset($GLOBALS['egw_info']['apps']);
@@ -1236,11 +1218,13 @@
 					$tr_class = $this->nextmatchs->alternate_row_color('',True);
 					$perm_html .= '<tr class="'.$tr_class.'">';
 				}
+				$acl_action = self::_acl_action($app,$group_info['account_id'],$group_info['account_name'],$options);
+
 				$perm_html .= '<td>' . $perm_display[$i][1] . '</td>'
 					. '<td><input type="checkbox" name="account_apps['
 					. $perm_display[$i][0] . ']" value="True"'.($group_info['account_apps'][$app]?' checked':'').'> '
-					. ($this->apps_with_acl[$app] && $group_info['account_id']?'<a href="'.$GLOBALS['egw']->link('/index.php','menuaction=preferences.uiaclprefs.index&acl_app='.$app.'&owner='.$group_info['account_id'])
-					. '"><img src="'.$GLOBALS['egw']->common->image('phpgwapi','edit').'" border="0" hspace="3" align="absmiddle" title="'
+					. ($acl_action?'<a href="'.$acl_action.'"'.$options
+					. '><img src="'.$GLOBALS['egw']->common->image('phpgwapi','edit').'" border="0" hspace="3" align="absmiddle" title="'
 					. lang('Grant Access').': '.lang("edit group ACL's").'"></a>':'&nbsp;').'</td>'.($i & 1?'</tr>':'')."\n";
 			}
 			if($i & 1)
@@ -1262,6 +1246,39 @@
 			$p->pfp('out','edit');
 		}
 
+		private function _acl_action($app,$account_id,$account_lid,&$options)
+		{
+			$options = '';
+			if (!($acl_action = $this->apps_with_acl[$app]) || !$account_id)
+			{
+				return false;
+			}
+			if ($acl_action === true)
+			{
+				$acl_action = array(
+					'menuaction' => 'preferences.uiaclprefs.index',
+					'acl_app' => '$app',
+					'owner'   => '$account_id',
+				);
+			}
+			$replacements = array(
+				'$app' => $app,
+				'$account_id' => $account_id,
+				'$account_lid' => $account_lid,
+			);
+			foreach($acl_action as $name => &$value)
+			{
+				$value = str_replace(array_keys($replacements),array_values($replacements),$value);
+			}
+			if ($acl_action['popup'])
+			{
+				list($w,$h) = explode('x',$acl_action['popup']);
+				$options = ' onclick="window.open(this,this.target,\'width='.(int)$w.',height='.(int)$h.',location=no,menubar=no,toolbar=no,scrollbars=yes,status=yes\'); return false;"';
+				unset($acl_action['popup']);
+			}
+			return $GLOBALS['egw']->link('/index.php',$acl_action);
+		}
+
 		function create_edit_user($_account_id,$_userData='',$_errors='')
 		{
 			$GLOBALS['egw_info']['flags']['include_xajax'] = true;
@@ -1270,10 +1287,6 @@
 
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 
 			$GLOBALS['egw']->common->egw_header();
@@ -1441,6 +1454,9 @@
 				'account_file_space' => $account_file_space,
 				'account_id'        => (int) $userData['account_id']
 			);
+            if (isset($userData['account_created'])) $var['account_status'].= '<br>'.lang('Created').': '.$GLOBALS['egw']->common->show_date($userData['account_created']);
+            if (isset($userData['account_modified'])) $var['account_status'].= '<br>'.lang('Modified').': '.$GLOBALS['egw']->common->show_date($userData['account_modified']);
+
 
 			if($userData['expires'] == -1)
 			{
@@ -1484,7 +1500,7 @@
 			{
 				array_push($selarray,$value['account_id']);
 			}
-			$t->set_var('groups_select','<div id="groupselector">' .$GLOBALS['egw']->html->checkbox_multiselect('account_groups[]',$selarray,$allGroupsSorted,true,'',min(3+count($allGroupsSorted),10),' style="width: 300px; text-align:left" ').'</div>');
+			$t->set_var('groups_select','<div id="groupselector">' .html::checkbox_multiselect('account_groups[]',$selarray,$allGroupsSorted,true,'',min(3+count($allGroupsSorted),10),' style="width: 300px; text-align:left" ').'</div>');
 
 			/* create list of available apps */
 			$apps =& CreateObject('phpgwapi.applications',$_account_id);
@@ -1502,10 +1518,11 @@
 					continue;
 				}
 				$checked = (@$userData['account_permissions'][$app] || @$db_perms[$app]) && $_account_id ? ' checked="1"' : '';
+				$acl_action = self::_acl_action($app,$_account_id,$userData['account_lid'],$options);
 				$part[$i&1] = sprintf('<td>%s</td><td><input type="checkbox" name="account_permissions[%s]" value="True"%s>',
 					$data['title'],$app,$checked).
-					($this->apps_with_acl[$app] && $_account_id?'<a href="'.$GLOBALS['egw']->link('/index.php','menuaction=preferences.uiaclprefs.index&acl_app='.$app.'&owner='.$_account_id)
-					. '"><img src="'.$GLOBALS['egw']->common->image('phpgwapi','edit').'" border="0" hspace="3" align="absmiddle" title="'
+					($acl_action?'<a href="'.$acl_action.'"'.$options
+					. '><img src="'.$GLOBALS['egw']->common->image('phpgwapi','edit').'" border="0" hspace="3" align="absmiddle" title="'
 					. lang('Grant Access').'"></a>':'&nbsp;').'</td>';
 
 				if ($i & 1)
@@ -1595,10 +1612,6 @@
 
 			unset($GLOBALS['egw_info']['flags']['noheader']);
 			unset($GLOBALS['egw_info']['flags']['nonavbar']);
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('jscode','openwindow','admin');
 			$GLOBALS['egw']->common->egw_header();
 
@@ -1636,7 +1649,7 @@
 		{
 			if($GLOBALS['egw']->acl->check('group_access',16,'admin') || $_POST['cancel'])
 			{
-				$GLOBALS['egw']->redirect($GLOBALS['egw']->link('/index.php','menuaction=admin.uiaccounts.list_groups'));
+				$GLOBALS['egw']->redirect_link('/index.php','menuaction=admin.uiaccounts.list_groups');
 				$GLOBALS['egw']->common->egw_exit();
 			}
 			elseif($_POST['submit'])
