@@ -13,7 +13,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.ui.inc.php 24106 2007-06-14 18:29:40Z nelius_weiss $ */
+	/* $Id: class.ui.inc.php 25144 2008-03-22 08:34:55Z ralfbecker $ */
 	
 	require_once(EGW_API_INC. '/class.html.inc.php');
 
@@ -62,7 +62,6 @@
 				'mail' => $GLOBALS['egw']->common->image('bookmarks','mail'),
 				'delete' => $GLOBALS['egw']->common->image('bookmarks','delete')
 			);
-			$this->html = new html();
 			$this->expandedcats = array();
 			$this->location_info = $this->bo->read_session_data();
 			$this->nextmatchs =& CreateObject('phpgwapi.nextmatchs');
@@ -795,14 +794,14 @@
 					if ($this->bo->check_perms2( $bm['owner'], $bm['access'], EGW_ACL_EDIT) ) {
 						$entry .= '<a href ="'.
 							$GLOBALS['egw']->link( '/index.php', 'menuaction=bookmarks.ui.edit&bm_id='. $id ). '">'.
-							$this->html->image( 'bookmarks', $this->img['edit'], lang( 'Edit this bookmark' ) ).
+							html::image( 'bookmarks', $this->img['edit'], lang( 'Edit this bookmark' ) ).
 							'</a>';
 					}
 					
 					//view
 					$entry .= '<a href ="'.
 						$GLOBALS['egw']->link( '/index.php', 'menuaction=bookmarks.ui.view&bm_id='. $id ). '">'.
-						$this->html->image( 'bookmarks', $this->img['view'], lang( 'View this bookmark' ) ).
+						html::image( 'bookmarks', $this->img['view'], lang( 'View this bookmark' ) ).
 						'</a>';
 					
 					//redirect
@@ -811,7 +810,7 @@
 						$bm['name']. '</a>';
 				}
 			}
-			$tree = $this->html->tree((array)$bm_tree, false, false, "null", 'foldertree', '', '', false, '/', null);
+			$tree = html::tree((array)$bm_tree, false, false, "null", 'foldertree', '', '', false, '/', null);
 			
 			$this->t->set_var('body',$tree);
 			$this->app_messages($this->t);
