@@ -12,7 +12,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.uiholiday.inc.php 23796 2007-05-04 11:47:40Z lkneschke $ */
+	/* $Id: class.uiholiday.inc.php 25164 2008-03-25 15:33:10Z ralfbecker $ */
 
 	/**
 	 * User interface for calendar holidays
@@ -42,19 +42,12 @@
 
 		function uiholiday()
 		{
-			$GLOBALS['egw']->nextmatchs =& CreateObject('phpgwapi.nextmatchs');
-
 			$this->bo =& CreateObject('calendar.boholiday');
 			$this->bo->check_admin();
 			$this->base_url = $this->bo->base_url;
 			$this->template_dir = $GLOBALS['egw']->common->get_tpl_dir('calendar');
 			$this->sb =& CreateObject('calendar.sbox');
 
-			// jscalendar is needed by the new navigation-menu AND it need to be loaded befor the header !!!
-			if (!is_object($GLOBALS['egw']->jscalendar))
-			{
-				$GLOBALS['egw']->jscalendar =& CreateObject('phpgwapi.jscalendar');
-			}
 			// calendar does not work with hidden sidebox atm.
 			unset($GLOBALS['egw_info']['user']['preferences']['common']['auto_hide_sidebox']);
 
