@@ -9,9 +9,9 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: index.php 19408 2005-10-14 10:10:06Z ralfbecker $ */
+	/* $Id: index.php 25568 2008-06-05 14:09:00Z leithoff $ */
 
-	$_GET['menuaction']     = 'emailadmin.ui.listProfiles';
+	$_GET['menuaction']     = 'emailadmin.emailadmin_ui.listProfiles';
 
 	$GLOBALS['egw_info'] = array(
 		'flags' => array(
@@ -22,5 +22,5 @@
 	);
 	include('../header.inc.php');
 
-	execmethod('emailadmin.ui.listProfiles');
+	execmethod('emailadmin.emailadmin_ui.listProfiles');
 ?>
