@@ -6,26 +6,24 @@
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package etemplate
  * @subpackage api
- * @copyright (c) 2007 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2007/8 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
- * @version $Id: class.bo_tracking.inc.php 24159 2007-06-21 18:49:57Z ralfbecker $ 
+ * @version $Id: class.bo_tracking.inc.php 26323 2008-11-08 10:37:52Z ralfbecker $
  */
 
-require_once(EGW_API_INC.'/class.html.inc.php');
-
 /**
  * Abstract base class for trackering:
  *  - logging all modifications of an entry
  *  - notifying users about changes in an entry
- * 
+ *
  * You need to extend these class in your application:
  *	1. set the required class-vars: app, id_field
  *	2. optional set class-vars: creator_field, assigned_field, check2prefs
  *	3. implement the required methods: get_config, get_details
- *	4. optionally re-implement: get_subject, get_body, get_attachments, get_link, get_message
+ *	4. optionally re-implement: get_title, get_subject, get_body, get_attachments, get_link, get_notification_link, get_message
  * They are all documented in this file via phpDocumentor comments.
  */
-class bo_tracking
+abstract class bo_tracking
 {
 	/**
 	 * Application we are tracking
@@ -55,7 +53,6 @@ class bo_tracking
 	 * Can be used to map the following prefs to different names:
 	 *  - notify_creator  - user wants to be notified for items he created
 	 *  - notify_assigned - user wants to be notified for items assigned to him
-	 *  - notify_html     - user wants his notifications as html-email
 	 * @var array
 	 */
 	var $check2pref;
@@ -73,13 +70,13 @@ class bo_tracking
 	var $prefer_user_as_sender = true;
 	/**
 	 * Should the current user be email-notified (about change he made himself)
-	 * 
+	 *
 	 * Popup notifications are never send to the current user!
 	 *
 	 * @var boolean
 	 */
 	var $notify_current_user = false;
-	
+
 	/**
 	 * Array with error-messages if track($data,$old) returns false
 	 *
@@ -94,10 +91,10 @@ class bo_tracking
 	 * @var historylog
 	 */
 	var $historylog;
-	
+
 	/**
 	 * Current user, can be set via bo_tracking::track(,,$user)
-	 * 
+	 *
 	 * @access private
 	 * @var int;
 	 */
@@ -122,28 +119,32 @@ class bo_tracking
 	 */
 	var $tz_offset_s;
 	/**
-	 * Reference to the html class
+	 * Should the class allow html content (for notifications)
 	 *
-	 * @var html
+	 * @var boolean
 	 */
-	var $html;
-	
+	var $html_content_allow = false;
+
 	/**
 	 * Constructor
 	 *
 	 * @return bo_tracking
 	 */
+	function __construct()
+	{
+
+	}
+
 	function bo_tracking()
 	{
-		$this->html =& html::singleton();
+		self::__construct();
 	}
 
 	/**
 	 * Get a config value, which can depend on $data and $old
-	 * 
+	 *
 	 * Need to be implemented in your extended tracking class!
 	 *
-	 * @abstract 
 	 * @param string $what possible values are:
 	 * 	- 'copy' array of email addresses notifications should be copied too, can depend on $data
 	 *  - 'lang' string lang code for copy mail
@@ -154,9 +155,9 @@ class bo_tracking
 	 */
 	function get_config($name,$data,$old=null)
 	{
-		die('You need to extend the bo_tracking class, to be able to use it (abstract base class)!');		
+		return null;
 	}
-	
+
 	/**
 	 * Tracks the changes in one entry $data, by comparing it with the last version in $old
 	 *
@@ -183,7 +184,7 @@ class bo_tracking
 		}
 		return $changes;
 	}
-	
+
 	/**
 	 * Save changes to the history log
 	 *
@@ -200,10 +201,9 @@ class bo_tracking
 		{
 			if ($old[$name] != $data[$name] && !(!$old[$name] && !$data[$name]))
 			{
-				if (!is_object($this->historylog))
+				if (!is_object($this->historylog) || $this->historylog->user != $this->user)
 				{
-					require_once(EGW_API_INC.'/class.historylog.inc.php');
-					$this->historylog =& new historylog($this->app);
+					$this->historylog = new historylog($this->app,$this->user);
 				}
 				$this->historylog->add($status,$data[$this->id_field],
 					is_array($data[$name]) ? implode(',',$data[$name]) : $data[$name],
@@ -213,7 +213,7 @@ class bo_tracking
 		}
 		return $changes;
 	}
-	
+
 	/**
 	 * sending all notifications for the changed entry
 	 *
@@ -227,7 +227,7 @@ class bo_tracking
 	{
 		$this->errors = $email_sent = array();
 
-		if (!$this->notify_current_user)		// should we notify the current user about his own changes
+		if (!$this->notify_current_user && $this->user)		// do we have a current user and should we notify the current user about his own changes
 		{
 			//error_log("do_notificaton() adding user=$this->user to email_sent, to not notify him");
 			$email_sent[] = $GLOBALS['egw']->accounts->id2name($this->user,'account_email');
@@ -235,10 +235,10 @@ class bo_tracking
 
 		// entry creator
 		if ($this->creator_field && ($email = $GLOBALS['egw']->accounts->id2name($data[$this->creator_field],'account_email')) &&
-			!in_array($email, $email_sent)) 
+			!in_array($email, $email_sent))
 		{
 			$this->send_notification($data,$old,$email,$data[$this->creator_field],'notify_creator');
-			$email_sent[] = $email;	
+			$email_sent[] = $email;
 		}
 
 		// assigned / responsible users
@@ -248,12 +248,12 @@ class bo_tracking
 			$assignees = $old_assignees = array();
 			if ($data[$this->assigned_field])	// current assignments
 			{
-				$assignees = is_array($data[$this->assigned_field]) ? 
+				$assignees = is_array($data[$this->assigned_field]) ?
 					$data[$this->assigned_field] : explode(',',$data[$this->assigned_field]);
 			}
 			if ($old && $old[$this->assigned_field])
 			{
-				$old_assignees = is_array($old[$this->assigned_field]) ? 
+				$old_assignees = is_array($old[$this->assigned_field]) ?
 					$old[$this->assigned_field] : explode(',',$old[$this->assigned_field]);
 			}
 			foreach(array_unique(array_merge($assignees,$old_assignees)) as $assignee)
@@ -268,7 +268,7 @@ class bo_tracking
 					{
 						$this->send_notification($data,$old,$email,$assignee,'notify_assigned',
 							in_array($assignee,$assignees) !== in_array($assignee,$old_assignees) || $deleted);	// assignment changed
-						$email_sent[] = $email;	
+						$email_sent[] = $email;
 					}
 				}
 				else	// item assignee is a group
@@ -292,7 +292,7 @@ class bo_tracking
 			$lang = $this->get_config('lang',$data,$old);
 			foreach($copies as $email)
 			{
-				if (strchr($email,'@') !== false && !in_array($email, $email_sent)) 
+				if (strchr($email,'@') !== false && !in_array($email, $email_sent))
 				{
 					$this->send_notification($data,$old,$email,$lang,'notify_copy');
 					$email_sent[] = $email;
@@ -304,38 +304,14 @@ class bo_tracking
 		if ($this->save_prefs) $GLOBALS['egw_info']['user'] = $this->save_prefs; unset($this->save_prefs);
 		if ($GLOBALS['egw_info']['user']['preferences']['common']['lang'] != $GLOBALS['egw']->translation->userlang)
 		{
-			$GLOBALS['egw']->translation->init();			
+			$GLOBALS['egw']->translation->init();
 		}
 		return !count($this->errors);
 	}
-	
-	/**
-	 * Send a popup notification via the notification app
-	 *
-	 * @param int $user
-	 * @param string $message
-	 * @return boolean true on success, false on error
-	 */
-	function popup_notification($user,$message)
-	{
-		static $is_php51;
-		if (is_null($is_php51)) $is_php51 = version_compare(phpversion(),'5.1.0','>=');
-
-		if (!$is_php51) return false;
-		
-		// check if the to notifying user has rights to run the notifcation app
-		$ids = $GLOBALS['egw']->accounts->memberships($user,true);
-		$ids[] = $user;
-		if (!$GLOBALS['egw']->acl->get_specific_rights_for_account($ids,'run','notifications')) return false;
-
-		if (!include_once(EGW_INCLUDE_ROOT. '/notifications/inc/class.notification.inc.php')) return false;
-
-		return is_null(notification::notify(array($user),$message));	// return the exeception on error
-	}
 
 	/**
 	 * Sending a notification to the given email-address
-	 * 
+	 *
 	 * Called by track() or externally for sending async notifications
 	 *
 	 * @param array $data current entry
@@ -350,9 +326,9 @@ class bo_tracking
 	{
 		//error_log("bo_trackering::send_notification(,,'$email',$user_or_lang,$check)");
 		if (!$email) return false;
-		
+
 		if (!$this->save_prefs) $this->save_prefs = $GLOBALS['egw_info']['user'];
-		
+
 		if (is_numeric($user_or_lang))	// user --> read everything from his prefs
 		{
 			if ($user_or_lang != $this->user)
@@ -369,6 +345,10 @@ class bo_tracking
 			{
 				return false;	// only notification about changed assignment requested
 			}
+			if($this->user == $user_or_lang && !$this->notify_current_user)
+			{
+				return false;  // no popup for own actions
+			}
 		}
 		else
 		{
@@ -380,73 +360,34 @@ class bo_tracking
 		{
 			$GLOBALS['egw']->translation->init();
 		}
-		// send popup notification
-		if (is_numeric($user_or_lang) && $this->user != $user_or_lang)	// no popup for own actions
-		{
-			//die('sending popup notification'.$this->html->htmlspecialchars($this->get_popup_message($data,$old)));
-			$this->popup_notification($user_or_lang,$this->get_popup_message($data,$old));
-		}
-		// PHPMailer aka send-class, seems not to be able to send more then one mail, IF we need to authenticate to the SMTP server
-		// There for the object is newly created for ever mail, 'til this get fixed in PHPMailer.
-		//if(!is_object($GLOBALS['egw']->send))
-		{
-			require_once(EGW_API_INC.'/class.send.inc.php');
-			$GLOBALS['egw']->send = $send =& new send();
-		}
-		//$send = &$GLOBALS['egw']->send;
-		$send->ClearAddresses();
-		$send->ClearAttachments();
 
-		// does the user wants html-emails
-		$html_email = !!$GLOBALS['egw_info']['user']['preferences']['tracker'][$this->check2pref ? $this->check2pref['notify_html'] : 'notify_html'];
-		$send->IsHTML($html_email);		
-
-		if (preg_match('/^(.+) *<(.+)>/',$email,$matches))	// allow to use eg. "Ralf Becker <ralf@egw.org>" as address
-		{
-			$send->AddAddress($matches[2],$matches[1]);
-		}
-		else
-		{
-			$send->AddAddress($email,is_numeric($user_or_lang) ? $GLOBALS['egw']->accounts->id2name($user_or_lang,'account_fullname') : '');
-		}
-		$send->AddCustomHeader("X-eGroupWare-type: {$this->app}update");
-
-		$sender = $this->get_sender($data,$old);
-		if (preg_match('/^(.+) *<(.+)>/',$sender,$matches))	// allow to use eg. "Ralf Becker <ralf@egw.org>" as sender
-		{
-			$send->From = $matches[2];
-			$send->FromName = $matches[1];
-		}
-		else
-		{
-			$send->From = $sender;
-			$send->FromName = '';
-		}
-		$send->Subject = $this->get_subject($data,$old);
-
-		$send->Body = $this->get_body($html_email,$data,$old);
-
-		foreach($this->get_attachments($data,$old) as $attachment)
-		{
-			if (isset($attachment['content']))
-			{
-				$send->AddStringAttachment($attachment['content'],$attachment['filename'],$attachment['encoding'],$attachment['mimetype']);
+		// send over notification_app
+		if ($GLOBALS['egw_info']['apps']['notifications']['enabled']) {
+			// send via notification_app
+			$receiver = is_numeric($user_or_lang) ? $user_or_lang : $email;
+			try {
+				$notification = new notifications();
+				$notification->set_receivers(array($receiver));
+				$notification->set_message($this->get_body(false,$data,$old,false)); // set message as plaintext
+				$notification->set_message($this->get_body(true,$data,$old,false)); // and html
+				$notification->set_sender($this->get_sender($data,$old,true));
+				$notification->set_subject($this->get_subject($data,$old));
+				$notification->set_links(array($this->get_notification_link($data,$old)));
+				$attachments = $this->get_attachments($data,$old);
+				if(is_array($attachments)) { $notification->set_attachments($attachments); }
+				$notification->send();
 			}
-			elseif (isset($attachment['path']))
-			{
-				$send->AddAttachment($attachment['path'],$attachment['filename'],$attachment['encoding'],$attachment['$mimetype']);
+			catch (Exception $exception) {
+				$this->errors[] = $exception->getMessage();
+				return false;
 			}
+		} else {
+			error_log('tracking: cannot send any notifications because notifications is not installed');
 		}
 
-		//echo "<p>bo_trackering::send_notification(): sending <pre>".print_r($send,true)."</pre>\n";
-		if (!$send->Send())
-		{
-			$this->errors[] = lang('Error while notifying %1: %2',$email,$send->ErrorInfo);
-			return false;
-		}
 		return true;
 	}
-	
+
 	/**
 	 * Return date+time formatted for the currently notified user (prefs in $GLOBALS['egw_info']['user']['preferences'])
 	 *
@@ -466,29 +407,34 @@ class bo_tracking
 		//error_log("bo_tracking::datetime($timestamp,$do_time)=date('$format',$timestamp+$this->tz_offset_s)='".date($format,$timestamp+$this->tz_offset_s).'\')');
 		return date($format,$timestamp+3600 * $GLOBALS['egw_info']['user']['preferences']['common']['tz_offset']);
 	}
-	
+
 	/**
 	 * Get sender address
-	 * 
+	 *
 	 * The default implementation prefers depending on the prefer_user_as_sender class-var the user over
-	 * what is returned by get_config('sender'). 
-	 * 
+	 * what is returned by get_config('sender').
+	 *
 	 * @param int $user account_lid of user
 	 * @param array $data
 	 * @param array $old
-	 * @return string
+	 * @param bool $prefer_id returns the userid rather than email
+	 * @return string or userid
 	 */
-	function get_sender($data,$old)
+	function get_sender($data,$old,$prefer_id=false)
 	{
 		$sender = $this->get_config('sender',$data,$old);
 		//echo "<p>bo_tracking::get_sender() get_config('sender',...)='".htmlspecialchars($sender)."'</p>\n";
 
-		if (($this->prefer_user_as_sender || !$sender) && $this->user && 
+		if (($this->prefer_user_as_sender || !$sender) && $this->user &&
 			($email = $GLOBALS['egw']->accounts->id2name($this->user,'account_email')))
 		{
 			$name = $GLOBALS['egw']->accounts->id2name($this->user,'account_fullname');
-			
-			$sender = $name ? $name.' <'.$email.'>' : $email;
+
+			if($prefer_id) {
+				$sender = $this->user;
+			} else {
+				$sender = $name ? $name.' <'.$email.'>' : $email;
+			}
 		}
 		elseif(!$sender)
 		{
@@ -498,9 +444,21 @@ class bo_tracking
 		return $sender;
 	}
 
+	/**
+	 * Get the title for a given entry, can be reimplemented
+	 *
+	 * @param array $data
+	 * @param array $old
+	 * @return string
+	 */
+	function get_title($data,$old)
+	{
+		return egw_link::title($this->app,$data[$this->id_field]);
+	}
+
 	/**
 	 * Get the subject for a given entry, can be reimplemented
-	 * 
+	 *
 	 * Default implementation uses the link-title
 	 *
 	 * @param array $data
@@ -509,17 +467,12 @@ class bo_tracking
 	 */
 	function get_subject($data,$old)
 	{
-		if (!is_object($GLOBALS['egw']->link))
-		{
-			require_once(EGW_API_INC.'/class.bolink.inc.php');
-			$GLOBALS['egw']->link =& new bolink();
-		}
-		return $GLOBALS['egw']->link->title($this->app,$data[$this->id_field]);
+		return egw_link::title($this->app,$data[$this->id_field]);
 	}
 
 	/**
 	 * Get the modified / new message (1. line of mail body) for a given entry, can be reimplemented
-	 * 
+	 *
 	 * Default implementation does nothing
 	 *
 	 * @param array $data
@@ -533,7 +486,7 @@ class bo_tracking
 
 	/**
 	 * Get a link to view the entry, can be reimplemented
-	 * 
+	 *
 	 * Default implementation checks get_config('link') (appending the id) or link::view($this->app,$id)
 	 *
 	 * @param array $data
@@ -547,23 +500,19 @@ class bo_tracking
 		{
 			if (strpos($link,$this->id_field.'=') === false)
 			{
-				$link .= '&'.$this->id_field.'='.$data[$this->id_field];
+				$link .= strpos($link,'?') === false ? '?' : '&';
+				$link .= $this->id_field.'='.$data[$this->id_field];
 			}
 		}
 		else
 		{
-			if (!is_object($GLOBALS['egw']->link))
-			{
-				require_once(EGW_API_INC.'/class.bolink.inc.php');
-				$GLOBALS['egw']->link =& new bolink();
-			}
-			if (($view = $GLOBALS['egw']->link->view($this->app,$data[$this->id_field])))
+			if (($view = egw_link::view($this->app,$data[$this->id_field])))
 			{
 				$link = $GLOBALS['egw']->link('/index.php',$view);
-				$popup = $GLOBALS['egw']->link->is_popup($this->app,'view');
+				$popup = egw_link::is_popup($this->app,'view');
 			}
 		}
-		if ($link{0} == '/')
+		if ($link[0] == '/')
 		{
 			$link = ($_SERVER['HTTPS'] || $GLOBALS['egw_info']['server']['enforce_ssl'] ? 'https://' : 'http://').
 				($GLOBALS['egw_info']['server']['hostname'] ? $GLOBALS['egw_info']['server']['hostname'] : $_SERVER['HTTP_HOST']).$link;
@@ -572,58 +521,78 @@ class bo_tracking
 		{
 			// remove the session-id in the notification mail!
 			$link = preg_replace('/(sessionid|kp3|domain)=[^&]+&?/','',$link);
-			
+
 			if ($popup) $link .= '&nopopup=1';
 		}
 		return $allow_popup ? array($link,$popup) : $link;
 	}
-	
+
 	/**
-	 * Get the body of the notification message, can be reimplemented
+	 * Get a link for notifications to view the entry, can be reimplemented
 	 *
-	 * @param boolean $html_email
 	 * @param array $data
 	 * @param array $old
-	 * @return string
+	 * @return array with link
 	 */
-	function get_body($html_email,$data,$old)
+	function get_notification_link($data,$old)
 	{
-		$body = '';
-		if ($html_email)
-		{	
-			$body = "<html>\n<body>\n".'<table cellspacing="2" cellpadding="0" border="0" width="100%">'."\n";
+		if($view = egw_link::view($this->app,$data[$this->id_field])) {
+			return array(	'text' 	=> $this->get_title($data,$old),
+							'view' 	=> $view,
+							'popup'	=> egw_link::is_popup($this->app,'view'),
+							);
 		}
-		// new or modified message
-		if (($message = $this->get_message($data,$old)))
-		{
-			$body .= $this->format_line($html_email,'message',false,$message);
-		}
-		if (($link = $this->get_link($data,$old)))
-		{
-			$body .= $this->format_line($html_email,'link',false,lang('You can respond by visiting:'),$link);
-		}
-		foreach($this->get_details($data) as $name => $detail)
-		{
-			// if there's no old entry, the entry is not modified by definition
-			// if both values are '', 0 or null, we count them as equal too
-			$modified = $old && $data[$name] != $old[$name] && !(!$data[$name] && !$old[$name]);
-			//if ($modified) error_log("data[$name]=".print_r($data[$name],true).", old[$name]=".print_r($old[$name],true)." --> modified=".(int)$modified);
-			if (empty($detail['value']) && !$modified) continue;	// skip unchanged, empty values
-			
-			$body .= $this->format_line($html_email,$detail['type'],$modified,
-				($detail['label'] ? $detail['label'].': ':'').$detail['value']);
-		}
-		if ($html_email)
-		{
-			$body .= "</table>\n</body>\n</html>\n";
-		}
-		return $body;
+		return false;
 	}
-	
+
+	/**
+     * Get the body of the notification message, can be reimplemented
+     *
+     * @param boolean $html_email
+     * @param array $data
+     * @param array $old
+     * @param boolean $integrate_link to have links embedded inside the body
+     * @return string
+     */
+    function get_body($html_email,$data,$old,$integrate_link = true)
+    {
+        $body = '';
+        if ($html_email)
+        {
+            $body = '<table cellspacing="2" cellpadding="0" border="0" width="100%">'."\n";
+        }
+        // new or modified message
+        if (($message = $this->get_message($data,$old)))
+        {
+            $body .= $this->format_line($html_email,'message',false,$message);
+        }
+        if ($integrate_link && ($link = $this->get_link($data,$old)))
+        {
+            $body .= $this->format_line($html_email,'link',false,lang('You can respond by visiting:'),$link);
+        }
+        foreach($this->get_details($data) as $name => $detail)
+        {
+            // if there's no old entry, the entry is not modified by definition
+            // if both values are '', 0 or null, we count them as equal too
+            $modified = $old && $data[$name] != $old[$name] && !(!$data[$name] && !$old[$name]);
+            //if ($modified) error_log("data[$name]=".print_r($data[$name],true).", old[$name]=".print_r($old[$name],true)." --> modified=".(int)$modified);
+            if (empty($detail['value']) && !$modified) continue;    // skip unchanged, empty values
+
+            $body .= $this->format_line($html_email,$detail['type'],$modified,
+                ($detail['label'] ? $detail['label'].': ':'').$detail['value']);
+        }
+        if ($html_email)
+        {
+            $body .= "</table>\n";
+        }
+
+        return $body;
+    }
+
 	/**
 	 * Format one line to the mail body
 	 *
-	 * @internal 
+	 * @internal
 	 * @param boolean $html_mail
 	 * @param string $type 'link', 'message', 'summary', 'multiline', 'reply' and ''=regular content
 	 * @param boolean $modified mark field as modified
@@ -634,13 +603,13 @@ class bo_tracking
 	function format_line($html_mail,$type,$modified,$line,$link=null)
 	{
 		$content = '';
-		
+
 		if ($html_mail)
 		{
-			$line = $this->html->htmlspecialchars($line);	// XSS
+			if (!$this->html_content_allow) $line = html::htmlspecialchars($line);	// XSS
 
 			$color = $modified ? 'red' : false;
-			$size  = $html_mail == 'medium' ? 'medium' : 'small';
+			$size  = '110%';
 			$bold = false;
 			$background = '#FFFFF1';
 			switch($type)
@@ -657,21 +626,26 @@ class bo_tracking
 					$bold = true;
 					break;
 				case 'multiline':
-					$line = nl2br($line);
+					// Only Convert nl2br on non-html content
+					$pos = strpos($line, '<br');
+					if ($pos===false)
+					{
+						$line = nl2br($line);
+					}
 					break;
 				case 'reply':
-					$background = '#F1F1F1';					
+					$background = '#F1F1F1';
 					break;
 				default:
-					$size = $size == 'small' ? 'x-small' : 'small';
+					$size = '100%';
 			}
 			$style = ($bold ? 'font-weight:bold;' : '').($size ? 'font-size:'.$size.';' : '').($color?'color:'.$color:'');
-			
+
 			$content = '<tr style="background-color: '.$background.';"><td style="'.$style.'">';
 		}
 		else	// text-mail
 		{
-			if ($type == 'reply') $content = str_repeat('-',64)."\n"; 
+			if ($type == 'reply') $content = str_repeat('-',64)."\n";
 
 			if ($modified) $content .= '> ';
 		}
@@ -680,10 +654,12 @@ class bo_tracking
 		if ($link)
 		{
 			$content .= ' ';
-			
+
 			if ($html_mail)
 			{
-				$content .= $this->html->a_href($link,$link,'','target="_blank"');
+				// the link is often too long for html boxes
+				// chunk-split allows to break lines if needed
+				$content .= html::a_href(chunk_split($link,40,'&#8203'),$link,'','target="_blank"');
 			}
 			else
 			{
@@ -691,14 +667,14 @@ class bo_tracking
 			}
 		}
 		if ($html_mail) $content .= '</td></tr>';
-		
+
 		$content .= "\n";
-		
+
 		return $content;
 	}
-	
+
 	/**
-	 * Get the attachments for a notificaton mail
+	 * Get the attachments for a notification
 	 *
 	 * @param array $data
 	 * @param array $old
@@ -706,39 +682,6 @@ class bo_tracking
 	 */
 	function get_attachments($data,$old)
 	{
-		return array();
+	 	return array();
 	}
-
-	/**
-	 * Get the message for the popup
-	 * 
-	 * Default implementation uses get_subject() with get_link() and get_message() as an extra line
-	 *
-	 * @param array $data
-	 * @param array $old
-	 * @return string
-	 */
-	function get_popup_message($data,$old)
-	{
-		$message = $this->html->htmlspecialchars($this->get_subject($data,$old));
-		
-		if ((list($link,$popup) = $this->get_link($data,$old,true)))
-		{
-			if ($popup)
-			{
-				list($width,$height) = explode('x',$popup);
-				$options = 'onclick="egw_openWindowCentered2(this.href,\'_blank\', \''.$width.'\', \''.$height.'\', \'yes\'); return false;"';
-			}
-			else
-			{
-				$options = 'target="_blank"';
-			}
-			$message = $this->html->a_href($this->html->htmlspecialchars($message),$link,'',$options);
-		}
-		if (($extra = $this->get_message($data,$old)))
-		{
-			$message .= '<br />'.$this->html->htmlspecialchars($extra);
-		}
-		return $message;
-	}
-}
\ No newline at end of file
+}
