@@ -6,7 +6,7 @@
 	 * @package etemplate
 	 * @link http://www.egroupware.org
 	 * @author Ralf Becker <RalfBecker@outdoor-training.de>
-	 * @version $Id: class.select_widget.inc.php 24337 2007-07-23 09:21:22Z ralfbecker $
+	 * @version $Id: class.select_widget.inc.php 25180 2008-03-25 16:42:23Z ralfbecker $
 	 */
 
 	/**
@@ -103,7 +103,7 @@
 		 */
 		function pre_process($name,&$value,&$cell,&$readonlys,&$extension_data,&$tmpl)
 		{
-			list($rows,$type,$type2,$type3) = explode(',',$cell['size']);
+			list($rows,$type,$type2,$type3,$type4) = explode(',',$cell['size']);
 
 			$extension_data['type'] = $cell['type'];
 
@@ -137,10 +137,6 @@
 					break;
 
 				case 'select-country':	// #Row|Extralabel,1=use country name, 0=use 2 letter-code
-					if (!is_object($GLOBALS['egw']->country))
-					{
-						$GLOBALS['egw']->country =& CreateObject('phpgwapi.country');
-					}
 					$cell['sel_options'] = $GLOBALS['egw']->country->countries();
 
 					if (($extension_data['country_use_name'] = $type) && $value)
@@ -155,19 +151,11 @@
 					break;
 
 				case 'select-state':
-					if (!is_object($GLOBALS['egw']->country))
-					{
-						$GLOBALS['egw']->country =& CreateObject('phpgwapi.country');
-					}
 					$cell['sel_options'] = $GLOBALS['egw']->country->us_states();
 					$cell['no_lang'] = True;
 					break;
 
 				case 'select-cat':	// !$type == globals cats too, $type2: extraStyleMultiselect, $type3: application, if not current-app
-					if (!is_object($GLOBALS['egw']->categories))
-					{
-						$GLOBALS['egw']->categories =& CreateObject('phpgwapi.categories');
-					}
 					if ($readonly)	// for readonly we dont need to fetch all cat's, nor do we need to indent them by level
 					{
 						$cell['no_lang'] = True;
@@ -222,7 +210,7 @@
 					$cell['no_lang'] = True;
 					break;
 
-				case 'select-account':	// options: #rows,{accounts(default)|both|groups|owngroups},{0(=lid)|1(default=name)|2(=lid+name),expand-multiselect-rows)}
+				case 'select-account':	// options: #rows,{accounts(default)|both|groups|owngroups},{0(=lid)|1(default=name)|2(=lid+name),expand-multiselect-rows,not-to-show-accounts,...)}
 					//echo "<p>select-account widget: name=$cell[name], type='$type', rows=$rows, readonly=".(int)($cell['readonly'] || $readonlys)."</p>\n";
 					if($type == 'owngroups') 
 					{
@@ -242,11 +230,7 @@
 					}
 					if ($this->ui == 'html' && $type != 'groups')	// use eGW's new account-selection (html only)
 					{
-						if (!is_object($GLOBALS['egw']->uiaccountsel))
-						{
-							require_once(EGW_API_INC.'/class.uiaccountsel.inc.php');
-							$GLOBALS['egw']->uiaccountsel =& new uiaccountsel;
-						}
+						$not = array_slice(explode(',',$cell['size']),4);
 						$help = (int)$cell['no_lang'] < 2 ? lang($cell['help']) : $cell['help'];
 						$onFocus = "self.status='".addslashes(htmlspecialchars($help))."'; return true;";
 						$onBlur  = "self.status=''; return true;";
@@ -261,7 +245,7 @@
 						}
 						if (($rows > 0 || $type3) && substr($name,-2) != '[]') $name .= '[]';
 						$value = $GLOBALS['egw']->uiaccountsel->selection($name,'eT_accountsel_'.str_replace(array('[','][',']'),array('_','_',''),$name),
-							$value,$type,$rows > 0 ? $rows : ($type3 ? -$type3 : 0),False,' onfocus="'.$onFocus.'" onblur="'.$onBlur.'"'.$noPrint_class,
+							$value,$type,$rows > 0 ? $rows : ($type3 ? -$type3 : 0),$not,' onfocus="'.$onFocus.'" onblur="'.$onBlur.'"'.$noPrint_class,
 							$cell['onchange'] == '1' ? 'this.form.submit();' : $cell['onchange'],
 							!empty($rows) && 0+$rows <= 0 ? lang($rows < 0 ? 'all' : $rows) : False);
 						if ($cell['noprint'])
@@ -385,7 +369,7 @@
 					$type3 = 1;
 					// fall-through
 					
-				case 'select-number':	// options: rows,min,max,decrement
+				case 'select-number':	// options: rows,min,max,decrement,suffix
 					$type = $type === '' ? 1 : intval($type);		// min
 					$type2 = $type2 === '' ? 10 : intval($type2);	// max
 					$format = '%d';
@@ -398,6 +382,7 @@
 					{
 						$type3 = -$type3;	// void infinite loop
 					}
+					if (!empty($type4)) $format .= lang($type4);
 					for ($i=0,$n=$type; $n <= $type2 && $i <= 100; $n += $type3,++$i)
 					{
 						$cell['sel_options'][$n] = sprintf($format,$n);
@@ -554,10 +539,6 @@
 				case 'select-country':
 					if ($extension_data['country_use_name'] && $value_in)
 					{
-						if (!is_object($GLOBALS['egw']->country))
-						{
-							$GLOBALS['egw']->country =& CreateObject('phpgwapi.country');
-						}
 						if (($value = $GLOBALS['egw']->country->get_full_name($value_in)))
 						{
 							break;
