@@ -6,7 +6,8 @@
  * @package etemplate
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker@outdoor-training.de>
- * @version $Id: class.so_sql.inc.php 24501 2007-10-07 13:29:59Z ralfbecker $
+ * @copyright 2002-8 by RalfBecker@outdoor-training.de
+ * @version $Id: class.so_sql.inc.php 26057 2008-10-07 08:17:09Z stefanbecker $
  */
 
 /**
@@ -24,63 +25,63 @@
  */
 class so_sql
 {
- 	/** 
- 	 * need to be set in the derived class to the db-table-name 
- 	 * 
+ 	/**
+ 	 * need to be set in the derived class to the db-table-name
+ 	 *
  	 * @var string
  	 */
 	var $table_name;
  	/**
  	 * db-col-name of autoincrement id or ''
- 	 * 
+ 	 *
  	 * @var string
  	 */
 	var $autoinc_id = '';
 	/**
 	 * all cols in data which are not (direct)in the db, for data_merge
-	 * 
+	 *
 	 * @var array
 	 */
 	var $non_db_cols = array();
 	/**
 	 * 4 turns on the so_sql debug-messages, default 0
-	 * 
+	 *
 	 * @var int
 	 */
 	var $debug = 0;
 	/**
 	 * string to be written to db if a col-value is '', eg. "''" or 'NULL' (default)
-	 * 
+	 *
 	 * @var string
 	 */
 	var $empty_on_write = 'NULL';
 	/**
 	 * total number of entries of last search with start != false
-	 * 
+	 *
 	 * @var int/boolean
 	 */
 	var $total = false;
 	/**
-	 * privat instance of the db-object
-	 * 
+	 * protected instance or reference (depeding on $no_clone param of constructor) of the db-object
+	 *
 	 * @var egw_db
 	 */
-	var $db;
+	protected $db;
 	/**
 	 * unique keys/index, set by derived class or via so_sql($app,$table)
-	 * 
+	 *
 	 * @var array
 	 */
 	var $db_uni_cols = array();
 	/**
 	 * db-col-name / internal-name pairs, set by derived calls or via so_sql($app,$table)
-	 * 
+	 *
 	 * @var array
 	 */
 	var $db_key_cols = array();
 	/**
-	 * db-col-name / internal-name pairs, set by derived calls or via so_sql($app,$table) 
-	 * 
+	 * db-col-name / internal-name pairs, set by derived calls or via so_sql($app,$table)
+	 *
 	 * @var array
 	 */
 	var $db_data_cols = array();
@@ -90,21 +91,41 @@ class so_sql
 	var $db_cols = array();
 	/**
 	 * eGW table definition
-	 * 
+	 *
 	 * @var array
 	 */
 	var $table_def = array();
+	/**
+	 * Appname to use in all queries, set via constructor
+	 *
+	 * @var string
+	 */
+	var $app;
 	/**
 	 * holds the content of all columns
-	 * 
+	 *
 	 * @var array
 	 */
 	var $data = array();
 	/**
-	 * @deprecated  a SO class dont need to and should NOT export functions (make them callable via menuaction)
+	 * Timestaps that need to be adjusted to user-time on reading or saving
+	 *
 	 * @var array
 	 */
-	var $public_functions = array();
+	var $timestamps = array();
+	/**
+	 * Offset in secconds between user and server-time,	it need to be add to a server-time to get the user-time
+	 * or substracted from a user-time to get the server-time
+	 *
+	 * @var int
+	 */
+	var $tz_offset_s;
+	/**
+	 * Current time as timestamp in user-time
+	 *
+	 * @var int
+	 */
+	var $now;
 
 	/**
 	 * constructor of the class
@@ -115,17 +136,28 @@ class so_sql
 	 * @param string $table should be set if table-defs to be read from <app>/setup/tables_current.inc.php
 	 * @param object/db $db database object, if not the one in $GLOBALS['egw']->db should be used, eg. for an other database
 	 * @param string $colum_prefix='' column prefix to automatic remove from the column-name, if the column name starts with it
-	 * 
+	 * @param boolean $no_clone=false can we avoid to clone the db-object, default no
+	 * 	new code using appnames and foreach(select(...,$app) can set it to avoid an extra instance of the db object
+	 *
 	 * @return so_sql
 	 */
-	function so_sql($app='',$table='',$db=null,$column_prefix='')
+	function __construct($app='',$table='',$db=null,$column_prefix='',$no_clone=false)
 	{
-		$this->db = is_object($db) ? clone($db) : clone($GLOBALS['egw']->db);
+		if ($no_clone)
+		{
+			$this->db = is_object($db) ? $db : $GLOBALS['egw']->db;
+		}
+		else
+		{
+			$this->db = is_object($db) ? clone($db) : clone($GLOBALS['egw']->db);
+		}
 		$this->db_cols = $this->db_key_cols + $this->db_data_cols;
 
 		if ($app)
 		{
-			$this->db->set_app($app);
+			$this->app = $app;
+
+			if (!$no_clone) $this->db->set_app($app);
 
 			if ($table) $this->setup_table($app,$table,$column_prefix);
 		}
@@ -136,6 +168,18 @@ class so_sql
 			echo "<p>so_sql('$app','$table')</p>\n";
 			_debug_array($this);
 		}
+		$this->tz_offset_s = $GLOBALS['egw']->datetime->tz_offset;
+		$this->now = time() + $this->tz_offset_s;	// time() is server-time and we need a user-time
+	}
+
+	/**
+	 * php4 constructor
+	 *
+	 * @deprecated use __construct
+	 */
+	function so_sql($app='',$table='',$db=null,$column_prefix='',$no_clone=false)
+	{
+		self::__construct($app,$table,$db,$column_prefix,$no_clone);
 	}
 
 	/**
@@ -179,9 +223,16 @@ class so_sql
 			{
 				$this->autoinc_id = $col;
 			}
-			if (in_array($name,$this->table_def['uc']))
+			foreach($this->table_def['uc'] as $k => $uni_index)
 			{
-				$this->db_uni_cols[$col] = $name;
+				if (is_array($uni_index) && in_array($name,$uni_index))
+				{
+					$this->db_uni_cols[$k][$col] = $name;
+				}
+				elseif($name === $uni_index)
+				{
+					$this->db_uni_cols[$col] = $name;
+				}
 			}
 		}
 	}
@@ -219,8 +270,9 @@ class so_sql
 	/**
 	 * changes the data from the db-format to your work-format
 	 *
-	 * it gets called everytime when data is read from the db
-	 * This function needs to be reimplemented in the derived class
+	 * It gets called everytime when data is read from the db.
+	 * This default implementation only converts the timestamps mentioned in $this->timestampfs from server to user time.
+	 * You can reimplement it in a derived class
 	 *
 	 * @param array $data if given works on that array and returns result, else works on internal data-array
 	 */
@@ -230,6 +282,13 @@ class so_sql
 		{
 			$data = &$this->data;
 		}
+		if ($this->tz_offset_s && $this->timestamps)
+		{
+			foreach($this->timestamps as $name)
+			{
+				if (isset($data[$name]) && $data[$name]) $data[$name] += $this->tz_offset_s;
+			}
+		}
 		// do the necessare changes here
 
 		return $data;
@@ -238,8 +297,9 @@ class so_sql
 	/**
 	 * changes the data from your work-format to the db-format
 	 *
-	 * It gets called everytime when data gets writen into db or on keys for db-searches
-	 * this needs to be reimplemented in the derived class
+	 * It gets called everytime when data gets writen into db or on keys for db-searches.
+	 * This default implementation only converts the timestamps mentioned in $this->timestampfs from user to server time.
+	 * You can reimplement it in a derived class
 	 *
 	 * @param array $data if given works on that array and returns result, else works on internal data-array
 	 */
@@ -249,6 +309,13 @@ class so_sql
 		{
 			$data = &$this->data;
 		}
+		if ($this->tz_offset_s && $this->timestamps)
+		{
+			foreach($this->timestamps as $name)
+			{
+				if (isset($data[$name]) && $data[$name]) $data[$name] -= $this->tz_offset_s;
+			}
+		}
 		// do the necessary changes here
 
 		return $data;
@@ -267,7 +334,7 @@ class so_sql
 		$this->db2data();
 
 		$this->data_merge($keys);
-		
+
 		return $this->data;
 	}
 
@@ -276,7 +343,7 @@ class so_sql
 	 *
 	 * @param array $keys array with keys in form internalName => value, may be a scalar value if only one key
 	 * @param string/array $extra_cols string or array of strings to be added to the SELECT, eg. "count(*) as num"
-	 * @param string $join sql to do a join, added as is after the table-name, eg. ", table2 WHERE x=y" or 
+	 * @param string $join sql to do a join, added as is after the table-name, eg. ", table2 WHERE x=y" or
 	 * @return array/boolean data if row could be retrived else False
 	 */
 	function read($keys,$extra_cols='',$join='')
@@ -285,8 +352,8 @@ class so_sql
 		{
 			$pk = array_values($this->db_key_cols);
 			if ($pk) $keys = array($pk[0] => $keys);
-		}	
-		
+		}
+
 		$this->init($keys);
 		$this->data2db();
 
@@ -302,10 +369,24 @@ class so_sql
 		{
 			foreach($this->db_uni_cols as $db_col => $col)
 			{
-				if ($this->data[$col] != '')
+				if (!is_array($col) && $this->data[$col] != '')
 				{
 					$query[$db_col] = $this->data[$col];
 				}
+				elseif(is_array($col))
+				{
+					$q = array();
+					foreach($col as $db_c => $c)
+					{
+						if ($this->data[$col] == '')
+						{
+							$q = null;
+							break;
+						}
+						$q[$db_c] = $this->data[$c];
+					}
+					if ($q) $query += $q;
+				}
 			}
 		}
 		if (!$query)	// no unique key in keys, lets try everything else
@@ -333,50 +414,49 @@ class so_sql
 				unset($query[$col]);
 			}
 		}
-		$this->db->select($this->table_name,'*'.($extra_cols?','.(is_array($extra_cols)?implode(',',$extra_cols):$extra_cols):''),
-			$query,__LINE__,__FILE__,False,'',False,0,$join);
-
-		if (!($row = $this->db->row(true)))
+		foreach($this->db->select($this->table_name,'*'.($extra_cols?','.(is_array($extra_cols)?implode(',',$extra_cols):$extra_cols):''),
+			$query,__LINE__,__FILE__,False,'',$this->app,0,$join) as $row)
 		{
-			if ($this->autoinc_id)
+			$cols = $this->db_cols;
+			if ($extra_cols)	// extra columns to report
 			{
-				unset($this->data[$this->db_key_cols[$this->autoinc_id]]);
+				foreach(is_array($extra_cols) ? $extra_cols : array($extra_cols) as $col)
+				{
+					if (FALSE!==stripos($col,' as ')) $col = preg_replace('/^.* as *([a-z0-9_]+) *$/i','\\1',$col);
+					$cols[$col] = $col;
+				}
+			}
+			foreach ($cols as $db_col => $col)
+			{
+				$this->data[$col] = $row[$db_col];
 			}
-			if ((int) $this->debug >= 4) echo "nothing found !!!</p>\n";
-
 			$this->db2data();
 
-			return False;
-		}
-		$cols = $this->db_cols;
-		if ($extra_cols)	// extra columns to report
-		{
-			foreach(is_array($extra_cols) ? $extra_cols : array($extra_cols) as $col)
+			if ((int) $this->debug >= 4)
 			{
-				if (FALSE!==stripos($col,'as')) $col = preg_replace('/^.*as *([a-z0-9_]+) *$/i','\\1',$col);
-				$cols[$col] = $col;
+				echo "data =\n"; _debug_array($this->data);
 			}
+			return $this->data;
 		}
-		foreach ($cols as $db_col => $col)
+		if ($this->autoinc_id)
 		{
-			$this->data[$col] = $row[$db_col];
+			unset($this->data[$this->db_key_cols[$this->autoinc_id]]);
 		}
+		if ((int) $this->debug >= 4) echo "nothing found !!!</p>\n";
+
 		$this->db2data();
 
-		if ((int) $this->debug >= 4)
-		{
-			echo "data =\n"; _debug_array($this->data);
-		}
-		return $this->data;
+		return False;
 	}
 
 	/**
 	 * saves the content of data to the db
 	 *
 	 * @param array $keys if given $keys are copied to data before saveing => allows a save as
-	 * @return int 0 on success and errno != 0 else
+	 * @param string|array $extra_where=null extra where clause, eg. to check an etag, returns true if no affected rows!
+	 * @return int|boolean 0 on success, or errno != 0 on error, or true if $extra_where is given and no rows affected
 	 */
-	function save($keys=null)
+	function save($keys=null,$extra_where=null)
 	{
 		if (is_array($keys) && count($keys)) $this->data_merge($keys);
 
@@ -399,7 +479,7 @@ class so_sql
 					$data[$db_col] = (string) $this->data[$col] === '' && $this->empty_on_write == 'NULL' ? null : $this->data[$col];
 				}
 			}
-			$this->db->insert($this->table_name,$data,false,__LINE__,__FILE__);
+			$this->db->insert($this->table_name,$data,false,__LINE__,__FILE__,$this->app);
 
 			if ($this->autoinc_id)
 			{
@@ -430,7 +510,7 @@ class so_sql
 					$data[] = $keys[$n];
 				}
 			}
-			$keys = '';
+			$keys = $extra_where;
 			foreach($this->db_key_cols as $db_col => $col)
 			{
 				$keys[$db_col] = $this->data[$col];
@@ -440,13 +520,18 @@ class so_sql
 				$data = $keys;
 				$keys = False;
 			}
-			if (!$this->autoinc_id)	// always try an insert if we have no autoinc_id, as we dont know if the data exists
+			if ($this->autoinc_id)
 			{
-				$this->db->insert($this->table_name,$data,$keys,__LINE__,__FILE__);
+				$this->db->update($this->table_name,$data,$keys,__LINE__,__FILE__,$this->app);
+				if (($nothing_affected = !$this->db->Errno && !$this->db->affected_rows()) && $extra_where)
+				{
+					return true;	// extra_where not met, eg. etag wrong
+				}
 			}
-			else
+			// always try an insert if we have no autoinc_id, as we dont know if the data exists
+			if (!$this->autoinc_id || $nothing_affected)
 			{
-				$this->db->update($this->table_name,$data,$keys,__LINE__,__FILE__);
+				$this->db->insert($this->table_name,$data,$keys,__LINE__,__FILE__,$this->app);
 			}
 		}
 		$this->db2data();
@@ -456,38 +541,53 @@ class so_sql
 
 	/**
 	 * Update only the given fields, if the primary key is not given, it will be taken from $this->data
-	 * 
+	 *
 	 * @param array $fields
 	 * @param boolean $merge=true if true $fields will be merged with $this->data (after update!), otherwise $this->data will be just $fields
-	 * @return int 0 on success, errno != 0 otherwise
+	 * @return int|boolean 0 on success, or errno != 0 on error, or true if $extra_where is given and no rows affected
 	 */
 	function update($fields,$merge=true)
 	{
-		if ($merge) $backup_data = $this->data ? $this->data : array();
+		if ($merge) $this->data_merge($fields);
 
-		if ($this->autoinc_id && !isset($fields[$this->autoinc_id]) ||
-			$this->db_key_cols && count(array_intersect(array_keys($this->db_key_cols),array_keys($fields)) != count($this->db_key_cols)))
+		$fields = $this->data2db($fields);
+
+		// extract the keys from $fields or - if not set there - from $this->data
+		$keys = array();
+		foreach($this->db_key_cols as $col => $name)
 		{
-			foreach($this->db_key_cols as $col => $name)
+			$keys[$col] = isset($fields[$name]) ? $fields[$name] : $this->data[$name];
+			unset($fields[$name]);
+		}
+		// extract the data from $fields
+		$data = array();
+		foreach($this->db_data_cols as $col => $name)
+		{
+			if (array_key_exists($name,$fields))
 			{
-				if (!isset($fields[$name]))
-				{
-					$fields[$name] = $this->data[$name];
-				}
+				$data[$col] = $fields[$name];
+				unset($fields[$name]);
 			}
 		}
-		$this->init($fields);
-
-		$ret = $this->save();
-		
-		if ($merge)
+		// add direct sql like 'etag=etag+1' (it has integer keys)
+		foreach($fields as $key => $value)
 		{
-			$this->init($backup_data);
-			$this->data_merge($fields);
+			if (is_int($key))
+			{
+				$data[] = $value;
+			}
 		}
-		return $ret;
+		if (!$data)
+		{
+			return 0;	// nothing to update
+		}
+		if (!$this->db->update($this->table_name,$data,$keys,__LINE__,__FILE__,$this->app))
+		{
+			return $this->db->Errno;
+		}
+		return 0;
 	}
-	
+
 	/**
 	 * deletes row representing keys in internal data or the supplied $keys if != null
 	 *
@@ -496,6 +596,10 @@ class so_sql
 	 */
 	function delete($keys=null)
 	{
+		if ($this->autoinc_id && $keys && !is_array($keys))
+		{
+			$keys = array($this->autoinc_id => $keys);
+		}
 		if (!is_array($keys) || !count($keys))	// use internal data
 		{
 			$data = $this->data;
@@ -518,7 +622,7 @@ class so_sql
 		{
 			$query[$db_col] = $data[$col];
 		}
-		$this->db->delete($this->table_name,$query,__LINE__,__FILE__);
+		$this->db->delete($this->table_name,$query,__LINE__,__FILE__,$this->app);
 
 		return $this->db->affected_rows();
 	}
@@ -531,7 +635,7 @@ class so_sql
 	 * For a union-query you call search for each query with $start=='UNION' and one more with only $order_by and $start set to run the union-query.
 	 *
 	 * @param array/string $criteria array of key and data cols, OR a SQL query (content for WHERE), fully quoted (!)
-	 * @param boolean/string/array $only_keys=true True returns only keys, False returns all cols. or 
+	 * @param boolean/string/array $only_keys=true True returns only keys, False returns all cols. or
 	 *	comma seperated list or array of columns to return
 	 * @param string $order_by='' fieldnames + {ASC|DESC} separated by colons ',', can also contain a GROUP BY (if it contains ORDER BY)
 	 * @param string/array $extra_cols='' string or array of strings to be added to the SELECT, eg. "count(*) as num"
@@ -568,24 +672,37 @@ class so_sql
 					{
 						$db_col = $col;
 					}
-					if ($wildcard || $criteria[$col]{0} == '!' ||
+					if ($wildcard || $criteria[$col][0] == '!' ||
 						is_string($criteria[$col]) && (strpos($criteria[$col],'*')!==false || strpos($criteria[$col],'?')!==false))
 					{
 						$cmp_op = ' '.$this->db->capabilities['case_insensitive_like'].' ';
-						if ($criteria[$col]{0} == '!')
+						$negate = false;
+						if ($criteria[$col][0] == '!')
 						{
 							$cmp_op = ' NOT'.$cmp_op;
 							$criteria[$col] = substr($criteria[$col],1);
+							$negate = true;
+						}
+						foreach(explode(' ',$criteria[$col]) as $crit)
+						{
+							$query[] = ($negate ? ' ('.$db_col.' IS NULL OR ' : '').$db_col.$cmp_op.$this->db->quote($wildcard.str_replace(array('%','_','*','?'),array('\\%','\\_','%','_'),$crit).$wildcard).($negate ? ') ' : '');
 						}
-						$query[] = $db_col.$cmp_op.$this->db->quote($wildcard.str_replace(array('%','_','*','?'),array('\\%','\\_','%','_'),$criteria[$col]).$wildcard);
 					}
 					elseif (strpos($db_col,'.')!==false)	// we have a table-name specified
 					{
 						list($table,$only_col) = explode('.',$db_col);
-						
+
 						$table_def = $this->db->get_table_definitions(true,$table);
-						
-						$query[] = $db_col.(is_array($val) ? ' IN ' : '=').$this->db->quote($val,$table_def['fd'][$only_col]);
+
+						if (is_array($val) && count($val) > 1)
+						{
+							array_walk($val,array($this->db,'quote'),$table_def['fd'][$only_col]['type']);
+							$query[] = $sql = $db_col.' IN (' .implode(',',$val).')';
+						}
+						else
+						{
+							$query[] = $db_col.'='.$this->db->quote(is_array($val)?array_shift($val):$val,$table_def['fd'][$only_col]['type']);
+						}
 					}
 					else
 					{
@@ -603,13 +720,13 @@ class so_sql
 				echo function_backtrace()."<br/>\n";
 				echo "filter=";_debug_array($filter);
 				echo "data2db(filter)=";_debug_array($data2db_filter);
-			}	
+			}
 			foreach($data2db_filter as $col => $val)
 			{
 				if ($val !== '')
 				{
 					// check if a db-internal name conversation necessary
-					if (!is_int($col) && ($c = array_search($col,$this->db_cols))) 
+					if (!is_int($col) && ($c = array_search($col,$this->db_cols)))
 					{
 						$col = $c;
 					}
@@ -627,13 +744,13 @@ class so_sql
 					}
 				}
 			}
-			if ($query) 
+			if ($query)
 			{
 				if ($op != 'AND')
 				{
 					$db_filter[] = '('.$this->db->column_data_implode(' '.$op.' ',$query).')';
 				}
-				else 
+				else
 				{
 					$db_filter = array_merge($db_filter,$query);
 				}
@@ -670,7 +787,7 @@ class so_sql
 
 		$num_rows = 0;	// as spec. in max_matches in the user-prefs
 		if (is_array($start)) list($start,$num_rows) = $start;
-		
+
 		if ($order_by && stripos($order_by,'ORDER BY')===false && stripos($order_by,'GROUP BY')===false)
 		{
 			$order_by = 'ORDER BY '.$order_by;
@@ -695,7 +812,7 @@ class so_sql
 				return true;	// waiting for further calls, before running the union-query
 			}
 			// running the union query now
-			if ($start !== false && $num_rows != 1)	// need to get the total too, saved in $this->total
+			if ($start !== false)	// need to get the total too, saved in $this->total
 			{
 				if ($this->db->Type == 'mysql' && $this->db->ServerInfo['version'] >= 4.0)
 				{
@@ -703,18 +820,17 @@ class so_sql
 				}
 				else	// cant do a count, have to run the query without limit
 				{
-					$this->db->union($union,__LINE__,__FILE__);
-					$this->total = $this->db->num_rows();
+					$this->total = $this->db->union($union,__LINE__,__FILE__)->NumRows();
 				}
 			}
-			$this->db->union($union,__LINE__,__FILE__,$order_by,$start,$num_rows);
+			$rs = $this->db->union($union,__LINE__,__FILE__,$order_by,$start,$num_rows);
 
 			$cols = $union_cols;
 			$union = $union_cols = array();
 		}
 		else	// no UNION
 		{
-			if ($start !== false && $num_rows != 1)	// need to get the total too, saved in $this->total
+			if ($start !== false)	// need to get the total too, saved in $this->total
 			{
 				if ($this->db->Type == 'mysql' && $this->db->ServerInfo['version'] >= 4.0)
 				{
@@ -722,17 +838,15 @@ class so_sql
 				}
 				elseif (!$need_full_no_count && (!$join || stripos($join,'LEFT JOIN')!==false))
 				{
-					$this->db->select($this->table_name,'COUNT(*)',$query,__LINE__,__FILE__,false,'',false,0,$join);
-					$this->total = $this->db->next_record() ? (int) $this->db->f(0) : false;
+					$this->total = $this->db->select($this->table_name,'COUNT(*)',$query,__LINE__,__FILE__,false,'',$this->app,0,$join)->fetchSingle();
 				}
 				else	// cant do a count, have to run the query without limit
 				{
-					$this->db->select($this->table_name,$colums,$query,__LINE__,__FILE__,false,$order_by,false,0,$join);
-					$this->total = $this->db->num_rows();
+					$this->total = $this->db->select($this->table_name,$colums,$query,__LINE__,__FILE__,false,$order_by,false,0,$join)->NumRows();
 				}
 			}
-			$this->db->select($this->table_name,$mysql_calc_rows.$colums,$query,__LINE__,__FILE__,
-				$start,$order_by,false,$num_rows,$join);
+			$rs = $this->db->select($this->table_name,$mysql_calc_rows.$colums,$query,__LINE__,__FILE__,
+				$start,$order_by,$this->app,$num_rows,$join);
 
 			$cols = $this->_get_columns($only_keys,$extra_cols);
 		}
@@ -740,10 +854,10 @@ class so_sql
 
 		if ($mysql_calc_rows)
 		{
-			$this->total = $this->db->Link_ID->GetOne('SELECT FOUND_ROWS()');
+			$this->total = $this->db->query('SELECT FOUND_ROWS()')->fetchSingle();
 		}
 		$arr = array();
-		for ($n = 0; ($row = $this->db->row(true)); ++$n)
+		if ($rs) foreach($rs as $row)
 		{
 			$data = array();
 			foreach($cols as $db_col => $col)
@@ -751,6 +865,7 @@ class so_sql
 				$data[$col] = $row[$db_col];
 			}
 			$arr[] = $this->db2data($data);
+			$n++;
 		}
 		return $n ? $arr : False;
 	}
@@ -758,11 +873,11 @@ class so_sql
 	/**
 	 * extract the requested columns from $only_keys and $extra_cols param of a search
 	 *
-	 * @internal 
+	 * @internal
 	 * @param boolean/string $only_keys=true True returns only keys, False returns all cols. comma seperated list of keys to return
 	 * @param string/array $extra_cols='' string or array of strings to be added to the SELECT, eg. "count(*) as num"
 	 * @return array with columns as db-name => internal-name pairs
-	 */	 
+	 */
 	function _get_columns($only_keys,$extra_cols)
 	{
 		//echo "_get_columns() only_keys="; _debug_array($only_keys); echo "extra_cols="; _debug_array($extra_cols);
@@ -818,12 +933,13 @@ class so_sql
 	 *	For other keys like 'filter', 'cat_id' you have to reimplement this method in a derived class.
 	 * @param array &$rows returned rows/competitions
 	 * @param array &$readonlys eg. to disable buttons based on acl, not use here, maybe in a derived class
-	 * @param string $join='' sql to do a join, added as is after the table-name, eg. ", table2 WHERE x=y" or 
+	 * @param string $join='' sql to do a join, added as is after the table-name, eg. ", table2 WHERE x=y" or
 	 *	"LEFT JOIN table2 ON (x=y)", Note: there's no quoting done on $join!
 	 * @param boolean $need_full_no_count=false If true an unlimited query is run to determine the total number of rows, default false
+	 * @param mixed $only_keys=false, see search
 	 * @return int total number of rows
 	 */
-	function get_rows($query,&$rows,&$readonlys,$join='',$need_full_no_count=false)
+	function get_rows($query,&$rows,&$readonlys,$join='',$need_full_no_count=false,$only_keys=false)
 	{
 		if ((int) $this->debug >= 4)
 		{
@@ -837,15 +953,17 @@ class so_sql
 				$criteria[$col] = $query['search'];
 			}
 		}
-		$rows = (array) $this->search($criteria,false,$query['order']?$query['order'].' '.$query['sort']:'',
+		$rows = $this->search($criteria,$only_keys,$query['order']?$query['order'].' '.$query['sort']:'',
 			'','%',false,'OR',$query['num_rows']?array((int)$query['start'],$query['num_rows']):(int)$query['start'],
 			$query['col_filter'],$join,$need_full_no_count);
 
+		if (!$rows) $rows = array();	// otherwise false returned from search would be returned as array(false)
+
 		return $this->total;
 	}
-		
+
 	/**
-	 * Check if values for unique keys are unique
+	 * Check if values for unique keys and the primary keys are unique are unique
 	 *
 	 * @param array $data data-set to check, defaults to $this->data
 	 * @return int 0: all keys are unique, 1: first key not unique, 2: ...
@@ -857,9 +975,27 @@ class so_sql
 			$data = $this->data;
 		}
 		$n = 1;
-		foreach($this->db_uni_cols as $db_col => $col)
+		$uni_keys = $this->db_uni_cols;
+		// add the primary key, only if it's NOT an auto id
+		if (!$this->autoinc_id)
 		{
-			if (list($other) = $this->search(array($db_col => $data[$col]),false,'','','',false,'AND',false,null,''))
+			$uni_keys[] = $this->db_key_cols;
+		}
+		foreach($uni_keys as $db_col => $col)
+		{
+			if (is_array($col))
+			{
+				$query = array();
+				foreach($col as $db_c => $c)
+				{
+					$query[$db_c] = $data[$c];
+				}
+			}
+			else
+			{
+				$query = array($db_col => $data[$col]);
+			}
+			foreach($this->db->select($this->table_name,$this->db_key_cols,$query,__LINE__,__FILE__,false,'',$this->app) as $other)
 			{
 				foreach($this->db_key_cols as $db_key_col => $key_col)
 				{
@@ -867,7 +1003,7 @@ class so_sql
 					{
 						if ((int) $this->debug >= 4)
 						{
-							echo "<p>not_unique in '$col' as for '$key_col': '${data[$key_col]}' != '${other[$key_col]}'</p>\n";
+							echo "<p>not_unique in ".array2string($col)." as for '$key_col': '${data[$key_col]}' != '${other[$key_col]}'</p>\n";
 						}
 						return $n;	// different entry => $n not unique
 					}
@@ -877,7 +1013,7 @@ class so_sql
 		}
 		return 0;
 	}
-	
+
 	/**
 	 * Query DB for a list / array with one colum as key and an other one(s) as value, eg. id => title pairs
 	 *
@@ -893,20 +1029,20 @@ class so_sql
 	function query_list($value_col,$key_col='',$filter=array(),$order='')
 	{
 		static $cache = array();
-		
+
 		$cache_key = serialize($value_col).'-'.$key_col.'-'.serialize($filter).'-'.$order;
-		
+
 		if (isset($cache[$cache_key]))
 		{
 			return $cache[$cache_key];
 		}
 		if (!is_array($value_col)) $value_col = array($value_col);
-		
+
 		$cols = array();
 		foreach($value_col as $key => $col)
 		{
 			$cols[$key] = preg_match('/AS ([a-z_0-9]+)$/i',$col,$matches) ? $matches[1] : $col;
-		}			
+		}
 		if (!$order) $order = current($cols);
 
 		if (($search =& $this->search(array(),($key_col ? $key_col.',' : 'DISTINCT ').implode(',',$value_col),$order,'','',false,'AND',false,$filter)))
@@ -939,14 +1075,3 @@ class so_sql
 		return $cache[$cache_key] =& $ret;
 	}
 }
-
-if (!function_exists("stripos")) 
-{
-	/**
-	 * stripos for php < 5
-	 */
-	function stripos($str,$needle,$offset=0)
-	{
-		return strpos(strtolower($str),strtolower($needle),$offset);
-	}
-}
