@@ -6,7 +6,7 @@
  * @subpackage api
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker@outdoor-training.de>
- * @version $Id: etemplate.js 24451 2007-09-20 08:46:14Z ralfbecker $ 
+ * @version $Id: etemplate.js 24450 2007-09-20 08:45:21Z ralfbecker $ 
  */
 
 function submitit(form,name)
@@ -254,3 +254,26 @@ function get_selected(form,suffix) {
 	}
 	return selected;
 }
+
+// set certain comma-separated values in a multiselection (div with checkboxes, used as replacement for a multiselection)
+function set_multiselection(name,values,reset)
+{
+	//alert("set_multiselection('"+name+"','"+values+"',"+reset+")");
+	checkboxes = document.getElementsByName(name);
+	div = document.getElementById(name.substr(0,name.length-2));
+	div_first = div.firstChild;
+	values = ','+values+',';
+	for (var i = 0; i < checkboxes.length; i++)	{
+		checkbox = checkboxes[i];
+		value = values.indexOf(','+checkbox.value+',') >= 0;
+		if (reset || value) {
+			//alert(checkbox.name+': value='+checkbox.value+', checked='+checkbox.checked+' --> '+value);
+			if (value && checkbox.parentNode != div_first) {
+				br = checkbox.parentNode.nextSibling;
+				div.insertBefore(div.removeChild(checkbox.parentNode),div_first);
+				div.insertBefore(div.removeChild(br),div_first);
+			}
+			checkbox.checked = value;
+		}
+	}
+}
