@@ -12,7 +12,7 @@
 	* option) any later version.                                                *
 	\***************************************************************************/
 
-	/* $Id: class.ajaxfelamimail.inc.php 23478 2007-03-04 06:41:53Z lkneschke $ */
+	/* $Id: class.ajaxfelamimail.inc.php 26402 2008-11-18 15:20:24Z leithoff $ */
 
 	class ajaxfelamimail {
 		// which profile to use(currently only 0 is supported)
@@ -36,8 +36,8 @@
 			$this->uiwidgets	=& CreateObject('felamimail.uiwidgets');
 			$this->_connectionStatus = $this->bofelamimail->openConnection();
 
-			$this->sessionDataAjax	= $GLOBALS['egw']->session->appsession('ajax_session_data');
-			$this->sessionData	= $GLOBALS['egw']->session->appsession('session_data');
+			$this->sessionDataAjax	= $GLOBALS['egw']->session->appsession('ajax_session_data','felamimail');
+			$this->sessionData	= $GLOBALS['egw']->session->appsession('session_data','felamimail');
 
 			if(!isset($this->sessionDataAjax['folderName'])) {
 				$this->sessionDataAjax['folderName'] = 'INBOX';
@@ -175,10 +175,6 @@
 		 */
 		function createACLTable($_acl) 
 		{
-			if(!is_object($GLOBALS['egw']->html)) {
-				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
-			}
-
 			$aclList = array('l','r','s','w','i','p','c','d','a');
 			$aclShortCuts = array(	'custom'	=> 'custom',
 									'lrs'		=> 'readable',
@@ -204,7 +200,7 @@
 						" onclick=\"xajax_doXMLHTTP('felamimail.ajaxfelamimail.updateSingleACL','$accountName','$acl',this.checked); document.getElementById('predefinedFor_$accountName').options[0].selected=true\"</td>";
 				}
 
-				$selectFrom = $GLOBALS['egw']->html->select('identity', $accountAcl['RIGHTS'], $aclShortCuts, false, "id=\"predefinedFor_$accountName\" style='width: 100px;' onChange=\"xajax_doXMLHTTP('felamimail.ajaxfelamimail.updateACL','$accountName',this.value)\"");
+				$selectFrom = html::select('identity', $accountAcl['RIGHTS'], $aclShortCuts, false, "id=\"predefinedFor_$accountName\" style='width: 100px;' onChange=\"xajax_doXMLHTTP('felamimail.ajaxfelamimail.updateACL','$accountName',this.value)\"");
 
 				$row .= "<td>$selectFrom</td>";
 				
@@ -240,6 +236,30 @@
 			return $response->getXML();
 		}
 
+        function toggleEditor($_composeID, $_content ,$_mode)
+        {
+            if($this->_debug) error_log("ajaxfelamimail::toggleEditor");
+            $bocompose  =& CreateObject('felamimail.bocompose', $_composeID);
+			if($_mode == 'simple') {
+				#if (isset($GLOBALS['egw_info']['server']['enabled_spellcheck'])) $_mode = 'egw_simple_spellcheck';
+        		$this->sessionData['mimeType'] = 'html';
+				// convert emailadresses presentet in angle brackets to emailadress only
+				$bocompose->replaceEmailAdresses($_content);
+			} else {
+				$this->sessionData['mimeType'] = 'text';
+				$_content = $bocompose->_getCleanHTML($_content);
+				$_content = $bocompose->convertHTMLToText($_content);
+			}
+			$htmlObject = html::fckEditorQuick('body', $_mode, $_content);
+			$this->saveSessionData();
+			$response =& new xajaxResponse();
+			$response->addScript('FCKeditorAPI_ConfirmCleanup();');
+			$response->addScript('FCKeditorAPI_Cleanup();');
+			$response->addAssign('editorArea', 'innerHTML', $htmlObject);
+            return $response->getXML();
+        }
+
+
 		/*
 		* delete a existing folder
 		*
@@ -284,17 +304,60 @@
 		function deleteSignatures($_signatures) 
 		{
 			if($this->_debug) error_log("ajaxfelamimail::deleteSignatures");
-			$boPreferences = CreateObject('felamimail.bopreferences');
+			$signatures = explode(",",$_signatures);
+			require_once(EGW_INCLUDE_ROOT.'/felamimail/inc/class.felamimail_bosignatures.inc.php');
+			$boSignatures = new felamimail_bosignatures();
 				
-			$boPreferences->deleteSignatures($_signatures);
-				
-			$signatures = $boPreferences->getListOfSignatures();
+			$boSignatures->deleteSignatures($signatures);
+			unset($signatures);
+			$signatures = $boSignatures->getListOfSignatures();
 
 			$response =& new xajaxResponse();
 			$response->addAssign('signatureTable', 'innerHTML', $this->uiwidgets->createSignatureTable($signatures));
 			return $response->getXML();
 		}
+
+		function changeActiveAccount($accountData)
+		{
+			if($this->_debug) error_log("ajaxfelamimail::changeActiveAccount");
+			require_once(EGW_INCLUDE_ROOT.'/felamimail/inc/class.bopreferences.inc.php');
+			$boPreferences  =& CreateObject('felamimail.bopreferences');
+			$boPreferences->setProfileActive(false);
+			if ($accountData) $boPreferences->setProfileActive(true,$accountData);
+
+			$response =& new xajaxResponse();
+			$response->addScript('refreshView();');
+			return $response->getXML();
+		}
 		
+		function deleteAccountData($accountIDs)
+		{
+			if($this->_debug) error_log("ajaxfelamimail::deleteAccountData");
+			$accountData = explode(",",$accountIDs);
+			require_once(EGW_INCLUDE_ROOT.'/felamimail/inc/class.bopreferences.inc.php');
+			$boPreferences  =& CreateObject('felamimail.bopreferences');
+			$boPreferences->deleteAccountData($accountData);
+			$preferences =& $boPreferences->getPreferences();
+			$allAccountData    = $boPreferences->getAllAccountData($preferences);
+			foreach ($allAccountData as $tmpkey => $accountData)
+			{
+				$identity =& $accountData['identity'];
+				foreach($identity as $key => $value) {
+					if(is_object($value) || is_array($value)) {
+						continue;
+					}
+					switch($key) {
+						default:
+							$tempvar[$key] = $value;
+					}
+				}
+				$accountArray[]=$tempvar;
+			}
+			$response =& new xajaxResponse();
+			$response->addAssign('userDefinedAccountTable', 'innerHTML', $this->uiwidgets->createAccountDataTable($accountArray));
+			return $response->getXML();
+		}
+
 		/*
 		* empty trash folder
 		*
@@ -337,6 +400,20 @@
 
 			return $this->generateMessageList($this->sessionData['mailbox']);
 		}
+
+		function sendNotify ($_uid, $_ret) 
+		{
+			$response =& new xajaxResponse();
+			if ($_ret==='true') {
+				if ( $this->bofelamimail->sendMDN($_uid) )
+					$this->bofelamimail->flagMessages("mdnsent",array($_uid));
+			} else {
+				 $this->bofelamimail->flagMessages("mdnnotsent",array($_uid));
+			}
+			return $response;
+
+		}
+
 		
 		function generateMessageList($_folderName) 
 		{
@@ -350,11 +427,14 @@
 			$listMode = 0;
 		
 			$this->bofelamimail->restoreSessionData();
-			
-			if($this->bofelamimail->isSentFolder($_folderName)) {
+			if($this->bofelamimail->isSentFolder($_folderName) || 
+				false !== in_array($_folderName,explode(',',$GLOBALS['egw_info']['user']['preferences']['felamimail']['messages_showassent_0']))) 
+			{
 				$listMode = 1;
 			} elseif($this->bofelamimail->isDraftFolder($_folderName)) {
 				$listMode = 2;
+			} elseif($this->bofelamimail->isTemplateFolder($_folderName)) {
+				$listMode = 3;
 			}
 
 			$maxMessages = $GLOBALS['egw_info']["user"]["preferences"]["common"]["maxmatchs"];
@@ -369,8 +449,9 @@
 			);
 
 			$headerTable = $this->uiwidgets->messageTable(
-				$headers, 
-				$listMode, 
+				$headers,
+				$listMode,
+				$_folderName,
 				$GLOBALS['egw_info']['user']['preferences']['felamimail']['message_newwindow'],
 				$GLOBALS['egw_info']['user']['preferences']['felamimail']['rowOrderStyle']
 			);
@@ -443,19 +524,29 @@
 				
 				$this->sessionDataAjax['folderName'] = $folderName;
 				$this->saveSessionData();
-				
+				$hasChildren=false;
+				if ($folderStatus['attributes'][0]=="\\HasChildren") $hasChildren=true;	
 				if(strtoupper($folderName) != 'INBOX') {
 					$response->addAssign("newMailboxName", "value", htmlspecialchars($folderStatus['shortDisplayName'], ENT_QUOTES, $this->charset));
+					$response->addAssign("newMailboxMoveName", "value", htmlspecialchars($folderStatus['displayName'], ENT_QUOTES, $this->charset));
 					$response->addScript("document.getElementById('mailboxRenameButton').disabled = false;");
 					$response->addScript("document.getElementById('newMailboxName').disabled = false;");
 					$response->addScript("document.getElementById('divDeleteButton').style.visibility = 'visible';");
 					$response->addScript("document.getElementById('divRenameButton').style.visibility = 'visible';");
+					// if the folder has children, we dont want to move it, since we dont handle the subscribing to subfolders after moving the folder
+					$response->addScript("document.getElementById('divMoveButton').style.visibility = ".($hasChildren ? "'hidden'" : "'visible'").";");
+					$response->addScript("document.getElementById('newMailboxMoveName').disabled = ".($hasChildren ? "true" : "false").";");
+					$response->addScript("document.getElementById('aMoveSelectFolder').style.visibility = ".($hasChildren ? "'hidden'" : "'visible'").";");
 				} else {
 					$response->addAssign("newMailboxName", "value", '');
+					$response->addAssign("newMailboxMoveName", "value", '');
 					$response->addScript("document.getElementById('mailboxRenameButton').disabled = true;");
 					$response->addScript("document.getElementById('newMailboxName').disabled = true;");
 					$response->addScript("document.getElementById('divDeleteButton').style.visibility = 'hidden';");
 					$response->addScript("document.getElementById('divRenameButton').style.visibility = 'hidden';");
+					$response->addScript("document.getElementById('divMoveButton').style.visibility = 'hidden';");
+					$response->addScript("document.getElementById('newMailboxMoveName').disabled = true;");
+					$response->addScript("document.getElementById('aMoveSelectFolder').style.visibility = 'hidden';");
 				}
 				$response->addAssign("folderName", "innerHTML", htmlspecialchars($folderStatus['displayName'], ENT_QUOTES, $this->charset));
 				if($folderACL = $this->bofelamimail->getIMAPACL($folderName)) {
@@ -518,7 +609,7 @@
 			
 			return $this->generateMessageList($this->sessionData['mailbox']);
 		}
-		
+
 		/*
 		* move messages to another folder
 		*
@@ -531,9 +622,22 @@
 		{
 			if($this->_debug) error_log("ajaxfelamimail::moveMessages");
 			$folderName = $this->_decodeEntityFolderName($_folderName);
-			$this->bofelamimail->moveMessages($folderName, $_selectedMessages['msg']);
+			if (!empty( $_selectedMessages['msg']) && !empty($folderName)) {
+				if ($this->sessionData['mailbox'] != $folderName) {
+					$this->bofelamimail->moveMessages($folderName, $_selectedMessages['msg']);
+				} else {
+					  if($this->_debug) error_log("ajaxfelamimail::moveMessages-> same folder than current selected");
+				}
 
-			return $this->generateMessageList($this->sessionData['mailbox']);
+				return $this->generateMessageList($this->sessionData['mailbox']);
+			} else {
+				$response =& new xajaxResponse();
+				$response->addScript('resetMessageSelect();');
+				$response->addScript('tellUser("'.lang('No messages selected, or lost selection. Changing to folder ').'","'.$_folderName.'");');
+				$response->addScript('onNodeSelect("'.$_folderName.'");');
+				return $response->getXML();
+ 
+			}
 		}
 
 		function quickSearch($_searchType, $_searchString, $_status) 
@@ -566,7 +670,7 @@
 			if ($this->_debug) error_log("ajaxfelamimail::refreshFolder");
 			$GLOBALS['egw']->session->commit_session();
 
-            $response =& new xajaxResponse();
+			$response =& new xajaxResponse();
 
 			if ($this->_connectionStatus === true) {
 				$folderName = $this->sessionData['mailbox'];
@@ -610,15 +714,40 @@
 		
 		function refreshSignatureTable() 
 		{
-				$boPreferences = CreateObject('felamimail.bopreferences');
-				
-				$signatures = $boPreferences->getListOfSignatures();
+			require_once(EGW_INCLUDE_ROOT.'/felamimail/inc/class.felamimail_bosignatures.inc.php');
+			$boSignatures = new felamimail_bosignatures();
+			$signatures = $boSignatures->getListOfSignatures();
 
-				$response =& new xajaxResponse();
-				$response->addAssign('signatureTable', 'innerHTML', $this->uiwidgets->createSignatureTable($signatures));
-				return $response->getXML();
+			$response =& new xajaxResponse();
+			$response->addAssign('signatureTable', 'innerHTML', $this->uiwidgets->createSignatureTable($signatures));
+			return $response->getXML();
 		}
 		
+		function refreshAccountDataTable()
+		{
+			require_once(EGW_INCLUDE_ROOT.'/felamimail/inc/class.bopreferences.inc.php');
+			$boPreferences  =& CreateObject('felamimail.bopreferences');
+			$preferences =& $boPreferences->getPreferences();
+			$allAccountData    = $boPreferences->getAllAccountData($preferences);
+			foreach ($allAccountData as $tmpkey => $accountData)
+			{
+				$identity =& $accountData['identity'];
+				foreach($identity as $key => $value) {
+					if(is_object($value) || is_array($value)) {
+						continue;
+					}
+					switch($key) {
+						default:
+						$tempvar[$key] = $value;
+					}
+				}
+				$accountArray[]=$tempvar;
+			}
+			$response =& new xajaxResponse();
+			$response->addAssign('userDefinedAccountTable', 'innerHTML', $this->uiwidgets->createAccountDataTable($accountArray));
+			return $response->getXML();
+		}
+
 		function reloadAttachments($_composeID) 
 		{
 			$bocompose	=& CreateObject('felamimail.bocompose', $_composeID);
@@ -663,10 +792,7 @@
 			}
 			
 			if(count($tableRows) > 0) {
-				if(!is_object($GLOBALS['egw']->html)) {
-					$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
-				}
-				$table = $GLOBALS['egw']->html->table($tableRows, "style='width:100%'");
+				$table = html::table($tableRows, "style='width:100%'");
 			}
 
 			$response =& new xajaxResponse();
@@ -684,44 +810,61 @@
 		*/
 		function renameFolder($_oldFolderName, $_parentFolder, $_folderName) 
 		{
+			if($this->_debug) error_log("ajaxfelamimail::renameFolder called as ($_oldFolderName, $_parentFolder, $_folderName)");
 			$oldFolderName = $this->_decodeEntityFolderName($_oldFolderName);
-			$folderName = $GLOBALS['egw']->translation->convert($_folderName, $this->charset, 'UTF7-IMAP');
+			$folderName = $GLOBALS['egw']->translation->convert($this->_decodeEntityFolderName($_folderName), $this->charset, 'UTF7-IMAP');
 			$parentFolder = $this->_decodeEntityFolderName($_parentFolder);
 			$parentFolder = ($_parentFolder == '--topfolder--' ? '' : $parentFolder);
-			if($this->_debug) error_log("ajaxfelamimail::renameFolder($oldFolderName, $parentFolder, $folderName)");
+			if($this->_debug) error_log("ajaxfelamimail::renameFolder work with ($oldFolderName, $parentFolder, $folderName)");
 
 			$response =& new xajaxResponse();
 			if(strtoupper($_oldFolderName) != 'INBOX' ) {
 				if($newFolderName = $this->bofelamimail->renameFolder($oldFolderName, $parentFolder, $folderName)) {
+					//enforce the subscription to the newly named server, as it seems to fail for names with umlauts
+					$rv = $this->bofelamimail->subscribe($newFolderName, true);
 					$newFolderName = $this->_encodeFolderName($newFolderName);
 					$folderName = $this->_encodeDisplayFolderName($folderName);
-
+					if ($parentFolder == '') {
+						#$folderStatus = $this->bofelamimail->getFolderStatus($newFolderName);
+						$HierarchyDelimiter = $this->bofelamimail->getHierarchyDelimiter();
+						#if($this->_debug) error_log("ajaxfelamimail::renameFolder Status of new Folder:".print_r($folderStatus,true));
+						if($this->_debug) error_log("ajaxfelamimail::rename/move Folder($newFolderName, $folderName)");
+						$buffarray = explode($HierarchyDelimiter, $newFolderName);
+						$folderName = $this->_encodeDisplayFolderName( $this->_decodeEntityFolderName(array_pop($buffarray)));
+						$_parentFolder = $parentFolder = implode($HierarchyDelimiter,$buffarray);
+						if($this->_debug) error_log("ajaxfelamimail::renameFolder insert new ITEM $folderName at $_parentFolder");
+						#$hasChildren = false;
+						#if ($folderStatus['attributes'][0]=="\\HasChildren") $hasChildren=true;
+					}
 					$response->addScript("tree.deleteItem('$_oldFolderName',0);");
 					$response->addScript("tree.insertNewItem('$_parentFolder','$newFolderName','$folderName',onNodeSelect,'folderClosed.gif',0,0,'CHILD,CHECKED,SELECT,CALL');");
 				}
 			}
 			return $response->getXML();
 		}
-		
+
 		function saveSessionData() 
 		{
-			$GLOBALS['egw']->session->appsession('ajax_session_data','',$this->sessionDataAjax);
-			$GLOBALS['egw']->session->appsession('session_data','',$this->sessionData);
+			$GLOBALS['egw']->session->appsession('ajax_session_data','felamimail',$this->sessionDataAjax);
+			$GLOBALS['egw']->session->appsession('session_data','felamimail',$this->sessionData);
 		}
 		
 		function saveSignature($_mode, $_id, $_description, $_signature, $_isDefaultSignature) 
 		{
-			$boPreferences = CreateObject('felamimail.bopreferences');
+			require_once(EGW_INCLUDE_ROOT.'/felamimail/inc/class.felamimail_bosignatures.inc.php');
+			
+			$boSignatures = new felamimail_bosignatures();
 			
 			$isDefaultSignature = ($_isDefaultSignature == 'true' ? true : false);
 				
-			$signatureID = $boPreferences->saveSignature($_id, $_description, $_signature, $isDefaultSignature);
-
+			$signatureID = $boSignatures->saveSignature($_id, $_description, $_signature, $isDefaultSignature);
+			
 			$response =& new xajaxResponse();
 
 			if($_mode == 'save') {
 				#$response->addAssign('signatureID', 'value', $signatureID);
-				#$response->addScript('window.close()');
+				$response->addScript("opener.fm_refreshSignatureTable()");
+				$response->addScript("document.getElementById('signatureDesc').focus();window.close();");
 			} else {
 				$response->addScript("opener.fm_refreshSignatureTable()");
 				$response->addAssign('signatureID', 'value', $signatureID);
@@ -729,25 +872,27 @@
 				
 			return $response->getXML();
 		}
+
+		function setComposeSignature($identity)
+		{
+			$boPreferences  =& CreateObject('felamimail.bopreferences');
+			$preferences =& $boPreferences->getPreferences();
+			$Identities = $preferences->getIdentity($identity);
+			//error_log(print_r($Identities->signature,true));
+
+			$response =& new xajaxResponse();
+			$response->addScript('setSignature('.$Identities->signature.');');
+			return $response->getXML();
+		}
 		
 		function searchAddress($_searchString) 
 		{
-			if (!is_object($GLOBALS['egw']->contacts)) {
-				$GLOBALS['egw']->contacts =& CreateObject('phpgwapi.contacts');
-			}
-			if (method_exists($GLOBALS['egw']->contacts,'search')) {	// 1.3+
-				$contacts = $GLOBALS['egw']->contacts->search(array(
-					'n_fn'       => $_searchString,
-					'email'      => $_searchString,
-					'email_home' => $_searchString,
-				),array('n_fn','email','email_home'),'n_fn','','%',false,'OR',array(0,20));
-			} else {	// < 1.3
-				$contacts = $GLOBALS['egw']->contacts->read(0,20,array(
-					'fn' => 1,
-					'email' => 1,
-					'email_home' => 1,
-				), $_searchString, 'tid=n', '', 'fn');
-			}
+			$contacts = $GLOBALS['egw']->contacts->search(array(
+				'n_fn'       => $_searchString,
+				'email'      => $_searchString,
+				'email_home' => $_searchString,
+			),array('n_fn','email','email_home'),'n_fn','','%',false,'OR',array(0,20));
+
 			$response =& new xajaxResponse();
 
 			if(is_array($contacts)) {
@@ -760,7 +905,7 @@
 						if(!empty($email) && !isset($jsArray[$email])) {
 							$i++;
 							$str = $GLOBALS['egw']->translation->convert(trim($contact['n_fn'] ? $contact['n_fn'] : $contact['fn']).' <'.trim($email).'>',$this->charset,'utf-8');
-							$innerHTML .= '<div class="inactiveResultRow" onclick="selectSuggestion($i)">'.
+							$innerHTML .= '<div class="inactiveResultRow" onmousedown="keypressed(13,1)" onmouseover="selectSuggestion('.($i-1).')">'.
 								htmlentities($str, ENT_QUOTES, 'utf-8').'</div>';
 							$jsArray[$email] = addslashes($str);
 						}
