@@ -10,7 +10,7 @@
 	* under the terms of the GNU General Public License as published by the     *
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
-	/* $Id: class.uicompose.inc.php 24782 2007-12-10 08:19:03Z leithoff $ */
+	/* $Id: class.uicompose.inc.php 26013 2008-09-25 09:30:59Z leithoff $ */
 
 	class uicompose
 	{
@@ -23,11 +23,12 @@
 			'getAttachment'		=> True,
 			'fileSelector'		=> True,
 			'forward'		=> True,
+			'composeAsNew'         => True,
 			'reply'			=> True,
 			'replyAll'		=> True,
 			'selectFolder'		=> True,
 		);
-		
+
 		var $destinations = array(
 			'to' 		=> 'to',
 			'cc'		=> 'cc',
@@ -53,19 +54,19 @@
 				else
 					$this->composeID = $_GET['composeid'];
 				$this->bocompose   =& CreateObject('felamimail.bocompose',$this->composeID,$this->displayCharset);
-			}			
+			}
 			$this->t 		=& CreateObject('phpgwapi.Template',EGW_APP_TPL);
 			$this->bofelamimail	=& CreateObject('felamimail.bofelamimail',$this->displayCharset);
 			$this->mailPreferences  = ExecMethod('felamimail.bopreferences.getPreferences');
 
 			$this->t->set_unknowns('remove');
-			
+
 			$this->rowColor[0] = $GLOBALS['egw_info']["theme"]["bg01"];
 			$this->rowColor[1] = $GLOBALS['egw_info']["theme"]["bg02"];
 
 
 		}
-		
+
 		function unhtmlentities ($string)
 		{
 			$trans_tbl = get_html_translation_table (HTML_ENTITIES);
@@ -89,23 +90,53 @@
 
 			$formData['subject'] 	= $this->bocompose->stripSlashes($_POST['subject']);
 			$formData['body'] 	= $this->bocompose->stripSlashes($_POST['body']);
+			// if the body is empty, maybe someone pasted something with scripts, into the message body
+			if(empty($formData['body']))
+			{
+				// this is to be found with the egw_unset_vars array for the _POST['body'] array
+				$name='_POST';
+				$key='body';
+				#error_log($GLOBALS['egw_unset_vars'][$name.'['.$key.']']);
+				if (isset($GLOBALS['egw_unset_vars'][$name.'['.$key.']']))
+				{
+					$formData['body'] = bocompose::_getCleanHTML( $GLOBALS['egw_unset_vars'][$name.'['.$key.']']);
+				}
+			}
 			$formData['priority'] 	= $this->bocompose->stripSlashes($_POST['priority']);
 			$formData['signatureID'] = (int)$_POST['signatureID'];
 			$formData['mimeType']	= $this->bocompose->stripSlashes($_POST['mimeType']);
 			$formData['disposition'] = (bool)$_POST['disposition'];
 			$formData['to_infolog'] = $_POST['to_infolog'];
 			//$formData['mailbox']	= $_GET['mailbox'];
-
+			if((bool)$_POST['printit'] == true) {
+				$formData['printit'] = 1; 
+				$formData['isDraft'] = 1;
+				// pint the composed message. therefore save it as draft and reopen it as plain printwindow
+				$formData['subject'] = "[".lang('printview').":]".$formData['subject'];
+				$messageUid = $this->bocompose->saveAsDraft($formData);
+				if (!$messageUid) {
+					 print "<script type=\"text/javascript\">alert('".lang("Error: Could not save Message as Draft")."');</script>";
+					return;
+				} 
+				$uidisplay   =& CreateObject('felamimail.uidisplay');
+				$uidisplay->printMessage($messageUid, $formData['printit']);
+				//$GLOBALS['egw']->link('/index.php',array('menuaction' => 'felamimail.uidisplay.printMessage','uid'=>$messageUid));
+				return;
+			}
 			if((bool)$_POST['saveAsDraft'] == true) {
+				$formData['isDraft'] = 1; 
 				// save as draft
-				$this->bocompose->saveAsDraft($formData);
+				$messageUid = $this->bocompose->saveAsDraft($formData);
+				if (!$messageUid) {
+					print "<script type=\"text/javascript\">alert('".lang("Error: Could not save Message as Draft")."');</script>";
+				}
 			} else {
 				if(!$this->bocompose->send($formData)) {
 					$this->compose();
 					return;
 				}
 			}
-					
+
 			#$GLOBALS['egw']->common->egw_exit();
 			print "<script type=\"text/javascript\">window.close();</script>";
 		}
@@ -115,28 +146,65 @@
 			// read the data from session
 			// all values are empty for a new compose window
 			$sessionData = $this->bocompose->getSessionData();
-			if (is_array($_GET['preset']))
+
+			if (is_array($_REQUEST['preset']))
 			{
-				if ($_GET['preset']['file'] && is_readable($_GET['preset']['file']))
+				#_debug_array($_REQUEST);
+				if ($_REQUEST['preset']['mailto']) {
+					// handle mailto strings such as
+					// mailto:larry,dan?cc=mike&bcc=sue&subject=test&body=type+your&body=message+here
+					// the above string may be htmlentyty encoded, then multiple body tags are supported
+					// first, strip the mailto: string out of the mailto URL
+					$tmp_send_to = trim(substr(html_entity_decode($_REQUEST['preset']['mailto']),7));
+					// check if there is more than the to address
+					$mailtoArray = explode('?',$tmp_send_to,2);
+					if ($mailtoArray[1]) {
+						// check if there are more than one requests
+						$addRequests = explode('&',$mailtoArray[1]);
+						foreach ($addRequests as $key => $reqval) {
+							// the additional requests should have a =, to separate key from value.
+							$keyValuePair = explode('=',$reqval,2);
+							$sessionData[$keyValuePair[0]] .= (strlen($sessionData[$keyValuePair[0]])>0 ? ' ':'') . $keyValuePair[1]; 
+						}
+					}
+					$sessionData['to']=$mailtoArray[0];
+					// if the mailto string is not htmlentity decoded the arguments are passed as simple requests
+					foreach(array('cc','bcc','subject','body') as $name) {
+						if ($_REQUEST[$name]) $sessionData[$name] .= (strlen($sessionData[$name])>0 ? ( $name == 'cc' || $name == 'bcc' ? ',' : ' ') : '') . $_REQUEST[$name];
+					}
+				}
+				if ($_REQUEST['preset']['file'] && is_readable($_REQUEST['preset']['file']))
 				{
-					$this->bocompose->addAttachment(array_merge($sessionData,$_GET['preset']));
+					$this->bocompose->addAttachment(array_merge($sessionData,$_REQUEST['preset']));
 					$sessionData = $this->bocompose->getSessionData();
 				}
 				foreach(array('to','cc','bcc','subject','body') as $name)
 				{
-					if ($_GET['preset'][$name]) $sessionData[$name] = $_GET['preset'][$name];
+					if ($_REQUEST['preset'][$name]) $sessionData[$name] = $_REQUEST['preset'][$name];
 				}
 			}
-			$preferences = ExecMethod('felamimail.bopreferences.getPreferences');
-			#_debug_array($preferences);
-			
+
 			// is the to address set already?
-			if (!empty($_GET['send_to']))
+			if (!empty($_REQUEST['send_to']))
 			{
-				$sessionData['to'] = base64_decode($_GET['send_to']);
+				$sessionData['to'] = base64_decode($_REQUEST['send_to']);
+			}
+			//is the MimeType set/requested
+			if (!empty($_REQUEST['mimeType'])) 
+			{
+				$sessionData['mimeType'] = $_REQUEST['mimeType'];
+			}
+			// is a certain signature requested?
+			// only the following values are supported (and make sense)
+			// no => means -2
+			// system => means -1
+			// default => fetches the default, which is standard behavior
+			if (!empty($_REQUEST['signature']) && (strtolower($_REQUEST['signature']) == 'no' || strtolower($_REQUEST['signature']) == 'system'))
+			{
+				$presetSig = (strtolower($_REQUEST['signature']) == 'no' ? -2 : -1);
 			}
 			$this->display_app_header();
-			
+
 			$this->t->set_file(array("composeForm" => "composeForm.tpl"));
 			$this->t->set_block('composeForm','header','header');
 			$this->t->set_block('composeForm','body_input');
@@ -145,12 +213,16 @@
 			$this->t->set_block('composeForm','attachment_row_bold');
 			$this->t->set_block('composeForm','destination_row');
 			$this->t->set_block('composeForm','simple_text');
-			
+
 			$this->translate();
-			
-			$this->t->set_var("link_addressbook",$GLOBALS['egw']->link('/index.php',array(
-				'menuaction' => 'addressbook.uicontacts.emailpopup',
-			)));
+
+			if ($GLOBALS['egw_info']['user']['apps']['addressbook']) {
+				$this->t->set_var("link_addressbook",$GLOBALS['egw']->link('/index.php',array(
+					'menuaction' => 'addressbook.addressbook_ui.emailpopup',
+				)));
+			} else {
+				$this->t->set_var("link_addressbook",'');
+			}
 			$this->t->set_var("focusElement",$_focusElement);
 
 			$linkData = array
@@ -184,31 +256,39 @@
 			{
 				$this->t->set_var('errorInfo','&nbsp;');
 			}
-			
+
 			// header
-			$allIdentities = $preferences->getIdentity();
+			$allIdentities = $this->mailPreferences->getIdentity();
 			#_debug_array($allIdentities);
 			$defaultIdentity = 0;
 			foreach($allIdentities as $key => $singleIdentity) {
+				#$identities[$singleIdentity->id] = $singleIdentity->realName.' <'.$singleIdentity->emailAddress.'>';
 				$identities[$key] = $singleIdentity->realName.' <'.$singleIdentity->emailAddress.'>';
-				if($singleIdentity->default)
+				if(!empty($singleIdentity->default)) {
+					#$defaultIdentity = $singleIdentity->id;
 					$defaultIdentity = $key;
+					$sessionData['signatureID'] = $singleIdentity->signature;
+				}
 			}
-			$selectFrom = $GLOBALS['egw']->html->select('identity', $defaultIdentity, $identities, true, "style='width:100%;'");			
+			$selectFrom = html::select('identity', $defaultIdentity, $identities, true, "style='width:100%;' onchange='changeIdentity(this);'");
 			$this->t->set_var('select_from', $selectFrom);
 
-			// from, to, cc, replyto
+			// navbar(, kind of)
 			$this->t->set_var('img_clear_left', $GLOBALS['egw']->common->image('felamimail','clear_left'));
 			$this->t->set_var('img_fileopen', $GLOBALS['egw']->common->image('phpgwapi','fileopen'));
 			$this->t->set_var('img_mail_send', $GLOBALS['egw']->common->image('felamimail','mail_send'));
 			$this->t->set_var('img_attach_file', $GLOBALS['egw']->common->image('felamimail','attach'));
 			$this->t->set_var('ajax-loader', $GLOBALS['egw']->common->image('felamimail','ajax-loader'));
 			$this->t->set_var('img_fileexport', $GLOBALS['egw']->common->image('felamimail','fileexport'));
-
+			// prepare print url/button
+			$this->t->set_var('img_print_it', $GLOBALS['egw']->common->image('felamimail','fileprint'));
+			$this->t->set_var('lang_print_it', lang('print it'));
+			$this->t->set_var('print_it', $printURL);
+			// from, to, cc, replyto
 			$destinationRows = 0;
-			foreach(array('to','cc','bcc','replyto') as $destination) {
+			foreach(array('to','cc','bcc','replyto','folder') as $destination) {
 				foreach((array)$sessionData[$destination] as $key => $value) {
-					$selectDestination = $GLOBALS['egw']->html->select('destination[]', $destination, $this->destinations, false, "style='width: 100%;' onchange='fm_compose_changeInputType(this)'");
+					$selectDestination = html::select('destination[]', $destination, $this->destinations, false, "style='width: 100%;' onchange='fm_compose_changeInputType(this)'");
 					$this->t->set_var('select_destination', $selectDestination);
 					$this->t->set_var('address', @htmlentities($value, ENT_QUOTES, $this->displayCharset));
 					$this->t->parse('destinationRows','destination_row',True);
@@ -217,73 +297,95 @@
 			}
 			while($destinationRows < 3) {
 				// and always add one empty row
-				$selectDestination = $GLOBALS['egw']->html->select('destination[]', 'to', $this->destinations, false, "style='width: 100%;' onchange='fm_compose_changeInputType(this)'");
+				$selectDestination = html::select('destination[]', 'to', $this->destinations, false, "style='width: 100%;' onchange='fm_compose_changeInputType(this)'");
 				$this->t->set_var('select_destination', $selectDestination);
 				$this->t->set_var('address', '');
 				$this->t->parse('destinationRows','destination_row',True);
 				$destinationRows++;
 			}
 			// and always add one empty row
-			$selectDestination = $GLOBALS['egw']->html->select('destination[]', 'to', $this->destinations, false, "style='width: 100%;' onchange='fm_compose_changeInputType(this)'");
+			$selectDestination = html::select('destination[]', 'to', $this->destinations, false, "style='width: 100%;' onchange='fm_compose_changeInputType(this)'");
 			$this->t->set_var('select_destination', $selectDestination);
 			$this->t->set_var('address', '');
 			$this->t->parse('destinationRows','destination_row',True);
 
 			$this->t->set_var("subject",@htmlentities($sessionData['subject'],ENT_QUOTES,$this->displayCharset));
-			$this->t->set_var('addressbookImage',$GLOBALS['egw']->common->image('phpgwapi/templates/phpgw_website','users'));
-			$this->t->set_var('infologImage',$GLOBALS['egw']->html->image('felamimail','to_infolog',lang('Save as infolog'),'width="17px" height="17px" valign="middle"' ));
-			$this->t->set_var('lang_save_as_infolog',lang('Save as infolog'));
+			if ($GLOBALS['egw_info']['user']['apps']['addressbook']) {
+				$this->t->set_var('addressbookButton','<button class="menuButton" type="button" onclick="addybook();" title="'.lang('addressbook').'">
+                    <img src="'.$GLOBALS['egw']->common->image('phpgwapi/templates/phpgw_website','users').'">
+                </button>');
+			} else {
+				$this->t->set_var('addressbookButton','');
+			}
+			if ($GLOBALS['egw_info']['user']['apps']['infolog']) {
+				$this->t->set_var('infologImage',html::image('felamimail','to_infolog',lang('Save as infolog'),'width="17px" height="17px" valign="middle"' ));
+				$this->t->set_var('lang_save_as_infolog',lang('Save as infolog'));
+				$this->t->set_var('infolog_checkbox','<input class="input_text" type="checkbox" id="to_infolog" name="to_infolog" />');
+			} else {
+				$this->t->set_var('infologImage','');
+				$this->t->set_var('lang_save_as_infolog','');
+				$this->t->set_var('infolog_checkbox','');
+			}
 			$this->t->set_var('lang_no_recipient',lang('No recipient address given!'));
 			$this->t->set_var('lang_no_subject',lang('No subject given!'));
 			$this->t->pparse("out","header");
 			
-
 			// body
 			if($sessionData['mimeType'] == 'html') {
+				$mode = 'simple';
+				#if (isset($GLOBALS['egw_info']['server']['enabled_spellcheck'])) $mode = 'egw_simple_spellcheck';
 				$style="border:0px; width:100%; height:400px;";
-			#	$this->t->set_var('tinymce', $GLOBALS['egw']->html->tinymceQuick('body', 'simple', $sessionData['body'], $style));
-				$cleanHTMLBody = $this->getCleanHTML($sessionData['body']);
-				$this->t->set_var('tinymce', $GLOBALS['egw']->html->fckEditorQuick('body', 'simple', $cleanHTMLBody));
+				$this->t->set_var('tinymce', html::fckEditorQuick('body', $mode, $sessionData['body']));
 				$this->t->set_var('mimeType', 'html');
+				$ishtml=1;
 			} else {
 				$style="border:0px; width:100%; height:400px;";
-			#	$this->t->set_var('tinymce', $GLOBALS['egw']->html->tinymceQuick('body', 'ascii', $sessionData['body'], $style));
-				$this->t->set_var('tinymce', $GLOBALS['egw']->html->fckEditorQuick('body', 'ascii', $sessionData['body']));
+				$this->t->set_var('tinymce', html::fckEditorQuick('body', 'ascii', $sessionData['body'],'400px','99%'));
 				$this->t->set_var('mimeType', 'text');
+				$ishtml=0;
 			}
-			
-			$signatures = ExecMethod('felamimail.bopreferences.getListOfSignatures');
 
+			require_once(EGW_INCLUDE_ROOT.'/felamimail/inc/class.felamimail_bosignatures.inc.php');
+			$boSignatures = new felamimail_bosignatures();
+			$signatures = $boSignatures->getListOfSignatures();
+			if (empty($sessionData['signatureID'])) {
+				if ($signatureData = $boSignatures->getDefaultSignature()) {
+					if (is_array($signatureData)) {
+						$sessionData['signatureID'] = $signatureData['signatureid'];
+					} else {
+						$sessionData['signatureID'] =$signatureData;
+					}
+				}
+			}
+	
 			$selectSignatures = array(
-				'-1' => lang('no signature')
+				'-2' => lang('no signature')
 			);
 			foreach($signatures as $signature) {
-				$selectSignatures[$signature['signatureid']] = $signature['description'];
+				$selectSignatures[$signature['fm_signatureid']] = $signature['fm_description'];
 			}
-			$selectBox = $GLOBALS['egw']->html->select('signatureID', $sessionData['signatureID'], $selectSignatures, true, "style='width: 100%;' onchange='fm_compose_changeInputType(this)'");
+			$selectBox = html::select('signatureID', ($presetSig ? $presetSig : $sessionData['signatureID']), $selectSignatures, true, "style='width: 70%;' onchange='fm_compose_changeInputType(this)'");
 			$this->t->set_var("select_signature", $selectBox);
+			$this->t->set_var("lang_editormode",lang("Editor type"));
+			$this->t->set_var("toggle_editormode", lang("Editor type").":&nbsp;<span><input name=\"_is_html\" value=\"".$ishtml."\" type=\"hidden\" /><input name=\"_editorselect\" onchange=\"fm_toggle_editor(this)\" ".($ishtml ? "checked=\"checked\"" : "")." id=\"_html\" value=\"html\" type=\"radio\"><label for=\"_html\">HTML</label><input name=\"_editorselect\" onchange=\"fm_toggle_editor(this)\" ".($ishtml ? "" : "checked=\"checked\"")." id=\"_plain\" value=\"plain\" type=\"radio\"><label for=\"_plain\">Plain text</label></span>");
 			$this->t->pparse("out","body_input");
 
 			// attachments
 			if (is_array($sessionData['attachments']) && count($sessionData['attachments']) > 0)
 			{
 				$imgClearLeft	=  $GLOBALS['egw']->common->image('felamimail','clear_left');
-	
 				foreach((array)$sessionData['attachments'] as $id => $attachment) {
 					$tempArray = array (
 						'1' => $attachment['name'],
 						'2' => $attachment['type'], '.2' => "style='text-align:center;'",
 						'3' => $attachment['size'],
-						'4' => "<img src='$imgClearLeft' onclick=\"fm_compose_deleteAttachmentRow(this,'$_composeID','$id')\">"
+						'4' => "<img src='$imgClearLeft' onclick=\"fm_compose_deleteAttachmentRow(this,'".$this->composeID."','$id')\">"
 					);
 					$tableRows[] = $tempArray;
 				}
-				
+
 				if(count($tableRows) > 0) {
-					if(!is_object($GLOBALS['egw']->html)) {
-						$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
-					}
-					$table = $GLOBALS['egw']->html->table($tableRows, "style='width:100%'");
+					$table = html::table($tableRows, "style='width:100%'");
 				}
 				$this->t->set_var('attachment_rows',$table);
 			}
@@ -291,7 +393,7 @@
 			{
 				$this->t->set_var('attachment_rows','');
 			}
-			
+
 			$this->t->pparse("out","attachment");
 		}
 
@@ -306,21 +408,17 @@
 			}
 			$this->compose('body');
 		}
-		
+
 
 		function display_app_header()
 		{
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('jscode','composeMessage','felamimail');
 			$GLOBALS['egw']->js->set_onload('javascript:initAll();');
 			$GLOBALS['egw_info']['flags']['include_xajax'] = True;
-			
+
 			$GLOBALS['egw']->common->egw_header();
 		}
-		
+
 		function fileSelector()
 		{
 			if(is_array($_FILES["addFileName"])) {
@@ -337,21 +435,21 @@
 					print "<script type='text/javascript'>document.getElementById('fileSelectorDIV1').style.display = 'inline';document.getElementById('fileSelectorDIV2').style.display = 'none';</script>";
 				}
 			}
-			
+
 			if(!@is_object($GLOBALS['egw']->js))
 			{
 				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
 			}
 			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
-			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');                        
+			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');
 			$GLOBALS['egw']->js->validate_file('jscode','composeMessage','felamimail');
 			$GLOBALS['egw']->common->egw_header();
 
 			#$uiwidgets		=& CreateObject('felamimail.uiwidgets');
-			
+
 			$this->t->set_file(array("composeForm" => "composeForm.tpl"));
 			$this->t->set_block('composeForm','fileSelector','fileSelector');
-			
+
 			$this->translate();
 
 			$linkData = array
@@ -384,113 +482,26 @@
 		}
 
 		function getAttachment()
-		{	
-			$bocompose  =& CreateObject('felamimail.bocompose', $_GET['_composeID']);			
+		{
+			$bocompose  =& CreateObject('felamimail.bocompose', $_GET['_composeID']);
 			$attachment =  $bocompose->sessionData['attachments'][$_GET['attID']] ;
 			header ("Content-Type: ".$attachment['type']."; name=\"". $this->bofelamimail->decode_header($attachment['name']) ."\"");
 			header ("Content-Disposition: inline; filename=\"". $this->bofelamimail->decode_header($attachment['name']) ."\"");
 			header("Expires: 0");
 			header("Cache-Control: must-revalidate, post-check=0, pre-check=0");
-			header("Pragma: public"); 
+			header("Pragma: public");
 			$fp = fopen($attachment['file'], 'rb');
 			fpassthru($fp);
 			$GLOBALS['egw']->common->egw_exit();
 			exit;
-																			
+
 		}
 
-		function getCleanHTML($_body)
-		{
-			$nonDisplayAbleCharacters = array('[\016]','[\017]',
-					'[\020]','[\021]','[\022]','[\023]','[\024]','[\025]','[\026]','[\027]',
-					'[\030]','[\031]','[\032]','[\033]','[\034]','[\035]','[\036]','[\037]');
 
-			$kses =& CreateObject('phpgwapi.kses');
-			$kses->AddHTML('p', array(
-					'align'	=> array('minlen' =>   1, 'maxlen' =>  10)
-				)
-			);
-			$kses->AddHTML('div', array(
-					'align'	=> array('minlen' =>   1, 'maxlen' =>  10)
-				)
-			);
-			$kses->AddHTML('br');
-			$kses->AddHTML('b');
-			$kses->AddHTML('center');
-			$kses->AddHTML('em');
-			$kses->AddHTML('font', array(
-					'color'	=> array('minlen' =>   1, 'maxlen' =>  10)
-				)
-			);
-			$kses->AddHTML('i');
-			$kses->AddHTML("s");
-			$kses->AddHTML('strike');
-			$kses->AddHTML('strong');
-			$kses->AddHTML('u');
-			$kses->AddHTML('hr', array(
-					"class"		=> array('maxlen' => 20),
-					"style"		=> array('minlen' => 1),
-				)
-			);
-			$kses->AddHTML("ul");
-			$kses->AddHTML('ol', array(
-					"type"	=> array('maxlen' => 20)
-				)
-			);
-			$kses->AddHTML("li");
-			$kses->AddHTML("h1");
-			$kses->AddHTML("h2");
-			$kses->AddHTML('a', array(
-					"href" 		=> array('maxlen' => 145, 'minlen' => 10),
-					"name" 		=> array('minlen' => 2),
-					'target'	=> array('maxlen' => 10)
-				)
-			);
-			$kses->AddHTML('pre', array(
-					"wrap" => array('maxlen' => 10)
-				)
-			);
-			
-			$kses->AddHTML(
-				"blockquote",array(
-					"class"	=> array("minlen" =>   1, 'maxlen' =>  20),
-					"style"	=> array("minlen" =>   1),
-					"cite"	=> array('maxlen' => 30),
-					"type"	=> array('maxlen' => 10),
-					"dir"	=> array("minlen" =>   1, 'maxlen' =>  10)
-				)
-			);
-			// strip comments out of the message completely
-			if ($_body) {
-				$begin_comment=stripos($_body,'<!--');
-				while ($begin_comment!==FALSE) {
-					//since there is a begin tag there should be an end tag, starting somewhere at least 4 chars further down
-					$end_comment=stripos($_body,'-->',$begin_comment+4);
-					if ($end_comment !== FALSE) {
-						$_body=substr($_body,0,$begin_comment-1).substr($_body,$end_comment+3);
-					} else {
-						//somehow there is a begin tag of a comment but no end tag. throw it away
-						$_body=str_replace('<!--','',$_body);
-					}
-					$begin_comment=stripos($_body,'<!--');
-					if (strlen($_body)<$begin_comment) break;
-				}
-			}
-			$body	= $kses->Parse($_body);
-
-			$body	= preg_replace($nonDisplayAbleCharacters, '', $body);
-			
-			return $body;
-		}
-		
 		function selectFolder()
 		{
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
-			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');                        
+			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');
 			$GLOBALS['egw']->js->validate_file('jscode','composeMessage','felamimail');
 			$GLOBALS['egw']->common->egw_header();
 
@@ -514,6 +525,18 @@
 			print $folderTree;
 		}
 
+		function composeAsNew() {
+			$icServer = (int)$_GET['icServer'];
+			$folder = base64_decode($_GET['folder']);
+			$replyID = $_GET['reply_id'];
+			$partID  = $_GET['part_id'];
+			if (!empty($folder) && !empty($replyID) ) {
+				// this fill the session data with the values from the original email
+				$this->bocompose->getDraftData($icServer, $folder, $replyID, $partID);
+			}
+			$this->compose('body');
+		}
+
 		function reply() {
 			$icServer = (int)$_GET['icServer'];
 			$folder = base64_decode($_GET['folder']);
@@ -525,7 +548,7 @@
 			}
 			$this->compose('body');
 		}
-		
+
 		function replyAll() {
 			$icServer = (int)$_GET['icServer'];
 			$folder = base64_decode($_GET['folder']);
@@ -537,7 +560,7 @@
 			}
 			$this->compose('body');
 		}
-		
+
 		function translate() {
 			$this->t->set_var("lang_message_list",lang('Message List'));
 			$this->t->set_var("lang_to",lang('to'));
@@ -564,12 +587,13 @@
 			$this->t->set_var('lang_adding_file_please_wait',lang('Adding file to message. Please wait!'));
 			$this->t->set_var('lang_receive_notification',lang('Receive notification'));
 			$this->t->set_var('lang_no_address_set',lang('can not send message. no recipient defined!'));
-			
+
 			$this->t->set_var("th_bg",$GLOBALS['egw_info']["theme"]["th_bg"]);
 			$this->t->set_var("bg01",$GLOBALS['egw_info']["theme"]["bg01"]);
 			$this->t->set_var("bg02",$GLOBALS['egw_info']["theme"]["bg02"]);
 			$this->t->set_var("bg03",$GLOBALS['egw_info']["theme"]["bg03"]);
 		}
+
 }
 
 ?>
