@@ -10,7 +10,7 @@
 	* under the terms of the GNU General Public License as published by the     *
 	* Free Software Foundation; version 2 of the License.                       *
 	\***************************************************************************/
-	/* $Id: class.uifelamimail.inc.php 23375 2007-02-02 07:18:33Z lkneschke $ */
+	/* $Id: class.uifelamimail.inc.php 26405 2008-11-19 12:06:39Z leithoff $ */
 
 	class uifelamimail
 	{
@@ -21,6 +21,7 @@
 			'changeFolder'		=> True,
 			'changeSorting'		=> True,
 			'compressFolder'	=> True,
+			'importMessage'		=> True,
 			'deleteMessage'		=> True,
 			'handleButtons'		=> True,
 			'hookAdmin'		=> True,
@@ -37,6 +38,7 @@
 		
 		// the object storing the data about the incoming imap server
 		var $icServerID=0;
+		var $connectionStatus = false;
 		
 		function uifelamimail()
 		{
@@ -156,13 +158,151 @@
 		} */
 
 
+		function importMessage()
+		{
+			if(is_array($_FILES["addFileName"])) {
+				#phpinfo();
+				#error_log(print_r($_FILES,true));
+				if($_FILES['addFileName']['error'] == $UPLOAD_ERR_OK) {
+					$formData['name']	= $_FILES['addFileName']['name'];
+					$formData['type']	= $_FILES['addFileName']['type'];
+					$formData['file']	= $_FILES['addFileName']['tmp_name'];
+					$formData['size']	= $_FILES['addFileName']['size'];
+					$message = $this->importMessageToFolder($formData);
+					print "<script type='text/javascript'>window.close();</script>";
+					if (!$message) {
+						print "<script type=\"text/javascript\">alert('".lang("Error: ").lang("Could not import Message:").htmlentities($formData['name'])."');</script>";
+						return;
+					} else {
+						$linkData = array(
+							'menuaction'	=> 'felamimail.uidisplay.display',
+							'uid'		=> $message['uid'],
+							'mailbox'    => base64_encode($message['folder']),
+						);
+						print "<script type=\"text/javascript\">opener.fm_readMessage('".$GLOBALS['egw']->link('/index.php',$linkData)."', 'displayMessage_".$message['uid']."', this);</script>";
+						return;
+					}
+				}
+			}
+			if(!@is_object($GLOBALS['egw']->js))
+			{
+				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
+			}
+			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
+			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');
+			$GLOBALS['egw']->js->validate_file('jscode','importMessage','felamimail');
+			$GLOBALS['egw']->common->egw_header();
+
+			#$uiwidgets		=& CreateObject('felamimail.uiwidgets');
+
+			$this->t->set_file(array("importMessage" => "importMessage.tpl"));
+			$this->t->set_block('importMessage','fileSelector','fileSelector');
+
+			$this->translate();
+
+			$linkData = array
+			(
+				'menuaction'	=> 'felamimail.uifelamimail.importMessage',
+			);
+			$this->t->set_var('file_selector_url', $GLOBALS['egw']->link('/index.php',$linkData));
+
+			$maxUploadSize = ini_get('upload_max_filesize');
+			$this->t->set_var('max_uploadsize', $maxUploadSize);
+
+			$this->t->set_var('ajax-loader', $GLOBALS['egw']->common->image('felamimail','ajax-loader'));
+
+			$this->t->pparse("out","fileSelector");
+		}
+
+		function importMessageToFolder($_formData,$_folder='')
+		{
+			if ($_formData['size'] != 0 && (is_uploaded_file($_formData['file']) || 
+				realpath(dirname($_formData['file'])) == realpath($GLOBALS['egw_info']['server']['temp_dir'])))
+			{
+				// ensure existance of eGW temp dir
+				// note: this is different from apache temp dir, 
+				// and different from any other temp file location set in php.ini
+				if (!file_exists($GLOBALS['egw_info']['server']['temp_dir']))
+				{
+					@mkdir($GLOBALS['egw_info']['server']['temp_dir'],0700);
+				}
+				
+				// if we were NOT able to create this temp directory, then make an ERROR report
+				if (!file_exists($GLOBALS['egw_info']['server']['temp_dir']))
+				{
+					$alert_msg .= 'Error:'.'<br>'
+						.'Server is unable to access phpgw tmp directory'.'<br>'
+						.$GLOBALS['egw_info']['server']['temp_dir'].'<br>'
+						.'Please check your configuration'.'<br>'
+						.'<br>';
+				}
+				
+				// sometimes PHP is very clue-less about MIME types, and gives NO file_type
+				// rfc default for unknown MIME type is:
+				$mime_type_default = 'message/rfc';
+				// so if PHP did not pass any file_type info, then substitute the rfc default value
+				if (substr(strtolower(trim($_formData['type'])),0,strlen($mime_type_default)) != $mime_type_default)
+				{
+					// fail silently
+					error_log("Message rejected, no message/rfc. Is:".$_formData['type']);
+					return false;
+				}
+				
+				$tmpFileName = $GLOBALS['egw_info']['server']['temp_dir'].
+					SEP.
+					$GLOBALS['egw_info']['user']['account_id'].
+					basename($_formData['file']);
+				
+				if (is_uploaded_file($_formData['file']))
+				{
+					move_uploaded_file($_formData['file'],$tmpFileName);	// requirement for safe_mode!
+				}
+				else
+				{
+					rename($_formData['file'],$tmpFileName);
+				}
+			} else {
+				// fail silently
+				error_log("Import of message ".$_formData['file']." failes to meet basic restrictions");
+				return false;
+			}
+			// -----------------------------------------------------------------------
+			#error_log(print_r($this->preferences->preferences['draftFolder'],true));
+			$fhandle = fopen($tmpFileName, "r");
+			$headercomplete = false;
+			$header = "";
+			$body = "";
+			while (!feof($fhandle)) {
+    			$buffer = fgets($fhandle, 4096);
+				if ($headercomplete === false && $buffer == "\r\n") {
+					$headercomplete = true;
+					continue;
+				}
+				if ($headercomplete == false) $header.=$buffer;
+				if ($headercomplete == true) $body.=$buffer;
+				#error_log($buffer);
+			}
+			fclose ($fhandle);
+			if ($_folder == '') $savingDestination = $this->preferences->preferences['draftFolder'];
+			if (empty($savingDestination) || $savingDestination == '') $savingDestination = $this->mailbox;
+			$message['folder'] = $savingDestination;
+			#error_log($header."\n".$body);
+			$message['uid'] = $this->bofelamimail->appendMessage($savingDestination,$header,$body,NULL);
+			error_log(print_r($message,true));
+			unlink($tmpFileName);
+			if (!$message['uid']) $message = false;
+			return $message;
+		}
+
 		function deleteMessage()
 		{
 			$preferences		= ExecMethod('felamimail.bopreferences.getPreferences');
 
 			$message[] = $_GET["message"];
-			
-			$this->bofelamimail->deleteMessages($message);
+			$mailfolder = NULL;
+			if (!empty($_GET['folder'])) $mailfolder  = base64_decode($_GET['folder']);
+	
+			$this->bofelamimail->deleteMessages($message,$mailfolder);
 
 			// set the url to open when refreshing
 			$linkData = array
@@ -178,12 +318,6 @@
 		
 		function display_app_header()
 		{
-			if(!@is_object($GLOBALS['egw']->js)) {
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
-			if(!@is_object($GLOBALS['egw']->html)) {
-				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
-			}
 			#$GLOBALS['egw']->js->validate_file('foldertree','foldertree');
 			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
 			$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');
@@ -255,7 +389,7 @@
 				$this->bofelamimail->setEMailProfile($profileID);
 			}
 			
-			$boemailadmin =& CreateObject('emailadmin.bo');
+			$boemailadmin = new emailadmin_bo();
 			
 			$profileList = $boemailadmin->getProfileList();
 			$profileID = $this->bofelamimail->getEMailProfile();
@@ -279,7 +413,7 @@
 			
 			$linkData = array
 			(
-				'menuaction'	=> 'emailadmin.ui.listProfiles'
+				'menuaction'	=> 'emailadmin.emailadmin_ui.listProfiles'
 			);
 			$this->t->set_var('lang_go_emailadmin', lang('use <a href="%1">EmailAdmin</a> to create profiles', $GLOBALS['egw']->link('/index.php',$linkData)));
 			
@@ -321,10 +455,28 @@
 			$urlMailbox		=  urlencode($this->mailbox);
 
 			$imapServer =& $preferences->getIncomingServer(0);
-
+			#_debug_array($imapServer);
+			$activeIdentity =& $preferences->getIdentity(0);
+			#_debug_array($activeIdentity);
 			$maxMessages		=&  $GLOBALS['egw_info']['user']['preferences']['common']['maxmatchs'];
+			if (empty($maxMessages)) $maxMessages = 23; // this seems to be the number off messages that fit the height of the folder tree
 			$userPreferences	=&  $GLOBALS['egw_info']['user']['preferences']['felamimail'];
-			
+			// retrieve data for/from user defined accounts
+			$selectedID = 0;
+			if($this->preferences->userDefinedAccounts) $allAccountData = $this->bopreferences->getAllAccountData($this->preferences);
+			if ($allAccountData) {
+				foreach ($allAccountData as $tmpkey => $accountData)
+				{
+					$identity =& $accountData['identity'];
+					$icServer =& $accountData['icServer'];
+					//_debug_array($identity);
+					//_debug_array($icServer);
+					if (empty($icServer->host)) continue;
+					$identities[$identity->id]=$identity->realName.' '.$identity->organization.' <'.$identity->emailAddress.'>';
+					if (!empty($identity->default)) $selectedID = $identity->id;
+				}
+			}
+
 			$this->display_app_header();
 
 			$this->t->set_file(array("body" => 'mainscreen.tpl'));
@@ -338,11 +490,36 @@
 			$this->t->set_block('body','subject_new_window');
 
 			$this->translate();
+			if (empty($imapServer->host) && count($identities)==0) {
+				$errormessage = "<br>".lang("There is no IMAP Server configured.");
+				if ($GLOBALS['egw_info']['user']['apps']['emailadmin']) {
+					$errormessage .= "<br>".lang("Configure a valid IMAP Server in emailadmin for the profile you are using.");
+				} else {
+					$errormessage .= "<br>".lang('Please ask the administrator to correct the emailadmin IMAP Server Settings for you.');
+				}
+				if($this->preferences->userDefinedAccounts)
+						$errormessage .= "<br>".lang('or configure an valid IMAP Server connection using the Manage Accounts/Identities preference in the Sidebox Menu.');
+		
+				$this->t->set_var('connection_error_message', $errormessage);
+				$this->t->set_var('message', '&nbsp;');
+				$this->t->parse('header_rows','error_message',True);
+
+				$this->t->parse("out","main");
+				print $this->t->get('out','main');
+
+				$GLOBALS['egw']->common->egw_footer();
+				exit;
+			}
 			
 			$this->t->set_var('oldMailbox',$urlMailbox);
 			$this->t->set_var('image_path',EGW_IMAGES);
 			#printf ("this->uifelamimail->viewMainScreen() Line 272: %s<br>",date("H:i:s",mktime()));
-
+			$linkData = array
+			(
+				'menuaction'    => 'felamimail.uifelamimail.viewMainScreen'
+			);
+			$refreshURL = $GLOBALS['egw']->link('/index.php',$linkData);
+			$this->t->set_var('reloadView',$refreshURL);
 			// display a warning if vacation notice is active
 			if(is_a($imapServer,'defaultimap') && $imapServer->enableSieve) {
 				$this->bosieve		=& CreateObject('felamimail.bosieve',$imapServer);
@@ -352,7 +529,7 @@
 			if(is_array($vacation) && $vacation['status'] == 'on')
 			{
 				$this->t->set_var('vacation_warning',
-					$GLOBALS['egw']->html->image('phpgwapi','dialog_warning',false,'style="vertical-align: middle; width: 16px;"').lang('Vacation notice is active'));
+					html::image('phpgwapi','dialog_warning',false,'style="vertical-align: middle; width: 16px;"').lang('Vacation notice is active'));
 			}
 			else
 			{
@@ -376,7 +553,7 @@
 			$linkData = array (
 				'menuaction'    => 'felamimail.uicompose.compose'
 			);
-			$urlCompose = "egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','compose', 700, 750);";
+			$urlCompose = "egw_openWindowCentered('".$GLOBALS['egw']->link('/index.php',$linkData)."','compose', 700, egw_getWindowOuterHeight());";
 
 			$navbarImages = array(
 				'new'			=> array(
@@ -457,11 +634,13 @@
 			foreach ($listOfImages as $image) {
 				$this->t->set_var($image, $GLOBALS['egw']->common->image('felamimail', $image));
 			}
-			$this->t->set_var('img_clear_left', $GLOBALS['egw']->html->image('felamimail', 'clear_left', lang('clear search'), 'style="margin-left:5px; cursor: pointer;" onclick="fm_clearSearch()"'));
+			$this->t->set_var('img_clear_left', html::image('felamimail', 'clear_left', lang('clear search'), 'style="margin-left:5px; cursor: pointer;" onclick="fm_clearSearch()"'));
 			// refresh settings
 			$refreshTime = $userPreferences['refreshTime'];
 			$this->t->set_var('refreshTime',$refreshTime*60*1000);
-			
+			// other settings
+			$prefaskformove = intval($userPreferences['prefaskformove']) ? intval($userPreferences['prefaskformove']) : 0;
+			$this->t->set_var('prefaskformove',$prefaskformove);	
 			#// set the url to open when refreshing
 			#$linkData = array
 			#(
@@ -529,7 +708,7 @@
 				'to'		=> 'to',
 				'cc'		=> 'cc',
 			);
-			$selectSearchType = $GLOBALS['egw']->html->select('searchType', $defaultSearchType, $searchTypes, false, "style='width:100%;' id='searchType' onchange='document.getElementById(\"quickSearch\").focus(); document.getElementById(\"quickSearch\").value=\"\" ;return false;'");
+			$selectSearchType = html::select('searchType', $defaultSearchType, $searchTypes, false, "style='width:100%;' id='searchType' onchange='document.getElementById(\"quickSearch\").focus(); document.getElementById(\"quickSearch\").value=\"\" ;return false;'");
 			$this->t->set_var('select_search', $selectSearchType);
 			
 			$statusTypes = array(
@@ -540,9 +719,31 @@
 				'seen'		=> 'read',
 				'deleted'	=> 'deleted',
 			);
-			$selectStatus = $GLOBALS['egw']->html->select('status', $defaultSelectStatus, $statusTypes, false, "style='width:100%;' onchange='javascript:quickSearch();' id='status'");
+			$selectStatus = html::select('status', $defaultSelectStatus, $statusTypes, false, "style='width:100%;' onchange='javascript:quickSearch();' id='status'");
 			$this->t->set_var('select_status', $selectStatus);
 
+			// the data needed here are collected at the start of this function
+			if (!isset($activeIdentity->id) && $selectedID == 0) {
+				$identities[0] = $activeIdentity->realName.' '.$activeIdentity->organization.' <'.$activeIdentity->emailAddress.'>';
+			}
+			// if you use user defined accounts you may want to access the profile defined with the emailadmin available to the user
+			if ($activeIdentity->id) {
+				$boemailadmin = new emailadmin_bo();
+				$defaultProfile = $boemailadmin->getUserProfile() ;
+				#_debug_array($defaultProfile);
+				$identitys =& $defaultProfile->identities;
+				$icServers =& $defaultProfile->ic_server;
+				foreach ($identitys as $tmpkey => $identity)
+				{
+					if (empty($icServers[$tmpkey]->host)) continue;
+					$identities[0] = $identity->realName.' '.$identity->organization.' <'.$identity->emailAddress.'>';
+				}
+				#$identities[0] = $defaultIdentity->realName.' '.$defaultIdentity->organization.' <'.$defaultIdentity->emailAddress.'>';
+			}
+			$selectAccount = html::select('accountSelect', $selectedID, $identities, true, "style='width:100%;' onchange='changeActiveAccount(this);'");
+			$this->t->set_var('accountSelect', $selectAccount);
+
+
 			if($this->connectionStatus === false) {
 				$this->t->set_var('connection_error_message', lang($this->bofelamimail->getErrorMessage()));
 				$this->t->set_var('message', '&nbsp;');
@@ -560,17 +761,28 @@
 					$headerCount = count($headers['header']);
 				}
 				
-				if ($userPreferences['sentFolder'] == $this->mailbox || $userPreferences['draftFolder'] == $this->mailbox) {
+				if ($this->bofelamimail->isSentFolder($this->mailbox) 
+					|| $this->bofelamimail->isDraftFolder($this->mailbox) 
+					|| $this->bofelamimail->isTemplateFolder($this->mailbox)) {
 					$this->t->set_var('lang_from',lang("to"));
 				} else {
 					$this->t->set_var('lang_from',lang("from"));
 				}
 				$msg_icon_sm = $GLOBALS['egw']->common->image('felamimail','msg_icon_sm');
-
+				// determine how to display the current folder: as sent folder (to address visible) or normal (from address visible) 
+				$sentFolderFlag =$this->bofelamimail->isSentFolder($this->mailbox);
+				if(false !== in_array($this->mailbox,explode(',',$GLOBALS['egw_info']['user']['preferences']['felamimail']['messages_showassent_0']))) {
+					$sentFolderFlag=1;
+					#_debug_array($GLOBALS['egw_info']['user']['preferences']['felamimail']);
+				}
+				$folderType = ($sentFolderFlag
+                            || $this->bofelamimail->isDraftFolder( $this->mailbox)
+                            || $this->bofelamimail->isTemplateFolder($this->mailbox));	
 				$this->t->set_var('header_rows',
 					$uiwidgets->messageTable(
 						$headers,
-						($userPreferences['sentFolder'] == $this->mailbox || $userPreferences['draftFolder'] == $this->mailbox),
+						$folderType,
+						$this->mailbox,
 						$userPreferences['message_newwindow'],
 						$userPreferences['rowOrderStyle']
 					)
@@ -807,11 +1019,13 @@
 			$this->t->set_var('lang_connection_failed',lang("The connection to the IMAP Server failed!!"));
 			$this->t->set_var('lang_select_target_folder',lang("Simply click the target-folder"));
 			$this->t->set_var('lang_updating_message_status',lang("updating message status"));
+			$this->t->set_var('lang_max_uploadsize',lang('max uploadsize'));
 			$this->t->set_var('lang_loading',lang('loading'));
 			$this->t->set_var('lang_deleting_messages',lang('deleting messages'));
 			$this->t->set_var('lang_open_all',lang("open all"));
 			$this->t->set_var('lang_close_all',lang("close all"));
 			$this->t->set_var('lang_moving_messages_to',lang('moving messages to'));
+			$this->t->set_var('lang_askformove',lang('Do you really want to move the selected messages to folder:'));
 			$this->t->set_var('lang_empty_trash',lang('empty trash'));
 			$this->t->set_var('lang_compress_folder',lang('compress folder'));
 			$this->t->set_var('lang_skipping_forward',lang('skipping forward'));
