@@ -12,7 +12,9 @@
 	* option) any later version.                                                *
 	\***************************************************************************/
 
-	/* $Id: class.uipreferences.inc.php 23423 2007-02-15 09:44:40Z lkneschke $ */
+	/* $Id: class.uipreferences.inc.php 26401 2008-11-18 11:24:44Z leithoff $ */
+
+	require_once(EGW_INCLUDE_ROOT.'/felamimail/inc/class.felamimail_bosignatures.inc.php');
 
 	class uipreferences
 	{
@@ -25,8 +27,10 @@
 			'editSignature'		=> 'True',
 			'listFolder'		=> 'True',
 			'listSignatures'	=> 'True',
+			'listAccountData'	=> 'True',
 			'showHeader'		=> 'True',
-			'getAttachment'		=> 'True'
+			'getAttachment'		=> 'True',
+			'listSelectFolder'	=> 'True',
 		);
 
 		function uipreferences()
@@ -61,20 +65,18 @@
 		// $_displayNavbar false == don't display navbar
 		function display_app_header($_displayNavbar)
 		{
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
-			
 			switch($_GET['menuaction'])
 			{
 				case 'felamimail.uipreferences.editSignature':
 					$GLOBALS['egw']->js->validate_file('jscode','listSignatures','felamimail');
 					#$GLOBALS['egw']->js->set_onload('fm_initEditLayout();');
 					break;
+				case 'felamimail.uipreferences.listAccountData':
 				case 'felamimail.uipreferences.editAccountData':
+					$GLOBALS['egw']->js->validate_file('tabs','tabs');
 					$GLOBALS['egw']->js->validate_file('jscode','editAccountData','felamimail');
 					$GLOBALS['egw']->js->set_onload('javascript:initEditAccountData();');
+					$GLOBALS['egw']->js->set_onload('javascript:initTabs();');
 					break;
 
 				case 'felamimail.uipreferences.listSignatures':
@@ -84,6 +86,7 @@
 
 				case 'felamimail.uipreferences.listFolder':
 				case 'felamimail.uipreferences.addACL':
+				case 'felamimail.uipreferences.listSelectFolder':
 					$GLOBALS['egw']->js->validate_file('tabs','tabs');
 					$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXCommon');
 					$GLOBALS['egw']->js->validate_file('dhtmlxtree','js/dhtmlXTree');
@@ -101,8 +104,8 @@
 		
 		function editForwardingAddress()
 		{
-			$bofelamimail	=& CreateObject('felamimail.bofelamimail',$GLOBALS['egw']->translation->charset());
-			$mailPrefs	= $bofelamimail->getMailPreferences();
+			if (!isset($this->bofelamimail)) $this->bofelamimail	=& CreateObject('felamimail.bofelamimail',$GLOBALS['egw']->translation->charset());
+			$mailPrefs	= $this->bofelamimail->getMailPreferences();
 			$ogServer	= $mailPrefs->getOutgoingServer(0);
 			
 			if(!is_a($ogServer, 'defaultsmtp') || !$ogServer->editForwardingAddress) {
@@ -143,12 +146,13 @@
 		}
 		
 		function editSignature() {
-			$signatureID = (int)$_GET['signatureID'];
-			
-			if($signatureID >= 0) {
-				$signatureData = $this->bopreferences->getSignature($signatureID);
+			if(isset($_GET['signatureID'])) {
+				$signatureID = (int)$_GET['signatureID'];
+		
+				$boSignatures = new felamimail_bosignatures();
+				$signatureData = $boSignatures->getSignature($signatureID);
 			}
-
+			
 			$this->display_app_header(false);
 			
 			$this->t->set_file(array('body' => 'preferences_edit_signature.tpl'));
@@ -156,30 +160,38 @@
 
 			$this->translate();
 
-			$linkData = array
-			(
+			$linkData = array (
 				'menuaction'    => 'felamimail.uipreferences.editSignature'
 			);
-			$this->t->set_var('form_action',$GLOBALS['egw']->link('/index.php',$linkData));
+			$this->t->set_var('form_action', $GLOBALS['egw']->link('/index.php',$linkData));
 
-			$this->t->set_var('description', ($signatureID >= 0 ? @htmlspecialchars($signatureData['description'], ENT_QUOTES, $this->charset) : ''));
+			if(isset($_GET['signatureID'])) {
+
+				$this->t->set_var('description', @htmlspecialchars($signatureData->fm_description, ENT_QUOTES, $this->charset));
 			
-			$this->t->set_var('signatureID', $signatureID);
+				$this->t->set_var('signatureID', $signatureID);
 
-			$style="width:100%; border:0px; height:150px;";
-			$this->t->set_var('tinymce',$GLOBALS['egw']->html->fckEditorQuick(
-				'signature', 'simple', 
-				($signatureID >= 0 ? $signatureData['signature'] : ''), 
-				'150px')
-			);
+				$this->t->set_var('tinymce',html::fckEditorQuick(
+					'signature', 'simple', 
+					$signatureData->fm_signature, 
+					'150px')
+				);
 
-			$this->t->set_var('checkbox_isDefaultSignature',$GLOBALS['egw']->html->checkbox(
-				'isDefaultSignature',
-				$signatureData['defaultsignature'],
-				'true',
-				'id="isDefaultSignature"'
-				)
-			);
+				$this->t->set_var('checkbox_isDefaultSignature',html::checkbox(
+					'isDefaultSignature',
+					$signatureData->fm_defaultsignature,
+					'true',
+					'id="isDefaultSignature"'
+					)
+				);
+			} else {
+				$this->t->set_var('tinymce',html::fckEditorQuick('signature', 'simple', '', '150px'));
+
+				$this->t->set_var('checkbox_isDefaultSignature',html::checkbox(
+					'isDefaultSignature', false, 'true', 'id="isDefaultSignature"'
+				));
+
+			}
 
 			$this->t->parse("out","main");
 			print $this->t->get('out','main');
@@ -187,10 +199,10 @@
 		
 		function editAccountData()
 		{
-			$boPreferences	=& CreateObject('felamimail.bopreferences');
-			$preferences =& $boPreferences->getPreferences();
+			if (!isset($this->bopreferences)) $this->bopreferences	=& CreateObject('felamimail.bopreferences');
+			$preferences =& $this->bopreferences->getPreferences();
 			
-			if(!$preferences->userDefinedAccounts) {
+			if(!($preferences->userDefinedAccounts || $preferences->userDefinedIdentities)) {
 				die('you are not allowed to be here');
 			}
 
@@ -213,14 +225,17 @@
 								break;
 						}
 					}
+				} else {
+					$icServer = NULL;
 				}
-				
 				// SMTP connection settings
 				$ogServer =& CreateObject('emailadmin.defaultsmtp');
 				if(is_array($_POST['og'])) {
 					foreach($_POST['og'] as $key => $value) {
 						$ogServer->$key = $value;
 					}
+				} else {
+					$ogServer = NULL;
 				}
 
 				// identity settings
@@ -230,12 +245,16 @@
 						$identity->$key = $value;
 					}
 				}
+				
 
+				$newID = $this->bopreferences->saveAccountData($icServer, $ogServer, $identity);
+				if ($identity->id == 'new') $identity->id = $newID;
 				if((int)$_POST['active']) {
-					$boPreferences->saveAccountData($icServer, $ogServer, $identity);
-					$boPreferences->setProfileActive(true);
+					#$boPreferences->saveAccountData($icServer, $ogServer, $identity);
+					$this->bopreferences->setProfileActive(false);
+					$this->bopreferences->setProfileActive(true,$identity->id);
 				} else {
-					$boPreferences->setProfileActive(false);
+					$this->bopreferences->setProfileActive(false,$identity->id);
 				}
 				
 				if($_POST['save']) {
@@ -247,6 +266,17 @@
 				return;
 			}
 
+			$folderList = array();
+			if (!isset($this->bofelamimail) || (int)$_POST['active']) $this->bofelamimail =& CreateObject('felamimail.bofelamimail',$GLOBALS['egw']->translation->charset());
+			if($this->bofelamimail->openConnection()) {
+				$folderObjects = $this->bofelamimail->getFolderObjects();
+				foreach($folderObjects as $folderName => $folderInfo) {
+					#_debug_array($folderData);
+					$folderList[$folderName] = $folderInfo->displayName;
+				}
+				$this->bofelamimail->closeConnection();
+			}
+
 			$this->display_app_header(TRUE);
 			
 			$this->t->set_file(array("body" => "edit_account_data.tpl"));
@@ -254,59 +284,108 @@
 
 			$this->translate();
 
-			$accountData	= $boPreferences->getAccountData($preferences);
-			$icServer =& $accountData['icServer'];
-			$ogServer =& $accountData['ogServer'];
-			$identity =& $accountData['identity'];
-			#_debug_array($icServer);
-			foreach($icServer as $key => $value) {
-				if(is_object($value) || is_array($value)) {
-					continue;
-				}
-				switch($key) {
-					case 'encryption':
-						$this->t->set_var('checked_ic_'. $key .'_'. $value, 'checked');
-						break;
+			// if there is no accountID with the call of the edit method, retrieve an active account
+			$account2retrieve = 'active';
+			if ((int)$_GET['accountID']) {
+				$account2retrieve = $_GET['accountID'];
+			}
+			if ($_GET['accountID'] == 'new') $account2retrieve = 'new';
+			if (!empty($newID) && $newID>0) $account2retrieve = $newID;
+			if ($account2retrieve != 'new') {
+				$accountData	= $this->bopreferences->getAccountData($preferences, $account2retrieve);
+				$icServer =& $accountData['icServer'];
+				#_debug_array($icServer);
+				$ogServer =& $accountData['ogServer'];
+				$identity =& $accountData['identity'];
+				#_debug_array($identity);
+			}
+
+			if ($icServer) {
+				foreach($icServer as $key => $value) {
+					if(is_object($value) || is_array($value)) {
+						continue;
+					}
+					switch($key) {
+						case 'encryption':
+							$this->t->set_var('checked_ic_'. $key .'_'. $value, 'checked');
+							break;
 						
-					case 'enableSieve':
-						$this->t->set_var('checked_ic_'.$key,($value ? 'checked' : ''));
-						break;
+						case 'enableSieve':
+							$this->t->set_var('checked_ic_'.$key,($value ? 'checked' : ''));
+							break;
 
-					case 'validatecert':
-						$this->t->set_var('checked_ic_'.$key,($value ? '' : 'checked'));
-						break;
+						case 'validatecert':
+							$this->t->set_var('checked_ic_'.$key,($value ? '' : 'checked'));
+							break;
 						
-					default:
-						$this->t->set_var("ic[$key]", $value);
-						break;
+						default:
+							$this->t->set_var("ic[$key]", $value);
+							break;
+					}
 				}
 			}
-
-			foreach($ogServer as $key => $value) {
-				if(is_object($value) || is_array($value)) {
-					continue;
-				}
-				#print "$key => $value<bR>";
-				switch($key) {
-					case 'smtpAuth':
-						$this->t->set_var('checked_og_'.$key,($value ? 'checked' : ''));
-					default:
-						$this->t->set_var("og[$key]", $value);
+			if ($ogServer) {
+				foreach($ogServer as $key => $value) {
+					if(is_object($value) || is_array($value)) {
+						continue;
+					}
+					#print "$key => $value<bR>";
+					switch($key) {
+						case 'smtpAuth':
+							$this->t->set_var('checked_og_'.$key,($value ? 'checked' : ''));
+						default:
+							$this->t->set_var("og[$key]", $value);
+					}
 				}
 			}
-
-			foreach($identity as $key => $value) {
-				if(is_object($value) || is_array($value)) {
-					continue;
+			$felamimail_bosignatures = new felamimail_bosignatures();
+			$signatures = $felamimail_bosignatures->getListOfSignatures();
+			$allSignatures = array(
+				'-2' => lang('no signature')
+			);
+			foreach ($signatures as $sigkey => $sig) {
+				$allSignatures[$sig['fm_signatureid']] = $sig['fm_description'];
+			}
+			$sigvalue = -2;
+			if ($identity) {
+				foreach($identity as $key => $value) {
+					if(is_object($value) || is_array($value)) {
+						continue;
+					}
+					switch($key) {
+						case 'signature':
+							$sigvalue = $value;
+							break;
+						default:
+							$this->t->set_var("identity[$key]", $value);
+					}
 				}
-				switch($key) {
-					default:
-						$this->t->set_var("identity[$key]", $value);
+ 				$this->t->set_var('accountID',$identity->id); 
+				$this->t->set_var('checked_active',($accountData['active'] ? ($preferences->userDefinedAccounts ? 'checked' : '') : ''));
+			} else {
+				if ($signatureData = $felamimail_bosignatures->getDefaultSignature()) {
+					if (is_array($signatureData)) {
+						$sigvalue = $signatureData['signatureid'];
+					} else {
+						$sigvalue =$signatureData;
+					}
 				}
+				$this->t->set_var('accountID','new');
 			}
 
-			$this->t->set_var('checked_active',($accountData['active'] ? 'checked' : ''));
-			
+			$trashOptions = array_merge(array('' => lang('default').' '.lang("folder settings"), 'none' => lang("Don't use Trash")),($accountData['active'] ? $folderList :array($icServer->trashfolder => $icServer->trashfolder)));
+			$sentOptions = array_merge(array('' => lang('default').' '.lang("folder settings"), 'none' => lang("Don't use Sent")),($accountData['active'] ? $folderList :array($icServer->sentfolder => $icServer->sentfolder)));
+			$draftOptions = array_merge(array('' => lang('default').' '.lang("folder settings"), 'none' => lang("Don't use draft folder")),($accountData['active'] ? $folderList :array($icServer->draftfolder => $icServer->draftfolder)));
+			$templateOptions = array_merge(array('' => lang('default').' '.lang("folder settings"), 'none' => lang("Don't use template folder")),($accountData['active'] ? $folderList :array($icServer->templatefolder => $icServer->templatefolder)));
+			$folderList = array_merge( array('' => lang('default').' '.lang("folder settings")),($accountData['active'] ? $folderList :$icServer->folderstoshowinhome));
+
+			$this->t->set_var('allowAccounts',($preferences->userDefinedAccounts ? 1 : 0));
+			$this->t->set_var('identity_selectbox', html::select('identity[signature]',$sigvalue,$allSignatures, true, "style='width: 250px;'"));
+			$this->t->set_var('folder_selectbox', html::select('ic[folderstoshowinhome]',$icServer->folderstoshowinhome,$folderList, true, "style='width: 250px;'",6));
+			$this->t->set_var('trash_selectbox', html::select('ic[trashfolder]',$icServer->trashfolder,$trashOptions, true, "style='width: 250px;'"));
+			$this->t->set_var('sent_selectbox', html::select('ic[sentfolder]',$icServer->sentfolder,$sentOptions, true, "style='width: 250px;'"));
+			$this->t->set_var('draft_selectbox', html::select('ic[draftfolder]',$icServer->draftfolder,$draftOptions, true, "style='width: 250px;'"));
+			$this->t->set_var('template_selectbox', html::select('ic[templatefolder]',$icServer->templatefolder,$templateOptions, true, "style='width: 250px;'"));
 			$linkData = array
 			(
 				'menuaction'    => 'felamimail.uipreferences.editAccountData'
@@ -319,6 +398,11 @@
 		
 		function listFolder()
 		{
+			if (!isset($this->bopreferences)) $this->bopreferences  =& CreateObject('felamimail.bopreferences');
+			$preferences =& $this->bopreferences->getPreferences();
+			if(!(empty($preferences->preferences['prefpreventmanagefolders']) || $preferences->preferences['prefpreventmanagefolders'] == 0)) {
+				die('you are not allowed to be here');
+			}
 			// rename a mailbox
 			if(isset($_POST['newMailboxName']))
 			{
@@ -413,22 +497,12 @@
 				'menuaction'    => 'felamimail.uipreferences.addACL'
 			);
 			$this->t->set_var('url_addACL',$GLOBALS['egw']->link('/index.php',$linkData));
-			
-			// create the link to show folder settings
-			#$linkData = array
-			#(
-			#	'menuaction'    => 'felamimail.uipreferences.listFolder',
-			#	'display'	=> 'settings'
-			#);
-			#$this->t->set_var('settings_url',$GLOBALS['egw']->link('/index.php',$linkData));
-			
-			// create the link to show folder acl
-			#$linkData = array
-			#(
-			#	'menuaction'    => 'felamimail.uipreferences.listFolder',
-			#	'display'	=> 'acl'
-			#);
-			#$this->t->set_var('acl_url',$GLOBALS['egw']->link('/index.php',$linkData));
+
+			$linkData = array
+			(
+					'menuaction'    => 'felamimail.uipreferences.listSelectFolder',
+			);
+			$this->t->set_var('folder_select_url',$GLOBALS['egw']->link('/index.php',$linkData));
 			
 			// folder select box
 			$icServer = $mailPrefs->getIncomingServer(0);
@@ -530,24 +604,105 @@
 
 			$linkData = array
 			(
-				'menuaction'    => 'felamimail.uipreferences.editSignature',
-				'signatureID'	=> '-1'
+				'menuaction'    => 'felamimail.uipreferences.editSignature'
 			);
 			$this->t->set_var('url_addSignature', $GLOBALS['egw']->link('/index.php',$linkData));
 			
 			$this->t->set_var('url_image_add',$GLOBALS['egw']->common->image('phpgwapi','new'));
 			$this->t->set_var('url_image_delete',$GLOBALS['egw']->common->image('phpgwapi','delete'));
 			
-			$signatures = $this->bopreferences->getListOfSignatures();
-			
+			$felamimail_bosignatures = new felamimail_bosignatures();
+			$signatures = $felamimail_bosignatures->getListOfSignatures();
+
 			$this->t->set_var('table', $this->uiwidgets->createSignatureTable($signatures));
 			
 			$this->t->pparse("out","main");			
 			$this->bofelamimail->closeConnection();
 		}
+
+		function listAccountData()
+		{
+			$this->display_app_header(TRUE);
+			if (!isset($this->bopreferences)) $this->bopreferences  =& CreateObject('felamimail.bopreferences');
+			$preferences =& $this->bopreferences->getPreferences();
+			$allAccountData    = $this->bopreferences->getAllAccountData($preferences);
+			if ($allAccountData) {
+				foreach ($allAccountData as $tmpkey => $accountData)
+				{
+					$identity =& $accountData['identity'];
+
+					#_debug_array($identity);
+			
+					foreach($identity as $key => $value) {
+						if(is_object($value) || is_array($value)) {
+							continue;
+						}
+						switch($key) {
+							default:
+								$tempvar[$key] = $value;
+						}
+					}
+					$accountArray[]=$tempvar;
+				}
+			}
+			$this->t->set_file(array("body" => "preferences_list_accounts.tpl"));
+			$this->t->set_block('body','main');
+
+			$this->translate();
+			
+			#print "<pre>";print_r($folderList);print "</pre>";
+			// set the default values for the sort links (sort by subject)
+			#$linkData = array
+			#(
+			#	'menuaction'    => 'felamimail.uipreferences.listFolder'
+			#);
+			#$this->t->set_var('form_action', $GLOBALS['egw']->link('/index.php',$linkData));
+
+			$linkData = array
+			(
+				'menuaction'    => 'felamimail.uipreferences.editAccountData',
+				'accountID'		=> 'new'
+			);
+			$this->t->set_var('url_addAccount', $GLOBALS['egw']->link('/index.php',$linkData));
+			
+			$this->t->set_var('url_image_add',$GLOBALS['egw']->common->image('phpgwapi','new'));
+			$this->t->set_var('url_image_delete',$GLOBALS['egw']->common->image('phpgwapi','delete'));
+			
+			$this->t->set_var('table', $this->uiwidgets->createAccountDataTable($accountArray));
+			
+			$this->t->pparse("out","main");			
+			$this->bofelamimail->closeConnection();
+		}
+
+		function listSelectFolder()
+		{
+			$this->display_app_header(False);
+			if (!isset($this->bofelamimail)) $this->bofelamimail    =& CreateObject('felamimail.bofelamimail',$GLOBALS['egw']->translation->charset());
+			if (!isset($this->uiwidgets)) $this->uiwidgets          =& CreateObject('felamimail.uiwidgets');
+			$this->bofelamimail->openConnection();
+			$mailPrefs  = $this->bofelamimail->getMailPreferences();
+			$icServer = $mailPrefs->getIncomingServer(0);
+			$folderObjects = $this->bofelamimail->getFolderObjects(false);
+			$folderTree = $this->uiwidgets->createHTMLFolder
+				(
+					$folderObjects,
+					'INBOX',
+					0,
+					lang('IMAP Server'),
+					$icServer->username.'@'.$icServer->host,
+					'divFolderTree',
+					false,
+					true
+				);
+			print '<script type="text/javascript">function onNodeSelect(_folderName){opener.document.getElementById("newMailboxMoveName").value = _folderName + "' . $this->bofelamimail->getHierarchyDelimiter() . '" + opener.document.getElementById("newMailboxName").value;self.close();}</script>';
+			print '<div id="divFolderTree" style="overflow:auto; width:375px; height:474px; margin-bottom: 0px;padding-left: 0px; padding-top:0px; z-index:100; border : 1px solid Silver;"></div>';
+			print $folderTree;
+		}
+
 		
 		function translate()
 		{
+			$this->t->set_var('lang_signature',lang('Signatur'));
 			$this->t->set_var("lang_folder_name",lang('folder name'));
 			$this->t->set_var("lang_folder_list",lang('folderlist'));
 			$this->t->set_var("lang_select",lang('select'));
@@ -561,6 +716,7 @@
 			$this->t->set_var("lang_create_subfolder",lang('create subfolder'));
 			$this->t->set_var("lang_delete_folder",lang('delete folder'));
 			$this->t->set_var("lang_confirm_delete",addslashes(lang("Do you really want to delete the '%1' folder?",$this->bofelamimail->sessionData['preferences']['mailbox'])));
+			$this->t->set_var("lang_really_delete_accountsettings",lang("Do you really want to delete the selected Accountsettings and the assosiated Identity."));
 			$this->t->set_var("lang_delete",lang('delete'));
 			$this->t->set_var("lang_imap_server",lang('IMAP Server'));
 			$this->t->set_var("lang_folder_settings",lang('folder settings'));
@@ -571,6 +727,8 @@
 			$this->t->set_var("lang_posting",lang('posting'));
 			$this->t->set_var("lang_none",lang('none'));
 			$this->t->set_var("lang_rename",lang('rename'));
+			$this->t->set_var("lang_move",lang('move'));
+			$this->t->set_var("lang_move_folder",lang('move folder'));
 			$this->t->set_var("lang_create",lang('create'));
 			$this->t->set_var('lang_open_all',lang("open all"));
 			$this->t->set_var('lang_close_all',lang("close all"));
@@ -590,6 +748,7 @@
 			$this->t->set_var('lang_port',lang('port'));
 			$this->t->set_var('lang_apply',lang('apply'));
 			$this->t->set_var('lang_use_costum_settings',lang('use custom settings'));
+			$this->t->set_var('lang_use_custom_ids',lang('use custom identities'));
 			$this->t->set_var('lang_identity',lang('identity'));
 			$this->t->set_var('lang_name',lang('name'));
 			$this->t->set_var('lang_organization',lang('organization'));
@@ -606,7 +765,11 @@
 			$this->t->set_var('lang_no_encryption',lang('no encryption'));
 			$this->t->set_var('lang_default_signature',lang('default signature'));
 			$this->t->set_var('lang_server_supports_sieve',lang('server supports mailfilter(sieve)'));
-			
+			$this->t->set_var('lang_sent_folder', lang('sent folder'));
+			$this->t->set_var('lang_trash_folder', lang('trash folder'));
+			$this->t->set_var('lang_draft_folder', lang('draft folder'));
+			$this->t->set_var('lang_template_folder', lang('template folder'));
+			$this->t->set_var('lang_folder_to_appear_on_main_screen', lang('if shown, which folders should appear on main screen'));
 			$this->t->set_var("th_bg",$GLOBALS['egw_info']["theme"]["th_bg"]);
 			$this->t->set_var("bg01",$GLOBALS['egw_info']["theme"]["bg01"]);
 			$this->t->set_var("bg02",$GLOBALS['egw_info']["theme"]["bg02"]);
