@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: tables_update.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
+	/* $Id: tables_update.inc.php 25959 2008-09-02 12:59:35Z leithoff $ */
 
 	$test[] = '0.8.2';
 	function felamimail_upgrade0_8_2()
@@ -379,11 +379,40 @@
 	$test[] = '1.3.003';
 	function felamimail_upgrade1_3_003()
 	{
-		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_ic_encryption',array(
-			'type' => 'int',
-			'precision' => '4',
-			'nullable' => False
-		));
+		#$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_ic_encryption',array(
+		#	'type' => 'int',
+		#	'precision' => '4',
+		#	'nullable' => False
+		#));
+
+		$GLOBALS['egw_setup']->oProc->RefreshTable('egw_felamimail_accounts',array(
+ 			'fd' => array(
+					'fm_owner' => array('type' => 'int','precision' => '4','nullable' => False),
+					'fm_id' => array('type' => 'auto'),
+					'fm_realname' => array('type' => 'varchar','precision' => '128'),
+					'fm_organization' => array('type' => 'varchar','precision' => '128'),
+					'fm_emailaddress' => array('type' => 'varchar','precision' => '128','nullable' => False),
+					'fm_ic_hostname' => array('type' => 'varchar','precision' => '128','nullable' => False),
+					'fm_ic_port' => array('type' => 'int','precision' => '4','nullable' => False),
+					'fm_ic_username' => array('type' => 'varchar','precision' => '128','nullable' => False),
+					'fm_ic_password' => array('type' => 'varchar','precision' => '128'),
+					'fm_ic_encryption' => array('type' => 'int','precision' => '4'),
+					'fm_og_hostname' => array('type' => 'varchar','precision' => '128','nullable' => False),
+					'fm_og_port' => array('type' => 'int','precision' => '4','nullable' => False),
+					'fm_og_smtpauth' => array('type' => 'bool','nullable' => False),
+					'fm_og_username' => array('type' => 'varchar','precision' => '128'),
+					'fm_og_password' => array('type' => 'varchar','precision' => '128'),
+					'fm_active' => array('type' => 'bool','nullable' => False),
+					'fm_ic_validatecertificate' => array('type' => 'bool','nullable' => False),
+				),
+			'pk' => array('fm_id'),
+			'fk' => array(),
+			'ix' => array('fm_owner'),
+			'uc' => array()
+			), array(
+				'fm_ic_encryption' => "CASE WHEN fm_ic_encryption THEN 1 ELSE 0 END",
+			)
+		);
 
 		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.3.004';
 	}
@@ -425,4 +454,84 @@
 	{
 		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.4';
 	}
+
+    $test[] = '1.4';
+    function felamimail_upgrade1_4()
+    {
+		$GLOBALS['egw_setup']->oProc->DropTable('egw_felamimail_cache');
+		$GLOBALS['egw_setup']->oProc->DropTable('egw_felamimail_displayfilter');
+		$GLOBALS['egw_setup']->oProc->DropTable('egw_felamimail_folderstatus');
+        $GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_signatureid',array(
+            'type' => 'int',
+            'precision' => '4'
+        ));
+ 
+        return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.5.001';
+    }
+
+    $test[] = '1.5.001';
+    function felamimail_upgrade1_5_001()
+    {
+
+        $GLOBALS['egw_setup']->oProc->CreateTable('egw_felamimail_displayfilter',
+            Array(
+                'fd' => array(
+                    'fmail_filter_accountid'     => array('type' => 'int', 'precision' => 4, 'nullable' => false),
+                    'fmail_filter_data'    => array('type' => 'text')
+                ),
+                'pk' => array('fmail_filter_accountid'),
+                'fk' => array(),
+                'ix' => array(),
+                'uc' => array()
+            )
+		);
+        return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.5.002';
+    }
+
+	$test[] = '1.5.002';
+	function felamimail_upgrade1_5_002()
+	{
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_ic_encryption',array(
+			'type' => 'int',
+			'precision' => '4',
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_ic_hostname',array(
+			'type' => 'varchar',
+			'precision' => '128',
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_ic_port',array(
+			'type' => 'int',
+			'precision' => '4',
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_ic_username',array(
+			'type' => 'varchar',
+			'precision' => '128',
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_ic_validatecertificate',array(
+			'type' => 'bool',
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_og_hostname',array(
+			'type' => 'varchar',
+			'precision' => '128',
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_og_port',array(
+			'type' => 'int',
+			'precision' => '4',
+		));
+		$GLOBALS['egw_setup']->oProc->AlterColumn('egw_felamimail_accounts','fm_og_smtpauth',array(
+			'type' => 'bool',
+		)); 
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.5.003';
+	}
+
+	$test[] = '1.5.003';
+	function felamimail_upgrade1_5_003()
+	{
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_ic_folderstoshowinhome',  array('type' => 'text'));
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_ic_sentfolder', array('type' => 'varchar','precision' => '128'));
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_ic_trashfolder',  array('type' => 'varchar','precision' => '128'));
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_ic_draftfolder',  array('type' => 'varchar','precision' => '128'));
+		$GLOBALS['egw_setup']->oProc->AddColumn('egw_felamimail_accounts','fm_ic_templatefolder',  array('type' => 'varchar','precision' => '128'));
+		return $GLOBALS['setup_info']['felamimail']['currentver'] = '1.6.001';
+	}
 ?>
