@@ -6,9 +6,14 @@
  * @package importexport
  * @link http://www.egroupware.org
  * @author Cornelius Weiss <nelius@cwtech.de>
- * @version $Id: default_records.inc.php 24164 2007-06-21 22:02:08Z nelius_weiss $
+ * @version $Id: default_records.inc.php 26211 2008-10-14 08:42:09Z ralfbecker $
  */
 
+if (!extension_loaded('dom'))
+{
+	echo "<p>Required PHP DOM extension missing, installation of ImportExport definitions aborted.</p>\n";
+	return;	// otherwise we mess up the whole eGroupware install process
+}
 require_once(EGW_INCLUDE_ROOT. '/importexport/inc/class.bodefinitions.inc.php');
 
 // This sets up $GLOBALS['egw']->accounts and $GLOBALS['egw']->db
@@ -30,6 +35,6 @@ while (false !== ($appdir = $egwdir->read())) {
 			$file = $defdir. '/'. $entry;
 			list( $filename, $extension) = explode('.',$entry);
 			if ( $extension != 'xml' ) continue;
-			bodefinitions::import( $file );			
+			bodefinitions::import( $file );
 		}
 }
