@@ -6,18 +6,18 @@
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package infolog
  * @subpackage setup
- * @copyright (c) 2003-6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2003-8 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
- * @version $Id: setup.inc.php 24159 2007-06-21 18:49:57Z ralfbecker $
+ * @version $Id: setup.inc.php 26257 2008-10-22 06:15:37Z ralfbecker $
  */
 
 $setup_info['infolog']['name']      = 'infolog';
-$setup_info['infolog']['version']   = '1.4';
+$setup_info['infolog']['version']   = '1.6';
 $setup_info['infolog']['app_order'] = 5;
 $setup_info['infolog']['tables']    = array('egw_infolog','egw_infolog_extra');
 $setup_info['infolog']['enable']    = 1;
 
-$setup_info['infolog']['author'] = 
+$setup_info['infolog']['author'] =
 $setup_info['infolog']['maintainer'] = array(
 	'name'  => 'Ralf Becker',
 	'email' => 'ralfbecker@outdoor-training.de'
@@ -34,41 +34,38 @@ $setup_info['infolog']['description'] =
 	The entries may be viewed or added from InfoLog direct or from within
 	the contact/address, project or calendar view.</p>
 	<p>Other documents / files can be linked to InfoLog entries and are store in the VFS
-	(eGroupWare\'s virtual file system). An extension of the VFS allows to symlink
-	the files to a fileserver, instead of placeing a copy in the VFS
-	(<i>need to be configured in the admin-section</i>).
-	It is planed to include emails and faxes into InfoLog in the future.</p>';
+	(eGroupWare\'s virtual file system).</p>';
 $setup_info['infolog']['note'] =
 	'<p>There is a <b>CSV import filter</b> (in the admin-section) to import existing data.
 	It allows to interactivly assign fields, customize the values with regular
-	expressions and direct calls to php-functions (e.g. to link the phone calls 
+	expressions and direct calls to php-functions (e.g. to link the phone calls
 	(again) to the addressbook entrys).</p>
 	<p><b>More information</b> about InfoLog and the current development-status can be found on the
 	<a href="http://www.egroupware.org/wiki/infolog" target="_blank">InfoLog page on our Website</a>.</p>';
 
 /* The hooks this app includes, needed for hooks registration */
-$setup_info['infolog']['hooks']['preferences'] = 'infolog.admin_prefs_sidebox_hooks.all_hooks';
-$setup_info['infolog']['hooks'][] = 'settings';
-$setup_info['infolog']['hooks']['verify_settings'] = 'infolog.admin_prefs_sidebox_hooks.verify_settings';
-$setup_info['infolog']['hooks']['admin'] = 'infolog.admin_prefs_sidebox_hooks.all_hooks';
-$setup_info['infolog']['hooks'][] = 'deleteaccount';
+$setup_info['infolog']['hooks']['preferences'] = 'infolog_hooks::all_hooks';
+$setup_info['infolog']['hooks']['settings'] = 'infolog_hooks::settings';
+$setup_info['infolog']['hooks']['verify_settings'] = 'infolog_hooks::verify_settings';
+$setup_info['infolog']['hooks']['admin'] = 'infolog_hooks::all_hooks';
+$setup_info['infolog']['hooks']['deleteaccount'] = 'infolog.infolog_so.change_delete_owner';
 $setup_info['infolog']['hooks'][] = 'home';
-$setup_info['infolog']['hooks']['addressbook_view'] = 'infolog.uiinfolog.hook_view';
-$setup_info['infolog']['hooks']['projects_view']    = 'infolog.uiinfolog.hook_view';
-$setup_info['infolog']['hooks']['calendar_view']    = 'infolog.uiinfolog.hook_view';
-$setup_info['infolog']['hooks']['infolog']          = 'infolog.uiinfolog.hook_view';
-$setup_info['infolog']['hooks']['calendar_include_events'] = 'infolog.boinfolog.cal_to_include';
-$setup_info['infolog']['hooks']['calendar_include_todos']  = 'infolog.boinfolog.cal_to_include';
-$setup_info['infolog']['hooks']['sidebox_menu'] = 'infolog.admin_prefs_sidebox_hooks.all_hooks';
-$setup_info['infolog']['hooks']['search_link'] = 'infolog.infolog_link_registry.search_link';
-$setup_info['infolog']['hooks']['pm_custom_app_icons'] = 'infolog.boinfolog.pm_icons';
+$setup_info['infolog']['hooks']['addressbook_view'] = 'infolog.infolog_ui.hook_view';
+$setup_info['infolog']['hooks']['projects_view']    = 'infolog.infolog_ui.hook_view';
+$setup_info['infolog']['hooks']['calendar_view']    = 'infolog.infolog_ui.hook_view';
+$setup_info['infolog']['hooks']['infolog']          = 'infolog.infolog_ui.hook_view';
+$setup_info['infolog']['hooks']['calendar_include_events'] = 'infolog.infolog_bo.cal_to_include';
+$setup_info['infolog']['hooks']['calendar_include_todos']  = 'infolog.infolog_bo.cal_to_include';
+$setup_info['infolog']['hooks']['sidebox_menu'] = 'infolog_hooks::all_hooks';
+$setup_info['infolog']['hooks']['search_link'] = 'infolog_hooks::search_link';
+$setup_info['infolog']['hooks']['pm_custom_app_icons'] = 'infolog.infolog_bo.pm_icons';
 
 /* Dependencies for this app to work */
 $setup_info['infolog']['depends'][] = array(
 	'appname' => 'phpgwapi',
-	'versions' => Array('1.3','1.4','1.5')
+	'versions' => Array('1.5','1.6','1.7')
 );
 $setup_info['infolog']['depends'][] = array(
 	'appname' => 'etemplate',
-	'versions' => Array('1.3','1.4','1.5')
+	'versions' => Array('1.5','1.6','1.7')
 );
