@@ -12,7 +12,7 @@
 	* http://www.goldenglair.com                                               *
 	\**************************************************************************/
 
-	/* $Id: hook_settings.inc.php 23594 2007-04-14 17:00:39Z ralfbecker $ */
+	/* $Id: hook_settings.inc.php 24628 2007-11-08 06:33:50Z ralfbecker $ */
 
 	$show_entries = array(
 		0 => lang('No'),
@@ -44,6 +44,15 @@
 			'xmlrpc'  => True,
 			'admin'   => False
 		),
+		'homeShowCats' => array(
+			'type'   => 'multiselect',
+			'label'  => 'Categories to displayed on main page?',
+			'name'   => 'homeShowCats',
+			'values' => ExecMethod('news_admin.bonews.rights2cats',EGW_ACL_READ),
+			'help'   => 'Which news categories should be displayed on the main screen.',
+			'xmlrpc' => True,
+			'admin'  => False		
+		),
 		'rtfEditorFeatures' => array(
 			'type'   => 'select',
 			'label'  => 'Features of the editor?',
