@@ -6,7 +6,8 @@
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package news_admin
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
- * @version $Id: index.php 22385 2006-08-31 10:17:32Z ralfbecker $ 
+ * @version $Id: index.php 25898 2008-08-14 13:53:17Z ralfbecker $
  */
 
-header('Location: ../index.php?menuaction=news_admin.uinews.index');
+header('Location: ../index.php?menuaction=news_admin.uinews.index'.
+	(isset($_GET['sessionid']) ? '&sessionid='.$_GET['sessionid'].'&kp3='.$_GET['kp3'] : ''));
