@@ -1,18 +1,18 @@
 <?php
 /**
  * eGroupWare - News admin
- * 
- * @link http://www.egroupware.org 
+ *
+ * @link http://www.egroupware.org
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @package news_admin
  * @subpackage setup
- * @version $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $
+ * @version $Id: setup.inc.php 26141 2008-10-10 11:44:47Z ralfbecker $
  */
 
 /* Basic information about this app */
 $setup_info['news_admin']['name']      = 'news_admin';
 $setup_info['news_admin']['title']     = 'News Admin';
-$setup_info['news_admin']['version']   = '1.4';
+$setup_info['news_admin']['version']   = '1.6';
 $setup_info['news_admin']['app_order'] = 16;
 $setup_info['news_admin']['enable']    = 1;
 
@@ -34,5 +34,16 @@ $setup_info['news_admin']['hooks'][] = 'config_validate';
 /* Dependencies for this app to work */
 $setup_info['news_admin']['depends'][] = array(
 	 'appname' => 'phpgwapi',
-	 'versions' => Array('1.3','1.4','1.5')
+	 'versions' => Array('1.4','1.5','1.6','1.7')
 );
+
+// installation checks for news_admin (PEAR)
+$setup_info['news_admin']['check_install'] = array(
+	'' => array(
+		'func' => 'pear_check',
+	),
+	'XML_Feed_Parser' => array(
+		'func' => 'pear_check',
+	),
+);
+
