@@ -12,10 +12,10 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: index.php 17773 2005-02-14 16:56:48Z alpeb $ */
+	/* $Id: index.php 24581 2007-10-21 05:50:59Z jgordor $ */
 
-	$phpgw_info = array();
-	$GLOBALS['phpgw_info']['flags'] = array(
+	$egw_info = array();
+	$GLOBALS['egw_info']['flags'] = array(
 		'currentapp' => 'phpbrain',
 		'noheader'   => True,
 		'nonavbar'   => True
@@ -25,5 +25,5 @@
 	$obj = CreateObject('phpbrain.uikb');
 	$obj->index();
 
-	$GLOBALS['phpgw']->common->phpgw_exit(true);
+	$GLOBALS['egw']->common->egw_exit(true);
 ?>
