@@ -1,44 +1,44 @@
 <?php
 /**
  * API - accounts LDAP backend
- * 
- * The LDAP backend of the accounts class now stores accounts, groups and the memberships completly in LDAP. 
+ *
+ * The LDAP backend of the accounts class now stores accounts, groups and the memberships completly in LDAP.
  * It does NO longer use the ACL class/table for group membership information.
  * Nor does it use the phpgwAcounts schema (part of that information is stored via shadowAccount now).
- * 
- * A user is recogniced by eGW, if he's in the user_context tree AND has the posixAccount object class AND 
+ *
+ * A user is recogniced by eGW, if he's in the user_context tree AND has the posixAccount object class AND
  * matches the LDAP search filter specified in setup >> configuration.
  * A group is recogniced by eGW, if it's in the group_context tree AND has the posixGroup object class.
  * The group members are stored as memberuid's.
- * 
- * The (positive) group-id's (gidnumber) of LDAP groups are mapped in this class to negative numeric 
+ *
+ * The (positive) group-id's (gidnumber) of LDAP groups are mapped in this class to negative numeric
  * account_id's to not conflict with the user-id's, as both share in eGW internaly the same numberspace!
- * 
+ *
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de> complete rewrite in 6/2006
- * 
- * This class replaces the former accounts_ldap class written by 
+ *
+ * This class replaces the former accounts_ldap class written by
  * Joseph Engo <jengo@phpgroupware.org>, Lars Kneschke <lkneschke@phpgw.de>,
  * Miles Lott <milos@groupwhere.org> and Bettina Gille <ceb@phpgroupware.org>.
  * Copyright (C) 2000 - 2002 Joseph Engo, Lars Kneschke
  * Copyright (C) 2003 Lars Kneschke, Bettina Gille
- * 
+ *
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @package api
  * @subpackage accounts
- * @version $Id: class.accounts_ldap.inc.php 25111 2008-03-19 11:37:19Z ralfbecker $
+ * @version $Id: class.accounts_ldap.inc.php 26000 2008-09-19 09:12:30Z leithoff $
  */
 
 /**
  * LDAP Backend for accounts
- * 
+ *
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  * @package api
  * @subpackage accounts
  * @access internal only use the interface provided by the accounts class
  */
-class accounts_backend
+class accounts_ldap
 {
 	/**
 	 * resource with connection to the ldap server
@@ -70,7 +70,7 @@ class accounts_backend
 	 * @var int
 	 */
 	var $total;
-	
+
 	var $ldapServerInfo;
 
 	/**
@@ -89,7 +89,7 @@ class accounts_backend
 	/**
 	 * Classes allowing to set a mail-address for a group and specify the memberaddresses as forwarding addresses
 	 *
-	 * @var unknown_type
+	 * @var array
 	 */
 	var $group_mail_classes = array(
 		'dbmailforwardingaddress' => 'mailforwardingaddress',
@@ -98,32 +98,48 @@ class accounts_backend
 	);
 	/**
 	 * reference to the translation class
-	 * 
-	 * @var object
+	 *
+	 * @var translation
 	 */
 	var $translation;
 
+	/**
+	 * Reference to our frontend
+	 *
+	 * @var accounts
+	 */
+	private $frontend;
+
+	/**
+	 * Instance of the ldap class
+	 *
+	 * @var ldap
+	 */
+	private $ldap;
+
 	/**
 	 * Constructor
 	 *
-	 * @return accounts_backend
+	 * @param accounts $frontend reference to the frontend class, to be able to call it's methods if needed
+	 * @return accounts_ldap
 	 */
-	function accounts_backend()
+	function __construct(accounts $frontend)
 	{
+		$this->frontend = $frontend;
+
 		// enable the caching in the session, done by the accounts class extending this class.
 		$this->use_session_cache = true;
 
-		$this->ds = $GLOBALS['egw']->common->ldapConnect();
-		if(!@is_object($GLOBALS['egw']->translation))
-		{
-			$GLOBALS['egw']->translation =& CreateObject('phpgwapi.translation');
-		}
-		$this->translation =& $GLOBALS['egw']->translation;
+		$this->ldap = new ldap();
+		$this->ds = $this->ldap->ldapConnect($this->frontend->config['ldap_host'],
+			$this->frontend->config['ldap_root_dn'],$this->frontend->config['ldap_root_pw']);
 
-		$this->user_context  = $GLOBALS['egw_info']['server']['ldap_context'];
-		$this->account_filter = $GLOBALS['egw_info']['server']['ldap_search_filter'];
-		$this->group_context = $GLOBALS['egw_info']['server']['ldap_group_context'] ? 
-			$GLOBALS['egw_info']['server']['ldap_group_context'] : $GLOBALS['egw_info']['server']['ldap_context'];
+		$this->translation = $GLOBALS['egw']->translation;
+
+		$this->user_context  = $this->frontend->config['ldap_context'];
+		$this->account_filter = $this->frontend->config['ldap_search_filter'];
+		$this->group_context = $this->frontend->config['ldap_group_context'] ?
+			$this->frontend->config['ldap_group_context'] : $this->frontend->config['ldap_context'];
 	}
 
 	/**
@@ -135,7 +151,7 @@ class accounts_backend
 	function read($account_id)
 	{
 		if (!(int)$account_id) return false;
-		
+
 		if ($account_id < 0)
 		{
 			return $this->_read_group($account_id);
@@ -145,7 +161,7 @@ class accounts_backend
 
 	/**
 	 * Saves / adds the data of one account
-	 * 
+	 *
 	 * If no account_id is set in data the account is added and the new id is set in $data.
 	 *
 	 * @param array $data array with account-data
@@ -157,10 +173,10 @@ class accounts_backend
 
 		$data_utf8 = $this->translation->convert($data,$this->translation->charset(),'utf-8');
 		$members = $data['account_members'];
-				
+
 		if (!is_object($this->ldapServerInfo))
 		{
-			$this->ldapServerInfo = $GLOBALS['egw']->ldap->getLDAPServerInfo($GLOBALS['egw_info']['server']['ldap_host']);
+			$this->ldapServerInfo = $this->ldap->getLDAPServerInfo($this->frontend->config['ldap_host']);
 		}
 		// common code for users and groups
 		// checks if accout_lid (dn) has been changed or required objectclass'es are missing
@@ -197,8 +213,7 @@ class accounts_backend
 						$members = $old ? $old['memberuid'] : $this->members($data['account_id']);
 					}
 					// if dn has changed --> delete the old entry, as we cant rename the dn
-					// $this->delete would call accounts::delete, which will delete als ACL of the user too!
-					accounts_backend::delete($data['account_id']);	
+					$this->delete($data['account_id']);
 					unset($old['dn']);
 					// removing the namedObject object-class, if it's included
 					if ($key !== false) unset($old['objectclass'][$key]);
@@ -237,11 +252,11 @@ class accounts_backend
 		{
 			$to_write = $this->_merge_group($to_write,$data_utf8);
 			$data['account_type'] = 'g';
-			
+
 			$groupOfNames = in_array('groupofnames',$old ? $old['objectclass'] : $to_write['objectclass']);
 			if (!$old && $groupOfNames || $members)
 			{
-				$to_write = array_merge($to_write,accounts_backend::set_members($members,
+				$to_write = array_merge($to_write,$this->set_members($members,
 					$data['account_id'],$groupOfNames,$dn));
 			}
 			// check if we should set a mail address and forwards for each member
@@ -259,7 +274,7 @@ class accounts_backend
 						}
 						if ($objectclass != 'dbmailforwardingaddress') $to_write['uid'] = $data_utf8['account_lid'];
 						$to_write['mail'] = $data_utf8['account_email'];
-						
+
 						if (!$members) $members = $this->members($data['account_id']);
 						$to_write[$forward] = array();
 						foreach ($members as $member)
@@ -284,7 +299,7 @@ class accounts_backend
 					break;
 				}
 			}
-		
+
 		}
 		else
 		{
@@ -298,7 +313,7 @@ class accounts_backend
 			}
 			$data['account_type'] = 'u';
 		}
-		
+
 		// remove memberuid when adding a group
 		if(!$old && is_array($to_write['memberuid']) && empty($to_write['memberuid'])) {
 			unset($to_write['memberuid']);
@@ -345,7 +360,7 @@ class accounts_backend
 		foreach($ldap as $var => $val)
 		{
 			if (is_int($var) || $var == 'count') continue;
-			
+
 			if (is_array($val) && $val['count'] == 1)
 			{
 				$arr[$var] = $val[0];
@@ -360,7 +375,7 @@ class accounts_backend
 		return $arr;
 	}
 
-	
+
 	/**
 	 * Delete one account, deletes also all acl-entries for that account
 	 *
@@ -383,7 +398,7 @@ class accounts_backend
 			$sri = ldap_search($this->ds, $this->user_context, 'uidnumber=' . $account_id);
 		}
 		if (!$sri) return false;
-		
+
 		$allValues = ldap_get_entries($this->ds, $sri);
 		if (!$allValues['count']) return false;
 
@@ -393,7 +408,7 @@ class accounts_backend
 	/**
 	 * Reads the data of one group
 	 *
-	 * @internal 
+	 * @internal
 	 * @param int $account_id numeric account-id (< 0 as it's for a group)
 	 * @return array/boolean array with account data (keys: account_id, account_lid, ...) or false if account not found
 	 */
@@ -401,14 +416,14 @@ class accounts_backend
 	{
 		$sri = ldap_search($this->ds, $this->group_context,'(&(objectClass=posixGroup)(gidnumber=' . abs($account_id).'))',
 			array('dn','gidnumber','cn','objectclass','mail'));
-		
+
 		$data = ldap_get_entries($this->ds, $sri);
 		if (!$data['count'])
 		{
 			return false;	// group not found
 		}
 		$data = $this->translation->convert($data[0],'utf-8');
-		
+
 		$group = array(
 			'account_dn'        => $data['dn'],
 			'account_id'        => -$data['gidnumber'][0],
@@ -421,7 +436,7 @@ class accounts_backend
 		);
 		if (!is_object($this->ldapServerInfo))
 		{
-			$this->ldapServerInfo = $GLOBALS['egw']->ldap->getLDAPServerInfo($GLOBALS['egw_info']['server']['ldap_host']);
+			$this->ldapServerInfo = $this->ldap->getLDAPServerInfo($this->frontend->config['ldap_host']);
 		}
 		foreach($this->group_mail_classes as $objectclass => $forward)
 		{
@@ -437,7 +452,7 @@ class accounts_backend
 	/**
 	 * Reads the data of one user
 	 *
-	 * @internal 
+	 * @internal
 	 * @param int $account_id numeric account-id
 	 * @return array/boolean array with account data (keys: account_id, account_lid, ...) or false if account not found
 	 */
@@ -445,15 +460,15 @@ class accounts_backend
 	{
 		$sri = ldap_search($this->ds, $this->user_context, '(&(objectclass=posixAccount)(uidnumber=' . (int)$account_id.'))',
 			array('dn','uidnumber','uid','gidnumber','givenname','sn','cn','mail','userpassword',
-			'shadowexpire','shadowlastchange','homedirectory','loginshell'));
-		
+				'shadowexpire','shadowlastchange','homedirectory','loginshell','createtimestamp','modifytimestamp'));
+
 		$data = ldap_get_entries($this->ds, $sri);
 		if (!$data['count'])
 		{
 			return false;	// user not found
 		}
 		$data = $this->translation->convert($data[0],'utf-8');
-		
+
 		$utc_diff = date('Z');
 		$user = array(
 			'account_dn'        => $data['dn'],
@@ -478,9 +493,11 @@ class accounts_backend
 			// 'account_lastlogin' => $data['phpgwaccountlastlogin'][0],
 			// 'account_lastloginfrom' => $data['phpgwaccountlastloginfrom'][0],
 			'person_id'         => $data['uid'][0],	// id of associated contact
+			'account_created' => isset($data['createtimestamp'][0]) ? $this->accounts_ldap2ts($data['createtimestamp'][0]) : null,
+			'account_modified' => isset($data['modifytimestamp'][0]) ? $this->accounts_ldap2ts($data['modifytimestamp'][0]) : null,
 		);
 		//echo "<p align=right>accounts_ldap::_read_user($account_id): shadowexpire={$data['shadowexpire'][0]} --> account_expires=$user[account_expires]=".date('Y-m-d H:i',$user['account_expires'])."</p>\n";
-		if ($GLOBALS['egw_info']['server']['ldap_extra_attributes'])
+		if ($this->frontend->config['ldap_extra_attributes'])
 		{
 			$user['homedirectory']  = $data['homedirectory'][0];
 			$user['loginshell']     = $data['loginshell'][0];
@@ -491,7 +508,7 @@ class accounts_backend
 	/**
 	 * Merges the group releavant account data from $data into $to_write
 	 *
-	 * @internal 
+	 * @internal
 	 * @param array $to_write data to write to ldap incl. objectclass ($data is NOT yet merged)
 	 * @param array $data array with account-data in utf-8
 	 * @return array merged data
@@ -503,11 +520,11 @@ class accounts_backend
 
 		return $to_write;
 	}
-	
+
 	/**
 	 * Merges the user releavant account data from $data into $to_write
 	 *
-	 * @internal 
+	 * @internal
 	 * @param array $to_write data to write to ldap incl. objectclass ($data is NOT yet merged)
 	 * @param array $data array with account-data in utf-8
 	 * @param boolean $new_entry
@@ -530,16 +547,12 @@ class accounts_backend
 			$to_write['mail']  = $data['account_email'] ? $data['account_email'] : array();
 		}
 		$to_write['cn']        = $data['account_fullname'] ? $data['account_fullname'] : $data['account_firstname'].' '.$data['account_lastname'];
-		
+
 		if (isset($data['account_passwd']) && $data['account_passwd'])
 		{
-			if(!@is_object($GLOBALS['egw']->auth))
-			{
-				$GLOBALS['egw']->auth =& CreateObject('phpgwapi.auth');
-			}
 			if (!preg_match('/^\\{[a-z5]{3,5}\\}.+/i',$data['account_passwd']))	// if it's not already entcrypted, do so now
 			{
-				$data['account_passwd'] = $GLOBALS['egw']->auth->encrypt_ldap($data['account_passwd']);
+				$data['account_passwd'] = auth::encrypt_ldap($data['account_passwd']);
 			}
 			$to_write['userpassword'] = $data['account_passwd'];
 		}
@@ -552,22 +565,22 @@ class accounts_backend
 		$shadowexpire = ($data['account_expires']-$utc_diff) / (24*3600);
 		$account_expire = $shadowexpire*3600*24+$utc_diff;
 		//echo "<p align=right>account_expires=".date('Y-m-d H:i',$data['account_expires'])." --> $shadowexpire --> ".date('Y-m-d H:i',$account_expire)."</p>\n";
-		$to_write['shadowexpire'] = !$data['account_status'] ? 	
+		$to_write['shadowexpire'] = !$data['account_status'] ?
 			($data['account_expires'] != -1 && $data['account_expires'] < time() ? round($shadowexpire) : 0) :
 			($data['account_expires'] != -1 ? round($shadowexpire) : array());	// array() = unset value
-		
+
 		if ($new_entry && is_array($to_write['shadowexpire']) && !count($to_write['shadowexpire']))
 		{
 			unset($to_write['shadowexpire']);	// gives protocoll error otherwise
 		}
-		
+
 		if ($data['account_lastpasswd_change']) $to_write['shadowlastchange'] = $data['lastpasswd_change']/(24*3600);
 
 		// lastlogin and lastlogin from are not availible via the shadowAccount object class
 		// $to_write['phpgwaccountlastlogin'] = $data['lastlogin'];
 		// $to_write['phpgwaccountlastloginfrom'] = $data['lastloginfrom'];
 
-		if ($GLOBALS['egw_info']['server']['ldap_extra_attributes'])
+		if ($this->frontend->config['ldap_extra_attributes'])
 		{
 			if (isset($data['homedirectory'])) $to_write['homedirectory']  = $data['homedirectory'];
 			if (isset($data['loginshell'])) $to_write['loginshell'] = $data['loginshell'] ? $data['loginshell'] : array();
@@ -600,9 +613,9 @@ class accounts_backend
 	 */
 	function search($param)
 	{
-		//echo "<p>accounts_backend::search(".print_r($param,true)."): ".microtime()."</p>\n";
+		//echo "<p>accounts_ldap::search(".print_r($param,true)."): ".microtime()."</p>\n";
 		$account_search = &$this->cache['account_search'];
-		
+
 		// check if the query is cached
 		$serial = serialize($param);
 		if (isset($account_search[$serial]))
@@ -625,7 +638,7 @@ class accounts_backend
 		else	// we need to run the unlimited query
 		{
 			$query = ldap::quote(strtolower($param['query']));
-	
+
 			$accounts = array();
 			if($param['type'] != 'groups')
 			{
@@ -678,7 +691,7 @@ class accounts_backend
 				$order = $propertyMap[$param['order']] ? $propertyMap[$param['order']] : 'uid';
 				$sri = ldap_search($this->ds, $this->user_context, $filter,array('uid', $order));
 				$fullSet = array();
-				foreach (ldap_get_entries($this->ds, $sri) as $key => $entry) 
+				foreach (ldap_get_entries($this->ds, $sri) as $key => $entry)
 				{
 					if ($key !== 'count') $fullSet[$entry['uid'][0]] = $entry[$order][0];
 				}
@@ -688,31 +701,39 @@ class accounts_backend
 					$relevantAccounts = array();
 					$sri = ldap_search($this->ds,$this->group_context,"(&(objectClass=posixGroup)(gidnumber=" . abs($param['type']) . "))",array('memberuid'));
 					$group = ldap_get_entries($this->ds, $sri);
-					
+
 					if (isset($group[0]['memberuid']))
 					{
 						$fullSet = array_intersect_key($fullSet, array_flip($group[0]['memberuid']));
 					}
 				}
 				$totalcount = count($fullSet);
-				
-				$sortFn = $param['sort'] == 'DESC' ? 'arsort' : 'asort';
-				$sortFn($fullSet);	
-				$relevantAccounts = is_numeric($start) ? array_slice(array_keys($fullSet), $start, $offset) : array_keys($fullSet);
 
-				$filter = "(" . "&(objectclass=posixaccount)" . '(|(uid='.implode(')(uid=',$relevantAccounts).'))' . $this->account_filter . ")";	
+				$sortFn = $param['sort'] == 'DESC' ? 'arsort' : 'asort';
+				$sortFn($fullSet);
+				$relevantAccounts = is_numeric($start) ? array_slice(array_keys($fullSet), $start, $offset) : array_keys($fullSet);
+				// if we do not have a start, or want the members of a certain group, we want all, that way we dont want to or the uids
+				// since if we have a whole lot of members, it slows the query down
+				// if you work with very big groups, it may present a problem 
+				if (is_numeric($start) || is_numeric($param['type'])) {
+					$filter = "(" . "&(objectclass=posixaccount)" . '(|(uid='.implode(')(uid=',$relevantAccounts).'))' . $this->account_filter . ")";
+				} else {
+					$filter = "(" . "&(objectclass=posixaccount)" . $this->account_filter . ")";
+				}
+
+				$filter = "(" . "&(objectclass=posixaccount)" . '(|(uid='.implode(')(uid=',$relevantAccounts).'))' . $this->account_filter . ")";
 				$filter = str_replace(array('%user','%domain'),array('*',$GLOBALS['egw_info']['user']['domain']),$filter);
-				
-				$sri = ldap_search($this->ds, $this->user_context, $filter,array('uid','uidNumber','givenname','sn','mail','shadowExpire'));
+
+				$sri = ldap_search($this->ds, $this->user_context, $filter,array('uid','uidNumber','givenname','sn','mail','shadowExpire','createtimestamp','modifytimestamp'));
 				//echo "<p>ldap_search(,$this->user_context,'$filter',) ".($sri ? '' : ldap_error($this->ds)).microtime()."</p>\n";
 				$allValues = ldap_get_entries($this->ds, $sri);
-				
+
 				$utc_diff = date('Z');
 				while (list($null,$allVals) = @each($allValues))
 				{
 					settype($allVals,'array');
 					$test = @$allVals['uid'][0];
-					if (!$GLOBALS['egw_info']['server']['global_denied_users'][$test] && $allVals['uid'][0])
+					if (!$this->frontend->config['global_denied_users'][$test] && $allVals['uid'][0])
 					{
 						$accounts[] = Array(
 							'account_id'        => $allVals['uidnumber'][0],
@@ -722,6 +743,9 @@ class accounts_backend
 							'account_lastname'  => $GLOBALS['egw']->translation->convert($allVals['sn'][0],'utf-8'),
 							'account_status'    => isset($allVals['shadowexpire'][0]) && $allVals['shadowexpire'][0]*24*3600-$utc_diff < time() ? false : 'A',
 							'account_email'     => $allVals['mail'][0],
+							'account_created' => isset($allVals['createtimestamp'][0]) ? $this->accounts_ldap2ts($allVals['createtimestamp'][0]) : null,
+							'account_modified' => isset($allVals['modifytimestamp'][0]) ? $this->accounts_ldap2ts($allVals['modifytimestamp'][0]) : null,
+
 						);
 					}
 				}
@@ -742,7 +766,7 @@ class accounts_backend
 				{
 					settype($allVals,'array');
 					$test = $allVals['cn'][0];
-					if (!$GLOBALS['egw_info']['server']['global_denied_groups'][$test] && $allVals['cn'][0])
+					if (!$this->frontend->config['global_denied_groups'][$test] && $allVals['cn'][0])
 					{
 						$accounts[] = Array(
 							'account_id'        => -$allVals['gidnumber'][0],
@@ -764,7 +788,7 @@ class accounts_backend
 			$account_search[$unl_serial]['data'] = $sortedAccounts = $arrayFunctions->arfsort($accounts,explode(',',$param['order']),$param['sort']);
 			$account_search[$unl_serial]['total'] = $this->total = isset($totalcount) ? $totalcount : count($accounts);
 		}
-		//echo "<p>accounts_backend::search() found $this->total: ".microtime()."</p>\n";
+		//echo "<p>accounts_ldap::search() found $this->total: ".microtime()."</p>\n";
 		// return only the wanted accounts
 		reset($sortedAccounts);
 		if(is_numeric($start) && is_numeric($offset))
@@ -775,13 +799,30 @@ class accounts_backend
 		return $sortedAccounts;
 	}
 
+	/**
+	 * Creates a timestamp from the date returned by the ldap server
+	 *
+	 * @internal
+	 * @param string $date YYYYmmddHHiiss
+	 * @return int
+	 */
+	function accounts_ldap2ts($date)
+	{
+		if (isset($date) && strlen($date)>0)
+		{
+			return gmmktime(substr($date,8,2),substr($date,10,2),substr($date,12,2),
+				substr($date,4,2),substr($date,6,2),substr($date,0,4));
+		}
+		return NULL;
+	}
+
 	/**
 	 * convert an alphanumeric account-value (account_lid, account_email) to the account_id
 	 *
 	 * Please note:
 	 * - if a group and an user have the same account_lid the group will be returned (LDAP only)
 	 * - if multiple user have the same email address, the returned user is undefined
-	 * 
+	 *
 	 * @param string $name value to convert
 	 * @param string $which='account_lid' type of $name: account_lid (default), account_email, person_id, account_fullname
 	 * @param string $account_type u = user, g = group, default null = try both
@@ -807,7 +848,9 @@ class accounts_backend
 			'account_email' => 'mail',
 			'account_fullname' => 'cn',
 		);
-		if (!isset($to_ldap[$which]) || $account_type === 'g') return False;
+		if (!isset($to_ldap[$which]) || $account_type === 'g') {
+		    return False;
+		}
 
 		$sri = ldap_search($this->ds, $this->user_context, '(&('.$to_ldap[$which].'=' . $name . ')(objectclass=posixaccount))');
 
@@ -820,6 +863,20 @@ class accounts_backend
 		return False;
 	}
 
+	/**
+	 * Convert an numeric account_id to any other value of that account (account_lid, account_email, ...)
+	 *
+	 * Uses the read method to fetch all data.
+	 *
+	 * @param int $account_id numerica account_id
+	 * @param string $which='account_lid' type to convert to: account_lid (default), account_email, ...
+	 * @return string/false converted value or false on error ($account_id not found)
+	 */
+	function id2name($account_id,$which='account_lid')
+	{
+		return $this->frontend->id2name($account_id,$which);
+	}
+
 	/**
 	 * Update the last login timestamps and the IP
 	 *
@@ -834,7 +891,7 @@ class accounts_backend
 		$entry['phpgwaccountlastlogin']     = time();
 		$entry['phpgwaccountlastloginfrom'] = $ip;
 
-		$sri = ldap_search($this->ds, $GLOBALS['egw_info']['server']['ldap_context'], 'uidnumber=' . (int)$_account_id);
+		$sri = ldap_search($this->ds, $this->frontend->config['ldap_context'], 'uidnumber=' . (int)$_account_id);
 		$allValues = ldap_get_entries($this->ds, $sri);
 
 		$dn = $allValues[0]['dn'];
@@ -842,7 +899,7 @@ class accounts_backend
 
 		return $allValues[0]['phpgwaccountlastlogin'][0];
 	}
-	
+
 	/**
 	 * Query memberships of a given account
 	 *
@@ -852,19 +909,19 @@ class accounts_backend
 	function memberships($account_id)
 	{
 		if (!(int) $account_id || !($account_lid = $this->id2name($account_id))) return false;
-		
+
 		$sri = ldap_search($this->ds,$this->group_context,'(&(objectClass=posixGroup)(memberuid='.ldap::quote($account_lid).'))',array('cn','gidnumber'));
 		$memberships = array();
 		foreach(ldap_get_entries($this->ds, $sri) as $key => $data)
 		{
 			if ($key === 'count') continue;
-			
+
 			$memberships[(string) -$data['gidnumber'][0]] = $data['cn'][0];
 		}
 		//echo "accounts::memberships($account_id)"; _debug_array($memberships);
 		return $memberships;
 	}
-	
+
 	/**
 	 * Query the members of a group
 	 *
@@ -874,12 +931,12 @@ class accounts_backend
 	function members($gid)
 	{
 		if (!is_numeric($gid)) return false;
-		
+
 		$gid = abs($gid);	// our gid is negative!
-		
+
 		$sri = ldap_search($this->ds,$this->group_context,"(&(objectClass=posixGroup)(gidnumber=$gid))",array('memberuid'));
 		$group = ldap_get_entries($this->ds, $sri);
-		
+
 		$members = array();
 		if (isset($group[0]['memberuid']))
 		{
@@ -894,7 +951,7 @@ class accounts_backend
 		//echo "accounts_ldap::members($gid)"; _debug_array($members);
 		return $members;
 	}
-	
+
 	/**
 	 * Sets the memberships of the given account
 	 *
@@ -926,10 +983,10 @@ class accounts_backend
 			$this->set_members($members,$gid);
 		}
 	}
-	
+
 	/**
 	 * Set the members of a group
-	 * 
+	 *
 	 * @param array $members array with uidnumber or uid's
 	 * @param int $gid gidnumber of group to set
 	 * @param boolean $groupOfNames=null should we set the member attribute of groupOfNames (default detect it)
@@ -943,7 +1000,7 @@ class accounts_backend
 
 		// do that group is a groupOfNames?
 		if (is_null($groupOfNames)) $groupOfNames = $this->id2name($gid,'groupOfNames');
-		
+
 		$to_write = array('memberuid' => array());
 		foreach((array)$members as $key => $member)
 		{
@@ -966,7 +1023,7 @@ class accounts_backend
 		if ($this->id2name($gid,'account_email') &&	($objectclass = $this->id2name($gid,'mailAllowed')))
 		{
 			$forward = $this->group_mail_classes[$objectclass];
-			
+
 			$to_write[$forward] = array();
 			foreach($members as $key => $member)
 			{
@@ -984,14 +1041,14 @@ class accounts_backend
 	/**
 	 * Using the common functions next_id and last_id, find the next available account_id
 	 *
-	 * @internal 
+	 * @internal
 	 * @param $string $account_type='u' (optional, default to 'u')
 	 * @return int/boolean integer account_id (negative for groups) or false if none is free anymore
 	 */
 	function _get_nextid($account_type='u')
 	{
-		$min = $GLOBALS['egw_info']['server']['account_min_id'] ? $GLOBALS['egw_info']['server']['account_min_id'] : 0;
-		$max = $GLOBALS['egw_info']['server']['account_max_id'] ? $GLOBALS['egw_info']['server']['account_max_id'] : 0;
+		$min = $this->frontend->config['account_min_id'] ? $this->frontend->config['account_min_id'] : 0;
+		$max = $this->frontend->config['account_max_id'] ? $this->frontend->config['account_max_id'] : 0;
 
 		if ($account_type == 'g')
 		{
@@ -1007,31 +1064,23 @@ class accounts_backend
 		do
 		{
 			$account_id = (int) $GLOBALS['egw']->common->next_id($type,$min,$max);
-		} 
-		while ($account_id && $this->exists($sign * $account_id));	// check need to include the sign!
+		}
+		while ($account_id && $this->frontend->exists($sign * $account_id));	// check need to include the sign!
 
-		if	(!$account_id || $GLOBALS['egw_info']['server']['account_max_id'] &&
-			$account_id > $GLOBALS['egw_info']['server']['account_max_id'])
+		if	(!$account_id || $this->frontend->config['account_max_id'] &&
+			$account_id > $this->frontend->config['account_max_id'])
 		{
 			return False;
 		}
 		return $sign * $account_id;
 	}
-}
 
-if (!function_exists('array_intersect_key'))    // php5.1 function
-{
-	function array_intersect_key($array1,$array2)
+	/**
+	 * __wakeup function gets called by php while unserializing the object to reconnect with the ldap server
+	 */
+	function __wakeup()
 	{
-		$intersection = $keys = array();
-		foreach(func_get_args() as $arr)
-		{
-			$keys[] = array_keys((array)$arr);
-		}
-		foreach(call_user_func_array('array_intersect',$keys) as $key)
-		{
-			$intersection[$key] = $array1[$key];
-		}
-		return $intersection;
-	}
+		$this->ds = $this->ldap->ldapConnect($this->frontend->config['ldap_host'],
+			$this->frontend->config['ldap_root_dn'],$this->frontend->config['ldap_root_pw']);
 	}
+}
