@@ -25,7 +25,7 @@
 	* Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA            *
 	\**************************************************************************/
 
-	/* $Id: class.common.inc.php 24605 2007-10-29 19:46:46Z ralfbecker $ */
+	/* $Id: class.common.inc.php 25983 2008-09-11 07:48:49Z ralfbecker $ */
 
 	$d1 = strtolower(@substr(EGW_API_INC,0,3));
 	$d2 = strtolower(@substr(EGW_SERVER_ROOT,0,3));
@@ -53,7 +53,7 @@
 		 * @param $str1
 		 * @param $str2
 		 */
-		function cmp_version($str1,$str2,$debug=False)
+		static function cmp_version($str1,$str2,$debug=False)
 		{
 			ereg("([0-9]+)\.([0-9]+)\.([0-9]+)[a-zA-Z]*([0-9]*)",$str1,$regs);
 			ereg("([0-9]+)\.([0-9]+)\.([0-9]+)[a-zA-Z]*([0-9]*)",$str2,$regs2);
@@ -84,7 +84,7 @@
 		 * @param $str1
 		 * @param $str2
 		 */
-		function cmp_version_long($str1,$str2,$debug=False)
+		static function cmp_version_long($str1,$str2,$debug=False)
 		{
 			ereg("([0-9]+)\.([0-9]+)\.([0-9]+)[a-zA-Z]*([0-9]*)\.([0-9]*)",$str1,$regs);
 			ereg("([0-9]+)\.([0-9]+)\.([0-9]+)[a-zA-Z]*([0-9]*)\.([0-9]*)",$str2,$regs2);
@@ -113,34 +113,6 @@
 			if($debug) { echo ' - all equal.'; }
 		}
 
-		/**
-		 * Convert an array into the format needed for the access column
-		 *
-		 * @param $access
-		 * @param $array
-		 */
-		function array_to_string($access,$array)
-		{
-			$this->debug_info[] = 'array_to_string() is a depreciated function - use ACL instead';
-			$s = '';
-			if ($access == 'group' || $access == 'public' || $access == 'none')
-			{
-				if (count($array))
-				{
-					while (($t = each($array)))
-					{
-						$s .= ',' . $t[1];
-					}
-					$s .= ',';
-				}
-				if (! count($array) && $access == 'none')
-				{
-					$s = '';
-				}
-			}
-			return $s;
-		}
-		
 		/**
 		* generate a unique id, which can be used for syncronisation
 		*
@@ -148,57 +120,31 @@
 		* @param string $_eventID the id of the content
 		* @return string the unique id
 		*/
-		function generate_uid($_appName, $_eventID)
+		static function generate_uid($_appName, $_eventID)
 		{
 			if(empty($_appName) || empty($_eventID)) return false;
-			
+
 			$suffix = $GLOBALS['egw_info']['server']['hostname'] ? $GLOBALS['egw_info']['server']['hostname'] : 'local';
 			$prefix = $_appName.'-'.$_eventID.'-'.$GLOBALS['egw_info']['server']['install_id'];
-			
+
 			return $prefix;
 		}
-		
+
 		/**
 		* get the local content id from a global UID
 		*
 		* @param sting $_globalUid the global UID
 		* @return int local egw content id
 		*/
-		function get_egwId($_globalUid)
+		static function get_egwId($_globalUid)
 		{
 			if(empty($_globalUid)) return false;
-			
+
 			$globalUidParts = explode('-',$_globalUid);
 			array_shift($globalUidParts);	// remove the app name
 			array_pop($globalUidParts);		// remove the install_id
-			
-			return implode('-',$globalUidParts);	// return the rest, allowing to have dashs in the id, can happen with LDAP!
-		}
 
-		// This is used for searching the access fields
-		/**
-		 * this function is used for searching the access fields
-		 *
-		 * @param $table
-		 * @param $owner
-		 */
-		function sql_search($table,$owner=0)
-		{
-			$this->debug_info[] = 'sql_search() is a deprecated function - use ACL instead';
-			$s = '';
-			if (!$owner)
-			{
-				$owner = $GLOBALS['egw_info']['user']['account_id'];
-			}
-			$groups = $GLOBALS['egw']->accounts->membership((int)$owner);
-			if(@is_array($groups))
-			{
-				while ($group = each($groups))
-				{
-					$s .= " OR $table LIKE '%," . $group[2] . ",%'";
-				}
-			}
-			return $s;
+			return implode('-',$globalUidParts);	// return the rest, allowing to have dashs in the id, can happen with LDAP!
 		}
 
 		/**
@@ -206,9 +152,9 @@
 		 *
 		 * @return $installedLanguages; an array containing the installed languages
 		 */
-		function getInstalledLanguages()
+		static function getInstalledLanguages()
 		{
-			$GLOBALS['egw']->db->query('SELECT DISTINCT lang FROM phpgw_lang');
+			$GLOBALS['egw']->db->query('SELECT DISTINCT lang FROM egw_lang');
 			while (@$GLOBALS['egw']->db->next_record())
 			{
 				$installedLanguages[$GLOBALS['egw']->db->f('lang')] = $GLOBALS['egw']->db->f('lang');
@@ -218,16 +164,17 @@
 		}
 
 		/**
-		 * return the preferred langugae of the users
+		 * get preferred language of the users
 		 *
-		 * it uses HTTP_ACCEPT_LANGUAGE (from the users browser) <br>
-		 * and .... to find out which languages are installed
+		 * Uses HTTP_ACCEPT_LANGUAGE (from the browser) and getInstalledLanguages to find out which languages are installed
+		 *
+		 * @return string
 		 */
-		function getPreferredLanguage()
+		static function getPreferredLanguage()
 		{
 			// create a array of languages the user is accepting
 			$userLanguages = explode(',',$_SERVER['HTTP_ACCEPT_LANGUAGE']);
-			$supportedLanguages = $this->getInstalledLanguages();
+			$supportedLanguages = self::getInstalledLanguages();
 
 			// find usersupported language
 			foreach($userLanguages as $key => $value)
@@ -259,35 +206,28 @@
 		 * Escaped Characters are: '*', '(', ')', ' ', '\', NUL
 		 * It's actually a PHP-Bug, that we have to escape space.
 		 * For all other Characters, refer to RFC2254.
-		 * 
+		 *
+		 * @deprecated use ldap::quote()
 		 * @param $string either a string to be escaped, or an array of values to be escaped
 		 * @return string
 		 */
-		function ldap_addslashes($string='')
+		static function ldap_addslashes($string='')
 		{
-			// use Lars new ldap class
-			if (!is_object($GLOBALS['egw']->ldap))
-			{
-				$GLOBALS['egw']->ldap =& CreateObject('phpgwapi.ldap');
-			}
 			return ldap::quote($string);
 		}
 
 		/**
 		 * connect to the ldap server and return a handle
 		 *
+		 * @deprecated use ldap::ldapConnect()
 		 * @param $host ldap host
 		 * @param $dn ldap_root_dn
 		 * @param $passwd ldap_root_pw
 		 * @return resource
 		 */
-		function ldapConnect($host='', $dn='', $passwd='')
+		static function ldapConnect($host='', $dn='', $passwd='')
 		{
 			// use Lars new ldap class
-			if (!is_object($GLOBALS['egw']->ldap))
-			{
-				$GLOBALS['egw']->ldap =& CreateObject('phpgwapi.ldap');
-			}
 			return $GLOBALS['egw']->ldap->ldapConnect($host,$dn,$passwd);
 		}
 
@@ -312,42 +252,12 @@
 			exit;
 		}
 
-		function egw_final()
-		{
-			if (!defined('EGW_FINAL'))
-			{
-				define('EGW_FINAL',True);
-
-				if (is_object($GLOBALS['egw']->accounts))
-				{
-					$GLOBALS['egw']->accounts->save_session_cache();
-				}
-				if (is_object($GLOBALS['egw']->link))
-				{
-					$GLOBALS['egw']->link->save_session_cache();
-				}
-				// call the asyncservice check_run function if it is not explicitly set to cron-only
-				//
-				if (!$GLOBALS['egw_info']['server']['asyncservice'])	// is default
-				{
-					ExecMethod('phpgwapi.asyncservice.check_run','fallback');
-				}
-				/* Clean up mcrypt */
-				if (@is_object($GLOBALS['egw']->crypto))
-				{
-					$GLOBALS['egw']->crypto->cleanup();
-					unset($GLOBALS['egw']->crypto);
-				}
-				$GLOBALS['egw']->db->disconnect();
-			}
-		}
-
 		/**
 		 * return a random string of size $size
 		 *
 		 * @param $size int-size of random string to return
 		 */
-		function randomstring($size)
+		static function randomstring($size)
 		{
 			$s = '';
 			srand((double)microtime()*1000000);
@@ -417,7 +327,7 @@
 				$lastname  = $GLOBALS['egw_info']['user']['lastname'];
 			}
 			$is_group = $GLOBALS['egw']->accounts->get_type($accountid ? $accountid : $lid) == 'g';
-			
+
 			if (empty($firstname)) $firstname = $lid;
 			if (empty($lastname) || $is_group)
 			{
@@ -433,7 +343,7 @@
 			{
 				$delimiter = '';
 			}
-			
+
 			$name = '';
 			switch($display)
 			{
@@ -476,10 +386,10 @@
 		 * create tabs
 		 *
 		 * @param array $tabs an array repersenting the tabs you wish to display, each element
-		 * 		 * 		 * 	 in the array is an array of 3 elements, 'label' which is the 
-		 * 		 * 		 * 	 text displaed on the tab (you should pass translated string, 
-		 * 		 * 		 * 	 create_tabs will not do <code>lang()</code> for you), 'link' 
-		 * 		 * 		 * 	 which is the uri, 'target', the frame name or '_blank' to show 
+		 * 		 * 		 * 	 in the array is an array of 3 elements, 'label' which is the
+		 * 		 * 		 * 	 text displaed on the tab (you should pass translated string,
+		 * 		 * 		 * 	 create_tabs will not do <code>lang()</code> for you), 'link'
+		 * 		 * 		 * 	 which is the uri, 'target', the frame name or '_blank' to show
 		 * 		 * 		 * 	 page in a new browser window.
 		 * @param mixed $selected the tab whos key is $selected will be displayed as current tab
 		 * @param $fontsize optional
@@ -657,6 +567,7 @@
 						$list[] = substr($file,0,strpos($file,'.'));
 					}
 				}
+                                closedir($dh);
 			}
 			if(!is_array($list))
 			{
@@ -668,8 +579,8 @@
 						$list[] = substr($file,0,strpos($file,'.'));
 					}
 				}
+				closedir($dh);
 			}
-			closedir($dh);
 			reset ($list);
 			return $list;
 		}
@@ -709,10 +620,10 @@
 		 * get template dir of an application
 		 *
 		 * @param $appname appication name optional can be derived from $GLOBALS['egw_info']['flags']['currentapp'];
-		 * @static 
+		 * @static
 		 * @return string/boolean dir or false if no dir is found
 		 */
-		function get_tpl_dir($appname = '')
+		static function get_tpl_dir($appname = '')
 		{
 			if (!$appname)
 			{
@@ -781,9 +692,11 @@
 					$ext = strtolower(strrchr($f,'.'));
 					if (($ext == '.gif' || $ext == '.png') && strpos($f,'navbar') === False)
 					{
+						closedir($d);
 						return True;
 					}
 				}
+				closedir($d);
 			}
 			return False;
 		}
@@ -880,12 +793,12 @@
 		function find_image($appname,$image)
 		{
 			$imagedir = '/'.$appname.'/templates/'.$GLOBALS['egw_info']['user']['preferences']['common']['template_set'].'/images';
-			
+
 			if (!@is_array($this->found_files[$appname]))
 			{
 				$imagedir_olddefault = '/'.$appname.'/templates/default/images';
 				$imagedir_default    = '/'.$appname.'/templates/idots/images';
-				
+
 				if (@is_dir(EGW_INCLUDE_ROOT.$imagedir_olddefault))
 				{
 					$d = dir(EGW_INCLUDE_ROOT.$imagedir_olddefault);
@@ -925,7 +838,7 @@
 					$d->close();
 				}
 			}
-			
+
 			if (!$GLOBALS['egw_info']['server']['image_type'])
 			{
 				// priority: GIF->JPG->PNG
@@ -1064,7 +977,7 @@
 
 		/**
 	 	 * prepare an array with variables used to render the navbar
-		 * 
+		 *
 		 * @deprecated inherit from egw_framework class in your template and use egw_framework::_navbar_vars()
 		 */
 		function navbar()
@@ -1075,7 +988,7 @@
 		/**
 		 * load header.inc.php for an application
 		 *
-		 * @deprecated 
+		 * @deprecated
 		 */
 		function app_header()
 		{
@@ -1093,7 +1006,7 @@
 		function egw_header()
 		{
 			echo $GLOBALS['egw']->framework->header();
-			
+
 			if (!$GLOBALS['egw_info']['flags']['nonavbar'])
 			{
 			   echo $GLOBALS['egw']->framework->navbar();
@@ -1176,15 +1089,12 @@
 		 *
 		 * uses the encryption type set in setup and calls the appropriate encryption functions
 		 *
+		 * @deprecated use auth::encrypt_password()
 		 * @param $password password to encrypt
 		 */
 		function encrypt_password($password,$sql=False)
 		{
-			if(!@is_object($GLOBALS['egw']->auth))
-			{
-				$GLOBALS['egw']->auth =& CreateObject('phpgwapi.auth');
-			}
-			return $GLOBALS['egw']->auth->encrypt_password($password,$sql);
+			return auth::encrypt_password($password,$sql);
 		}
 
 		/**
@@ -1262,11 +1172,6 @@
 		 */
 		function show_date($t = 0, $format = '', $adjust_to_usertime=true)
 		{
-			if(!is_object($GLOBALS['egw']->datetime))
-			{
-				$GLOBALS['egw']->datetime =& CreateObject('phpgwapi.datetime');
-			}
-
 			if (!$t)
 			{
 				$t = $GLOBALS['egw']->datetime->gmtnow;
@@ -1363,7 +1268,7 @@
 
 			return $h12.':'.$min.$sec.$ampm;
 		}
-		
+
 		/**
 		 * Format an email address according to the system standard
 		 *
@@ -1383,7 +1288,7 @@
 				'&szlig;' => 'ss',
 				' ' => '',
 			);
-			foreach (array('first','last','account') as $name) 
+			foreach (array('first','last','account') as $name)
 			{
 				$$name = htmlentities($$name,ENT_QUOTES,$GLOBALS['egw']->translation->charset());
 				$$name = str_replace(array_keys($extra),array_values($extra),$$name);
@@ -1411,10 +1316,10 @@
 			$email = str_replace(array('first','last','initial','account','dot','underscore','-'),
 				array($first,$last,substr($first,0,1),$account,$dot,$underscore,''),
 				$GLOBALS['egw_info']['server']['email_address_format'] ? $GLOBALS['egw_info']['server']['email_address_format'] : 'first-dot-last').
-				'@'.$domain;
+				($domain ? '@'.$domain : '');
 			//echo " = '$email'</p>\n";
 			return $email;
-		}			
+		}
 
 		// This is not the best place for it, but it needs to be shared bewteen Aeromail and SM
 		/**
@@ -1789,7 +1694,7 @@
 			system("grep -r '^[ \t]*function' *");
 			echo '</pre>';
 		}
-		
+
 		var $nextid_table = 'egw_nextid';
 
 		/**
@@ -1815,7 +1720,7 @@
 				return False;
 			}
 			++$id;
-			
+
 			if($id < $min) $id = $min;
 
 			$GLOBALS['egw']->db->insert($this->nextid_table,array('id' => $id),array('appname' => $appname),__LINE__,__FILE__);
@@ -1851,7 +1756,7 @@
 			}
 			return (int)$id;
 		}
-		
+
 		/**
 		 * gets an eGW conformat referer from $_SERVER['HTTP_REFERER'], suitable for direct use in the link function
 		 *
@@ -1862,7 +1767,7 @@
 		function get_referer($default='',$referer='')
 		{
 			if (!$referer) $referer = $_SERVER['HTTP_REFERER'];
-			
+
 			$webserver_url = $GLOBALS['egw_info']['server']['webserver_url'];
 			if (empty($webserver_url) || $webserver_url{0} == '/')	// url is just a path
 			{
@@ -1875,7 +1780,7 @@
 			$referer = str_replace('/etemplate/process_exec.php','/index.php',$referer);
 
 			if (empty($referer)) $referer = $default;
-			
+
 			return $referer;
 		}
 
@@ -1889,12 +1794,12 @@
 		{
 			$this->egw_final();
 		}
-		
+
 		function phpgw_header()
 		{
 			$this->egw_header();
 		}
-		
+
 		function phpgw_footer()
 		{
 			$this->egw_footer();
