@@ -1,7 +1,7 @@
 <?php
 /**
  * eGW API - framework
- * 
+ *
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de> rewrite in 12/2006
  * @author Pim Snel <pim@lingewoud.nl> author of the idots template set
@@ -9,12 +9,12 @@
  * @package api
  * @subpackage framework
  * @access public
- * @version $Id$
+ * @version $Id: class.egw_framework.inc.php 26210 2008-10-13 18:23:02Z ralfbecker $
  */
 
 /**
  * eGW API - framework: virtual base class for all template sets
- * 
+ *
  * This class creates / renders the eGW framework:
  *  a) html header
  *  b) navbar
@@ -22,12 +22,12 @@
  *  d) main application area
  *  e) footer
  * It replaces several methods in the common class and the diverse templates.
- * 
- * Existing apps either set $GLOBALS['egw_info']['flags']['noheader'] and call $GLOBALS['egw']->common->egw_header() and 
+ *
+ * Existing apps either set $GLOBALS['egw_info']['flags']['noheader'] and call $GLOBALS['egw']->common->egw_header() and
  * (if $GLOBALS['egw_info']['flags']['nonavbar'] is true) parse_navbar() or it's done by the header.inc.php include.
  * The app's hook_sidebox then calls the public function display_sidebox().
  * And the app calls $GLOBALS['egw']->common->egw_footer().
- * 
+ *
  * This are the authors (and their copyrights) of the original egw_header, egw_footer methods of the common class:
  * This file written by Dan Kuykendall <seek3r@phpgroupware.org>
  * and Joseph Engo <jengo@phpgroupware.org>
@@ -36,7 +36,7 @@
  * Copyright (C) 2000, 2001 Dan Kuykendall
  * Copyright (C) 2003 Lars Kneschke
  */
-class egw_framework
+abstract class egw_framework
 {
 	/**
 	 * Name of the template set, eg. 'idots'
@@ -47,7 +47,7 @@ class egw_framework
 
 	/**
 	 * Constructor
-	 * 
+	 *
 	 * The constructor instanciates the class in $GLOBALS['egw']->framework, from where it should be used
 	 *
 	 * @return egw_framework
@@ -58,27 +58,27 @@ class egw_framework
 
 		if (!is_object($GLOBALS['egw']->framework))
 		{
-			$GLOBALS['egw']->framework =& $this;
+			$GLOBALS['egw']->framework = $this;
 		}
 	}
-	
+
 	/**
 	 * Renders an applicaton page with the complete eGW framework (header, navigation and menu)
-	 * 
+	 *
 	 * This is the (new) prefered way to render a page in eGW!
 	 *
 	 * @param string $content html of the main application area
 	 * @param string $app_header=null application header, default what's set in $GLOBALS['egw_info']['flags']['app_header']
 	 * @param string $navbar=null show the navigation, default !$GLOBALS['egw_info']['flags']['nonavbar'], false gives a typical popu
-	 * 
+	 *
 	 */
 	function render($content,$app_header=null,$navbar=null)
 	{
 		if (!is_null($app_header)) $GLOBALS['egw_info']['flags']['app_header'] = $app_header;
 		if (!is_null($navbar)) $GLOBALS['egw_info']['flags']['nonavbar'] = !$navbar;
-		
+
 		echo $this->header();
-		
+
 		if (!isset($GLOBALS['egw_info']['flags']['nonavbar']) || !$GLOBALS['egw_info']['flags']['nonavbar'])
 		{
 		   echo $this->navbar();
@@ -93,21 +93,15 @@ class egw_framework
 	 *
 	 * @return string with html
 	 */
-	function header()
-	{
-		die('virtual, need to be reimplemented in the template!!!');		
-	}
+	abstract function header();
 
 	/**
 	 * Returns the html from the body-tag til the main application area (incl. opening div tag)
 	 *
 	 * @return string with html
 	 */
-	function navbar()
-	{
-		die('virtual, need to be reimplemented in the template!!!');		
-	}
-	
+	abstract function navbar();
+
 	/**
 	 * Returns the content of one sidebox
 	 *
@@ -115,49 +109,36 @@ class egw_framework
 	 * @param string $menu_title
 	 * @param array $file
 	 */
-	function sidebox($appname,$menu_title,$file)
-	{
-		die('virtual, need to be reimplemented in the template!!!');
-	}
-	
+	abstract function sidebox($appname,$menu_title,$file);
+
 	/**
 	 * Returns the html from the closing div of the main application area to the closing html-tag
 	 *
 	 * @return string
 	 */
-	function footer()
-	{
-		die('virtual, need to be reimplemented in the template!!!');
-	}
-	
+	abstract function footer();
+
 	/**
 	 * displays a login screen
 	 *
 	 * @string $extra_vars for login url
 	 * @return string
 	 */
-	function login_screen($extra_vars)
-	{
-		die('virtual, need to be reimplemented in the template!!!');
-	}
-	
+	abstract function login_screen($extra_vars);
+
 	/**
 	 * displays a login denied message
 	 *
 	 * @return string
 	 */
-	function denylogin_screen()
-	{
-		die('virtual, need to be reimplemented in the template!!!');
-	}
-	
+	abstract function denylogin_screen();
+
 	/**
 	 * Get footer as array to eg. set as vars for a template (from idots' head.inc.php)
 	 *
-	 * @internal PHP5 protected
 	 * @return array
 	 */
-	function _get_footer()
+	protected function _get_footer()
 	{
 		$var = Array(
 			'img_root'       => $GLOBALS['egw_info']['server']['webserver_url'] . '/phpgwapi/templates/'.$this->template.'/images',
@@ -165,13 +146,19 @@ class egw_framework
 		);
 		if($GLOBALS['egw_info']['user']['preferences']['common']['show_generation_time'])
 		{
-			$totaltime = sprintf('%4.2lf',perfgetmicrotime() - $GLOBALS['egw_info']['flags']['page_start_time']); 
+			$totaltime = sprintf('%4.2lf',microtime(true) - $GLOBALS['egw_info']['flags']['page_start_time']);
 
-			$var['page_generation_time'] = '<div id="divGenTime"><br/><span>'.lang('Page was generated in %1 seconds',$totaltime).'</span></div>';
+			$var['page_generation_time'] = '<div id="divGenTime"><br/><span>'.lang('Page was generated in %1 seconds',$totaltime);
+			if ($GLOBALS['egw_info']['flags']['session_restore_time'])
+			{
+				$var['page_generation_time'] .= ' '.lang('(session restored in %1 seconds)',
+					sprintf('%4.2lf',$GLOBALS['egw_info']['flags']['session_restore_time']));
+			}
+			$var['page_generation_time'] .= '</span></div>';
 		}
 		$var['powered_by'] = lang('Powered by').' <a href="'.$GLOBALS['egw_info']['server']['webserver_url'].'/about.php">eGroupWare</a> '.lang('version').' '.$GLOBALS['egw_info']['server']['versions']['phpgwapi'];
 		$var['activate_tooltips'] = '<script src="'.$GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/js/wz_tooltip/wz_tooltip.js" type="text/javascript"></script>';
-		
+
 		return $var;
 	}
 
@@ -180,11 +167,11 @@ class egw_framework
 	 *
 	 * @return string html
 	 */
-	function _get_app_footer()
+	protected static function _get_app_footer()
 	{
 		ob_start();
 		// Include the apps footer files if it exists
-		if (EGW_APP_INC != EGW_API_INC &&	// this prevents an endless inclusion on the homepage 
+		if (EGW_APP_INC != EGW_API_INC &&	// this prevents an endless inclusion on the homepage
 			                                // (some apps set currentapp in hook_home => it's not releyable)
 			(file_exists (EGW_APP_INC . '/footer.inc.php') || isset($_GET['menuaction'])) &&
 			$GLOBALS['egw_info']['flags']['currentapp'] != 'home' &&
@@ -193,7 +180,7 @@ class egw_framework
 			!@$GLOBALS['egw_info']['flags']['noappfooter'])
 		{
 			list($app,$class,$method) = explode('.',(string)$_GET['menuaction']);
-			if ($class && is_object($GLOBALS[$class]) && is_array($GLOBALS[$class]->public_functions) && 
+			if ($class && is_object($GLOBALS[$class]) && is_array($GLOBALS[$class]->public_functions) &&
 				isset($GLOBALS[$class]->public_functions['footer']))
 			{
 				$GLOBALS[$class]->footer();
@@ -206,31 +193,30 @@ class egw_framework
 		$content = ob_get_contents();
 		ob_end_clean();
 
-		return $content;	
+		return $content;
 	}
 
 	/**
 	 * Get header as array to eg. set as vars for a template (from idots' head.inc.php)
 	 *
-	 * @internal PHP5 protected
 	 * @return array
 	 */
-	function _get_header()
+	protected function _get_header()
 	{
 		// get used language code
 		$lang_code = $GLOBALS['egw_info']['user']['preferences']['common']['lang'];
-	
+
 		//pngfix defaults to yes
 		if(!$GLOBALS['egw_info']['user']['preferences']['common']['disable_pngfix'])
 		{
 			$pngfix_src = $GLOBALS['egw_info']['server']['webserver_url'] . '/phpgwapi/templates/idots/js/pngfix.js';
-			$pngfix ='<!-- This solves the Internet Explorer PNG-transparency bug, but only for IE 5.5 and higher --> 
-			<!--[if gte IE 5.5000]>
+			$pngfix ='<!-- This solves the Internet Explorer PNG-transparency bug, but only for IE 5.5 - 6.0 and higher -->
+			<!--[if lt IE 7.0]>
 			<script src="'.$pngfix_src.'" type="text/javascript">
 			</script>
 			<![endif]-->';
 		}
-	
+
 		if(!$GLOBALS['egw_info']['user']['preferences']['common']['disable_slider_effects'])
 		{
 			$slider_effects_src = $GLOBALS['egw_info']['server']['webserver_url'] . '/phpgwapi/templates/idots/js/slidereffects.js';
@@ -243,7 +229,7 @@ class egw_framework
 			$simple_show_hide = '<script src="'.$simple_show_hide_src.'" type="text/javascript">
 			</script>';
 		}
-	
+
 		if ($GLOBALS['egw_info']['flags']['app_header'])
 		{
 			$app = $GLOBALS['egw_info']['flags']['app_header'];
@@ -253,9 +239,9 @@ class egw_framework
 			$app = $GLOBALS['egw_info']['flags']['currentapp'];
 			$app = isset($GLOBALS['egw_info']['apps'][$app]) ? $GLOBALS['egw_info']['apps'][$app]['title'] : lang($app);
 		}
-	
+
 		if($app!='wiki') $robots ='<meta name="robots" content="none" />';
-		
+
 		return $this->_get_css()+array(
 			'img_icon'      	=> EGW_IMAGES_DIR . '/favicon.ico',
 			'img_shortcut'  	=> EGW_IMAGES_DIR . '/favicon.ico',
@@ -265,8 +251,8 @@ class egw_framework
 			'lang_code'			=> $lang_code,
 			'charset'       	=> $GLOBALS['egw']->translation->charset(),
 			'website_title' 	=> strip_tags($GLOBALS['egw_info']['server']['site_title']. ($app ? " [$app]" : '')),
-			'body_tags'     	=> $this->_get_body_attribs(),
-			'java_script'   	=> $this->_get_js(),
+			'body_tags'     	=> self::_get_body_attribs(),
+			'java_script'   	=> self::_get_js(),
 			'meta_robots'		=> $robots,
 			'dir_code'			=> lang('language_direction_rtl') != 'rtl' ? '' : ' dir="rtl"',
 		);
@@ -275,11 +261,10 @@ class egw_framework
 	/**
 	 * Get navbar as array to eg. set as vars for a template (from idots' navbar.inc.php)
 	 *
-	 * @internal PHP5 protected
 	 * @param array $apps navbar apps from _get_navbar_apps
 	 * @return array
 	 */
-	function _get_navbar($apps)
+	protected function _get_navbar($apps)
 	{
 		$var['img_root'] = $GLOBALS['egw_info']['server']['webserver_url'] . '/phpgwapi/templates/'.$this->template.'/images';
 
@@ -293,13 +278,12 @@ class egw_framework
 		 }
 
 		// current users for admins
-			   $var['current_users'] = $this->_current_users();
-		
+		$var['current_users'] = $this->_current_users();
+
 		// quick add selectbox
 		$var['quick_add'] = $this->_get_quick_add();
 
 		$var['user_info'] = $this->_user_time_info();
-		
 
 		if($GLOBALS['egw_info']['user']['lastpasswd_change'] == 0)
 		{
@@ -326,23 +310,22 @@ class egw_framework
 			$var['logo_file'] = $GLOBALS['egw']->common->image('phpgwapi',$GLOBALS['egw_info']['server']['login_logo_file']?$GLOBALS['egw_info']['server']['login_logo_file']:'logo');
 		}
 		$var['logo_url'] = $GLOBALS['egw_info']['server']['login_logo_url']?$GLOBALS['egw_info']['server']['login_logo_url']:'http://www.eGroupWare.org';
-		
+
 		if (substr($var['logo_url'],0,4) != 'http')
 		{
 			$var['logo_url'] = 'http://'.$var['logo_url'];
 		}
 		$var['logo_title'] = $GLOBALS['egw_info']['server']['login_logo_title']?$GLOBALS['egw_info']['server']['login_logo_title']:'www.eGroupWare.org';
-		
+
 		return $var;
 	}
 
 	/**
-	* Returns html with user and time
-	* 
-	* @access protected
-	* @return void
-	*/
-	function _user_time_info()
+	 * Returns html with user and time
+	 *
+	 * @return void
+	 */
+	protected static function _user_time_info()
 	{
 	   $now = time();
 	   $user_info = '<b>'.$GLOBALS['egw']->common->display_fullname() .'</b>'. ' - '
@@ -352,11 +335,17 @@ class egw_framework
 	   return $user_info;
 	}
 
-	function _current_users()
+	/**
+	 * Prepare the current users
+	 *
+	 * @return string
+	 */
+	protected static function _current_users()
 	{
 	   if( $GLOBALS['egw_info']['user']['apps']['admin'] && $GLOBALS['egw_info']['user']['preferences']['common']['show_currentusers'])
 	   {
-		  $current_users = '<a href="' . $GLOBALS['egw']->link('/index.php','menuaction=admin.uicurrentsessions.list_sessions') . '">' . lang('Current users') . ': ' . $GLOBALS['egw']->session->total() . '</a>'; 
+		  $current_users = '<a href="' . $GLOBALS['egw']->link('/index.php','menuaction=admin.uicurrentsessions.list_sessions') . '">' .
+		  	lang('Current users') . ': ' . $GLOBALS['egw']->session->session_count() . '</a>';
 		  return $current_users;
 	   }
 	}
@@ -366,22 +355,17 @@ class egw_framework
 	 *
 	 * @return string
 	 */
-	function _get_quick_add()
+	protected static function _get_quick_add()
 	{
-		if (!is_object($GLOBALS['egw']->link))
-		{
-			require_once(EGW_API_INC.'/class.bolink.inc.php');
-			$GLOBALS['egw']->link =& new bolink();
-		}
-		$apps = $GLOBALS['egw']->link->app_list('add');
+		$apps = egw_link::app_list('add');
 		asort($apps);	// sort them alphabetic
-		
+
 		$options = array(lang('Add').' ...');
 		foreach($apps as $app => $label)
 		{
-			$link = $GLOBALS['egw']->link('/index.php',$GLOBALS['egw']->link->add($app,$GLOBALS['egw_info']['flags']['currentapp'],$GLOBALS['egw_info']['flags']['currentid'])+
+			$link = $GLOBALS['egw']->link('/index.php',egw_link::add($app,$GLOBALS['egw_info']['flags']['currentapp'],$GLOBALS['egw_info']['flags']['currentid'])+
 				(is_array($GLOBALS['egw_info']['flags']['quick_add']) ? $GLOBALS['egw_info']['flags']['quick_add'] : array()));
-			if (($popup = $GLOBALS['egw']->link->is_popup($app,'add')))
+			if (($popup = egw_link::is_popup($app,'add')))
 			{
 				list($w,$h) = explode('x',$popup);
 				$action = "window.open('$link','_blank','width=$w,height=$h,location=no,menubar=no,toolbar=no,scrollbars=yes,status=yes');";
@@ -392,25 +376,63 @@ class egw_framework
 			}
 			$options[$action] = $label;
 		}
-		if (!is_object($GLOBALS['egw']->html))
+		return html::select('quick_add','',$options,true,$options=' onchange="eval(this.value); this.value=0; return false;"');
+	}
+
+	/**
+	 * Prepare notification signal (blinking bell)
+	 *
+	 * @return string
+	 */
+	protected static function _get_notification_bell()
+	{
+		return html::div(
+			html::a_href(
+				html::image('notifications','notificationbell',lang('notifications')),
+				'javascript: notificationwindow_display();'
+			),
+			'id="notificationbell"', // options
+			'', // class
+			'display: none' //style
+		);
+	}
+
+	/**
+	 * Get the link to an application's index page
+	 *
+	 * @param string $app
+	 * @return string
+	 */
+	public function index($app)
+	{
+		$data =& $GLOBALS['egw_info']['user']['apps'][$app];
+		if (!isset($data))
 		{
-			require_once(EGW_API_INC.'/class.html.inc.php');
-			$GLOBALS['egw']->html =& new html();
+			throw new egw_exception_wrong_parameter("'$app' not a valid app for this user!");
 		}
-		return $GLOBALS['egw']->html->select('quick_add','',$options,true,$options=' onchange="eval(this.value); this.value=0; return false;"');		
+		$index = '/'.$app.'/index.php';
+		if (isset($data['index']))
+		{
+			if ($data['index'][0] == '/')
+			{
+				$index = $data['index'];
+			}
+			else
+			{
+				$index = '/index.php?menuaction='.$data['index'];
+			}
+		}
+		return $GLOBALS['egw']->link($index,$GLOBALS['egw_info']['flags']['params'][$app]);
 	}
-	
 
 	/**
 	 * Prepare an array with apps used to render the navbar
-	 * 
+	 *
 	 * This is similar to the former common::navbar() method - though it returns the vars and does not place them in global scope.
 	 *
-	 * @internal PHP5 protected
-	 * @static 
 	 * @return array
 	 */
-	function _get_navbar_apps()
+	protected static function _get_navbar_apps()
 	{
 		list($first) = each($GLOBALS['egw_info']['user']['apps']);
 		if(is_array($GLOBALS['egw_info']['user']['apps']['admin']) && $first != 'admin')
@@ -429,7 +451,7 @@ class egw_framework
 		unset($index);
 		unset($value);
 		unset($newarray);
-		
+
 		$apps = array();
 		foreach($GLOBALS['egw_info']['user']['apps'] as $app => $data)
 		{
@@ -441,7 +463,7 @@ class egw_framework
 			if ($app == 'preferences' || $GLOBALS['egw_info']['apps'][$app]['status'] != 2 && $GLOBALS['egw_info']['apps'][$app]['status'] != 3)
 			{
 				$apps[$app]['title'] = $GLOBALS['egw_info']['apps'][$app]['title'];
-				$apps[$app]['url']   = $GLOBALS['egw']->link('/' . $app . '/index.php',$GLOBALS['egw_info']['flags']['params'][$app]);
+				$apps[$app]['url']   = self::index($app);
 				$apps[$app]['name']  = $app;
 
 				// create popup target
@@ -460,15 +482,17 @@ class egw_framework
 					$apps[$app]['target'] = '';
 				}
 
+				$icon = isset($data['icon']) ?  $data['icon'] : 'navbar';
+				$icon_app = isset($data['icon_app']) ? $data['icon_app'] : $app;
 				if ($app != $GLOBALS['egw_info']['flags']['currentapp'])
 				{
-					$apps[$app]['icon']  = $GLOBALS['egw']->common->image($app,Array('navbar','nonav'));
-					$apps[$app]['icon_hover']  = $GLOBALS['egw']->common->image_on($app,Array('navbar','nonav'),'-over');
+					$apps[$app]['icon']  = $GLOBALS['egw']->common->image($icon_app,Array($icon,'nonav'));
+					$apps[$app]['icon_hover']  = $GLOBALS['egw']->common->image_on($icon_app,Array($icon,'nonav'),'-over');
 				}
 				else
 				{
-					$apps[$app]['icon']  = $GLOBALS['egw']->common->image_on($app,Array('navbar','nonav'),'-over');
-					$apps[$app]['icon_hover']  = $GLOBALS['egw']->common->image($app,Array('navbar','nonav'));
+					$apps[$app]['icon']  = $GLOBALS['egw']->common->image_on($icon_app,Array($icon,'nonav'),'-over');
+					$apps[$app]['icon_hover']  = $GLOBALS['egw']->common->image($icon_app,Array($icon,'nonav'));
 				}
 			}
 		}
@@ -500,10 +524,10 @@ class egw_framework
 		$apps['logout']['url']   = $GLOBALS['egw']->link('/logout.php');
 		$apps['logout']['icon']  = $GLOBALS['egw']->common->image('phpgwapi',Array('logout','nonav'));
 		$apps['logout']['icon_hover']  = $GLOBALS['egw']->common->image_on('phpgwapi',Array('logout','nonav'),'-over');
-		
+
 		return $apps;
 	}
-	
+
 	/**
 	 * Used by template headers for including CSS in the header
 	 *
@@ -511,20 +535,19 @@ class egw_framework
 	 * 'file_css'  - link tag of the app.css file of the current app
 	 * 'theme_css' - url of the theme css file
 	 * 'print_css' - url of the print css file
-	 * 
-	 * @internal PHP5 protected
+	 *
 	 * @author Dave Hall (*based* on verdilak? css inclusion code)
 	 * @return array with keys 'app_css' from the css method of the menuaction-class and 'file_css' (app.css file of the application)
 	 */
-	function _get_css()
+	protected function _get_css()
 	{
 		$app_css = '';
 		if(isset($_GET['menuaction']))
 		{
 			list($app,$class,$method) = explode('.',$_GET['menuaction']);
-			if(is_array($GLOBALS[$class]->public_functions) &&
-				$GLOBALS[$class]->public_functions['css'])
+			if(is_array($GLOBALS[$class]->public_functions) && $GLOBALS[$class]->public_functions['css'])
 			{
+				error_log("Deprecated functionality in $app class $class: using of public_function css, use \$GLOBALS['egw_info']['flags']['css'] or an app.css file!");
 				$app_css .= $GLOBALS[$class]->css();
 			}
 		}
@@ -542,7 +565,7 @@ class egw_framework
 			if (!file_exists(EGW_SERVER_ROOT.$css_file))
 			{
 				$css_file = '/'.$appname.'/templates/default/app.css';
-				
+
 				if (!file_exists(EGW_SERVER_ROOT.$css_file)) $css_file = '';
 			}
 			if($css_file)
@@ -565,7 +588,7 @@ class egw_framework
 			$print_css = '/phpgwapi/templates/idots/print.css';
 		}
 		$print_css = $GLOBALS['egw_info']['server']['webserver_url'] . $print_css .'?'.filemtime(EGW_SERVER_ROOT.$print_css);
-	
+
 		return array(
 			'app_css'   => $app_css,
 			'css_file'  => $css_file,
@@ -581,19 +604,13 @@ class egw_framework
 	 * in eGW.  One change then all templates will support it (as long as they
 	 * include a call to this method).
 	 *
-	 * @internal PHP5 protected
 	 * @author Dave Hall (*vaguely based* on verdilak? css inclusion code)
 	 * @return string the javascript to be included
 	 */
-	function _get_js()
+	public static function _get_js()
 	{
 		$java_script = '';
-		
-		if(!@is_object($GLOBALS['egw']->js))
-		{
-			$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-		}
-		
+
 		// always include javascript helper functions
 		$GLOBALS['egw']->js->validate_file('jsapi','jsapi');
 
@@ -608,18 +625,18 @@ class egw_framework
 			{
 				$GLOBALS['egw']->js->validate_jsapi();
 			}
-			
+
 			if(@is_object($GLOBALS['egw']->js))
 			{
 				$java_script .= $GLOBALS['egw']->js->get_javascript_globals();
 			}
 		}
-		
+
 		if ($GLOBALS['egw']->acl->check('run',1,'notifications') && !$GLOBALS['egw_info']['user']['preferences']['notifications']['disable_ajaxpopup'])
 		{
 			$GLOBALS['egw_info']['flags']['include_xajax'] = true;
 		}
-		
+
 		if ($GLOBALS['egw_info']['flags']['include_xajax'])
 		{
 			require_once(EGW_SERVER_ROOT.'/phpgwapi/inc/xajax.inc.php');
@@ -631,13 +648,13 @@ class egw_framework
 			$java_script .= $xajax->getJavascript($GLOBALS['egw_info']['server']['webserver_url'] . '/phpgwapi/js/');
 		}
 
-		/* this flag is for all javascript code that has to be put before other jscode. 
+		/* this flag is for all javascript code that has to be put before other jscode.
 		Think of conf vars etc...  (pim@lingewoud.nl) */
 		if (isset($GLOBALS['egw_info']['flags']['java_script_thirst']))
 		{
 			$java_script .= $GLOBALS['egw_info']['flags']['java_script_thirst'] . "\n";
 		}
-		
+
 		if(@is_object($GLOBALS['egw']->js))
 		{
 			$java_script .= $GLOBALS['egw']->js->get_script_links();
@@ -662,11 +679,10 @@ class egw_framework
 	/**
 	 * Returns on(Un)Load attributes from js class
 	 *
-	 * @internal PHP5 protected
 	 * @author Dave Hall - skwashd at egroupware.org
 	 * @returns string body attributes
 	 */
-	function _get_body_attribs()
+	protected static function _get_body_attribs()
 	{
 		if(@is_object($GLOBALS['egw']->js))
 		{
@@ -707,5 +723,3 @@ if (!function_exists('display_sidebox'))
 		$GLOBALS['egw']->framework->sidebox($appname,$menu_title,$file);
 	}
  }
-
-
