@@ -5,12 +5,12 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
- * @version $Id: class.jscalendar.inc.php 23926 2007-05-23 21:39:52Z lkneschke $
+ * @version $Id: class.jscalendar.inc.php 25776 2008-07-23 13:59:16Z stefanbecker $
  */
 
 /**
  * Wrapper for the jsCalendar
- * 
+ *
  * The constructor loads the necessary javascript-files.
  *
  * @package api
@@ -39,20 +39,22 @@ class jscalendar
 	 * @param string $path='jscalendar'
 	 * @return jscalendar
 	 */
-	function jscalendar($do_header=True,$path='jscalendar')
+	function jscalendar($do_header=True,$path='jscalendar',$scriptreturn=false)
 	{
 		$this->jscalendar_url = $GLOBALS['egw_info']['server']['webserver_url'].'/phpgwapi/js/'.$path;
 		$this->dateformat = $GLOBALS['egw_info']['user']['preferences']['common']['dateformat'];
 
-		if ($do_header && (strpos($GLOBALS['egw_info']['flags']['java_script'],'jscalendar')===false))
-		{
-			$GLOBALS['egw_info']['flags']['java_script'] .=
+		$js=
 '<link rel="stylesheet" type="text/css" media="all" href="'.$this->jscalendar_url.'/calendar-blue.css" title="blue" />
 <script type="text/javascript" src="'.$this->jscalendar_url.'/calendar.js"></script>
 <script type="text/javascript" src="'.$GLOBALS['egw']->link('/phpgwapi/inc/jscalendar-setup.php',
 	array_intersect_key($GLOBALS['egw_info']['user']['preferences']['common'],array('lang'=>1,'dateformat'=>1))).'"></script>
 ';
+		if ($do_header && (strpos($GLOBALS['egw_info']['flags']['java_script'],'jscalendar')===false))
+		{
+			$GLOBALS['egw_info']['flags']['java_script'] .=$js;
 		}
+		if ($scriptreturn==true) return $js;  //if the header is already send to the Browser
 	}
 
 	/**
@@ -91,7 +93,7 @@ class jscalendar
 				$short = lang($m = adodb_date('M',$ts));	// check if we have a translation of the short-cut
 				if ($short == $m || $substr($short,-1) == '*')	// if not generate one by truncating the translation of the long name
 				{
-					$short = $chars_shortcut > 0 ? $substr(lang(adodb_date('F',$ts)),0,$chars_shortcut) : 
+					$short = $chars_shortcut > 0 ? $substr(lang(adodb_date('F',$ts)),0,$chars_shortcut) :
 						$substr(lang(adodb_date('F',$ts)),$chars_shortcut);
 				}
 				$date = str_replace(adodb_date('M',$ts),$short,$date);
@@ -140,6 +142,7 @@ Calendar.setup(
 	 */
 	function flat($url,$date=null,$weekUrl='',$weekTTip='',$monthUrl='',$monthTTip='',$id='calendar-container')
 	{
+		$javascript=$this->jscalendar(false,'jscalendar',true);
 		if ($date)	// string if format YYYYmmdd or timestamp
 		{
 			$date = is_int($date) ? adodb_date('m/d/Y',$date) :
@@ -147,7 +150,7 @@ Calendar.setup(
 		}
 		return '
 <div id="'.$id.'"></div>
-
+'.$javascript.'
 <script type="text/javascript">
 function dateChanged(calendar) {
 '.  // Beware that this function is called even if the end-user only
@@ -167,17 +170,20 @@ function monthClicked(calendar,monthstart) {
  window.location = "'.$monthUrl.'&date=" + monthstart.print("%Y%m%d");
 }
 ' : '').'
-Calendar.setup(
-{
-  flat         : "'.$id.'",
-  flatCallback : dateChanged'.($weekUrl ? ',
-  flatWeekCallback : weekClicked' : '').($weekTTip ? ',
-  flatWeekTTip : "'.addslashes($weekTTip).'"' : '').($monthUrl ? ',
-  flatMonthCallback : monthClicked' : '').($monthTTip ? ',
-  flatMonthTTip : "'.addslashes($monthTTip).'"' : '').($date ? ',
-  date : "'.$date.'"
-' : '').'    }
-);
+
+	Calendar.setup(
+	{
+  		flat         : "'.$id.'",
+  		flatCallback : dateChanged'.($weekUrl ? ',
+  		flatWeekCallback : weekClicked' : '').($weekTTip ? ',
+  		flatWeekTTip : "'.addslashes($weekTTip).'"' : '').($monthUrl ? ',
+  		flatMonthCallback : monthClicked' : '').($monthTTip ? ',
+  		flatMonthTTip : "'.addslashes($monthTTip).'"' : '').($date ? ',
+ 		date : "'.$date.'"
+		' : '').'
+	}
+	);
+
 </script>';
 	}
 
