@@ -521,8 +521,10 @@
 				if (!isset($string2[1]))
 				{
 					return $string2[0];
+				} else {
+					return '';
 				}
- 			}
+			}
 			return '';
 		} # function _bad_protocol_once
 
