@@ -14,7 +14,7 @@ include_once 'Horde/SyncML/Command/Sync/ContentSyncElement.php';
  * @author  Anthony Mills <amills@pyramid6.com>
  * @author  Karsten Fourmont <fourmont@gmx.de>
  *
- * @version $Revision: 24605 $
+ * @version $Revision: 26307 $
  * @since   Horde 3.0
  * @package Horde_SyncML
  */
@@ -22,45 +22,45 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 
 	function endSync($currentCmdID, &$output) {
 		global $registry;
-		
+
 		$state = &$_SESSION['SyncML.state'];
-		
+
 		$syncType = $this->_targetLocURI;
-		
+
 		$hordeType = $state->getHordeType($syncType);
-		
+
 		$refts = $state->getServerAnchorLast($syncType);
 		$currentCmdID = $this->handleSync($currentCmdID,
                                           $hordeType,
                                           $syncType,
                                           $output,
                                           $refts);
-		
+
 		return $currentCmdID;
 	}
 
 	function handleSync($currentCmdID, $hordeType, $syncType,&$output, $refts) {
 		global $registry;
-		
+
 		// array of Items which got modified, but got never send to the client before
 		$missedAdds = array();
-		
-		$history = $GLOBALS['phpgw']->contenthistory;
+
+		$history = $GLOBALS['egw']->contenthistory;
 		$state = &$_SESSION['SyncML.state'];
 		$counter = 0;
-		
+
 		$changes = &$state->getChangedItems($hordeType);
 		$deletes = &$state->getDeletedItems($hordeType);
 		$adds = &$state->getAddedItems($hordeType);
-		
+
 		Horde::logMessage("SyncML: ".count($changes).' changed items found for '.$hordeType, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		Horde::logMessage("SyncML: ".count($deletes).' deleted items found for '.$hordeType, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		Horde::logMessage("SyncML: ".count($adds).   ' added items found for '.$hordeType  , __FILE__, __LINE__, PEAR_LOG_DEBUG);
-		
+
 		// handle changes
 		if(is_array($changes)) {
 			while($guid = array_shift($changes)) {
-				$guid_ts = $history->getTSforAction($guid, 'modify');
+				$guid_ts = $state->getSyncTSforAction($guid, 'modify');
 				$sync_ts = $state->getChangeTS($syncType, $guid);
 				Horde::logMessage("SyncML: timestamp modify guid_ts: $guid_ts sync_ts: $sync_ts", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 				if ($sync_ts && $sync_ts == $guid_ts) {
@@ -77,7 +77,7 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 					Horde::logMessage("SyncML: unable to create change for $guid: locid not found in map", __FILE__, __LINE__, PEAR_LOG_WARNING);
 					continue;
 				}
-			
+
 				// Create a replace request for client.
 				$contentType = $state->getPreferedContentTypeClient($this->_sourceLocURI, $this->_targetLocURI);
 				$c = $registry->call($hordeType. '/export',
@@ -98,7 +98,7 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 
 					$currentCmdID = $cmd->outputCommand($currentCmdID, $output, 'Replace');
 					$state->log('Server-Replace');
-				
+
 					// return if we have to much data
 					if (++$counter >= MAX_ENTRIES
 						&& isset($contentType['mayFragment'])
@@ -115,7 +115,7 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 		// handle deletes
 		if(is_array($deletes)) {
 			while($guid = array_shift($deletes)) {
-				$guid_ts = $history->getTSforAction($guid, 'delete');
+				$guid_ts = $state->getSyncTSforAction($guid, 'delete');
 				$sync_ts = $state->getChangeTS($syncType, $guid);
 				Horde::logMessage("SyncML: timestamp delete guid_ts: $guid_ts sync_ts: $sync_ts", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 				if ($sync_ts && $sync_ts == $guid_ts) {
@@ -124,13 +124,13 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 					Horde::logMessage("SyncML: delete $guid ignored, came from client", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 					continue;
 				}
-				
+
 				$locid = $state->getLocID($syncType, $guid);
 				if (!$locid) {
 					Horde::logMessage("SyncML: unable to create delete for $guid: locid not found in map", __FILE__, __LINE__, PEAR_LOG_WARNING);
 					continue;
 				}
-				
+
 				Horde::logMessage("SyncML: delete: $guid", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 				// Create a Delete request for client.
 				$cmd = &new Horde_SyncML_Command_Sync_ContentSyncElement();
@@ -139,7 +139,7 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 				$currentCmdID = $cmd->outputCommand($currentCmdID, $output, 'Delete');
 				$state->log('Server-Delete');
 				$state->removeUID($syncType, $locid);
-				
+
 				$contentType = $state->getPreferedContentTypeClient($this->_sourceLocURI, $this->_targetLocURI);
 				// return if we have to much data
 				if(++$counter >= MAX_ENTRIES
@@ -160,10 +160,10 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 			$adds = &$state->getAddedItems($hordeType);
 			Horde::logMessage("SyncML: merged adds counter ".count($adds).' / '.$adds[0], __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		}
-		
+
 		if(is_array($adds)) {
 			while($guid = array_shift($adds)) {
-				$guid_ts = $history->getTSforAction($guid, 'add');
+				$guid_ts = $state->getSyncTSforAction($guid, 'add');
 				$sync_ts = $state->getChangeTS($syncType, $guid);
 				Horde::logMessage("SyncML: timestamp add $guid guid_ts: $guid_ts sync_ts: $sync_ts", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 				if ($sync_ts && $sync_ts == $guid_ts) {
@@ -172,9 +172,9 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 					Horde::logMessage("SyncML: add: $guid ignored, came from client", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 					continue;
 				}
-				
+
 				$locid = $state->getLocID($syncType, $guid);
-				
+
 				if ($locid && $refts == 0) {
 					// For slow sync (ts=0): do not add data for which we
 					// have a locid again.  This is a heuristic to avoid
@@ -183,10 +183,10 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 					continue;
 				}
 				Horde::logMessage("SyncML: add: $guid", __FILE__, __LINE__, PEAR_LOG_DEBUG);
-				
+
 				// Create an Add request for client.
 				$contentType = $state->getPreferedContentTypeClient($this->_sourceLocURI, $this->_targetLocURI);
-				
+
 				$cmd = &new Horde_SyncML_Command_Sync_ContentSyncElement();
 				$c = $registry->call($hordeType . '/export',
 					array(
@@ -194,7 +194,7 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 						'contentType'	=> $contentType ,
 					)
 				);
-				
+
 				if (!is_a($c, 'PEAR_Error')) {
 					// Item in history but not in database. Strange, but can happen.
 					$cmd->setContent($c);
@@ -206,7 +206,7 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 					$cmd->setSourceURI($guid);
 					$currentCmdID = $cmd->outputCommand($currentCmdID, $output, 'Add');
 					$state->log('Server-Add');
-					
+
 					// return if we have to much data
 					if(++$counter >= MAX_ENTRIES
 						&& isset($contentType['mayFragment'])
@@ -219,31 +219,31 @@ class Horde_SyncML_Sync_TwoWaySync extends Horde_SyncML_Sync {
 			}
 		}
 		#Horde::logMessage("SyncML: handling sync ".$currentCmdID, __FILE__, __LINE__, PEAR_LOG_DEBUG);
-		
+
 		$state->clearSync($syncType);
-		
+
 		return $currentCmdID;
 	}
-	
+
 	function loadData() {
 		global $registry;
-		
+
 		$state = &$_SESSION['SyncML.state'];
 		$syncType = $this->_targetLocURI;
 		$hordeType = $state->getHordeType($syncType);
 		$refts = $state->getServerAnchorLast($syncType);
-		
+
 		Horde::logMessage("SyncML: reading changed items from database for $hordeType", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		$state->setChangedItems($hordeType, $registry->call($hordeType. '/listBy', array('action' => 'modify', 'timestamp' => $refts)));
-		
+
 		Horde::logMessage("SyncML: reading deleted items from database for $hordeType", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		$state->setDeletedItems($hordeType, $registry->call($hordeType. '/listBy', array('action' => 'delete', 'timestamp' => $refts)));
-		
+
 		Horde::logMessage("SyncML: reading added items from database for $hordeType", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		$state->setAddedItems($hordeType, $registry->call($hordeType. '/listBy', array('action' => 'add', 'timestamp' => $refts)));
-		
+
 		$this->_syncDataLoaded = TRUE;
-		
+
 		return count($state->getChangedItems($hordeType)) +
 			count($state->getDeletedItems($hordeType)) +
 			count($state->getAddedItems($hordeType));
