@@ -1,6 +1,6 @@
 <?php
 
-require_once PHPGW_SERVER_ROOT.'/phpgwapi/inc/horde/Horde/iCalendar.php';
+require_once EGW_API_INC.'/horde/Horde/iCalendar.php';
 
 /**
  * Class representing vNotes.
@@ -13,7 +13,7 @@ require_once PHPGW_SERVER_ROOT.'/phpgwapi/inc/horde/Horde/iCalendar.php';
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Karsten Fourmont <fourmont@gmx.de>
- * @version $Revision: 18844 $
+ * @version $Revision: 25838 $
  * @package Horde_iCalendar
  */
 class Horde_iCalendar_vnote extends Horde_iCalendar {
