@@ -12,7 +12,7 @@
 	* Free Software Foundation; either version 2 of the License, or (at your   *
 	* option) any later version.                                               *
 	\**************************************************************************/
-	/* $Id: class.uicategories.inc.php 24717 2007-11-27 17:23:40Z pbf $ */
+	/* $Id: class.uicategories.inc.php 25181 2008-03-25 16:43:57Z ralfbecker $ */
 
 	class uicategories
 	{
@@ -431,11 +431,7 @@
 			$GLOBALS['egw']->template->set_var('access','<input type="checkbox" name="cat_access" value="True"'
 				. ($cat['access'] == 'private' ? ' checked' : '') . '>');
 
-			if (!is_object($GLOBALS['egw']->html))
-			{
-				$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
-			}
-			$GLOBALS['egw']->template->set_var('color',$GLOBALS['egw']->html->inputColor('cat_data[color]',$cat['data']['color'],lang('Click to select a color')));
+			$GLOBALS['egw']->template->set_var('color',html::inputColor('cat_data[color]',$cat['data']['color'],lang('Click to select a color')));
 
 			$options = '<option value=""'.(!$cat['data']['icon'] ? ' selected="1"':'').'>'.lang('none')."</options>\n";
 			foreach ($this->icons as $icon)
