@@ -5,9 +5,9 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package projectmanager
- * @copyright (c) 2005 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2005-8 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
- * @version $Id: class.datasource.inc.php 22355 2006-08-26 16:30:45Z ralfbecker $ 
+ * @version $Id: class.datasource.inc.php 26296 2008-11-01 10:21:55Z ralfbecker $
  */
 
 /**
@@ -28,7 +28,7 @@ define('PM_USED_BUDGET',16);
 /** int timestamp planned start-date */
 define('PM_PLANNED_START',32);
 /** int timestamp real start-date */
-define('PM_REAL_START',64);		
+define('PM_REAL_START',64);
 /** int timestamp planned end-date */
 define('PM_PLANNED_END',128);
 /** int timestamp real end-date */
@@ -47,24 +47,21 @@ define('PM_UNITPRICE',8192);
 define('PM_PLANNED_QUANTITY',16384);
 /** double used quantity */
 define('PM_USED_QUANTITY',32768);
+/** int seconds replanned time */
+define('PM_REPLANNED_TIME',65536);
 /** all data-types or'ed together, need to be changed if new data-types get added */
-define('PM_ALL_DATA',65535);
+define('PM_ALL_DATA',131071);
 
 /**
  * DataSource baseclass of the ProjectManager
  *
- * This is the baseclass of all DataSources, each spezific DataSource extends it and implement 
+ * This is the baseclass of all DataSources, each spezific DataSource extends it and implement
  * an own get method.
  *
  * The read method of this class sets (if not set by the get method) the planned start- and endtime:
  *  - planned start from the end of a start constrain or the project start-time
  *  - planned end from the planned time and a start-time
  *  - real or planned start and end from each other
- *
- * @package projectmanager
- * @author RalfBecker-AT-outdoor-training.de
- * @copyright (c) 2005 by RalfBecker-AT-outdoor-training.de
- * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
  */
 class datasource
 {
@@ -90,6 +87,7 @@ class datasource
 	var $name2id = array(
 		'pe_completion'     => PM_COMPLETION,
 		'pe_planned_time'   => PM_PLANNED_TIME,
+		'pe_replanned_time' => PM_REPLANNED_TIME,
 		'pe_used_time'      => PM_USED_TIME,
 		'pe_planned_budget' => PM_PLANNED_BUDGET,
 		'pe_used_budget'    => PM_USED_BUDGET,
@@ -103,10 +101,10 @@ class datasource
 		'pl_id'				=> PM_PRICELIST_ID,
 		'pe_unitprice'      => PM_UNITPRICE,
 		'pe_planned_quantity' => PM_PLANNED_QUANTITY,
-		'pe_used_quantity'  => PM_USED_QUANTITY,		
+		'pe_used_quantity'  => PM_USED_QUANTITY,
 	);
 	/**
-	 * @var boprojectelements-object $bo_pe pe object to read other pe's (eg. for constraints)
+	 * @var projectmanager_elements_bo-object $bo_pe pe object to read other pe's (eg. for constraints)
 	 */
 	var $bo_pe;
 
@@ -115,17 +113,19 @@ class datasource
 	 *
 	 * @param string $type=null type of the datasource
 	 */
-	function datasource($type=null)
+	function __construct($type=null)
 	{
 		$this->type = $type;
-
-		if (!is_object($GLOBALS['egw']->link))
-		{
-			$GLOBALS['egw']->link =& CreateObject('phpgwapi.bolink');
-		}
-		$this->link =& $GLOBALS['egw']->link;
 	}
-	
+
+	/**
+	 * PHP4 constructor
+	 */
+	function datasource($type=null)
+	{
+		self::__construct($type);
+	}
+
 	/**
 	 * get an item from the underlaying app and convert applying data ia a datasource array
 	 *
@@ -134,13 +134,13 @@ class datasource
 	 * Not set values mean they are not supported by the datasource.
 	 *
 	 * Reimplent this function for spezial datasource types (not read!)
-	 * 
+	 *
 	 * @param mixed $data_id id as used in the link-class for that app, or complete entry as array
 	 * @return array/boolean array with the data supported by that source or false on error (eg. not found, not availible)
 	 */
 	function get($data_id)
 	{
-		if (($title = $this->link->title($this->type,$data_id)))
+		if (($title = egw_link::title($this->type,$data_id)))
 		{
 			return array(
 				'pe_title'  => $title,
@@ -149,14 +149,14 @@ class datasource
 		}
 		return false;
 	}
-	
+
 	/**
 	 * read an item from a datasource (via the get methode) and try to set (guess) some not supported values
 	 *
 	 * A datasource array can contain values for the keys: completiton, {planned|used}_time, {planned|used}_budget,
 	 *	{planned|real}_start, {planned|real}_end
 	 * Not set values mean they are not supported by the datasource.
-	 * 
+	 *
 	 * @param mixed $data_id id as used in the link-class for that app, or complete entry as array
 	 * @param array $pe_data data of the project-element or null, eg. to use the constraints
 	 * @return array/boolean array with the data supported by that source or false on error (eg. not found, not availible)
@@ -164,9 +164,9 @@ class datasource
 	function read($data_id,$pe_data=null)
 	{
 		$ds = $this->get($data_id);
-		
+
 		//echo "<p>datasource::read($data_id,$pe_data) ds="; _debug_array($ds);
-		
+
 		if ($ds)
 		{
 			// setting a not set planned start from a contrains
@@ -176,7 +176,7 @@ class datasource
 				$start = 0;
 				if (!is_object($this->bo_pe))
 				{
-					$this->bo_pe =& CreateObject('projectmanager.boprojectelements',$pe_data['pm_id']);
+					$this->bo_pe = new projectmanager_elements_bo($pe_data['pm_id']);
 				}
 				foreach($pe_data['pe_constraints']['start'] as $start_pe_id)
 				{
@@ -204,21 +204,21 @@ class datasource
 			{
 				if (!is_object($this->bo_pe))
 				{
-					$this->bo_pe =& CreateObject('projectmanager.boprojectelements',$pe_data['pm_id']);
+					$this->bo_pe = new projectmanager_elements_bo($pe_data['pm_id']);
 				}
 				if ($this->bo_pe->pm_id != $pe_data['pm_id'])
 				{
-					$this->bo_pe->boprojectelements($pe_data['pm_id']);
+					$this->bo_pe->__construct($pe_data['pm_id']);
 				}
 				if ($this->bo_pe->project->data['pm_planned_start'] || $this->bo_pe->project->data['pm_real_start'])
 				{
-					$ds['pe_planned_start'] = $this->bo_pe->project->data['pm_planned_start'] ? 
+					$ds['pe_planned_start'] = $this->bo_pe->project->data['pm_planned_start'] ?
 						$this->bo_pe->project->data['pm_planned_start'] : $this->bo_pe->project->data['pm_real_start'];
 					unset($ds['ignore_planned_start']);
 				}
 			}
-			// calculating the planned end-date from the planned time
-			if ((!$ds['pe_planned_end'] || $ds['ignore_planned_end']) && $ds['pe_planned_time'])
+			// calculating the planned end-date from the planned or replanned time
+			if ((!$ds['pe_planned_end'] || $ds['ignore_planned_end']) && $ds['pe_replanned_time'])
 			{
 				if ($ds['pe_planned_start'] && is_object($this->project))
 				{
@@ -227,6 +227,32 @@ class datasource
 					unset($ds['ignore_planned_end']);
 				}
 			}
+			elseif ((!$ds['pe_planned_end'] || $ds['ignore_planned_end']) && $ds['pe_planned_time'])
+			{
+				if ($ds['pe_planned_start'] && is_object($this->project))
+				{
+					$ds['pe_planned_end'] = $this->project->date_add($ds['pe_planned_start'],$ds['pe_planned_time'],$ds['pe_resources'][0]);
+					unset($ds['ignore_planned_end']);
+				}
+			}
+			// calculating the real end-date from the real or planned/replanned time
+			if ((!$ds['pe_real_end'] || $ds['ignore_real_end']) && $ds['pe_real_start'] &&
+				($ds['pe_used_time'] && !$ds['ignore_used_time'] || $ds['pe_replanned_time']) && is_object($this->project))
+			{
+				$ds['pe_real_end'] = $this->project->date_add($ds['pe_real_start'],
+					($t = $ds['pe_used_time'] && !$ds['ignore_used_time'] ? $ds['pe_used_time'] : $ds['pe_replanned_time']),$ds['pe_resources'][0]);
+				//echo "<p>$ds[pe_title] set real end to ".date('D Y-m-d H:i',$ds['pe_real_end'])."</p>\n";
+				unset($ds['ignore_real_end']);
+			}
+                        elseif ((!$ds['pe_real_end'] || $ds['ignore_real_end']) && $ds['pe_real_start'] &&
+                                ($ds['pe_used_time'] && !$ds['ignore_used_time'] || $ds['pe_planned_time']) && is_object($this->project))
+                        {
+                                $ds['pe_real_end'] = $this->project->date_add($ds['pe_real_start'],
+                                        ($t = $ds['pe_used_time'] && !$ds['ignore_used_time'] ? $ds['pe_used_time'] : $ds['pe_planned_time']),$ds['pe_resources'][0]);
+                                //echo "<p>$ds[pe_title] set real end to ".date('D Y-m-d H:i',$ds['pe_real_end'])."</p>\n";
+                                unset($ds['ignore_real_end']);
+                        }
+
 			// setting real or planned start- or end-date, from each other if not set
 			foreach(array('start','end') as $name)
 			{
@@ -256,11 +282,26 @@ class datasource
 					$ds['warning']['completion_by_time'] = $compl_by_time;
 				}
 			}
+			// try calculating a (second) completion from the times
+			if (!empty($ds['pe_used_time']) && (int) $ds['pe_replanned_time'] > 0)
+			{
+				$compl_by_time = $ds['pe_used_time'] / $ds['pe_replanned_time'];
+
+				// if no completion is given by the datasource use the calculated one
+				if (!isset($ds['pe_completion']))
+				{
+					$ds['pe_completion'] = $compl_by_time;
+				}
+				elseif ($compl_by_time < $ds['pe_completion'])
+				{
+					$ds['warning']['completion_by_time'] = $compl_by_time;
+				}
+			}
 			// try calculating a (second) completion from the budget
 			if(!empty($ds['pe_used_budget']) && $ds['pe_planned_budget'] > 0)
 			{
 				$compl_by_budget = $ds['pe_used_budget'] / $ds['pe_planned_budget'];
-			
+
 				// if no completion is given by the datasource use the calculated one
 				if (!isset($ds['pe_completion']))
 				{
@@ -296,11 +337,10 @@ class datasource
 					}
 				}
 			}
-				
 		}
 		return $ds;
 	}
-	
+
 	/**
 	 * reading the not-overwritten values from the element-data
 	 *
@@ -322,4 +362,4 @@ class datasource
 		}
 		return $values;
 	}
-}
\ No newline at end of file
+}
