@@ -5,9 +5,9 @@
  * @link http://www.egroupware.org
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package projectmanager
- * @copyright (c) 2005 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2005-8 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
- * @version $Id: class.projectmanager_widget.inc.php 24486 2007-10-02 13:40:49Z ralfbecker $ 
+ * @version $Id: class.projectmanager_widget.inc.php 26091 2008-10-07 17:57:50Z ralfbecker $
  */
 
 /**
@@ -17,7 +17,7 @@
  */
 class projectmanager_widget
 {
-	/** 
+	/**
 	 * @var array $public_functions exported methods of this class
 	 */
 	var $public_functions = array(
@@ -36,7 +36,7 @@ class projectmanager_widget
 	 *
 	 * @param string $ui '' for html
 	 */
-	function projectmanager_widget($ui)
+	function __construct($ui)
 	{
 		$this->ui = $ui;
 	}
@@ -48,7 +48,7 @@ class projectmanager_widget
 	 *
 	 * @param string $name form-name of the control
 	 * @param mixed &$value value / existing content, can be modified
-	 * @param array &$cell array with the widget, can be modified for ui-independent widgets 
+	 * @param array &$cell array with the widget, can be modified for ui-independent widgets
 	 * @param array &$readonlys names of widgets as key, to be made readonly
 	 * @param mixed &$extension_data data the extension can store persisten between pre- and post-process
 	 * @param object &$tmpl reference to the template we belong too
@@ -69,12 +69,12 @@ class projectmanager_widget
 		switch ($cell['type'])
 		{
 			case 'projectmanager-select':
-				if (!is_object($GLOBALS['boprojectmanager']))
+				if (!is_object($GLOBALS['projectmanager_bo']))
 				{
-					CreateObject('projectmanager.boprojectmanager');	// assigns itselft to $GLOBALS['boprojectmanager']
+					$GLOBALS['projectmanager_bo'] = new projectmanager_bo();
 				}
-				$cell['sel_options'] = $GLOBALS['boprojectmanager']->link_query('');
-				if ($value && !isset($cell['sel_options'][$value]) && ($title = $GLOBALS['boprojectmanager']->link_title($value)))
+				$cell['sel_options'] = $GLOBALS['projectmanager_bo']->link_query('');
+				if ($value && !isset($cell['sel_options'][$value]) && ($title = $GLOBALS['projectmanager_bo']->link_title($value)))
 				{
 					$cell['sel_options'][$value] = $title;
 				}
@@ -93,21 +93,20 @@ class projectmanager_widget
 					{
 						if (!is_object($this->pricelist))
 						{
-							require_once(EGW_INCLUDE_ROOT.'/projectmanager/inc/class.bopricelist.inc.php');
-							$this->pricelist =& new bopricelist();
+							$this->pricelist =& new projectmanager_pricelist_bo();
 						}
 						$pricelist[$pm_id] = $this->pricelist->pricelist($pm_id);
 					}
 					if (!is_array($pricelist[$pm_id])) continue;
 
-					foreach($pricelist[$pm_id] as $pl_id => $label) 
+					foreach($pricelist[$pm_id] as $pl_id => $label)
 					{
 						if (!isset($cell['sel_options'][$pl_id]))
 						{
 							$cell['sel_options'][$pl_id] = $label;
 						}
 						// if pl_id already used as index, we use pl_id-price as index
-						elseif (preg_match('/\(([0-9.,]+)\)$/',$label,$matches) && 
+						elseif (preg_match('/\(([0-9.,]+)\)$/',$label,$matches) &&
 								!isset($cell['sel_options'][$pl_id.'-'.$matches[1]]))
 						{
 							$cell['sel_options'][$pl_id.'-'.$matches[1]] = $label;
