@@ -6,31 +6,31 @@
  * @author Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @package projectmanager
  * @subpackage setup
- * @copyright (c) 2005 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
+ * @copyright (c) 2005-8 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
- * @version $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ 
+ * @version $Id: setup.inc.php 26091 2008-10-07 17:57:50Z ralfbecker $
  */
 
 $setup_info['projectmanager']['name']      = 'projectmanager';
-$setup_info['projectmanager']['version']   = '1.4';
+$setup_info['projectmanager']['version']   = '1.6';
 $setup_info['projectmanager']['app_order'] = 5;
 $setup_info['projectmanager']['tables']    = array('egw_pm_projects','egw_pm_extra','egw_pm_elements','egw_pm_constraints','egw_pm_milestones','egw_pm_roles','egw_pm_members','egw_pm_pricelist','egw_pm_prices');
 $setup_info['projectmanager']['enable']    = 1;
 
-$setup_info['projectmanager']['author'] = 
+$setup_info['projectmanager']['author'] =
 $setup_info['projectmanager']['maintainer'] = array(
 	'name'  => 'Ralf Becker',
 	'email' => 'RalfBecker@outdoor-training.de'
 );
 $setup_info['projectmanager']['license']  = 'GPL';
-$setup_info['projectmanager']['description'] = 
+$setup_info['projectmanager']['description'] =
 'The projectmanager is a complete rewrite of the projects app using modern object orientated programming
-technics and a widget based user-interface (eTemplate). It has a better integration in eGroupWare 
+technics and a widget based user-interface (eTemplate). It has a better integration in eGroupWare
 by using other already existing apps like InfoLog, Calendar or the TimeSheet.<br>
-For more information see the <a href="http://outdoor-training.de/pdf/projects-rewrite.pdf" 
-target="_blank">concept of the rewrite</a> (<a href="http://outdoor-training.de/pdf/Neuprogrammierung-Projektmanagement.pdf" 
+For more information see the <a href="http://outdoor-training.de/pdf/projects-rewrite.pdf"
+target="_blank">concept of the rewrite</a> (<a href="http://outdoor-training.de/pdf/Neuprogrammierung-Projektmanagement.pdf"
 target="_blank">german version</a>).';
-$setup_info['projectmanager']['note'] = 
+$setup_info['projectmanager']['note'] =
 'It is sponsored by:<ul>
 <li> <a href="http://www.blanke-textil.de" target="_blank">Fritz Blanke GmbH & Co.KG</a></li>
 <li> <a href="http://www.digitask.de" target="_blank">DigiTask GmbH</a></li>
@@ -39,20 +39,20 @@ $setup_info['projectmanager']['note'] =
 </ul>';
 
 /* The hooks this app includes, needed for hooks registration */
-$setup_info['projectmanager']['hooks']['preferences'] = 'projectmanager.pm_admin_prefs_sidebox_hooks.all_hooks';
-$setup_info['projectmanager']['hooks']['settings'] = 'projectmanager.pm_admin_prefs_sidebox_hooks.settings';
-$setup_info['projectmanager']['hooks']['admin'] = 'projectmanager.pm_admin_prefs_sidebox_hooks.all_hooks';
-$setup_info['projectmanager']['hooks']['sidebox_menu'] = 'projectmanager.pm_admin_prefs_sidebox_hooks.all_hooks';
-$setup_info['projectmanager']['hooks']['search_link'] = 'projectmanager.boprojectmanager.search_link';
+$setup_info['projectmanager']['hooks']['preferences'] = 'projectmanager_hooks::all_hooks';
+$setup_info['projectmanager']['hooks']['settings'] = 'projectmanager_hooks::settings';
+$setup_info['projectmanager']['hooks']['admin'] = 'projectmanager_hooks::all_hooks';
+$setup_info['projectmanager']['hooks']['sidebox_menu'] = 'projectmanager_hooks::all_hooks';
+$setup_info['projectmanager']['hooks']['search_link'] = 'projectmanager_hooks::search_link';
 
 /* Dependencies for this app to work */
 $setup_info['projectmanager']['depends'][] = array(
 	 'appname' => 'phpgwapi',
-	 'versions' => Array('1.3','1.4','1.5')
+	 'versions' => Array('1.5','1.6','1.7')
 );
 $setup_info['projectmanager']['depends'][] = array(
 	 'appname' => 'etemplate',
-	 'versions' => Array('1.3','1.4','1.5')
+	 'versions' => Array('1.5','1.6','1.7')
 );
 // installation checks for email
 $setup_info['projectmanager']['check_install'] = array(
@@ -60,20 +60,3 @@ $setup_info['projectmanager']['check_install'] = array(
 		'func' => 'gd_check',
 	),
 );
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
