@@ -7,7 +7,7 @@
  * @link http://www.egroupware.org
  * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
  * @author Lukas Weiss <wnz_gh05t@users.sourceforge.net>
- * @version $Id: class.bo_resources.inc.php 24207 2007-06-25 16:44:20Z ralfbecker $
+ * @version $Id: class.bo_resources.inc.php 26267 2008-10-24 11:30:53Z leithoff $
  */
 
 
@@ -18,9 +18,7 @@
  */
 class bo_resources
 {
-	var $vfs_basedir = '/resources/';
-	var $pictures_dir = '/resources/pictures/';
-	var $thumbs_dir = '/resources/pictures/thumbs/';
+	const PICTURE_NAME = '.picture.jpg';
 	var $resource_icons = '/resources/templates/default/images/resource_icons/';
 	var $debug = 0;
 	/**
@@ -29,18 +27,14 @@ class bo_resources
 	 * @var so_resources
 	 */
 	var $so;
-	
+
 	function bo_resources()
 	{
 		$this->so =& CreateObject('resources.so_resources');
 		$this->acl =& CreateObject('resources.bo_acl');
 		$this->cats = $this->acl->egw_cats;
-		$this->vfs =& CreateObject('phpgwapi.vfs');
-		$this->link =& CreateObject('phpgwapi.bolink');
-		$this->conf =& CreateObject('phpgwapi.config');
-		$this->conf->read_repository();
-		
-		$this->cal_right_transform = array(	
+
+		$this->cal_right_transform = array(
 			EGW_ACL_CALREAD 	=> EGW_ACL_READ,
 			EGW_ACL_DIRECT_BOOKING 	=> EGW_ACL_READ | EGW_ACL_ADD | EGW_ACL_EDIT | EGW_ACL_DELETE,
 			EGW_ACL_CAT_ADMIN 	=> EGW_ACL_READ | EGW_ACL_ADD | EGW_ACL_EDIT | EGW_ACL_DELETE,
@@ -58,7 +52,7 @@ class bo_resources
 		$query['search'] = $query['search'] ? $query['search'] : '*';
 		$criteria = array('name' => $query['search'], 'short_description' => $query['search'], 'inventory_number' => $query['search']);
 		$read_onlys = 'res_id,name,short_description,quantity,useable,bookable,buyable,cat_id,location,storage_info';
-		
+
 		$accessory_of = $query['view_accs_of'] ? $query['view_accs_of'] : -1;
  		$filter = array('accessory_of' => $accessory_of);
 		if ($query['filter'])
@@ -73,10 +67,10 @@ class bo_resources
 		if($query['show_bookable']) $filter = $filter + array('bookable' => true);
 		$order_by = $query['order'] ? $query['order'].' '. $query['sort'] : '';
 		$start = (int)$query['start'];
-		
+
 		$rows = $this->so->search($criteria,$read_onlys,$order_by,'','%',$empty=False,$op='OR',$start,$filter,$join='',$need_full_no_count=false);
 		$nr = $this->so->total;
-		
+
 		// we are called to serve bookable resources (e.g. calendar-dialog)
 		if($query['show_bookable'])
 		{
@@ -88,7 +82,7 @@ class bo_resources
 			// we don't need all the following testing
 			return $nr;
 		}
-		
+
 		foreach((array)$rows as $num => $resource)
 		{
 			if (!$this->acl->is_permitted($resource['cat_id'],EGW_ACL_EDIT))
@@ -117,7 +111,7 @@ class bo_resources
 				$readonlys["buyable[$resource[res_id]]"] = true;
 			}
 			$readonlys["view_acc[$resource[res_id]]"] = true;
-			$links = $this->link->get_links('resources',$resource['res_id']);
+			$links = egw_link::get_links('resources',$resource['res_id']);
 			if(count($links) != 0 && $accessory_of == -1)
 			{
 				foreach ($links as $link_num => $link)
@@ -154,7 +148,7 @@ class bo_resources
 		}
 		return $this->so->read(array('res_id' => $res_id));
 	}
-	
+
 	/**
 	 * saves a resource. pictures are saved in vfs
 	 *
@@ -168,7 +162,6 @@ class bo_resources
 		{
 			return lang('You are not permitted to edit this reource!');
 		}
-		
 		// we need an id to save pictures and make links...
 		if(!$resource['res_id'])
 		{
@@ -178,13 +171,12 @@ class bo_resources
 		switch ($resource['picture_src'])
 		{
 			case 'own_src':
-				$vfs_data = array('string' => $this->pictures_dir.$resource['res_id'].'.jpg','relatives' => array(RELATIVE_ROOT));
 				if($resource['own_file']['size'] > 0)
 				{
 					$msg = $this->save_picture($resource['own_file'],$resource['res_id']);
 					break;
 				}
-				elseif($this->vfs->file_exists($vfs_data))
+				elseif(@egw_vfs::stat('/apps/resources/'.$resource['res_id'].'/'.self::PICTURE_NAME))
 				{
 					break;
 				}
@@ -210,7 +202,7 @@ class bo_resources
 		{
 			return $msg;
 		}
-		
+
 		// delete old pictures
 		if($resource['picture_src'] != 'own_src')
 		{
@@ -220,13 +212,13 @@ class bo_resources
 		// save links
 		if(is_array($resource['link_to']['to_id']))
 		{
-			$this->link->link('resources',$resource['res_id'],$resource['link_to']['to_id']);
+			egw_link::link('resources',$resource['res_id'],$resource['link_to']['to_id']);
 		}
 		if($resource['accessory_of'] != -1)
 		{
-			$this->link->link('resources',$resource['res_id'],'resources',$resource['accessory_of']);
+			egw_link::link('resources',$resource['res_id'],'resources',$resource['accessory_of']);
 		}
-		
+
 		if(!empty($resource['res_id']) && $this->so->get_value("cat_id",$resource['res_id']) != $resource['cat_id'] && $resource['accessory_of'] == -1)
 		{
 			$accessories = $this->get_acc_list($resource['res_id']);
@@ -238,7 +230,7 @@ class bo_resources
 				$this->so->save();
 			}
 		}
-		
+
 		return $this->so->save($resource) ? false : lang('Something went wrong by saving resource');
 	}
 
@@ -254,18 +246,18 @@ class bo_resources
 		{
 			return lang('You are not permitted to delete this reource!');
 		}
-		
+
 		if ($this->so->delete(array('res_id'=>$res_id)))
 		{
 			$this->remove_picture($res_id);
-	 		$this->link->unlink(0,'resources',$res_id);
+	 		egw_link::unlink(0,'resources',$res_id);
 	 		// delete the resource from the calendar
-	 		ExecMethod('calendar.socal.change_delete_user','r'.$res_id);
+	 		ExecMethod('calendar.calendar_so.deleteaccount','r'.$res_id);
 	 		return false;
 		}
 		return lang('Something went wrong by deleting resource');
 	}
-	
+
 	/**
 	 * gets list of accessories for resource
 	 *
@@ -283,12 +275,12 @@ class bo_resources
 		}
 		return $acc_list;
 	}
-	
+
 	/**
 	 * returns info about resource for calender
 	 * @author Cornelius Weiss<egw@von-und-zu-weiss.de>
 	 * @param int/array $res_id single id or array $num => $res_id
-	 * @return array 
+	 * @return array
 	 */
 	function get_calendar_info($res_id)
 	{
@@ -296,7 +288,7 @@ class bo_resources
 		if(!is_array($res_id) && $res_id < 1) return;
 
 		$data = $this->so->search(array('res_id' => $res_id),'res_id,cat_id,name,useable');
-		
+
 		foreach($data as $num => $resource)
 		{
 			$data[$num]['rights'] = false;
@@ -311,12 +303,12 @@ class bo_resources
 		}
 		return $data;
 	}
-	
+
 	/**
 	 * returns status for a new calendar entry depending on resources ACL
 	 * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
 	 * @param int $res_id single id
-	 * @return array 
+	 * @return array
 	 */
 	function get_calendar_new_status($res_id)
 	{
@@ -324,28 +316,144 @@ class bo_resources
 		if($data[0]['bookable'] == 0) return 'x';
 		return $this->acl->is_permitted($data[0]['cat_id'],EGW_ACL_DIRECT_BOOKING) ? A : U;
 	}
-	
+
 	/**
 	 * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
 	 * query infolog for entries matching $pattern
+	 * @param string|array $pattern if it's a string it is the string we will search for as a criteria, if it's an array we
+	 * 	will seach for 'search' key in this array to get the string criteria. others keys handled are actually used
+	 *	for calendar disponibility.
 	 *
 	 */
 	function link_query( $pattern )
 	{
-		$criteria = array('name' => $pattern, 'short_description' => $pattern);
-		$only_keys = 'res_id,name,short_description';
+		if (is_array($pattern))
+		{
+			$criteria =array('name' => $pattern['search']
+					,'short_description' => $pattern['search']);
+		}
+		else
+		{
+			$criteria = array('name' => $pattern
+				, 'short_description' => $pattern);
+		}
+		$only_keys = 'res_id,name,short_description,bookable,useable';
 		$filter = array(
 			'cat_id' => array_flip((array)$this->acl->get_cats(EGW_ACL_READ)),
 			//'accessory_of' => '-1'
 		);
 		$data = $this->so->search($criteria,$only_keys,$order_by='',$extra_cols='',$wildcard='%',$empty,$op='OR',false,$filter);
-		foreach($data as $num => $resource)
+		// maybe we need to check disponibility of the searched resources in the calendar if $pattern ['exec'] contains some extra args
+		$show_conflict=False;
+		if (is_array($pattern) && isset($pattern['exec']) )
 		{
-			$list[$resource['res_id']] = $resource['name']. ($resource['short_description'] ? ', ['.$resource['short_description'].']':'');
+			// we'll use a cache for resources info taken from database
+			static $res_info_cache = array();
+			$cal_info=$pattern['exec'];
+			if ( isset($cal_info['start']) && isset($cal_info['duration']))
+			{
+				//get a calendar objet for reservations
+				if ( (!isset($this->bocal)) || !(is_object($this->bocal)))
+				{
+					require_once(EGW_INCLUDE_ROOT.'/calendar/inc/class.calendar_bo.inc.php');
+					$this->bocal =& CreateObject('calendar.calendar_bo');
+				}
+
+				//get the real timestamps from infos we have on the event
+				//use etemplate date widget to handle date values
+				require_once(EGW_INCLUDE_ROOT.'/phpgwapi/inc/class.jscalendar.inc.php');
+				$jscal=& CreateObject('phpgwapi.jscalendar');
+				$startarr= $jscal->input2date($cal_info['start']['str'],$raw='raw',$day='day',$month='month',$year='year');
+				if (isset($cal_info['whole_day'])) {
+					$startarr['hour'] = $startarr['minute'] = 0;
+					unset($startarr['raw']);
+					$start = $this->bocal->date2ts($startarr);
+					$end = $start + 86399;
+				} else {
+					$startarr['hour'] = $cal_info['start']['H'];
+					$startarr['minute'] = $cal_info['start']['i'];
+					unset($startarr['raw']);
+					$start = $this->bocal->date2ts($startarr);
+					$end = $start + ($cal_info['duration']);
+				}
+
+				// search events matching our timestamps
+ 				$resource_list=array();
+				foreach($data as $num => $resource)
+				{
+					// we only need resources id for the search, but with a 'r' prefix
+					// now we take this loop to store a new resource array indexed with resource id
+					// and as we work for calendar we use only bookable resources
+					if ((isset($resource['bookable'])) && ($resource['bookable'])){
+						$res_info_cache[$resource['res_id']]=$resource;
+						$resource_list[]='r'.$resource['res_id'];
+					}
+				}
+				$overlapping_events =& $this->bocal->search(array(
+					'start' => $start,
+					'end'   => $end,
+					'users' => $resource_list,
+					'ignore_acl' => true,   // otherwise we get only events readable by the user
+					'enum_groups' => false,  // otherwise group-events would not block time
+				));
+
+				// parse theses overlapping events
+				foreach($overlapping_events as $event)
+				{
+					if ($event['non_blocking']) continue; // ignore non_blocking events
+					if (isset($cal_info['event_id']) && $event['id']==$cal_info['event_id']) {
+						continue; //ignore this event, it's the current edited event, no conflict by def
+					}
+					// now we are interested only on resources booked by theses events
+					if (isset($event['participants']) && is_array($event['participants'])){
+						foreach($event['participants'] as $part_key => $part_detail){
+							if ($part_key{0}=='r')
+							{ //now we gatta resource here
+								//need to check the quantity of this resource
+								$resource_id=substr($part_key,1);
+								// if we do not find this resource in our indexed array it's certainly
+								// because it was unset, non bookable maybe
+								if (!isset($res_info_cache[$resource_id])) continue;
+								// to detect ressources with default to 1 quantity
+								if (!isset($res_info_cache[$resource_id]['useable'])) {
+									$res_info_cache[$resource_id]['useable'] = 1;
+								}
+								// now decrement this quantity usable
+								// TODO : decrement with real event quantity, not 1
+								// but this quantity is not given by calendar search, we should re-use a cal object
+								// to load specific cal infos, like quantity... lot of requests
+								$res_info_cache[$resource_id]['useable']--;
+							}
+						}
+					}
+				}
+			}
+		}
+		if (isset($res_info_cache)) {
+			$show_conflict= (isset($pattern['exec']['show_conflict'])&& ($pattern['exec']['show_conflict']=='0'))? False:True;
+			// if we have this array indexed on resource id it means non-bookable resource are removed and we are working for calendar
+			// so we'll loop on this one and not $data
+			foreach($res_info_cache as $id => $resource) {
+				//maybe this resource is reserved
+				if ( ($resource['useable'] < 1) )
+				{
+					if($show_conflict) {
+						$list[$id] = ' ('.lang('conflict').') '.$resource['name']. ($resource['short_description'] ? ', ['.$resource['short_description'].']':'');
+					}
+				} else {
+				        $list[$id] = $resource['name']. ($resource['short_description'] ? ', ['.$resource['short_description'].']':'');
+				}
+			}
+		} else {
+			// we are not working for the calendar, we loop on the initial $data
+			foreach($data as $num => $resource)
+			{
+				$id=$resource['res_id'];
+				$list[$id] = $resource['name']. ($resource['short_description'] ? ', ['.$resource['short_description'].']':'');
+			}
 		}
 		return $list;
 	}
-		
 	/**
 	 * @author Cornelius Weiss <egw@von-und-zu-weiss.de>
 	 * get title for an infolog entry identified by $res_id
@@ -362,7 +470,7 @@ class bo_resources
 
 		return $resource['name']. ($resource['short_description'] ? ', ['.$resource['short_description'].']':'');
 	}
-	
+
 	/**
 	 * resizes and saves an pictures in vfs
 	 *
@@ -370,23 +478,9 @@ class bo_resources
 	 * @param array $file array with key => value
 	 * @param int $resource_id
 	 * @return mixed string with msg if somthing went wrong; nothing if all right
-	 * TODO make thumb an picture sizes choosable by preferences
-	 */	
+	 */
 	function save_picture($file,$resouce_id)
 	{
-		// test upload dir
-		$vfs_data = array('string'=>$this->vfs_basedir,'relatives'=>array(RELATIVE_ROOT));
-		if (!($this->vfs->file_exists($vfs_data)))
-		{
-			$this->vfs->override_acl = 1;
-			$this->vfs->mkdir($vfs_data);
-			$vfs_data['string'] = $this->pictures_dir;
-			$this->vfs->mkdir($vfs_data);
-			$vfs_data['string'] = $this->thumbs_dir;
-			$this->vfs->mkdir($vfs_data);
-			$this->vfs->override_acl = 0;
-		}
-		
 		switch($file['type'])
 		{
 			case 'image/gif':
@@ -403,89 +497,61 @@ class bo_resources
 			default:
 				return lang('Picture type is not supported, sorry!');
 		}
-		
+
 		$src_img_size = getimagesize($file['tmp_name']);
 		$dst_img_size = array( 0 => 320, 1 => 240);
-		$thumb_size = array( 0 => 64, 1 => 48);
-		
-		$tmp_dir = $GLOBALS['egw_info']['server']['temp_dir'].'/';
-		if($src_img_size[0] > 64 || $src_img_size[1] > 48)
+
+		$tmp_name = tempnam($GLOBALS['egw_info']['server']['temp_dir'],'resources-picture');
+		if($src_img_size[0] > $dst_img_size[0] || $src_img_size[1] > $dst_img_size[1])
 		{
-			$f = $thumb_size[0] / $src_img_size[0];
-			$f = $thumb_size[1] / $src_img_size[1] < $f ? $thumb_size[1] / $src_img_size[1] : $f;
+			$f = $dst_img_size[0] / $src_img_size[0];
+			$f = $dst_img_size[1] / $src_img_size[1] < $f ? $dst_img_size[1] / $src_img_size[1] : $f;
 			$dst_img = imagecreatetruecolor($src_img_size[0] * $f, $src_img_size[1] * $f);
 			imagecopyresized($dst_img,$src_img,0,0,0,0,$src_img_size[0] * $f,$src_img_size[1] * $f,$src_img_size[0],$src_img_size[1]);
-			imagejpeg($dst_img,$tmp_dir.$resouce_id.'.thumb.jpg');
-			if($src_img_size[0] > $dst_img_size[0] || $src_img_size[1] > $dst_img_size[1])
-			{
-				$f = $dst_img_size[0] / $src_img_size[0];
-				$f = $dst_img_size[1] / $src_img_size[1] < $f ? $dst_img_size[1] / $src_img_size[1] : $f;
-				$dst_img = imagecreatetruecolor($src_img_size[0] * $f, $src_img_size[1] * $f);
-				imagecopyresized($dst_img,$src_img,0,0,0,0,$src_img_size[0] * $f,$src_img_size[1] * $f,$src_img_size[0],$src_img_size[1]);
-				imagejpeg($dst_img,$tmp_dir.$resouce_id.'.jpg');
-			}
-			else
-			{
-				imagejpeg($src_img,$tmp_dir.$resouce_id.'.jpg');
-			}
+			imagejpeg($dst_img,$tmp_name);
 			imagedestroy($dst_img);
 		}
 		else
 		{
-				imagejpeg($src_img,$tmp_dir.$resouce_id.'.jpg');
-				imagejpeg($src_img,$tmp_dir.$resouce_id.'.thumb.jpg');
+			imagejpeg($src_img,$tmp_name);
 		}
 		imagedestroy($src_img);
-			
-		$this->vfs->override_acl = 1;
-		$this->vfs->cp(array(
-			'from' => $tmp_dir.$resouce_id.'.jpg',
-			'to'   => $this->pictures_dir.$resouce_id.'.jpg',
-			'relatives' => array(RELATIVE_NONE|VFS_REAL,RELATIVE_ROOT)
+
+		egw_link::attach_file('resources',$resouce_id,array(
+			'tmp_name' => $tmp_name,
+			'name'     => self::PICTURE_NAME,
+			'type'     => 'image/jpeg',
 		));
-		$this->vfs->set_attributes(array(
-			'string' => $this->pictures_dir.$resouce_id.'.jpg',
-			'relatives' => array (RELATIVE_ROOT),
-			'attributes' => array (
-				'mime_type' => 'image/jpeg',
-				'comment' => 'picture of resource no.'.$resouce_id,
-				'app' => $GLOBALS['egw_info']['flags']['currentapp']
-		)));
-		$this->vfs->cp(array(
-			'from' => $tmp_dir.$resouce_id.'.thumb.jpg',
-			'to'   => $this->thumbs_dir.$resouce_id.'.jpg',
-			'relatives' => array(RELATIVE_NONE|VFS_REAL,RELATIVE_ROOT)
-			));
-		$this->vfs->set_attributes(array(
-			'string' => $this->thumbs_dir.$resouce_id.'.jpg',
-			'relatives' => array (RELATIVE_ROOT),
-			'attributes' => array (
-				'mime_type' => 'image/jpeg',
-				'comment' => 'thumbnail of resource no.'.$resouce_id,
-				'app' => $GLOBALS['egw_info']['flags']['currentapp']
-		)));
-		$this->vfs->override_acl = 0;
-		return;
 	}
-	
+
 	/**
 	 * get resource picture either from vfs or from symlink
 	 * Cornelius Weiss <egw@von-und-zu-weiss.de>
 	 * @param int $res_id id of resource
-	 * @param bool $size false = thumb, true = full pic
+	 * @param bool $fullsize false = thumb, true = full pic
 	 * @return string url of picture
 	 */
-	function get_picture($res_id=0,$size=false)
+	function get_picture($res_id=0,$fullsize=false)
 	{
 		if ($res_id > 0)
 		{
 			$src = $this->so->get_value('picture_src',$res_id);
 		}
+#echo $scr."<br>". $this->pictures_dir."<br>";
 		switch($src)
 		{
 			case 'own_src':
-				$picture = $this->conf->config_data['dont_use_vfs'] ? $GLOBALS['egw_info']['server']['webserver_url'] : 'vfs:';
-				$picture .= $size ? $this->pictures_dir.$res_id.'.jpg' : $this->thumbs_dir.$res_id.'.jpg';
+				$picture = egw_link::vfs_path('resources',$res_id,self::PICTURE_NAME,true);	// vfs path
+				if ($fullsize)
+				{
+					$picture = egw::link(egw_vfs::download_url($picture));
+				}
+				else
+				{
+					$picture = egw::link('/etemplate/thumbnail.php',array('path' => $picture));
+				}
+				//$picture=$GLOBALS['egw_info']['server'].$picture;
+#echo $picture."<br>";
 				break;
 			case 'cat_src':
 				list($picture) = $this->cats->return_single($this->so->get_value('cat_id',$res_id));
@@ -502,7 +568,7 @@ class bo_resources
 		}
 		return $picture;
 	}
-	
+
 	/**
 	 * remove_picture
 	 * removes picture from vfs
@@ -513,15 +579,11 @@ class bo_resources
 	 */
 	function remove_picture($res_id)
 	{
-		$vfs_data = array('string' => $this->pictures_dir.$res_id.'.jpg','relatives' => array(RELATIVE_ROOT));
-		$this->vfs->override_acl = 1;
-		if($this->vfs->file_exists($vfs_data))
+		if (($arr = egw_link::delete_attached('resources',$res_id,self::PICTURE_NAME)))
 		{
-			$this->vfs->rm($vfs_data);
-			$vfs_data['string'] = $this->thumbs_dir.$res_id.'.jpg';
-			$this->vfs->rm($vfs_data);
+			return array_shift($arr);	// $arr = array($path => (bool)$ok);
 		}
-		$this->vfs->override_acl = 0;
+		return false;
 	}
 
 	/**
