@@ -10,27 +10,23 @@
 	*  Free Software Foundation; version 2 of the License.                     *
 	\**************************************************************************/
 
-	/* $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ */
+	/* $Id: setup.inc.php 26147 2008-10-10 11:53:42Z ralfbecker $ */
 
 	$setup_info['sambaadmin']['name']	= 'sambaadmin';
 	$setup_info['sambaadmin']['title']	= 'SambaAdmin';
 	$setup_info['sambaadmin']['version']	= '1.4';
 	$setup_info['sambaadmin']['app_order']	= 99;
 
-	$setup_info['sambaadmin']['author']	= array(
-		'name'	=> 'Lars Kneschke',
-		'email'	=> 'lkneschke@users.sourceforge.net',
-	);
+	$setup_info['sambaadmin']['author']	= 'Lars Kneschke';
 
 	$setup_info['sambaadmin']['license']	= 'GPL';
 	$setup_info['sambaadmin']['description']= 'Manage LDAP based Samba servers';
 
 	$setup_info['sambaadmin']['maintainer'] = array(
-		'name'	=> 'Lars Kneschke',
-		'email'	=> 'lkneschke@linux-at-work.de',
+		'name'	=> 'eGroupware coreteam',
+		'email'	=> 'egroupware-developers@lists.sf.net',
 	);
 
-
 	$setup_info['sambaadmin']['tables']    = array();
 	$setup_info['sambaadmin']['enable']    = 1;
 
@@ -39,7 +35,7 @@
 	$setup_info['sambaadmin']['hooks'][]	= 'edit_user';
 	$setup_info['sambaadmin']['hooks'][]	= 'admin';
 	$setup_info['sambaadmin']['hooks'][]	= 'changepassword';
-	
+
 	$setup_info['sambaadmin']['hooks']['addaccount']	= 'sambaadmin.bosambaadmin.updateAccount';
 	$setup_info['sambaadmin']['hooks']['editaccount']	= 'sambaadmin.bosambaadmin.updateAccount';
 	$setup_info['sambaadmin']['hooks']['editgroup']		= 'sambaadmin.bosambaadmin.updateGroup';
@@ -47,6 +43,5 @@
 	/* Dependacies for this app to work */
 	$setup_info['sambaadmin']['depends'][]	= array(
 		'appname'  => 'phpgwapi',
-		'versions' => Array('1.3','1.4','1.5')
+		'versions' => Array('1.4','1.5','1.6','1.7')
 	);
-?>
