@@ -14,7 +14,7 @@
 	*  Free Software Foundation; either version 2 of the License, or (at your  *
 	*  option) any later version.                                              *
 	\**************************************************************************/
-	/* $Id: class.setup_process.inc.php 22372 2006-08-30 04:48:56Z ralfbecker $ */
+	/* $Id: class.setup_process.inc.php 26254 2008-10-21 14:22:27Z ralfbecker $ */
 
 	/* app status values:
 	U	Upgrade required/available
@@ -55,9 +55,10 @@
 		 * @param string $type='new' defaults to new(install), could also be 'upgrade'
 		 * @param boolean $DEBUG=false print debugging info
 		 * @param boolean $force_en=false install english language files
-		 * @param string $system_charset=null charset to use	
+		 * @param string $system_charset=null charset to use
+		 * @param array $preset_config=array()
 		 */
-		function pass($setup_info,$method='new',$DEBUG=False,$force_en=False)
+		function pass($setup_info,$method='new',$DEBUG=False,$force_en=False,$preset_config=array())
 		{
 			if(!$method)
 			{
@@ -118,7 +119,7 @@
 					case 'new':
 						/* Create tables and insert new records for each app in this list */
 						$passing = $this->current($pass,$DEBUG);
-						$this->save_minimal_config();
+						$this->save_minimal_config($preset_config);
 						$passing = $this->default_records($passing,$DEBUG);
 						$do_langs = true;	// just do it once at the end of all passes
 						break;
@@ -190,51 +191,59 @@
 		/**
 		 * saves a minimal default config, so you get a running install without entering and saveing Step #2 config
 		 *
+		 * @param array $preset_config=array()
 		 */
-		function save_minimal_config()
+		function save_minimal_config(array $preset_config=array())
 		{
 			$is_windows = strtoupper(substr(PHP_OS,0,3)) == 'WIN';
-		
-			$GLOBALS['current_config']['site_title'] = 'eGroupWare';
-			$GLOBALS['current_config']['hostname']  = $_SERVER['HTTP_HOST'] ? $_SERVER['HTTP_HOST'] : 'localhost';
+
+			$current_config['site_title'] = 'eGroupWare';
+			$current_config['hostname']  = $_SERVER['HTTP_HOST'] ? $_SERVER['HTTP_HOST'] : 'localhost';
 
 			// guessing the eGW url
 			$parts = explode('/',$_SERVER['PHP_SELF']);
 			array_pop($parts);	// remove config.php
 			array_pop($parts);	// remove setup
-			$GLOBALS['current_config']['webserver_url'] = implode('/',$parts);
+			$current_config['webserver_url'] = implode('/',$parts);
 			$egroupwareDirName = end($parts);
 
 			if(!$is_windows) {
 				if(@is_dir('/tmp')) {
-					$GLOBALS['current_config']['temp_dir'] = '/tmp';
+					$current_config['temp_dir'] = '/tmp';
 				} else {
-					$GLOBALS['current_config']['temp_dir'] = '/path/to/temp/dir';
+					$current_config['temp_dir'] = '/path/to/temp/dir';
 				}
-				$GLOBALS['current_config']['files_dir'] = '/var/lib/'.$egroupwareDirName.'/'.$GLOBALS['egw_setup']->ConfigDomain.'/files';
-				$GLOBALS['current_config']['backup_dir'] = '/var/lib/'.$egroupwareDirName.'/'.$GLOBALS['egw_setup']->ConfigDomain.'/backup';
+				$current_config['files_dir'] = '/var/lib/'.$egroupwareDirName.'/'.$GLOBALS['egw_setup']->ConfigDomain.'/files';
+				$current_config['backup_dir'] = '/var/lib/'.$egroupwareDirName.'/'.$GLOBALS['egw_setup']->ConfigDomain.'/backup';
 			} else {
 				if(@is_dir('c:\\windows\\temp')) {
-					$GLOBALS['current_config']['temp_dir'] = 'c:\\windows\\temp';
+					$current_config['temp_dir'] = 'c:\\windows\\temp';
 				} else {
-					$GLOBALS['current_config']['temp_dir'] = 'c:\\path\\to\\temp\\dir';
+					$current_config['temp_dir'] = 'c:\\path\\to\\temp\\dir';
 				}
-				$GLOBALS['current_config']['files_dir'] = 'c:\\Program files\\'.$egroupwareDirName.'\\'.$GLOBALS['egw_setup']->ConfigDomain.'\\files';
-				$GLOBALS['current_config']['backup_dir'] = 'c:\\Program files\\'.$egroupwareDirName.'\\'.$GLOBALS['egw_setup']->ConfigDomain.'\\backup';
-			} 
-			$datetime =& CreateObject('phpgwapi.datetime');
-			$GLOBALS['current_config']['tz_offset'] = $datetime->getbestguess();
+				$current_config['files_dir'] = 'c:\\Program files\\'.$egroupwareDirName.'\\'.$GLOBALS['egw_setup']->ConfigDomain.'\\files';
+				$current_config['backup_dir'] = 'c:\\Program files\\'.$egroupwareDirName.'\\'.$GLOBALS['egw_setup']->ConfigDomain.'\\backup';
+			}
+			$datetime =& CreateObject('phpgwapi.egw_datetime');
+			$current_config['tz_offset'] = $datetime->getbestguess();
 			unset($datetime);
 
 			// RalfBecker: php.net recommend this for security reasons, it should be our default too
-			$GLOBALS['current_config']['usecookies'] = 'True';
-			
+			$current_config['usecookies'] = 'True';
+
 			if ($GLOBALS['egw_setup']->system_charset)
 			{
-				$GLOBALS['current_config']['system_charset'] = $GLOBALS['egw_setup']->system_charset;
+				$current_config['system_charset'] = $GLOBALS['egw_setup']->system_charset;
 			}
 
-			foreach($GLOBALS['current_config'] as $name => $value)
+			$current_config['install_id'] = md5($_SERVER['HTTP_HOST'].microtime(true).$GLOBALS['egw_setup']->ConfigDomain);
+
+			if ($preset_config)
+			{
+				$current_config = array_merge($current_config,$preset_config);
+			}
+
+			foreach($current_config as $name => $value)
 			{
 				$GLOBALS['egw_setup']->db->insert($GLOBALS['egw_setup']->config_table,array(
 					'config_value' => $value,
@@ -243,6 +252,9 @@
 					'config_name' => $name,
 				),__FILE__,__LINE__);
 			}
+
+			// so the default_records use the current data
+			$GLOBALS['egw_setup']->setup_account_object($current_config);
 		}
 
 		/**
@@ -517,9 +529,9 @@
 				}
 
 				/* if upgrade required, or if we are running again after an upgrade or dependency failure */
-				if($DEBUG) 
-				{ 
-					echo '<div style="text-align: left; border: thin dashed black; margin-top: 5px;">'."process->upgrade(): Incoming : appname: $appname, version: $appdata[currentver], status: $appdata[status]\n"; 
+				if($DEBUG)
+				{
+					echo '<div style="text-align: left; border: thin dashed black; margin-top: 5px;">'."process->upgrade(): Incoming : appname: $appname, version: $appdata[currentver], status: $appdata[status]\n";
 				}
 				if($appdata['status'] == 'U' || $appdata['status'] == 'D' ||$appdata['status'] == 'V' || $appdata['status'] == '') // TODO this is not getting set for api upgrade, sometimes ???
 				{
@@ -534,7 +546,7 @@
 							include ($appdir . 'tables_update.inc.php');
 							$this->updateincluded[$appname] = True;
 						}
-						while ($currentver && $currentver != $targetver && 
+						while ($currentver && $currentver != $targetver &&
 							function_exists($function = $appname . '_upgrade' . str_replace('.','_',$currentver)))
 						{
 							if($DEBUG)
@@ -558,7 +570,7 @@
 							}
 						}
 						if ($currentver == $targetver)	// upgrades succesful
-						{	
+						{
 							if($DEBUG)
 							{
 								echo "<br>process->upgrade(): Upgrade of $appname to $targetver is completed.\n";
@@ -598,7 +610,7 @@
 							$GLOBALS['egw_setup']->register_hooks($appname);
 						}
 					}
-					
+
 				}
 				else
 				{
