@@ -9,7 +9,7 @@
   *  option) any later version.                                              *
   \**************************************************************************/
 
-  /* $Id: schematoy.php 23420 2007-02-14 14:08:55Z milosch $ */
+  /* $Id: schematoy.php 24773 2007-12-09 08:03:56Z ralfbecker $ */
 
 	$GLOBALS['DEBUG'] = True;
 
@@ -31,7 +31,7 @@
 	// Does not return unless user is authorized
 
 	$tpl_root = $GLOBALS['egw_setup']->html->setup_tpl_dir('setup');
-	$GLOBALS['setup_tpl'] = CreateObject('setup.Template',$tpl_root);
+	$GLOBALS['setup_tpl'] = CreateObject('phpgwapi.Template',$tpl_root);
 	$GLOBALS['setup_tpl']->set_file(array(
 		'T_head' => 'head.tpl',
 		'T_footer' => 'footer.tpl',
