@@ -9,7 +9,7 @@
 *  option) any later version.                                              *
 \**************************************************************************/
 
-/* $Id: class.Categories_UI.inc.php 18395 2005-06-02 05:27:33Z lkneschke $ */
+/* $Id: class.Categories_UI.inc.php 25174 2008-03-25 16:12:51Z ralfbecker $ */
 
 class Categories_UI
 {
@@ -135,10 +135,10 @@ class Categories_UI
 			'focus_reload_close' => $focus_reload_close,
 			'add_edit' => ($cat_id ? lang('Edit Category') : lang('Add Category')),
 			'cat_id' => $cat_id,
-			'catname' => $cat->name,
-			'catdesc' => $cat->description,
+			'catname' => $cat ? $cat->name : $inputcatname,
+			'catdesc' => $cat ? $cat->description : $inputcatdesc,
 			'indexpageselect' => $indexpageselect,
-			'sort_order' => $cat->sort_order,
+			'sort_order' => $cat ? $cat->sort_order : $inputsortorder,
 			'parent_dropdown' => $this->getParentOptions($_GET['addsub'] ? $_GET['addsub'] : $cat->parent,$cat_id),
 			'stateselect' => $GLOBALS['Common_BO']->inputstateselect($cat->state),
 			'old_parent' => $cat->parent,
