@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.Content_UI.inc.php 19647 2005-11-07 08:03:54Z ralfbecker $ */
+	/* $Id: class.Content_UI.inc.php 26337 2008-11-11 09:40:53Z ralfbecker $ */
 
 	class Content_UI
 	{
@@ -22,7 +22,6 @@
 		var $sitelanguages;
 		var $worklanguage;
 		var $errormsg;
-		var $langselect;
 
 		var $public_functions = array
 		(
@@ -42,31 +41,11 @@
 			$this->viewable =& $GLOBALS['Common_BO']->viewable;
 
 			$this->sitelanguages = $GLOBALS['Common_BO']->sites->current_site['sitelanguages'];
-			$savelanguage = $_POST['savelanguage'];
-			$savelanguage = $savelanguage ? $savelanguage : 
-				($GLOBALS['sitemgr_info']['userlang'] ? $GLOBALS['sitemgr_info']['userlang'] :
-				$GLOBALS['egw']->session->appsession('worklanguage','sitemgr') ?
-				$GLOBALS['egw']->session->appsession('worklanguage','sitemgr') : $this->sitelanguages[0]);
-			//$GLOBALS['sitemgr_info']['userlang']=$savelanguage;
-			$this->worklanguage = $savelanguage;
-			//$GLOBALS['egw']->session->appsession('worklanguage','sitemgr',$savelanguage);
-
+			$GLOBALS['sitemgr_info']['userlang'] = $GLOBALS['egw']->session->appsession('language','sitemgr-site');
+			$this->worklanguage = isset($_POST['savelanguage']) ? $_POST['savelanguage'] :
+				($GLOBALS['sitemgr_info']['userlang'] ? $GLOBALS['sitemgr_info']['userlang'] : $this->sitelanguages[0]);
+			error_log(__METHOD__."() sitemgr_info[userlanguage]={$GLOBALS['sitemgr_info']['userlang']}, common[lang]={$GLOBALS['egw_info']['user']['preferences']['common']['lang']}, _POST[savelanguage]=$_POST[savelanguage], sitelanguages=".implode(', ',$this->sitelanguages)." --> worklanguage=$this->worklanguage");
 			$this->errormsg = array();
-
-			if (count($this->sitelanguages) > 1)
-			{
-				$this->langselect = lang('as') . ' <select name="savelanguage">';
-				foreach ($this->sitelanguages as $lang)
-				{
-					$selected= '';
-					if ($lang == $this->worklanguage)
-					{
-						$selected = 'selected="selected" ';
-					}
-					$this->langselect .= '<option ' . $selected .'value="' . $lang . '">'. $GLOBALS['Common_BO']->getlangname($lang) . '</option>';
-				}
-				$this->langselect .= '</select> ';
-			}
 		}
 
 		function manage()
@@ -172,22 +151,41 @@
 					$block->title = $inputblocktitle;
 					$block->sort_order = $inputblocksort;
 					$block->view = $inputblockview;
+
+					foreach($element as $version_id => &$content)
+					{
+						if (isset($GLOBALS['egw_unset_vars']["_POST[element][$version_id][i18n][htmlcontent]"]) && !isset($content['i18n']['htmlcontent']))
+						{
+							if ($this->acl->is_admin())
+							{
+								$content['i18n']['htmlcontent'] =& $GLOBALS['egw_unset_vars']["_POST[element][$version_id][i18n][htmlcontent]"];
+								unset($GLOBALS['egw_unset_vars']["_POST[element][$version_id][i18n][htmlcontent]"]);
+							}
+							else
+							{
+								$this->errormsg[] = lang('You need to be an administrator of this website to enter javascript!');
+							}
+						}
+					}
 				}
-				$result = $this->bo->saveblockdata($block,$element,$inputstate,$this->worklanguage,$_POST['scope']);
-				if ($result !== True)
+				if (!$this->errormsg)
 				{
-					//result should be an array of validationerrors
-					$this->errormsg = $result;
-				}
-				else
-				{
-					$this->errormsg[] = lang('Block saved');
-					$focus_reload_close = 'opener.location.reload();';
-				}
-				if ($_GET['sort_order'] || $block_id && $btnSaveBlock && $result === True)
-				{
-					echo '<html><head></head><body onload="opener.location.reload();self.close()"></body></html>';
-					$GLOBALS['egw']->common->egw_exit();
+					$result = $this->bo->saveblockdata($block,$element,$inputstate,$this->worklanguage,$_POST['scope']);
+					if ($result !== True)
+					{
+						//result should be an array of validationerrors
+						$this->errormsg = $result;
+					}
+					else
+					{
+						$this->errormsg[] = lang('Block saved');
+						$focus_reload_close = 'opener.location.reload();';
+					}
+					if ($_GET['sort_order'] || $block_id && $btnSaveBlock && $result === True)
+					{
+						echo '<html><head></head><body onload="opener.location.reload();self.close()"></body></html>';
+						$GLOBALS['egw']->common->egw_exit();
+					}
 				}
 			}
 			elseif ($btnReloadBlock && $block_id)
@@ -413,7 +411,7 @@
 					'block' => $this->bo->getlangblocktitle($block_id,$this->sitelanguages[0]),
 					'blockid' => $block_id,
 					'scope' => $this->blockscope($block->cat_id,$block->page_id),
-					'addedorremovedorreplaced' => ($block->cnt == 2) ? 'replaced' : 
+					'addedorremovedorreplaced' => ($block->cnt == 2) ? 'replaced' :
 						(($block->state == SITEMGR_STATE_PREPUBLISH) ? 'added' : 'removed'),
 					'edit' =>  $GLOBALS['egw']->link('/index.php',array(
 						'block_id' => $block_id,
@@ -551,7 +549,7 @@
 		{
 			$returnValue = '';
 			foreach($modules as $id => $module)
-			{ 
+			{
 				$returnValue.='<option title="' . lang($module['description']) . '" value="'.$id.'">'.
 					$module['module_name'].'</option>'."\n";
 			}
@@ -593,11 +591,7 @@
 				}
 				if (count($scopes) > 1)
 				{
-					if (!is_object($GLOBALS['egw']->html))
-					{
-						$GLOBALS['egw']->html =& CreateObject('phpgwapi.html');
-					}
-					return $GLOBALS['egw']->html->select('scope',array($scope),$scopes,True);
+					return html::select('scope',array($scope),$scopes,True);
 				}
 				else
 				{
@@ -628,10 +622,20 @@
 			//TODO: wrap a module storage around createmodule as in template3,
 			//TODO: so that we do not create the same module object twice
 			$moduleobject =& $this->modulebo->createmodule($block->module_name);
+
+			if (count($this->sitelanguages) > 1)
+			{
+				$langs = array();
+				foreach ($this->sitelanguages as $lang)
+				{
+					$langs[$lang] = $GLOBALS['Common_BO']->getlangname($lang);
+				}
+				$langselect = html::select('savelanguage',$this->worklanguage,$langs,false,' onchange="this.form.submit()"');
+			}
 			$this->t->set_var(array(
 				'moduleinfo' => $block->module_name,
 				'description' => lang($moduleobject->description),
-				'savelang' => $this->langselect
+				'savelang' => $langselect
 			));
 
 			//if the block is in our scope and we are entitled we edit it
@@ -679,8 +683,8 @@
 				$this->t->set_var('EvBlock','');
 				while (list($version_id,$version) = each($versions))
 				{
-					//set the version of the block which is referenced by the moduleobject, 
-					//so that we retrieve a interface with the current version's arguments 
+					//set the version of the block which is referenced by the moduleobject,
+					//so that we retrieve a interface with the current version's arguments
 					$block->set_version($version);
 					$editormoduleelements = $moduleobject->get_user_interface();
 					$this->t->set_var(array(
