@@ -9,7 +9,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.module_navigation.inc.php 22730 2006-10-24 21:38:12Z nelius_weiss $ */
+	/* $Id: class.module_navigation.inc.php 26338 2008-11-11 10:24:42Z ralfbecker $ */
 
 	/**
 	 * Navigation framework module
@@ -46,18 +46,18 @@
 	 *
 	 * @author Cornelius Weiss<egw@von-und-zu-weiss.de>
 	 * @package sitemgr
-	 * 
+	 *
 	 */
 	class module_navigation extends Module
 	{
 		var $lastcatdepth = 0;
 		var $lastpagedepth = 0;
-		
+
 		function module_navigation()
 		{
 			$this->arguments = array(
 				'nav_type' => array(
-					'type' => 'select', 
+					'type' => 'select',
 					'label' => lang('Select type of Navigation'),
 					'options' => array(
 						0 => lang('Select one'),
@@ -71,8 +71,9 @@
 						8 => 'path',
 						9 => lang('custom'),
 					   10 => 'tabs',
+					   11 => 'XML Sitemap',
 					)
-				)	
+				)
 			);
 			$this->nav_args = array(
 				1 => array( // Currentsection
@@ -115,7 +116,7 @@
 					),
 					'main_cats_to_include' => array(
 						'type' => 'textfield',
-						'label' => lang('Which main categories schuld be included (comma seperated list, empty for all)'),
+						'label' => lang('Which main categories should be included (comma separated list, empty for all)'),
 					)),
 				4 => array( // Navigation
 					'description' => lang("This module displays the root categories in one block each, with pages and subcategories (incl. their pages if activated).")
@@ -126,7 +127,7 @@
 				6 => array( // Toc
 					'description' => lang('This module provides a complete table of contents, it is automatically used by the toc and category_id GET parameters'),
 					'category_id' =>array(
-						'type' => 'textfield', 
+						'type' => 'textfield',
 						'label' => lang('The category to display, 0 for complete table of contents')
 					)),
 				7 => array( // Toc_block
@@ -136,8 +137,12 @@
 					'description' => lang('This module provides the path to the element currently shown'),
 					'no_show_sep' => array(
 						'type' => 'checkbox',
-						'label'=> lang('Don\'t use egroupware css ">" separator (for templates that uses images/simbols for lists)')
-					)),
+						'label'=> lang('Don\'t use egroupware css ">" separator (for templates that uses images/symbols for lists)')),
+					'suppress_hide_pages' => array(
+						'type' => 'checkbox',
+						'label'=> lang('Don\'t show hiden pages in the path way')),
+
+						),
 				9 => array( //Custom
 					'description' => lang('This module is a customisable navigation element'),
 					'alignment' => array(
@@ -211,19 +216,19 @@
 							lang('Seperate Cats / Pages of one tab by :').
 							lang('cats are numeric, pages strings'),
 					),
-				));
+				),
+				11 => array(	// xml sitemap
+					'description' => lang('This module provides an XML sitemap (see www.sitemap.org)'),
+				),
+			);
 			$this->title = 'Navigation element';
 			$this->description = lang("This module displays any kind of navigation element.");
 		}
-		
+
 		function get_user_interface()
 		{
-			if(!@is_object($GLOBALS['egw']->js))
-			{
-				$GLOBALS['egw']->js =& CreateObject('phpgwapi.javascript');
-			}
 			$GLOBALS['egw']->js->validate_file('tabs','tabs');
-				
+
 			// I know, this is ugly. If you find a better solution for this, please help!
 			$interface[] = array(
 				'label' => "
@@ -240,20 +245,20 @@
 			$this->arguments['nav_type']['params'] = array(
 				'onchange' => 'javascript:tab.display(this.value)'
 			);
-			
+
 			$elementname = 'element[' . $this->block->version . '][nav_type]';
 			$interface[] = array(
 				'label' => '<b>'.$this->arguments['nav_type']['label'].'</b>'.
 					parent::build_input_element($this->arguments['nav_type'],$this->block->arguments['nav_type'],$elementname)
 			);
-			
+
 			// build the tab elements
 			$tabs = '';
 			for($id = 1; $id < count($this->arguments['nav_type']['options']); $id++)
 			{
 				$description = $this->nav_args[$id]['description'];
 				unset($this->nav_args[$id]['description']);
-				
+
 				$tmpargs = $this->arguments;
 				$this->arguments = $this->nav_args[$id];
 				$tabs .= '<div id="tabcontent'. $id. '" class="inactivetab"><table>';
@@ -273,7 +278,7 @@
 				$this->arguments = $tmpargs;
 			}
 			$interface[] = array('label' => $tabs);
-			
+
 			// show current tab
 			$interface[] = array(
 				'label' => "
@@ -284,7 +289,7 @@
 
 			return $interface;
 		}
-		
+
 		// strip options from other nav_types
 		function validate(&$data)
 		{
@@ -296,11 +301,11 @@
 			$data = $val_data;
 			return true;
 		}
-		
+
 		function get_content(&$arguments,$properties)
 		{
 			$out =  "<!-- navigation-context begins here -->\n".
-				"<div id=\"navigation-context\">\n".
+				"<div id=\"navigation-context".$arguments['nav_type']."\">\n".
 				"  <div id=\"navigation-";
 			switch ($arguments['nav_type'])
 			{
@@ -323,7 +328,7 @@
 					$arguments = array_merge($arguments, array(
 						'max_cat_depth' => '2',
 						'max_pages_depth' => '2',
-						'showhidden' => false,
+						'showhidden' => true,
 						'suppress_parent' => true,
 						'suppress_show_all' => true,
 						'suppress_cat_link' => true,
@@ -346,7 +351,8 @@
 				case 5 : // Sitetree
 					$out .= "sitetree\">\n";
 					$out .= $this->type_sitetree($arguments,$properties);
-					$out .= "  </div>\n<!-- navigation context ends here -->\n</div>\n";
+					$out .= "  </div>\n</div>\n".
+						"<!-- navigation context ends here -->\n\n";
 					return $out;
 				case 6 : // Toc
 					$out .= "toc\">\n";
@@ -364,7 +370,7 @@
 							'max_cat_depth' => '10',
 							'max_pages_depth' => '0',
 							'no_full_index' => true,
-							
+
 						));
 					}
 					// like currentsection of a certain cat
@@ -393,7 +399,7 @@
 				case 8 : // Path
 					if(!$arguments['no_show_sep'])
 					{
-						$out .= "path\">\n";	
+						$out .= "path\">\n";
 					}
 					else
 					{
@@ -406,11 +412,11 @@
 						'no_full_index' => true,
 					));
 					break;
-					
+
 				case 9 : // Custom
 					$out .= "custom\" ";
-					$out .= "class=\"alignment-". $arguments['alignment']."\" ";
-					$out .= "class=\"textalign-". $arguments['textalign']."\"";
+					$out .= "class=\"alignment-". $arguments['alignment'].";";
+					$out .= "textalign-". $arguments['textalign']."\"";
 					$out .= ">\n";
 					break;
 				case 10 : // tabs
@@ -418,18 +424,21 @@
 					$out .= $this->type_tabs($arguments,$properties);
 					$out .= "  </div>\n<!-- navigation context ends here -->\n</div>\n";
 					return $out;
+				case 11: // xml sitemap
+					return $this->type_xml_sitemap($arguments,$properties);
 				case 4 : // Navigation
 				default:
 					$out .= "navigation\">\n";
 					$out .= $this->type_navigation($arguments,$properties);
-					$out .= "  </div>\n<!-- navigation context ends here -->\n</div>\n";
+					$out .= "  </div>\n</div>\n".
+						"<!-- navigation context ends here -->\n\n";
 					return $out;
 			}
-				
+
 			$this->objbo =& $GLOBALS['objbo'];
 			$this->page =& $GLOBALS['page'];
 			$this->category =& $this->objbo->getcatwrapper($this->page->cat_id);
-			
+
 			if (!$arguments['suppress_parent'])
 			{
 				$parent = $this->category->parent;
@@ -442,7 +451,7 @@
 					$out .= "\n<br />\n";
 				}
 			}
-			
+
 			if($arguments['show_subcats_above'])
 			{
 				$catlinks = $arguments['category_id'] ?
@@ -456,26 +465,26 @@
 						$this->encapsulate($arguments,$catlinks,'cat',(int)$this->page->cat_id);
 					$out .= "\n<br />\n";
 				}
-				
+
 			}
-			
+
 			if($arguments['nav_title'])
 			{
 				$out .= "\n<span class=\"nav-title\">".$arguments['nav_title']."</span>\n";
 			}
-			
+
 			if (!$arguments['suppress_show_all'])
 			{
 				$out .= ' (<a href="'.sitemgr_link2('/index.php','category_id='.$this->page->cat_id).
 					'"><i>'.lang('show all').'</i></a>)'."\n";
 			}
-			
+
 			// relative cat or pages depth ?
 			if (strpos($arguments['max_cat_depth'],'+') === 0) (int)$arguments['max_cat_depth'] += $this->category->depth;
 			if (strpos($arguments['max_pages_depth'],'+') === 0) (int)$arguments['max_pages_depth'] += $this->category->depth;
-			
+
 			$cat_tree = $cat_tree_data = array('root');
-			
+
 			$this->lastcatdepth = 0; // indicate start of first cat block!
 			foreach(($this->objbo->getCatLinks(0,true,true) + array( 0 => array('depth' => 0))) as $cat_id => $cat)
 			{
@@ -505,7 +514,7 @@
 							$cat_tree_data[$num]['pages_only'] = true;
 						}
 					}
-					
+
 					//expand rest
 					$cat_tree = array_reverse($cat_tree); $cat_tree_data = array_reverse($cat_tree_data);
 					$outstack = array($cat_tree[count($cat_tree) -1]); $outstack_data = array($cat_tree_data[count($cat_tree) -1]);
@@ -530,17 +539,18 @@
 					}
 					continue;
 				}
-				
+
 				if($arguments['path_only'])
 				{
 					if($cat_id != $this->page->cat_id) continue;
 					unset($cat_tree_data[0]);
-					$pages = $this->objbo->getPageLinks($cat_id,true,true);
+					$suppress_hide_pages=!$arguments['suppress_hide_pages']?true:false;
+					$pages = $this->objbo->getPageLinks($cat_id,$suppress_hide_pages,true);
 					if($this->page->id) $cat_tree_data[] = $pages[$this->page->id];
 					$out .= $this->encapsulate($arguments,$cat_tree_data,'cat',$cat_id);
 					break;
 				}
-				
+
  				if($arguments['current_section_only'] && array_search($this->page->cat_id,$cat_tree) === false) continue;
 				if((int)$arguments['category_id'] > 0 && (int)$arguments['category_id'] != $cat_id) continue;
 				if(! empty($arguments['main_cats_to_include'])) {
@@ -548,11 +558,11 @@
 					$test = array_intersect($main_cats_to_include,$cat_tree);
 					if (empty($test)) continue;
 				}
-				
+
 //  			_debug_array($cat_tree);
 				if($cat['depth'] <= $arguments['max_cat_depth'])
 				{
-					if(!($arguments['suppress_current_cat'] && $this->page->cat_id == $cat_id) && 
+					if(!($arguments['suppress_current_cat'] && $this->page->cat_id == $cat_id) &&
 						!($arguments['suppress_main_cats'] && $cat['depth'] == 1))
 					{
 						if($arguments['suppress_cat_link'])
@@ -568,7 +578,7 @@
 					if($arguments['suppress_current_page']) unset($pages[$this->page->id]);
 					$out .= $this->encapsulate($arguments,$pages,'page',$cat_id,$cat['depth'] +1);
 				}
-				
+
 			}
 			if (!$arguments['no_full_index'])
 			{
@@ -577,15 +587,16 @@
 				$out .= "    </div>\n";
 			}
 
-			$out .= "  </div>\n<!-- navigation context ends here -->\n</div>\n";
+			$out .= "  </div>\n</div>\n".
+						"<!-- navigation context ends here -->\n\n";
 			return $out;
 		}
-		
+
 		/**
 		 * encapsulates navigation elements
 		 *
 		 * @param $arguments of module.
-		 * @param $data 
+		 * @param $data
 		 * @param $type string 'cat' or 'page'
 		 * @param $cat_id of cat itselve or of cat page belongs to.
 		 * @param $depth logical deps of cat or page.
@@ -594,6 +605,7 @@
 		function encapsulate($arguments,$data,$type,$cat_id,$depth=1)
 		{
 			$out = '';
+			//$out .= "    <!-- BEGIN encapsulate(".$type.") -->\n";
 			if(empty($arguments['main_cats_to_include']) && $arguments['nav_type'] != 6) {
 				// do we have to start or finish a block?
 				if ($type == 'cat')
@@ -601,25 +613,25 @@
 					// finish old block
 					if ($this->lastcatdepth >= $depth)
 					{
-						while($this->lastcatdepth != $depth - 1 && $this->lastcatdepth != 0)
+						while($this->lastcatdepth != $depth - 1 && $this->lastcatdepth > 0)
 						{
-							$out .= "  </div>\n";
-							//$out .= "  <!-- NAV CAT BLOCK OF DEPTH ". $this->lastcatdepth. " ENDS HERE-->\n";
+							$out .= "    </div>\n";
+							//$out .= "    <!-- NAV CAT BLOCK OF DEPTH ". $this->lastcatdepth. " ENDS HERE-->\n";
 							$this->lastcatdepth--;
 						}
 					}
 					$this->lastcatdepth = $depth;
-					
+
 					// marker to end last block
 					if ($depth == 0) return $out;
-					
-					//$out .= "  <!-- NAV CAT BLOCK OF DEPTH ". $depth. " STARTS HERE-->\n";
-					$out .= "  <div class=\"nav-cat-block blockdepth-".$depth. ($this->page->cat_id == $cat_id ? ' active' : ' inactive'). "\">\n";
+
+					//$out .= "    <!-- NAV CAT BLOCK OF DEPTH ". $depth. " STARTS HERE-->\n";
+					$out .= "    <div class=\"nav-cat-block blockdepth-".$depth. ($this->page->cat_id == $cat_id ? ' active' : ' inactive'). "\">\n";
 				}
-			}			
-			$out .= "    <div class=\"nav-".$type."-entry depth-".$depth."\">\n";
-			$out .= "      <ul>\n";
-			
+			}
+			$out .= "      <div class=\"nav-".$type."-entry depth-".$depth."\">\n";
+			$out .= "        <ul>\n";
+
 			if (is_array($data))
 			foreach($data as $id => $entry)
 			{
@@ -634,32 +646,47 @@
 					$entry['link'] = "<div class=\"nav-highlight_current_page\">".$entry['link'].'</div>';
 				}
 
-				$out .= "        <li>\n";
-				$out .= "          ".$entry['link']."\n";
-				
+				$out .= "          <li>\n";
+				$out .= "            ".$entry['link']."\n";
+
 				if($arguments['show_edit_icons'])
 				{
 					$out .= "<span class=\"nav-edit-icons\">";
-					$out .= $type == 'cat' ? 
+					$out .= $type == 'cat' ?
 						$this->objbo->getEditIconsCat($id) :
 						$this->objbo->getEditIconsPage($id,$cat_id);
 					$out .= "</span>\n";
 				}
- 				
+
 				if(($arguments['show_cat_description'] && $type == 'cat') || ($arguments['show_page_description'] && $type == 'page'))
 				{
 					$out .= "<span class=\"nav-".$type."-description\">";
 					$out .= $type =='cat' ? $entry['description'] : $entry['subtitle'];
 					$out .= "</span>\n";
 				}
-				
+
 				$out .= "        </li>\n";
 			}
-			$out .= "      </ul>\n";
-			$out .= "    </div>\n";
+			$out .= "        </ul>\n";
+			$out .= "      </div><!-- class=\"nav-".$type."-entry depth-".$depth."\" -->\n";
+			if(empty($arguments['main_cats_to_include']) && $arguments['nav_type'] == 8) {
+				// do we have to start or finish a block?
+				if ($type == 'cat')
+				{
+					// finish old block
+					while($this->lastcatdepth > 0)
+					{
+						$out .= "    </div>\n";
+						$out .= "    <!-- DEPTH ". $this->lastcatdepth. " ENDS HERE-->\n";
+						$this->lastcatdepth--;
+					}
+				}
+			}
+			//$out .= "    <!-- END encapsulate() -->\n";
+
 			return $out;
 		}
-		
+
 
 		function type_navigation(&$arguments,$properties)
 		{
@@ -681,7 +708,7 @@
 			$this->template->set_block('cat_block','level1');
 			$this->template->set_block('cat_block','level2');
 			$this->template->set_block('cat_block','block_end');
-			
+
 			$last_cat_id = 0;
 			foreach($index_pages as $ipage)
 			{
@@ -711,7 +738,7 @@
 					}
 				}
 				$last_cat_id = $ipage['cat_id'];
-				
+
 				// show the pages of the active cat or first-level pages
 				if ($ipage['page_id'] && ($ipage['cat_id'] == $page->cat_id || $ipage['catdepth'] == 1))
 				{
@@ -726,7 +753,60 @@
 			}
 			return $content;
 		}
-		
+
+		/**
+		 * XML sitemap
+		 *
+		 * Currently we only output pages, not categories.
+		 *
+		 * @link http://www.sitemaps.org/
+		 */
+		function type_xml_sitemap(&$arguments,$properties)
+		{
+			global $objbo,$page;
+			$index_pages = $objbo->getIndex(False,False,True);
+
+			if (!count($index_pages))
+			{
+				return lang('You do not have access to any content on this site.');
+			}
+			if (!extension_loaded('xmlwriter') && (!function_exists('dl') || !dl(PHP_SHLIB_PREFIX.'xmlwriter.'.PHP_SHLIB_SUFFIX)) ||
+				!function_exists('xmlwriter_open_uri'))
+			{
+				return 'XML sitemap requires xmlwriter PHP extension!';
+			}
+			// show in edit mode only a link to download the sitemap, so the page can still be edited
+			if ($GLOBALS['sitemgr_info']['mode'] == 'Edit' && !isset($_GET['xml_sitemap_test']))
+			{
+				return '<a href="'.$this->link(array(),array('xml_sitemap_test' => 1)).'" target="_blank">XML Sitemap</a>';
+			}
+			ob_end_clean();
+			header('Content-Type: text/xml');
+			$xml = xmlwriter_open_uri('php://output');
+			xmlwriter_start_document($xml,'1.0','utf-8');
+			xmlwriter_set_indent($xml,4);
+			xmlwriter_start_element_ns($xml,null,'urlset','http://www.sitemaps.org/schemas/sitemap/0.9');
+
+			$last_cat_id = 0;
+			foreach($index_pages as $ipage)
+			{
+				xmlwriter_start_element($xml,'url');
+
+				// pages
+				$link = $ipage['page_url'];
+				if ($link[0] == '/') $link = ($_SERVER['https'] ? 'https://' : 'http://').$_SERVER['HTTP_HOST'].$link;
+				if (isset($_GET['lang'])) $link .= '&lang='.$_GET['lang'];
+				//xmlwriter_write_comment($xml,$ipage['pagetitle']);
+				xmlwriter_write_element($xml,'loc',$link);
+
+				xmlwriter_end_element($xml);	// url
+			}
+			xmlwriter_end_element($xml);	// urlset
+			xmlwriter_end_document($xml);
+			@exit;	// otherwise we get a warning about some shutdown problem, messing up the xml
+			$GLOBALS['egw']->common->egw_exit();
+		}
+
 		function type_sitetree(&$arguments,$properties)
 		{
 			$title = '';
@@ -739,21 +819,21 @@
 				$this->expandedcats = Array();
 			}
 			$topcats = $GLOBALS['objbo']->getCatLinks(0,False);
-	
+
 			$content = "<script type='text/javascript'>
 				// the whole thing only works in a DOM capable browser or IE 4*/
-				
+
 				function add(catid)
 				{
 					document.cookie = 'block[" . $this->block->id . "][menutree][' + catid + ']=';
-				}	
-				
+				}
+
 				function remove(catid)
 				{
 					var now = new Date();
 					document.cookie = 'block[" . $this->block->id . "][menutree][' + catid + ']=; expires=' + now.toGMTString();
 				}
-				
+
 				function toggle(image, catid)
 				{
 					if (document.getElementById)
@@ -764,7 +844,7 @@
 					{
 						return;
 					}
-				
+
 					if (styleObj.style.display == 'none')
 					{
 						add(catid);
@@ -779,14 +859,14 @@
 					}
 				}
 				</script>";
-				
+
 			if (count($topcats)==0)
 			{
 				$content=lang('You do not have access to any content on this site.');
 			}
 			else
 			{
-				$content .= "\n" . 
+				$content .= "\n" .
 					'<table border="0" cellspacing="0" cellpadding="0" width="100%">' .
 					$this->showcat($topcats) .
 					'</table>' .
@@ -795,7 +875,7 @@
 			}
 			return $content;
 		}
-		
+
 		/**
 		 * provides tabs like on egroupware.org
 		 *
@@ -809,13 +889,13 @@
 			$tab_links = explode(',',$_arguments['tab_links']);
 			foreach (explode(',',$_arguments['tab_active']) as $num => $active)
 			{
-				
+
 				$current = false;
 				foreach (explode(':',$active) as $item)
 				{
 					if (!is_numeric($item) && $GLOBALS['page']->name == $item) $current = true;
 					elseif($GLOBALS['page']->cat_id == $item) $current = true;
-					
+
 					if ($current) break;
 				}
 				$out .= '      <li'. ($current ? ' id="current"' : ''). '>';
@@ -824,7 +904,7 @@
 			$out .= "    </ul>\n";
 			return $out;
 		}
-		
+
 		function showcat($cats)
 		{
 			foreach($cats as $cat_id => $cat)
@@ -833,19 +913,19 @@
 				$childrenandself = array_keys($GLOBALS['objbo']->getCatLinks($cat_id));
 				$childrenandself[] = $cat_id;
 				$catcolour = in_array($GLOBALS['page']->cat_id,$childrenandself) ? "red" : "black";
-				$tree .= "\n" . 
-					'<tr><td width="10%">' . 
+				$tree .= "\n" .
+					'<tr><td width="10%">' .
 					'<img src="images/tree_' .
 					($status ? "collapse" : "expand") .
-					'.gif" onclick="toggle(this, \'' . 
-					$cat_id . 
+					'.gif" onclick="toggle(this, \'' .
+					$cat_id .
 					'\')"></td><td><b title="' .
 					$cat['description'] .
 					'" style="color:' .
 					$catcolour .
 					'">'.
-					$cat['name'] . 
-					'</b></td></tr>' . 
+					$cat['name'] .
+					'</b></td></tr>' .
 					"\n";
 				$subcats = $GLOBALS['objbo']->getCatLinks($cat_id,False);
 				$pages = $GLOBALS['objbo']->getPageLinks($cat_id);
@@ -862,18 +942,18 @@
 						//we abuse the subtitle in a nonstandard way: we want it to serve as a *short title* that is displayed
 						//in the tree menu, so that we can have long titles on the page that would not be nice in the tree menu
 						$title = $page['subtitle'] ? $page['subtitle'] : $page['title'];
-						$tree .= '<tr><td colspan="2">' . 
-							(($page_id == $GLOBALS['page']->id) ? 
+						$tree .= '<tr><td colspan="2">' .
+							(($page_id == $GLOBALS['page']->id) ?
 								('<span style="color:red">' . $title . '</span>') :
 								('<a href="' . sitemgr_link('page_name='. $page['name']) . '">' . $title . '</a>')
-							) . 
+							) .
 							'</td></tr>';
 					}
 					if ($subcats)
 					{
 						$tree .= $this->showcat($subcats);
 					}
-	
+
 					$tree .= '</table></td></tr>';
 				}
 			}
