@@ -10,13 +10,13 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: class.mos_ui.inc.php 22781 2006-11-01 17:54:05Z nelius_weiss $ */
+	/* $Id: class.mos_ui.inc.php 26071 2008-10-07 10:20:46Z ralfbecker $ */
 
 	function mosCountModules($contentarea)
 	{
 		global $objui;
 		return (int)$objui->t->count_blocks($contentarea);
-		
+
 	}
 
 	/**
@@ -46,7 +46,7 @@
 	{
 		echo $url;
 	}
-	
+
 	function mosShowHead()
 	{
 		global $objui,$mosConfig_sitename;
@@ -56,26 +56,22 @@
 		echo $objui->t->parse();
 	}
 
-	function mosPathWay()
+	function mosPathWay($suppress_hide_pages=false)
 	{
 		global $objui;
-		
-		$module_navigation_path = array('','navigation','nav_type=8&no_show_sep=on');
-		
+		if ($suppress_hide_pages==true) $suppress_hide='&suppress_hide_pages=on';
+		$module_navigation_path = array('','navigation','nav_type=8&no_show_sep=on'.$suppress_hide);
+
 		echo $objui->t->exec_module($module_navigation_path);
 	}
-	
+
 	/**
 	* Returns current date according to current local and time offset
 	* @param string format optional format for strftime
 	* @returns current date
 	*/
-	function mosCurrentDate( $format="" ) {
-		
-		if (!is_object($GLOBALS['egw']->datetime))
-		{
-			$GLOBALS['egw']->datetime =& CreateObject('phpgwapi.datetime');
-		}
+	function mosCurrentDate( $format="" )
+	{
 		$tz_offset_s = $GLOBALS['egw']->datetime->tz_offset;
 
 		if ($format=="") {
@@ -86,17 +82,17 @@
 	}
 
 	function mosMainBody()
-	{ 
+	{
 		global $mosConfig_live_site;
 		global $objui;
-		 
+
 		// message passed via the url
 		$mosmsg = strval($_GET['mosmsg']);
 		$popMessages = false;
-		
+
 		// Browser Check
 		$browserCheck = 0;
-		if ( isset( $_SERVER['HTTP_USER_AGENT'] ) && isset( $_SERVER['HTTP_REFERER'] ) && strpos($_SERVER['HTTP_REFERER'], $mosConfig_live_site) !== false ) {
+		if ( isset( $_SERVER['HTTP_USER_AGENT'] ) && isset( $_SERVER['HTTP_REFERER'] ) && !empty( $mosConfig_live_site )   && strpos($_SERVER['HTTP_REFERER'], $mosConfig_live_site) !== false ) {
 			$browserCheck = 1;
 		}
 
@@ -104,19 +100,24 @@
 		if ( strlen( $mosmsg ) > 150 ) {
 			$mosmsg = substr( $mosmsg, 0, 150 );
 		}
-		
+
 		// mosmsg outputed within html
 		if ($mosmsg && !$popMessages && $browserCheck) {
 			echo "\n<div class=\"message\">$mosmsg</div>";
 		}
-	
+
 		// mosmsg outputed in JS Popup
 		if ($mosmsg && $popMessages && $browserCheck) {
 			echo "\n<script language=\"javascript\">alert('$mosmsg');</script>";
 		}
-		
+
 		// load the center module
-		mosLoadModules('center');
+		if (!file_exists($file = $objui->templateroot.'/mainbody.tpl'))
+		{
+			$file = realpath(dirname(__FILE__).'/../mos-compat/mainbody.tpl');
+		}
+		$objui->t->loadfile($file);
+		echo $objui->t->parse();
 	}
 
 	// this is just to make some templates work, it does nothing actually atm.
@@ -126,9 +127,12 @@
 		{
 		}
 
-		function loadObjectList()
+		function loadObjectList($ids)
 		{
-			return array();
+			require_once(dirname(__FILE__).'/../mos-compat/class.joomla.inc.php');
+			$joomla = new joomla();
+			$rows = $joomla->getmenu($ids);
+			return $rows;
 		}
 	}
 
@@ -179,12 +183,12 @@
 			$objbo->loadSearchResult($search_result,$lang,$mode,$options);
 			$this->generatePage();
 		}
-		
+
 		function generatePage()
 		{
 			global $database;
 			global $objui;
-			$database =& new mos_database;
+			$database = new mos_database;
 
 			// add a content-type header to overwrite an existing default charset in apache (AddDefaultCharset directiv)
 			header('Content-type: text/html; charset='.$GLOBALS['egw']->translation->charset());
@@ -204,6 +208,7 @@
 			define('_SEARCH_BOX',lang('Search').' ...');
 			define( '_ISO','charset='.$GLOBALS['egw']->translation->charset());
 			define( '_VALID_MOS',True );
+//			define( '_JEXEC', True );
 			define( '_VALID_MYCSSMENU',True );
 			ini_set('include_path',$this->mos_compat_dir.(strtoupper(substr(PHP_OS, 0, 3)) == 'WIN' ? ';' : ':').ini_get('include_path'));
 
