@@ -9,12 +9,12 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: index.php 23913 2007-05-22 04:04:13Z lkneschke $ */
+	/* $Id: index.php 26234 2008-10-19 06:05:52Z ralfbecker $ */
 
 	$site_id=0;
 	/**
 	 * Determine the site from the URL ($_SERVER['PHP_SELF'])
-	 * 
+	 *
 	 * @param array &$anon_account anon account_info with keys 'user', 'passwd' and optional 'passwd_type'
 	 * @return boolean true if a site is found or dies if not site defined for the URL
 	 */
@@ -39,7 +39,7 @@
 			);
 
 			$sitemgr_info['anonymous_user'] = $anon_account['login'];
-			
+
 			if($GLOBALS['egw_info']['server']['allow_cookie_auth'])
 			{
 				$eGW_remember = explode('::::',stripslashes($_COOKIE['eGW_remember']));
@@ -75,7 +75,7 @@
 	include('./config.inc.php');
 
 	// do we use a different domain and are already loged in?
-	if (isset($GLOBALS['egw_info']['server']['default_domain']) && 
+	if (isset($GLOBALS['egw_info']['server']['default_domain']) &&
 		@$_REQUEST['domain'] != $GLOBALS['egw_info']['server']['default_domain'])
 	{
 		// force our default domain
@@ -99,8 +99,8 @@
 	{
 		sitemgr_get_site($anon_account);
 	}
-	
-	// switch to current website. 
+
+	// switch to current website.
 	if ($GLOBALS['egw_info']['user']['preferences']['sitemgr']['currentsite'] != $site_id)
 	{
 		$GLOBALS['egw_info']['user']['preferences']['sitemgr']['currentsite'] = $site_id;
@@ -147,8 +147,14 @@
 	elseif (file_exists($templateroot.'/index.php'))	// mambo open source template
 	{
 		include_once './inc/class.mos_ui.inc.php';
+		if (file_exists($templateroot.'/joomla.xml.php'))	// Joomla template
+		{
+			include_once './mos-compat/class.joomla.inc.php';
+			include_once './mos-compat/class.JFilterOutput.inc.php';
+			include_once './mos-compat/joomla_Legacy_function.inc.php';
+		}
 	}
-	if (!class_exists('ui'))
+	else
 	{
 		echo '<h3>'.lang("Invalid template directory '%1' !!!",$templateroot)."</h3>\n";
 		if (!is_dir($GLOBALS['sitemgr_info']['site_dir'] . SEP . 'templates') || !is_readable($GLOBALS['sitemgr_info']['site_dir'] . SEP . 'templates'))
@@ -171,19 +177,18 @@
 	$toc = $_GET['toc'];
 	$index = $_GET['index'];
 	$search_content = $_POST['searchword'] ? $_POST['searchword'] : $_GET['searchword'];
-	
+
 	// Check for explicit modules calls
 	if ($_GET['module'])
 	{
-		// Check for RSS feed in news_admin
-		// temporary hack. this should be extendet to a generalized 
-		// moduel call which gets executed before "nomal" sitemgr operations
-		if ($_GET['module']=='news_admin')
-		{
-			include($GLOBALS['sitemgr_info']['egw_path'] . 'news_admin/website/export.php');
-			// No more stuff in the generated xml
-			$GLOBALS['egw']->common->egw_exit();
-		}
+		// we (miss-)use the addcontent handler to call the module
+		$GLOBALS['egw']->session->appsession('addcontent','sitemgr',array(array(
+			'module_name' => $_GET['module'],
+			'arguments' => array(),
+			'page' => false,
+			'area' => false,
+			'sort_order' => false
+		)));
 	}
 
 	if ($page_name && $page_name != 'index.php')
@@ -220,7 +225,7 @@
 	}
 	elseif ($search_content)
 	{
-		// Make compatibility with mos search boxes, if not lang, mode and view option, default all languages 
+		// Make compatibility with mos search boxes, if not lang, mode and view option, default all languages
 		// any words mode and view options advgoogle
 		$search_lang = $_POST['search_lang'] ? $_POST['search_lang'] : "all";
 		$search_mode = $_POST['search_mode'] ? $_POST['search_mode'] : "any";
@@ -237,13 +242,7 @@
 		}
 		else
 		{
-			$index = 1; 
+			$index = 1;
 			$objui->displayIndex();
 		}
 	}
-	if (DEBUG_TIMER)
-	{
-		$GLOBALS['debug_timer_stop'] = perfgetmicrotime();
-		echo 'Page loaded in ' . ($GLOBALS['debug_timer_stop'] - $GLOBALS['debug_timer_start']) . ' seconds.';
-	}
-?>
