@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: soap.php 22567 2006-10-03 15:18:03Z ralfbecker $ */
+	/* $Id: soap.php 25931 2008-08-21 06:21:32Z ralfbecker $ */
 
 	$GLOBALS['egw_info'] = array(
 		'flags' => array(
@@ -22,6 +22,9 @@
 	);
 	include('./header.inc.php');
 
+	include_once(EGW_API_INC . '/xml_functions.inc.php');	// not sure that's neccessary, but I have no way to test
+	include_once(EGW_API_INC . '/soap_functions.inc.php');
+
 	$GLOBALS['server'] = CreateObject('phpgwapi.soap_server');
 	/* _debug_array($GLOBALS['server']);exit; */
 	/* include(EGW_API_INC . '/soaplib.soapinterop.php'); */
