@@ -26,7 +26,7 @@ $_services['import'] = array(
 );
 
 $_services['search'] = array(
-    'args' => array('content', 'contentType'),
+    'args' => array('content', 'contentType', 'id'),
     'type' => 'integer'
 );
 
@@ -69,14 +69,14 @@ function _egwcalendarsync_list($_startDate='', $_endDate='')
 		'enum_recuring' => false,
 		'enum_groups' => true,
 	);
-	
-	$events =& ExecMethod('calendar.bocal.search',$searchFilter);
-	
+
+	$events =& ExecMethod('calendar.calendar_bo.search',$searchFilter);
+
 	foreach((array)$events as $event)
 	{
-		$guids[] = $GLOBALS['egw']->common->generate_uid('calendar',$event['id']);
+		$guids[] = 'calendar-' . $event['id'];
 	}
-	return $guids;	
+	return $guids;
 }
 
 /**
@@ -91,8 +91,8 @@ function _egwcalendarsync_list($_startDate='', $_endDate='')
 function &_egwcalendarsync_listBy($action, $timestamp)
 {
 	Horde::logMessage("SymcML: egwcalendarsync listBy action: $action timestamp: $timestamp", __FILE__, __LINE__, PEAR_LOG_DEBUG);
-
-	$allChangedItems = $GLOBALS['egw']->contenthistory->getHistory('calendar', $action, $timestamp);
+  $state		= $_SESSION['SyncML.state'];
+	$allChangedItems = $state->getHistory('calendar', $action, $timestamp);
 	Horde::logMessage("SymcML: egwcalendarsync getHistory('calendar', $action, $timestamp)=".print_r($allChangedItems,true), __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
 	if($action == 'delete')
@@ -101,7 +101,7 @@ function &_egwcalendarsync_listBy($action, $timestamp)
 	}
 
 	// query the calendar, to check if we are a participants in these changed events
-	$boCalendar =& CreateObject('calendar.bocal');
+	$boCalendar =& new calendar_bo();
 	$user = (int) $GLOBALS['egw_info']['user']['account_id'];
 	$show_rejected = $GLOBALS['egw_info']['user']['preferences']['calendar']['show_rejected'];
 
@@ -109,7 +109,7 @@ function &_egwcalendarsync_listBy($action, $timestamp)
 	$ids = $guids = array();
 	foreach($allChangedItems as $guid)
 	{
-		$ids[] = $GLOBALS['egw']->common->get_egwId($guid);
+		$ids[] = $state->get_egwId($guid);
 	}
 
 	// read all events in one go, and check if the user participats
@@ -120,7 +120,7 @@ function &_egwcalendarsync_listBy($action, $timestamp)
 			Horde::logMessage("SymcML: egwcalendarsync check participation for $event[id] / $event[title]", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 			if (isset($event['participants'][$user]) && ($show_rejected || $event['participants'][$user] != 'R'))
 			{
-				$guids[] = $guid = $GLOBALS['egw']->common->generate_uid('calendar',$event['id']);
+				$guids[] = $guid = 'calendar-' . $event['id'];
 				Horde::logMessage("SymcML: egwcalendarsync added id $event[id] ($guid) / $event[title]", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 			}
 		}
@@ -156,7 +156,7 @@ function _egwcalendarsync_import($content, $contentType, $notepad = null)
 	{
 		$options = array();
 	}
-	
+
 	switch ($contentType)
 	{
 		case 'text/x-vcalendar':
@@ -164,48 +164,55 @@ function _egwcalendarsync_import($content, $contentType, $notepad = null)
 		case 'text/calendar':
 			$state = $_SESSION['SyncML.state'];
 			$deviceInfo = $state->getClientDeviceInfo();
-			$boical	=& CreateObject('calendar.boical');
+			$boical	= new calendar_ical();
 			$boical->setSupportedFields($deviceInfo['manufacturer'],$deviceInfo['model']);
 			$calendarId = $boical->importVCal($content);
 			break;
-			
+
 		case 'text/x-s4j-sifc':
 		case 'text/x-s4j-sift':
 		case 'text/x-s4j-sifn':
 			Horde::logMessage("SyncML: egwcalendarsync import treating bad calendar content-type '$contentType' as if is was 'text/x-s4j-sife'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		case 'text/x-s4j-sife':
-			$sifcalendar =& CreateObject('calendar.sifcalendar');
+			$sifcalendar = new calendar_sif();
 			$calendarId = $sifcalendar->addSIF($content,-1);
 			break;
-			
+
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
-	
+
 	if (is_a($calendarId, 'PEAR_Error'))
 	{
-		return $calendarId;
+		return 'calendar-' . $calendarId;
 	}
+	
+	if(!$calendarId) {
+  		return false;
+  	}
 
-	$guid = $GLOBALS['egw']->common->generate_uid('calendar',$calendarId);
+	$guid = 'calendar-' . $calendarId;
 	Horde::logMessage("SymcML: egwcalendarsync import imported: ".$guid, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 	return $guid;
 }
 
 /**
- * Import a memo represented in the specified contentType.
+ * Search a memo represented in the specified contentType.
+ * used for SlowSync to check / rebuild content_map.
  *
  * @param string $content      The content of the memo.
  * @param string $contentType  What format is the data in? Currently supports:
  *                             text/plain
  *                             text/x-vnote
- * @param string $notepad      (optional) The notepad to save the memo on.
+ * @param string $contentid    the contentid read from contentmap we are expecting the content to be
  *
  * @return string  The new GUID, or false on failure.
  */
-function _egwcalendarsync_search($content, $contentType)
+function _egwcalendarsync_search($content, $contentType, $contentid)
 {
-	Horde::logMessage("SymcML: egwcalendarsync search content: $content contenttype: $contentType", __FILE__, __LINE__, PEAR_LOG_DEBUG);
+	Horde::logMessage("SymcML: egwcalendarsync search content: $content contenttype: $contentType contentid: $contentid", __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
+	$state			= $_SESSION['SyncML.state'];
 
 	if (is_array($contentType))
 	{
@@ -217,7 +224,7 @@ function _egwcalendarsync_search($content, $contentType)
 	{
 		$options = array();
 	}
-	
+
 	switch ($contentType)
 	{
 		case 'text/x-vcalendar':
@@ -225,27 +232,27 @@ function _egwcalendarsync_search($content, $contentType)
 		case 'text/calendar':
 			$state = $_SESSION['SyncML.state'];
 			$deviceInfo = $state->getClientDeviceInfo();
-			$boical	=& CreateObject('calendar.boical');
+			$boical	= new calendar_ical();
 			$boical->setSupportedFields($deviceInfo['manufacturer'],$deviceInfo['model']);
-			$eventId = $boical->search($content);
+			$eventId = $boical->search($content,$state->get_egwID($contentid));
 			break;
-			
+
 		case 'text/x-s4j-sifc':
 		case 'text/x-s4j-sift':
 		case 'text/x-s4j-sifn':
 			Horde::logMessage("SyncML: egwcalendarsync treating bad calendar content-type '$contentType' as if is was 'text/x-s4j-sife'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		case 'text/x-s4j-sife':
-			$sifcalendar =& CreateObject('calendar.sifcalendar');
-			$eventId = $sifcalendar->search($content);
+			$sifcalendar = new calendar_sif();
+			$eventId = $sifcalendar->search($content,$state->get_egwID($contentid));
 			break;
-			
+
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
 
 	if (is_a($eventId, 'PEAR_Error'))
 	{
-		return $eventId;
+		return 'calendar-' . $eventId;
 	}
 
 	if(!$eventId)
@@ -254,7 +261,7 @@ function _egwcalendarsync_search($content, $contentType)
 	}
 	else
 	{
-		$eventId = $GLOBALS['egw']->common->generate_uid('calendar', $eventId);
+		$eventId = 'calendar-' . $eventId;
 		Horde::logMessage('SymcML: egwcalendarsync search found: '. $eventId, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		return $eventId;
 	}
@@ -278,7 +285,7 @@ function _egwcalendarsync_search($content, $contentType)
  */
 function _egwcalendarsync_export($guid, $contentType)
 {
-	
+
 #    require_once dirname(__FILE__) . '/base.php';
 #
 #    $storage = &Mnemo_Driver::singleton();
@@ -291,7 +298,7 @@ function _egwcalendarsync_export($guid, $contentType)
 #        return PEAR::raiseError(_("Permission Denied"));
 #    }
 #
-
+  $state		= $_SESSION['SyncML.state'];
 	if (is_array($contentType))
 	{
 		$options = $contentType;
@@ -304,10 +311,10 @@ function _egwcalendarsync_export($guid, $contentType)
 	}
 
 	Horde::logMessage("SymcML: egwcalendarsync export guid: $guid contenttype: ".$contentType, __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	
 
-	$eventID	= $GLOBALS['egw']->common->get_egwId($guid);
-	
+
+	$eventID	= $state->get_egwId($guid);
+
 	switch ($contentType)
 	{
 		case 'text/x-vcalendar':
@@ -315,7 +322,7 @@ function _egwcalendarsync_export($guid, $contentType)
 		case 'text/calendar':
 			$state = $_SESSION['SyncML.state'];
 			$deviceInfo = $state->getClientDeviceInfo();
-			$boical	=& CreateObject('calendar.boical');
+			$boical	= new calendar_ical();
 			$boical->setSupportedFields($deviceInfo['manufacturer'],$deviceInfo['model']);
 			$vcal_version = ($contentType == 'text/x-vcalendar') ? '1.0' : '2.0';
 			return $boical->exportVCal($eventID,$vcal_version);
@@ -326,7 +333,7 @@ function _egwcalendarsync_export($guid, $contentType)
 		case 'text/x-s4j-sifn':
 			Horde::logMessage("SyncML: egwcalendarsync export treating bad calendar content-type '$contentType' as if is was 'text/x-s4j-sife'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		case 'text/x-s4j-sife':
-			$sifcalendar =& CreateObject('calendar.sifcalendar');
+			$sifcalendar = new calendar_sif();
 			if($sifevent = $sifcalendar->getSIF($eventID))
 			{
 				return $sifevent;
@@ -336,7 +343,7 @@ function _egwcalendarsync_export($guid, $contentType)
 				return PEAR::raiseError(_("Access Denied"));
 			}
 			break;
-		
+
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
@@ -354,6 +361,7 @@ function _egwcalendarsync_delete($guid)
 {
 	// Handle an arrray of GUIDs for convenience of deleting multiple
 	// contacts at once.
+	$state = $_SESSION['SyncML.state'];
 	if (is_array($guid))
 	{
 		foreach ($guid as $g)
@@ -364,18 +372,18 @@ function _egwcalendarsync_delete($guid)
 				return $result;
 			}
 		}
-		
+
 		return true;
 	}
-	
+
 	#if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_DELETE))) {
 	#	return PEAR::raiseError(_("Permission Denied"));
 	#}
-	Horde::logMessage("SymcML: egwcalendarsync delete id: ".$GLOBALS['egw']->common->get_egwId($guid), __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	
-	$bocalendar =& CreateObject('calendar.bocalupdate');
-	
-	return $bocalendar->delete($GLOBALS['egw']->common->get_egwId($guid));
+	Horde::logMessage("SymcML: egwcalendarsync delete id: ".$state->get_egwId($guid), __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
+	$bocalendar =& new calendar_boupdate();
+
+	return $bocalendar->delete($state->get_egwId($guid));
 	#return $bocalendar->expunge();
 }
 
@@ -394,7 +402,7 @@ function _egwcalendarsync_delete($guid)
 function _egwcalendarsync_replace($guid, $content, $contentType)
 {
 	Horde::logMessage("SymcML: egwcalendarsync replace guid: $guid content: $content contenttype: $contentType", __FILE__, __LINE__, PEAR_LOG_DEBUG);
-
+  
 	if (is_array($contentType))
 	{
 		$options = $contentType;
@@ -405,30 +413,29 @@ function _egwcalendarsync_replace($guid, $content, $contentType)
 	{
 		$options = array();
 	}
+  $state = $_SESSION['SyncML.state'];
+	$eventID = $state->get_egwId($guid);
 
-	$eventID = $GLOBALS['egw']->common->get_egwId($guid);
-	
 	switch ($contentType)
 	{
 		case 'text/x-vcalendar':
 		case 'text/vcalendar':
 		case 'text/calendar':
-			$state = $_SESSION['SyncML.state'];
 			$deviceInfo = $state->getClientDeviceInfo();
-			$boical	=& CreateObject('calendar.boical');
+			$boical	= new calendar_ical();
 			$boical->setSupportedFields($deviceInfo['manufacturer'],$deviceInfo['model']);
 			return $boical->importVCal($content, $eventID);
 			break;
-			
+
 		case 'text/x-s4j-sifc':
 		case 'text/x-s4j-sift':
 		case 'text/x-s4j-sifn':
 			error_log("[_egwsifcalendarsync_replace] Treating bad calendar content-type '".$contentType."' as if is was 'text/x-s4j-sife'");
 		case 'text/x-s4j-sife':
-			$sifcalendar =& CreateObject('calendar.sifcalendar');
+			$sifcalendar = new calendar_sif();
 			return $sifcalendar->addSIF($content,$eventID);
 			break;
-			
+
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
