@@ -26,7 +26,7 @@ $_services['import'] = array(
 );
 
 $_services['search'] = array(
-    'args' => array('content', 'contentType'),
+    'args' => array('content', 'contentType','id'),
     'type' => 'integer'
 );
 
@@ -55,30 +55,32 @@ $_services['replace'] = array(
 function _egwcontactssync_list()
 {
 	$guids = array();
-	
+
 	#Horde::logMessage("SymcML: egwcontactssync list ", __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	
+
 	// hardcode your search creteria here
 	$criteria = array();
-	
+
 	$filter = array();
 	if ($GLOBALS['egw_info']['user']['preferences']['addressbook']['hide_accounts'])
 	{
 		$filter['account_id'] = null;
 	}
-	
+
 	// hardcode your filter here
 	//$filter['cat_id'] = '!215';
-	$allContacts = ExecMethod2('addressbook.bocontacts.search',$criteria,True,'','','',False,'AND',false,$filter);
+	$allContacts = ExecMethod2('addressbook.addressbook_bo.search',$criteria,True,'','','',False,'AND',false,$filter);
 
 	#Horde::logMessage("SymcML: egwcontactssync list ", __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	
+
 	$guids = array();
 	foreach((array)$allContacts as $contact)
 	{
-        #Horde::logMessage("SymcML: egwcontactssync list generate id for: ". $contact['id'], __FILE__, __LINE__, PEAR_LOG_DEBUG);
-        #Horde::logMessage("SymcML: egwcontactssync list generate id for: ". print_r($contact, true), __FILE__, __LINE__, PEAR_LOG_DEBUG);
-		$guids[] = $GLOBALS['egw']->common->generate_uid('contacts', $contact['id']);
+    #Horde::logMessage("SymcML: egwcontactssync list generate id for: ". $contact['id'], __FILE__, __LINE__, PEAR_LOG_DEBUG);
+    #Horde::logMessage("SymcML: egwcontactssync list generate id for: ". print_r($contact, true), __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
+	  $guids[] = "contacts-".$contact['id'];
+    
 	}
 
 	#Horde::logMessage("SymcML: egwcontactssync list found ids: ". print_r($guids, true), __FILE__, __LINE__, PEAR_LOG_DEBUG);
@@ -96,11 +98,11 @@ function _egwcontactssync_list()
  * @return array  An array of GUIDs matching the action and time criteria.
  */
 function &_egwcontactssync_listBy($action, $timestamp) {
-	
+
 	#Horde::logMessage("SymcML: egwcontactssync listBy action: $action timestamp: $timestamp", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 	$state = $_SESSION['SyncML.state'];
-	
-	$allChangedItems = (array)$GLOBALS['egw']->contenthistory->getHistory('contacts', $action, $timestamp);
+
+	$allChangedItems = (array)$state->getHistory('contacts', $action, $timestamp);
 	#Horde::logMessage('SymcML: egwcontactssync listBy $allChangedItems: '. print_r($allChangedItems,true), __FILE__, __LINE__, PEAR_LOG_DEBUG);
 	$allReadAbleItems = (array)_egwcontactssync_list();
 	#Horde::logMessage('SymcML: egwcontactssync listBy $allReadAbleItems: '. print_r($allReadAbleItems,true), __FILE__, __LINE__, PEAR_LOG_DEBUG);
@@ -150,10 +152,10 @@ function _egwcontactssync_import($content, $contentType, $notepad = null)
 	$deviceInfo		= $state->getClientDeviceInfo();
 	#error_log(print_r($deviceInfo, true));
 
-	
+
 	switch ($contentType) {
 		case 'text/x-vcard':
-			$vcaladdressbook	=& CreateObject('addressbook.vcaladdressbook');
+			$vcaladdressbook	= new addressbook_vcal();
 			$vcaladdressbook->setSupportedFields($deviceInfo['manufacturer'],$deviceInfo['model']);
 
 			$contactId		= $vcaladdressbook->addVCard($content, false);
@@ -164,48 +166,54 @@ function _egwcontactssync_import($content, $contentType, $notepad = null)
 		case 'text/x-s4j-sifn':
 			error_log("[_egwcontactssync_import] Treating bad contact content-type '".$contentType."' as if is was 'text/x-s4j-sifc'");
 		case 'text/x-s4j-sifc':
-			$sifaddressbook		=& CreateObject('addressbook.sifaddressbook');
+			$sifaddressbook		= new addressbook_sif();
 			$contactId = 		$sifaddressbook->addSIF($content);
 			break;
-			
+
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
-	
+
 	if (is_a($contactId, 'PEAR_Error')) {
-		return $contactId;
+		return 'contacts-' .$contactId;
 	}
+	
+	if(!$contactId) {
+  		return false;
+  	}
 
 	#Horde::logMessage("SymcML: egwcontactssync import imported: ".$GLOBALS['egw']->common->generate_uid('contacts',$contactId), __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	return $GLOBALS['egw']->common->generate_uid('contacts',$contactId);
+	//return $GLOBALS['egw']->common->generate_uid('contacts',$contactId);
+  return 'contacts-' .$contactId;
 }
 
 /**
- * Import a memo represented in the specified contentType.
+ * Search a memo represented in the specified contentType,
+ * used for SlowSync to check / rebuild content_map.
  *
  * @param string $content      The content of the memo.
  * @param string $contentType  What format is the data in? Currently supports:
  *                             text/plain
  *                             text/x-vnote
- * @param string $notepad      (optional) The notepad to save the memo on.
+ * @param string $contentid    the contentid read from contentmap we are expecting the content to be
+ *
  *
  * @return string  The new GUID, or false on failure.
  */
-function _egwcontactssync_search($content, $contentType)
+function _egwcontactssync_search($content, $contentType, $contentid)
 {
-//error_log("_egwcontactssync_search");
-	Horde::logMessage("SymcML: egwcontactssync search content: $content contenttype: $contentType", __FILE__, __LINE__, PEAR_LOG_DEBUG);
+	Horde::logMessage("SymcML: egwcontactssync search content: $content contenttype: $contentType contentid: $contentid", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 
 	$state			= $_SESSION['SyncML.state'];
 	$deviceInfo		= $state->getClientDeviceInfo();
 
-	
+
 	switch ($contentType) {
 		case 'text/x-vcard':
-			$vcaladdressbook =& CreateObject('addressbook.vcaladdressbook');
+			$vcaladdressbook = new addressbook_vcal();
 			$vcaladdressbook->setSupportedFields($deviceInfo['manufacturer'],$deviceInfo['model']);
 
-			$contactId = $vcaladdressbook->search($content);
+			$contactId = $vcaladdressbook->search($content,$state->get_egwID($contentid));
 			break;
 
 		case 'text/x-s4j-sife':
@@ -213,24 +221,24 @@ function _egwcontactssync_search($content, $contentType)
 		case 'text/x-s4j-sifn':
 			#Horde::logMessage("SymcML: egwcontactssync search content: Treating bad contact content-type '$contentType' as if it was 'text/x-s4j-sifc'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		case 'text/x-s4j-sifc':
-			$sifaddressbook	=& CreateObject('addressbook.sifaddressbook');
-			$contactId = $sifaddressbook->search($content);
+			$sifaddressbook	= new addressbook_sif();
+			$contactId = $sifaddressbook->search($content,$state->get_egwID($contentid));
 			break;
-			
+
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
-	
+
 	if (is_a($contactId, 'PEAR_Error')) {
-		return $contactId;
+		return 'contacts-' .$contactId;
 	}
 
 	#error_log("SymcML: egwcontactssync search found: $contactId");
-	Horde::logMessage("SymcML: egwcontactssync search found: ".$GLOBALS['egw']->common->generate_uid('contacts',$contactId), __FILE__, __LINE__, PEAR_LOG_DEBUG);
+	Horde::logMessage("SymcML: egwcontactssync search found: contacts-".$contactId, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 	if(!$contactId) {
 		return false;
 	} else {
-		return $GLOBALS['egw']->common->generate_uid('contacts',$contactId);
+		return 'contacts-' . $contactId;
 	}
 }
 
@@ -261,16 +269,16 @@ function _egwcontactssync_export($guid, $contentType)
 	} else {
 		$options = array();
 	}
-	
+
 	$state		= $_SESSION['SyncML.state'];
 	$deviceInfo	= $state->getClientDeviceInfo();
 
-	$contactID		= $GLOBALS['egw']->common->get_egwId($guid);
-	
+	$contactID		= $state->get_egwId($guid);
+
 	switch ($contentType)
 	{
 		case 'text/x-vcard':
-			$vcaladdressbook	=& CreateObject('addressbook.vcaladdressbook');
+			$vcaladdressbook	= new addressbook_vcal();
 			$vcaladdressbook->setSupportedFields($deviceInfo['manufacturer'],$deviceInfo['model']);
 
 			if($vcard = $vcaladdressbook->getVCard($contactID))
@@ -281,7 +289,7 @@ function _egwcontactssync_export($guid, $contentType)
 			{
 				return PEAR::raiseError(_("Access Denied"));
 			}
-			
+
 			break;
 
 		case 'text/x-s4j-sift':
@@ -290,8 +298,8 @@ function _egwcontactssync_export($guid, $contentType)
 			#Horde::logMessage("SyncML: egwcontactssync_export Treating bad contact content-type '$contentType' as if is was 'text/x-s4j-sifc'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 			/* fall through */
 		case 'text/x-s4j-sifc':
-			$sifaddressbook	=& CreateObject('addressbook.sifaddressbook');
-			$contactID	= $GLOBALS['egw']->common->get_egwId($guid);
+			$sifaddressbook	= new addressbook_sif();
+			$contactID	= $state->get_egwId($guid);
 			if($sifcard = $sifaddressbook->getSIF($contactID))
 			{
 				return $sifcard;
@@ -300,9 +308,9 @@ function _egwcontactssync_export($guid, $contentType)
 			{
 				return PEAR::raiseError(_("Access Denied"));
 			}
-			
+
 			break;
-		
+
 		default:
 			#Horde::logMessage("SymcML: export unsupported", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 			return PEAR::raiseError(_("Unsupported Content-Type."));
@@ -319,6 +327,7 @@ function _egwcontactssync_export($guid, $contentType)
  */
 function _egwcontactssync_delete($guid)
 {
+	$state = $_SESSION['SyncML.state'];
 	// Handle an arrray of GUIDs for convenience of deleting multiple
 	// contacts at once.
 	if (is_array($guid)) {
@@ -328,16 +337,17 @@ function _egwcontactssync_delete($guid)
 				return $result;
 			}
 		}
-		
+
 		return true;
 	}
-	Horde::logMessage("SymcML: egwcontactssync delete guid: $guid egwid: ". $GLOBALS['egw']->common->get_egwId($guid), __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	
+	Horde::logMessage("SymcML: egwcontactssync delete guid: $guid egwid: ". $state->get_egwId($guid), __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
 	#if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_DELETE))) {
 	#	return PEAR::raiseError(_("Permission Denied"));
 	#}
-	
-	return ExecMethod('addressbook.vcaladdressbook.delete', $GLOBALS['egw']->common->get_egwId($guid));
+ 
+	return ExecMethod('addressbook.addressbook_vcal.delete', $state->get_egwId($guid));
+
 }
 
 /**
@@ -354,8 +364,8 @@ function _egwcontactssync_delete($guid)
  */
 function _egwcontactssync_replace($guid, $content, $contentType)
 {
-//error_log("_egwcontactsync_replace");
-	Horde::logMessage("SymcML: egwcontactssync replace guid: $guid with content: $content", __FILE__, __LINE__, PEAR_LOG_DEBUG);
+
+	#Horde::logMessage("SymcML: egwcontactssync replace guid: $guid with content: $content", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 	#if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_EDIT))) {
 	#	return PEAR::raiseError(_("Permission Denied"));
 	#}
@@ -363,16 +373,16 @@ function _egwcontactssync_replace($guid, $content, $contentType)
 	$state		= $_SESSION['SyncML.state'];
 	$deviceInfo	= $state->getClientDeviceInfo();
 
-	$contactID	= $GLOBALS['egw']->common->get_egwId($guid);
+	$contactID	= $state->get_egwId($guid);
 
 	switch ($contentType) {
 		case 'text/x-vcard':
-			$vcaladdressbook =& CreateObject('addressbook.vcaladdressbook');
+			$vcaladdressbook = new addressbook_vcal();
 			$vcaladdressbook->setSupportedFields($deviceInfo['manufacturer'],$deviceInfo['model']);
 			$result = $vcaladdressbook->addVCard($content,$contactID);
 			return $result;
 			break;
-    			
+
 		case 'text/x-s4j-sife':
 		case 'text/x-s4j-sift':
 		case 'text/x-s4j-sifn':
@@ -383,7 +393,7 @@ function _egwcontactssync_replace($guid, $content, $contentType)
 			#fwrite($handle, base64_decode($content));
 			#fclose($handle);
 
-			$sifaddressbook		=& CreateObject('addressbook.sifaddressbook');
+			$sifaddressbook		= new addressbook_sif();
 			$result = $sifaddressbook->addSIF($content,$contactID);
 			return $result;
 			break;
