@@ -26,7 +26,7 @@ $_services['import'] = array(
 );
 
 $_services['search'] = array(
-    'args' => array('content', 'contentType'),
+    'args' => array('content', 'contentType','id'),
     'type' => 'integer'
 );
 
@@ -57,7 +57,7 @@ function _egwnotessync_list()
 	$guids = array();
 
 	#Horde::logMessage("SymcML: egwnotessync list ", __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	
+
 	$searchFilter = array
 	(
 		'order'		=> 'info_datemodified',
@@ -68,12 +68,12 @@ function _egwnotessync_list()
 			'info_type'	=> 'note',
 		),
 	);
-	
-	$notes =& ExecMethod('infolog.boinfolog.search',$searchFilter);
-	
+
+	$notes =& ExecMethod('infolog.infolog_bo.search',$searchFilter);
+
 	foreach((array)$notes as $note)
 	{
-		$guids[] = $GLOBALS['egw']->common->generate_uid('infolog_note',$note['info_id']);
+		$guids[] = 'infolog_note-'.$note['info_id'];
 	}
 	return $guids;
 }
@@ -90,22 +90,22 @@ function _egwnotessync_list()
 function &_egwnotessync_listBy($action, $timestamp)
 {
 	#Horde::logMessage("SymcML: egwnotessync listBy action: $action timestamp: $timestamp", __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	
-	$allChangedItems = $GLOBALS['egw']->contenthistory->getHistory('infolog_note', $action, $timestamp);
-	
+  $state = $_SESSION['SyncML.state'];
+	$allChangedItems = $state->getHistory('infolog_note', $action, $timestamp);
+
 	if($action == 'delete')
 	{
 		return $allChangedItems;	// InfoLog has no further info about deleted entries
 	}
-	$boInfolog =& CreateObject('infolog.boinfolog');
+	$infolog_bo = new infolog_bo();
 	$user = $GLOBALS['egw_info']['user']['account_id'];
 
 	$readAbleItems = array();
 	foreach($allChangedItems as $guid)
 	{
-		$uid = $GLOBALS['egw']->common->get_egwId($guid);
+		$uid = $state->get_egwId($guid);
 
-		if(($info = $boInfolog->read($uid)) &&		// checks READ rights too and returns false if none
+		if(($info = $infolog_bo->read($uid)) &&		// checks READ rights too and returns false if none
 			// for filter my = all items the user is responsible for:
 			//($user == $info['info_owner'] && !count($info['info_responsible']) || in_array($user,$info['info_responsible'])))
 			// for filter own = all items the user own or is responsible for:
@@ -165,8 +165,8 @@ function _egwnotessync_import($content, $contentType, $notepad = null)
 	{
 		case 'text/plain':
 		case 'text/x-vnote':
-			$vcalInfolog =& CreateObject('infolog.vcalinfolog');
-			$noteId = $vcalInfolog->importVNOTE($content, $contentType);
+			$infolog_ical = new infolog_ical();
+			$noteId = $infolog_ical->importVNOTE($content, $contentType);
 			break;
 
 		case 'text/x-s4j-sifc':
@@ -174,37 +174,45 @@ function _egwnotessync_import($content, $contentType, $notepad = null)
 		case 'text/x-s4j-sift':
 			Horde::logMessage("SyncML: egwnotessync import treating bad task content-type '$contentType' as if is was 'text/x-s4j-sifn'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		case 'text/x-s4j-sifn':
-			$sifInfolog	=& CreateObject('infolog.sifinfolog');
-			$noteId = $sifInfolog->addSIF($content,-1,'note');
+			$infolog_sif	= new infolog_sif();
+			$noteId = $infolog_sif->addSIF($content,-1,'note');
 			error_log("Done add note: noteId=$noteId");
 			break;
 
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
-	
+
 	if (is_a($noteId, 'PEAR_Error'))
 	{
-		return $noteId;
+		return 'infolog_note-' . $noteId;
 	}
 
+	if(!$noteId) {
+  		return false;
+  	}
+
 	#Horde::logMessage("SymcML: egwnotessync import imported: ".$GLOBALS['egw']->common->generate_uid('infolog',$noteId), __FILE__, __LINE__, PEAR_LOG_DEBUG);
-	return $GLOBALS['egw']->common->generate_uid('infolog_note',$noteId);
+	return 'infolog_note-' . $noteId;
 }
 
 /**
- * Import a memo represented in the specified contentType.
+ * Search a memo represented in the specified contentType.
+ * used for SlowSync to check / rebuild content_map.
  *
  * @param string $content      The content of the memo.
  * @param string $contentType  What format is the data in? Currently supports:
  *                             text/plain
  *                             text/x-vnote
- * @param string $notepad      (optional) The notepad to save the memo on.
+ * @param string $contentid    the contentid read from contentmap we are expecting the content to be
  *
  * @return string  The new GUID, or false on failure.
  */
-function _egwnotessync_search($content, $contentType)
+function _egwnotessync_search($content, $contentType, $contentid)
 {
+
+	$state			= $_SESSION['SyncML.state'];
+
 	if (is_array($contentType))
 	{
 		$options = $contentType;
@@ -220,26 +228,26 @@ function _egwnotessync_search($content, $contentType)
 	{
 		case 'text/x-vnote':
 		case 'text/plain':
-			$vcalInfolog =& CreateObject('infolog.vcalinfolog');
-			$noteId	= $vcalInfolog->searchVNOTE($content, $contentType);
+			$infolog_ical = new infolog_ical();
+			$noteId	= $infolog_ical->searchVNOTE($content, $contentType, $state->get_egwID($contentid));
 			break;
-			
+
 		case 'text/x-s4j-sifc':
 		case 'text/x-s4j-sife':
 		case 'text/x-s4j-sift':
 			Horde::logMessage("SyncML: egwnotessync search treating bad task content-type '$contentType' as if is was 'text/x-s4j-sifn'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		case 'text/x-s4j-sifn':
-			$sifInfolog	=& CreateObject('infolog.sifinfolog');
-			$noteId = $sifInfolog->searchSIF($content,'note');
+			$infolog_sif	= new infolog_sif();
+			$noteId = $infolog_sif->searchSIF($content,'note', $state->get_egwID($contentid));
 			break;
-			
+
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
-	
+
 	if (is_a($noteId, 'PEAR_Error'))
 	{
-		return $noteId;
+		return 'infolog_note-' . $noteId;
 	}
 
 	#Horde::logMessage("SymcML: egwsifnotessync import imported: ".$GLOBALS['egw']->common->generate_uid('infolog_note',$noteId), __FILE__, __LINE__, PEAR_LOG_DEBUG);
@@ -249,7 +257,7 @@ function _egwnotessync_search($content, $contentType)
 		return false;
 	}
 
-	return $GLOBALS['egw']->common->generate_uid('infolog_note',$noteId);
+	return 'infolog_note-' . $noteId;
 }
 
 /**
@@ -270,7 +278,8 @@ function _egwnotessync_search($content, $contentType)
  */
 function _egwnotessync_export($guid, $contentType)
 {
-	Horde::logMessage("SymcML: egwnotessync export guid: $guid contenttype: ".$contentType, __FILE__, __LINE__, PEAR_LOG_DEBUG);
+	  $state = $_SESSION['SyncML.state'];
+	  Horde::logMessage("SymcML: egwnotessync export guid: $guid contenttype: ".$contentType, __FILE__, __LINE__, PEAR_LOG_DEBUG);
 #    require_once dirname(__FILE__) . '/base.php';
 #
 #    $storage = &Mnemo_Driver::singleton();
@@ -293,15 +302,15 @@ function _egwnotessync_export($guid, $contentType)
 	{
 		$options = array();
 	}
-	
-	$noteId = $GLOBALS['egw']->common->get_egwId($guid);
-	
+
+	$noteId = $state->get_egwId($guid);
+
 	switch ($contentType)
 	{
 		case 'text/x-vnote':
 		case 'text/plain':
-			$vcalInfolog =& CreateObject('infolog.vcalinfolog');
-			return $vcalInfolog->exportVNOTE($noteId, $contentType);
+			$infolog_ical = new infolog_ical();
+			return $infolog_ical->exportVNOTE($noteId, $contentType);
 			break;
 
 		case 'text/x-s4j-sifc':
@@ -309,8 +318,8 @@ function _egwnotessync_export($guid, $contentType)
 		case 'text/x-s4j-sift':
 			Horde::logMessage("SyncML: egwnotessync export treating bad task content-type '$contentType' as if is was 'text/x-s4j-sifn'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		case 'text/x-s4j-sifn':
-			$sifInfolog	=& CreateObject('infolog.sifinfolog');
-			if($note = $sifInfolog->getSIF($noteId, 'note'))
+			$infolog_sif	= new infolog_sif();
+			if($note = $infolog_sif->getSIF($noteId, 'note'))
 			{
 				return $note;
 			}
@@ -319,7 +328,7 @@ function _egwnotessync_export($guid, $contentType)
 				return PEAR::raiseError(_("Access Denied"));
 			}
 			break;
-		
+
 		default:
 			return PEAR::raiseError(_("Unsupported Content-Type."));
 	}
@@ -335,13 +344,14 @@ function _egwnotessync_export($guid, $contentType)
  */
 function _egwnotessync_delete($guid)
 {
+	$state = $_SESSION['SyncML.state'];
 	// Handle an arrray of GUIDs for convenience of deleting multiple
 	// notes at once.
 	if (is_array($guid))
 	{
 		foreach ($guid as $g)
 		{
-			$result = _egwnotessync_delete($guid);
+			$result = _egwnotessync_delete($g);
 			if (is_a($result, 'PEAR_Error'))
 			{
 				return $result;
@@ -359,8 +369,8 @@ function _egwnotessync_delete($guid)
 	#	return PEAR::raiseError(_("Permission Denied"));
 	#}
 	#
-	
-	return ExecMethod('infolog.boinfolog.delete',$GLOBALS['egw']->common->get_egwId($guid));
+
+	return ExecMethod('infolog.infolog_bo.delete',$state->get_egwId($guid));
 }
 
 /**
@@ -378,7 +388,7 @@ function _egwnotessync_delete($guid)
 function _egwnotessync_replace($guid, $content, $contentType)
 {
 	#Horde::logMessage("SymcML: egwnotessync replace guid: $guid", __FILE__, __LINE__, PEAR_LOG_DEBUG);
-
+  $state		= $_SESSION['SyncML.state'];
 	#$memo = $storage->getByGUID($guid);
 	#if (is_a($memo, 'PEAR_Error')) {
 	#	return $memo;
@@ -387,7 +397,7 @@ function _egwnotessync_replace($guid, $content, $contentType)
 	#if (!array_key_exists($memo['memolist_id'], Mnemo::listNotepads(false, PERMS_EDIT))) {
 	#	return PEAR::raiseError(_("Permission Denied"));
 	#}
-	
+
 	if (is_array($contentType))
 	{
 		$options = $contentType;
@@ -398,15 +408,15 @@ function _egwnotessync_replace($guid, $content, $contentType)
 	{
 		$options = array();
 	}
-	
-	$noteId = $GLOBALS['egw']->common->get_egwId($guid);
-	
+
+	$noteId = $state->get_egwId($guid);
+
 	switch ($contentType)
 	{
 		case 'text/plain':
 		case 'text/x-vnote':
-			$vcalInfolog =& CreateObject('infolog.vcalinfolog');
-			return $vcalInfolog->importVNOTE($content, $contentType, $noteId);
+			$infolog_ical = new infolog_ical();
+			return $infolog_ical->importVNOTE($content, $contentType, $noteId);
 			break;
 
 		case 'text/x-s4j-sifc':
@@ -414,8 +424,8 @@ function _egwnotessync_replace($guid, $content, $contentType)
 		case 'text/x-s4j-sift':
 			Horde::logMessage("SyncML: egwnotessync replace treating bad task content-type '$contentType' as if is was 'text/x-s4j-sifn'", __FILE__, __LINE__, PEAR_LOG_DEBUG);
 		case 'text/x-s4j-sifn':
-			$sifInfolog	=& CreateObject('infolog.sifinfolog');
-			return $sifInfolog->addSIF($content, $infoId, 'note');
+			$infolog_sif	= new infolog_sif();
+			return $infolog_sif->addSIF($content, $infoId, 'note');
 			break;
 
 		default:
