@@ -8,7 +8,7 @@
  * @subpackage setup
  * @copyright (c) 2005/6 by Ralf Becker <RalfBecker-AT-outdoor-training.de>
  * @license http://opensource.org/licenses/gpl-license.php GPL - GNU General Public License
- * @version $Id: setup.inc.php 23741 2007-04-30 10:29:44Z lkneschke $ 
+ * @version $Id: setup.inc.php 26128 2008-10-10 10:51:35Z ralfbecker $
  */
 
 if (!defined('TIMESHEET_APP'))
@@ -17,40 +17,39 @@ if (!defined('TIMESHEET_APP'))
 }
 
 $setup_info[TIMESHEET_APP]['name']      = TIMESHEET_APP;
-$setup_info[TIMESHEET_APP]['version']   = '1.4';
+$setup_info[TIMESHEET_APP]['version']   = '1.6';
 $setup_info[TIMESHEET_APP]['app_order'] = 5;
 $setup_info[TIMESHEET_APP]['tables']    = array('egw_timesheet', 'egw_timesheet_extra');
 $setup_info[TIMESHEET_APP]['enable']    = 1;
 
-$setup_info[TIMESHEET_APP]['author'] = 
+$setup_info[TIMESHEET_APP]['author'] =
 $setup_info[TIMESHEET_APP]['maintainer'] = array(
 	'name'  => 'Ralf Becker',
 	'email' => 'RalfBecker@outdoor-training.de'
 );
 $setup_info[TIMESHEET_APP]['license']  = 'GPL';
-$setup_info[TIMESHEET_APP]['description'] = 
+$setup_info[TIMESHEET_APP]['description'] =
 'Tracking times and other activities for the Projectmanager.';
-$setup_info[TIMESHEET_APP]['note'] = 
+$setup_info[TIMESHEET_APP]['note'] =
 'The TimeSheet application is sponsored by:<ul>
 <li> <a href="http://www.stylite.de" target="_blank">Stylite GmbH</a></li>
 <li> <a href="http://www.outdoor-training.de" target="_blank">Outdoor Unlimited Training GmbH</a></li>
 </ul>';
 
 /* The hooks this app includes, needed for hooks registration */
-$setup_info[TIMESHEET_APP]['hooks']['preferences'] = TIMESHEET_APP.'.ts_admin_prefs_sidebox_hooks.all_hooks';
-$setup_info[TIMESHEET_APP]['hooks']['settings'] = TIMESHEET_APP.'.ts_admin_prefs_sidebox_hooks.settings';
-$setup_info[TIMESHEET_APP]['hooks']['admin'] = TIMESHEET_APP.'.ts_admin_prefs_sidebox_hooks.all_hooks';
-$setup_info[TIMESHEET_APP]['hooks']['sidebox_menu'] = TIMESHEET_APP.'.ts_admin_prefs_sidebox_hooks.all_hooks';
-$setup_info[TIMESHEET_APP]['hooks']['search_link'] = TIMESHEET_APP.'.botimesheet.search_link';
-$setup_info[TIMESHEET_APP]['hooks']['pm_cumulate'] = TIMESHEET_APP.'.botimesheet.cumulate';
+$setup_info[TIMESHEET_APP]['hooks']['preferences'] = 'timesheet_hooks::all_hooks';
+$setup_info[TIMESHEET_APP]['hooks']['settings'] = 'timesheet_hooks::settings';
+$setup_info[TIMESHEET_APP]['hooks']['admin'] = 'timesheet_hooks::all_hooks';
+$setup_info[TIMESHEET_APP]['hooks']['sidebox_menu'] = 'timesheet_hooks::all_hooks';
+$setup_info[TIMESHEET_APP]['hooks']['search_link'] = 'timesheet_hooks::search_link';
+$setup_info[TIMESHEET_APP]['hooks']['pm_cumulate'] = 'timesheet_hooks::cumulate';
 
 /* Dependencies for this app to work */
 $setup_info[TIMESHEET_APP]['depends'][] = array(
 	 'appname' => 'phpgwapi',
-	 'versions' => Array('1.3','1.4','1.5')
+	 'versions' => Array('1.5','1.6','1.7')
 );
 $setup_info[TIMESHEET_APP]['depends'][] = array(
 	 'appname' => 'etemplate',
-	 'versions' => Array('1.3','1.4','1.5')
+	 'versions' => Array('1.5','1.6','1.7')
 );
-
