@@ -10,7 +10,7 @@
 	*  option) any later version.                                              *
 	\**************************************************************************/
 
-	/* $Id: xmlrpc.php 22567 2006-10-03 15:18:03Z ralfbecker $ */
+	/* $Id: xmlrpc.php 25931 2008-08-21 06:21:32Z ralfbecker $ */
 	/* $Source$ */
 	/*list($usec, $sec) = explode(" ", microtime());
 	$GLOBALS['concisus']['script_start'] = ((float)$usec + (float)$sec);*/
@@ -22,7 +22,10 @@
 			'disable_Template_class' => True
 		)
 	);
-	include('header.inc.php');
+	include('./header.inc.php');
+
+	include_once(EGW_API_INC . '/xml_functions.inc.php');
+	include_once(EGW_API_INC . '/soap_functions.inc.php');	// not sure that's neccessary, but I have no way to test
 
 	//viniciuscb: a secure way to know if we're in a xmlrpc call...
 	$GLOBALS['egw_info']['server']['xmlrpc'] = true;
